/* Generated by Cython 3.0.8 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "define_macros": [
            [
                "NPY_NO_DEPRECATED_API",
                "0"
            ]
        ],
        "depends": [
            "/usr/lib/python3.12/site-packages/numpy/core/include/numpy/arrayobject.h",
            "/usr/lib/python3.12/site-packages/numpy/core/include/numpy/arrayscalars.h",
            "/usr/lib/python3.12/site-packages/numpy/core/include/numpy/ndarrayobject.h",
            "/usr/lib/python3.12/site-packages/numpy/core/include/numpy/ndarraytypes.h",
            "/usr/lib/python3.12/site-packages/numpy/core/include/numpy/npy_common.h",
            "/usr/lib/python3.12/site-packages/numpy/core/include/numpy/ufuncobject.h",
            "pandas/_libs/hashtable_class_helper.pxi.in",
            "pandas/_libs/hashtable_func_helper.pxi.in",
            "pandas/_libs/khash_for_primitive_helper.pxi.in",
            "pandas/_libs/src/klib/khash.h",
            "pandas/_libs/src/klib/khash_python.h"
        ],
        "include_dirs": [
            "pandas/_libs/src/klib",
            "/usr/lib/python3.12/site-packages/numpy/core/include",
            "/usr/lib/python3.12/site-packages/numpy/core/include",
            "/usr/lib/python3.12/site-packages/numpy/core/include",
            "/usr/lib/python3.12/site-packages/numpy/core/include",
            "/usr/lib/python3.12/site-packages/numpy/core/include",
            "/usr/lib/python3.12/site-packages/numpy/core/include",
            "/usr/lib/python3.12/site-packages/numpy/core/include"
        ],
        "language": "c",
        "name": "pandas._libs.hashtable",
        "sources": [
            "pandas/_libs/hashtable.pyx"
        ]
    },
    "module_name": "pandas._libs.hashtable"
}
END: Cython Metadata */

#ifndef PY_SSIZE_T_CLEAN
#define PY_SSIZE_T_CLEAN
#endif /* PY_SSIZE_T_CLEAN */
#if defined(CYTHON_LIMITED_API) && 0
  #ifndef Py_LIMITED_API
    #if CYTHON_LIMITED_API+0 > 0x03030000
      #define Py_LIMITED_API CYTHON_LIMITED_API
    #else
      #define Py_LIMITED_API 0x03030000
    #endif
  #endif
#endif

#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02070000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.7+ or Python 3.3+.
#else
#if defined(CYTHON_LIMITED_API) && CYTHON_LIMITED_API
#define __PYX_EXTRA_ABI_MODULE_NAME "limited"
#else
#define __PYX_EXTRA_ABI_MODULE_NAME ""
#endif
#define CYTHON_ABI "3_0_8" __PYX_EXTRA_ABI_MODULE_NAME
#define __PYX_ABI_MODULE_NAME "_cython_" CYTHON_ABI
#define __PYX_TYPE_MODULE_PREFIX __PYX_ABI_MODULE_NAME "."
#define CYTHON_HEX_VERSION 0x030008F0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(_WIN32) && !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #define HAVE_LONG_LONG
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#define __PYX_LIMITED_VERSION_HEX PY_VERSION_HEX
#if defined(GRAALVM_PYTHON)
  /* For very preliminary testing purposes. Most variables are set the same as PyPy.
     The existence of this section does not imply that anything works or is even tested */
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 1
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(PYPY_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS (PY_MAJOR_VERSION >= 3)
  #endif
  #if PY_VERSION_HEX < 0x03090000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1 && PYPY_VERSION_NUM >= 0x07030C00)
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(CYTHON_LIMITED_API)
  #ifdef Py_LIMITED_API
    #undef __PYX_LIMITED_VERSION_HEX
    #define __PYX_LIMITED_VERSION_HEX Py_LIMITED_API
  #endif
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 1
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #undef CYTHON_CLINE_IN_TRACEBACK
  #define CYTHON_CLINE_IN_TRACEBACK 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_TYPE_SPECS
  #define CYTHON_USE_TYPE_SPECS 1
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #endif
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_GIL
  #define CYTHON_FAST_GIL 0
  #undef CYTHON_METH_FASTCALL
  #define CYTHON_METH_FASTCALL 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_MODULE_STATE
  #define CYTHON_USE_MODULE_STATE 1
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 0
  #endif
#elif defined(Py_GIL_DISABLED) || defined(Py_NOGIL)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #ifndef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #define CYTHON_COMPILING_IN_LIMITED_API 0
  #define CYTHON_COMPILING_IN_GRAAL 0
  #define CYTHON_COMPILING_IN_NOGIL 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #ifndef CYTHON_USE_TYPE_SPECS
    #define CYTHON_USE_TYPE_SPECS 0
  #endif
  #ifndef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #ifndef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0 || PY_VERSION_HEX >= 0x030B00A2
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_GIL
    #define CYTHON_FAST_GIL (PY_MAJOR_VERSION < 3 || PY_VERSION_HEX >= 0x03060000 && PY_VERSION_HEX < 0x030C00A6)
  #endif
  #ifndef CYTHON_METH_FASTCALL
    #define CYTHON_METH_FASTCALL (PY_VERSION_HEX >= 0x030700A1)
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP487_INIT_SUBCLASS
    #define CYTHON_PEP487_INIT_SUBCLASS 1
  #endif
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #elif !defined(CYTHON_PEP489_MULTI_PHASE_INIT)
    #define CYTHON_PEP489_MULTI_PHASE_INIT 1
  #endif
  #ifndef CYTHON_USE_MODULE_STATE
    #define CYTHON_USE_MODULE_STATE 0
  #endif
  #if PY_VERSION_HEX < 0x030400a1
    #undef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE 0
  #elif !defined(CYTHON_USE_TP_FINALIZE)
    #define CYTHON_USE_TP_FINALIZE 1
  #endif
  #if PY_VERSION_HEX < 0x030600B1
    #undef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS 0
  #elif !defined(CYTHON_USE_DICT_VERSIONS)
    #define CYTHON_USE_DICT_VERSIONS  (PY_VERSION_HEX < 0x030C00A5)
  #endif
  #if PY_VERSION_HEX < 0x030700A3
    #undef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK 0
  #elif !defined(CYTHON_USE_EXC_INFO_STACK)
    #define CYTHON_USE_EXC_INFO_STACK 1
  #endif
  #ifndef CYTHON_UPDATE_DESCRIPTOR_DOC
    #define CYTHON_UPDATE_DESCRIPTOR_DOC 1
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if !defined(CYTHON_VECTORCALL)
#define CYTHON_VECTORCALL  (CYTHON_FAST_PYCCALL && PY_VERSION_HEX >= 0x030800B1)
#endif
#define CYTHON_BACKPORT_VECTORCALL (CYTHON_METH_FASTCALL && PY_VERSION_HEX < 0x030800B1)
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_MAJOR_VERSION < 3
    #include "longintrepr.h"
  #endif
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(maybe_unused) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(maybe_unused)
        #define CYTHON_UNUSED [[maybe_unused]]
      #endif
    #endif
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
  #define CYTHON_MAYBE_UNUSED_VAR(x) CYTHON_UNUSED_VAR(x)
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_USE_CPP_STD_MOVE
  #if defined(__cplusplus) && (\
    __cplusplus >= 201103L || (defined(_MSC_VER) && _MSC_VER >= 1600))
    #define CYTHON_USE_CPP_STD_MOVE 1
  #else
    #define CYTHON_USE_CPP_STD_MOVE 0
  #endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
            typedef unsigned char     uint8_t;
            typedef unsigned short    uint16_t;
            typedef unsigned int      uint32_t;
        #else
            typedef unsigned __int8   uint8_t;
            typedef unsigned __int16  uint16_t;
            typedef unsigned __int32  uint32_t;
        #endif
    #endif
    #if _MSC_VER < 1300
        #ifdef _WIN64
            typedef unsigned long long  __pyx_uintptr_t;
        #else
            typedef unsigned int        __pyx_uintptr_t;
        #endif
    #else
        #ifdef _WIN64
            typedef unsigned __int64    __pyx_uintptr_t;
        #else
            typedef unsigned __int32    __pyx_uintptr_t;
        #endif
    #endif
#else
    #include <stdint.h>
    typedef uintptr_t  __pyx_uintptr_t;
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus)
    /* for clang __has_cpp_attribute(fallthrough) is true even before C++17
     * but leads to warnings with -pedantic, since it is a C++17 feature */
    #if ((defined(_MSVC_LANG) && _MSVC_LANG >= 201703L) || __cplusplus >= 201703L)
      #if __has_cpp_attribute(fallthrough)
        #define CYTHON_FALLTHROUGH [[fallthrough]]
      #endif
    #endif
    #ifndef CYTHON_FALLTHROUGH
      #if __has_cpp_attribute(clang::fallthrough)
        #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
      #elif __has_cpp_attribute(gnu::fallthrough)
        #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
      #endif
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif
#ifdef __cplusplus
  template <typename T>
  struct __PYX_IS_UNSIGNED_IMPL {static const bool value = T(0) < T(-1);};
  #define __PYX_IS_UNSIGNED(type) (__PYX_IS_UNSIGNED_IMPL<type>::value)
#else
  #define __PYX_IS_UNSIGNED(type) (((type)-1) > 0)
#endif
#if CYTHON_COMPILING_IN_PYPY == 1
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x030A0000)
#else
  #define __PYX_NEED_TP_PRINT_SLOT  (PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000)
#endif
#define __PYX_REINTERPRET_FUNCION(func_pointer, other_pointer) ((func_pointer)(void(*)(void))(other_pointer))

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_DefaultClassType PyClass_Type
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_DefaultClassType PyType_Type
#if CYTHON_COMPILING_IN_LIMITED_API
    static CYTHON_INLINE PyObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
        PyObject *exception_table = NULL;
        PyObject *types_module=NULL, *code_type=NULL, *result=NULL;
        #if __PYX_LIMITED_VERSION_HEX < 0x030B0000
        PyObject *version_info;
        PyObject *py_minor_version = NULL;
        #endif
        long minor_version = 0;
        PyObject *type, *value, *traceback;
        PyErr_Fetch(&type, &value, &traceback);
        #if __PYX_LIMITED_VERSION_HEX >= 0x030B0000
        minor_version = 11;
        #else
        if (!(version_info = PySys_GetObject("version_info"))) goto end;
        if (!(py_minor_version = PySequence_GetItem(version_info, 1))) goto end;
        minor_version = PyLong_AsLong(py_minor_version);
        Py_DECREF(py_minor_version);
        if (minor_version == -1 && PyErr_Occurred()) goto end;
        #endif
        if (!(types_module = PyImport_ImportModule("types"))) goto end;
        if (!(code_type = PyObject_GetAttrString(types_module, "CodeType"))) goto end;
        if (minor_version <= 7) {
            (void)p;
            result = PyObject_CallFunction(code_type, "iiiiiOOOOOOiOO", a, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else if (minor_version <= 10) {
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOiOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, fline, lnos, fv, cell);
        } else {
            if (!(exception_table = PyBytes_FromStringAndSize(NULL, 0))) goto end;
            result = PyObject_CallFunction(code_type, "iiiiiiOOOOOOOiOO", a,p, k, l, s, f, code,
                          c, n, v, fn, name, name, fline, lnos, exception_table, fv, cell);
        }
    end:
        Py_XDECREF(code_type);
        Py_XDECREF(exception_table);
        Py_XDECREF(types_module);
        if (type) {
            PyErr_Restore(type, value, traceback);
        }
        return result;
    }
    #ifndef CO_OPTIMIZED
    #define CO_OPTIMIZED 0x0001
    #endif
    #ifndef CO_NEWLOCALS
    #define CO_NEWLOCALS 0x0002
    #endif
    #ifndef CO_VARARGS
    #define CO_VARARGS 0x0004
    #endif
    #ifndef CO_VARKEYWORDS
    #define CO_VARKEYWORDS 0x0008
    #endif
    #ifndef CO_ASYNC_GENERATOR
    #define CO_ASYNC_GENERATOR 0x0200
    #endif
    #ifndef CO_GENERATOR
    #define CO_GENERATOR 0x0020
    #endif
    #ifndef CO_COROUTINE
    #define CO_COROUTINE 0x0080
    #endif
#elif PY_VERSION_HEX >= 0x030B0000
  static CYTHON_INLINE PyCodeObject* __Pyx_PyCode_New(int a, int p, int k, int l, int s, int f,
                                                    PyObject *code, PyObject *c, PyObject* n, PyObject *v,
                                                    PyObject *fv, PyObject *cell, PyObject* fn,
                                                    PyObject *name, int fline, PyObject *lnos) {
    PyCodeObject *result;
    PyObject *empty_bytes = PyBytes_FromStringAndSize("", 0);
    if (!empty_bytes) return NULL;
    result =
      #if PY_VERSION_HEX >= 0x030C0000
        PyUnstable_Code_NewWithPosOnlyArgs
      #else
        PyCode_NewWithPosOnlyArgs
      #endif
        (a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, name, fline, lnos, empty_bytes);
    Py_DECREF(empty_bytes);
    return result;
  }
#elif PY_VERSION_HEX >= 0x030800B2 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_NewWithPosOnlyArgs(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, p, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
#endif
#if PY_VERSION_HEX >= 0x030900A4 || defined(Py_IS_TYPE)
  #define __Pyx_IS_TYPE(ob, type) Py_IS_TYPE(ob, type)
#else
  #define __Pyx_IS_TYPE(ob, type) (((const PyObject*)ob)->ob_type == (type))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_Is)
  #define __Pyx_Py_Is(x, y)  Py_Is(x, y)
#else
  #define __Pyx_Py_Is(x, y) ((x) == (y))
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsNone)
  #define __Pyx_Py_IsNone(ob) Py_IsNone(ob)
#else
  #define __Pyx_Py_IsNone(ob) __Pyx_Py_Is((ob), Py_None)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsTrue)
  #define __Pyx_Py_IsTrue(ob) Py_IsTrue(ob)
#else
  #define __Pyx_Py_IsTrue(ob) __Pyx_Py_Is((ob), Py_True)
#endif
#if PY_VERSION_HEX >= 0x030A00B1 || defined(Py_IsFalse)
  #define __Pyx_Py_IsFalse(ob) Py_IsFalse(ob)
#else
  #define __Pyx_Py_IsFalse(ob) __Pyx_Py_Is((ob), Py_False)
#endif
#define __Pyx_NoneAsNull(obj)  (__Pyx_Py_IsNone(obj) ? NULL : (obj))
#if PY_VERSION_HEX >= 0x030900F0 && !CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyObject_GC_IsFinalized(o) PyObject_GC_IsFinalized(o)
#else
  #define __Pyx_PyObject_GC_IsFinalized(o) _PyGC_FINALIZED(o)
#endif
#ifndef CO_COROUTINE
  #define CO_COROUTINE 0x80
#endif
#ifndef CO_ASYNC_GENERATOR
  #define CO_ASYNC_GENERATOR 0x200
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef Py_TPFLAGS_SEQUENCE
  #define Py_TPFLAGS_SEQUENCE 0
#endif
#ifndef Py_TPFLAGS_MAPPING
  #define Py_TPFLAGS_MAPPING 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_METH_FASTCALL
  #define __Pyx_METH_FASTCALL METH_FASTCALL
  #define __Pyx_PyCFunction_FastCall __Pyx_PyCFunctionFast
  #define __Pyx_PyCFunction_FastCallWithKeywords __Pyx_PyCFunctionFastWithKeywords
#else
  #define __Pyx_METH_FASTCALL METH_VARARGS
  #define __Pyx_PyCFunction_FastCall PyCFunction
  #define __Pyx_PyCFunction_FastCallWithKeywords PyCFunctionWithKeywords
#endif
#if CYTHON_VECTORCALL
  #define __pyx_vectorcallfunc vectorcallfunc
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  PY_VECTORCALL_ARGUMENTS_OFFSET
  #define __Pyx_PyVectorcall_NARGS(n)  PyVectorcall_NARGS((size_t)(n))
#elif CYTHON_BACKPORT_VECTORCALL
  typedef PyObject *(*__pyx_vectorcallfunc)(PyObject *callable, PyObject *const *args,
                                            size_t nargsf, PyObject *kwnames);
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  ((size_t)1 << (8 * sizeof(size_t) - 1))
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(((size_t)(n)) & ~__Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET))
#else
  #define __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET  0
  #define __Pyx_PyVectorcall_NARGS(n)  ((Py_ssize_t)(n))
#endif
#if PY_MAJOR_VERSION >= 0x030900B1
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_CheckExact(func)
#else
#define __Pyx_PyCFunction_CheckExact(func)  PyCFunction_Check(func)
#endif
#define __Pyx_CyOrPyCFunction_Check(func)  PyCFunction_Check(func)
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  (((PyCFunctionObject*)(func))->m_ml->ml_meth)
#elif !CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyOrPyCFunction_GET_FUNCTION(func)  PyCFunction_GET_FUNCTION(func)
#endif
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CyOrPyCFunction_GET_FLAGS(func)  (((PyCFunctionObject*)(func))->m_ml->ml_flags)
static CYTHON_INLINE PyObject* __Pyx_CyOrPyCFunction_GET_SELF(PyObject *func) {
    return (__Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_STATIC) ? NULL : ((PyCFunctionObject*)func)->m_self;
}
#endif
static CYTHON_INLINE int __Pyx__IsSameCFunction(PyObject *func, void *cfunc) {
#if CYTHON_COMPILING_IN_LIMITED_API
    return PyCFunction_Check(func) && PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
#else
    return PyCFunction_Check(func) && PyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
#endif
}
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCFunction(func, cfunc)
#if __PYX_LIMITED_VERSION_HEX < 0x030900B1
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  ((void)m, PyType_FromSpecWithBases(s, b))
  typedef PyObject *(*__Pyx_PyCMethod)(PyObject *, PyTypeObject *, PyObject *const *, size_t, PyObject *);
#else
  #define __Pyx_PyType_FromModuleAndSpec(m, s, b)  PyType_FromModuleAndSpec(m, s, b)
  #define __Pyx_PyCMethod  PyCMethod
#endif
#ifndef METH_METHOD
  #define METH_METHOD 0x200
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyThreadState_Current PyThreadState_Get()
#elif !CYTHON_FAST_THREAD_STATE
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyThreadState_Current PyThreadState_GetUnchecked()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE void *__Pyx_PyModule_GetState(PyObject *op)
{
    void *result;
    result = PyModule_GetState(op);
    if (!result)
        Py_FatalError("Couldn't find the module state");
    return result;
}
#endif
#define __Pyx_PyObject_GetSlot(obj, name, func_ctype)  __Pyx_PyType_GetSlot(Py_TYPE(obj), name, func_ctype)
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((func_ctype) PyType_GetSlot((type), Py_##name))
#else
  #define __Pyx_PyType_GetSlot(type, name, func_ctype)  ((type)->name)
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if PY_MAJOR_VERSION < 3
    #if CYTHON_COMPILING_IN_PYPY
        #if PYPY_VERSION_NUM < 0x07030600
            #if defined(__cplusplus) && __cplusplus >= 201402L
                [[deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")]]
            #elif defined(__GNUC__) || defined(__clang__)
                __attribute__ ((__deprecated__("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6")))
            #elif defined(_MSC_VER)
                __declspec(deprecated("`with nogil:` inside a nogil function will not release the GIL in PyPy2 < 7.3.6"))
            #endif
            static CYTHON_INLINE int PyGILState_Check(void) {
                return 0;
            }
        #else  // PYPY_VERSION_NUM < 0x07030600
        #endif  // PYPY_VERSION_NUM < 0x07030600
    #else
        static CYTHON_INLINE int PyGILState_Check(void) {
            PyThreadState * tstate = _PyThreadState_Current;
            return tstate && (tstate == PyGILState_GetThisThreadState());
        }
    #endif
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000 || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX > 0x030600B4 && PY_VERSION_HEX < 0x030d0000 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStrWithError(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStr(PyObject *dict, PyObject *name) {
    PyObject *res = __Pyx_PyDict_GetItemStrWithError(dict, name);
    if (res == NULL) PyErr_Clear();
    return res;
}
#elif PY_MAJOR_VERSION >= 3 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000)
#define __Pyx_PyDict_GetItemStrWithError  PyDict_GetItemWithError
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#else
static CYTHON_INLINE PyObject * __Pyx_PyDict_GetItemStrWithError(PyObject *dict, PyObject *name) {
#if CYTHON_COMPILING_IN_PYPY
    return PyDict_GetItem(dict, name);
#else
    PyDictEntry *ep;
    PyDictObject *mp = (PyDictObject*) dict;
    long hash = ((PyStringObject *) name)->ob_shash;
    assert(hash != -1);
    ep = (mp->ma_lookup)(mp, name, hash);
    if (ep == NULL) {
        return NULL;
    }
    return ep->me_value;
#endif
}
#define __Pyx_PyDict_GetItemStr           PyDict_GetItem
#endif
#if CYTHON_USE_TYPE_SLOTS
  #define __Pyx_PyType_GetFlags(tp)   (((PyTypeObject *)tp)->tp_flags)
  #define __Pyx_PyType_HasFeature(type, feature)  ((__Pyx_PyType_GetFlags(type) & (feature)) != 0)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  (Py_TYPE(obj)->tp_iternext)
#else
  #define __Pyx_PyType_GetFlags(tp)   (PyType_GetFlags((PyTypeObject *)tp))
  #define __Pyx_PyType_HasFeature(type, feature)  PyType_HasFeature(type, feature)
  #define __Pyx_PyObject_GetIterNextFunc(obj)  PyIter_Next
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_SetItemOnTypeDict(tp, k, v) PyObject_GenericSetAttr((PyObject*)tp, k, v)
#else
  #define __Pyx_SetItemOnTypeDict(tp, k, v) PyDict_SetItem(tp->tp_dict, k, v)
#endif
#if CYTHON_USE_TYPE_SPECS && PY_VERSION_HEX >= 0x03080000
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  {\
    PyTypeObject *type = Py_TYPE((PyObject*)obj);\
    assert(__Pyx_PyType_HasFeature(type, Py_TPFLAGS_HEAPTYPE));\
    PyObject_GC_Del(obj);\
    Py_DECREF(type);\
}
#else
#define __Pyx_PyHeapTypeObject_GC_Del(obj)  PyObject_GC_Del(obj)
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GetLength(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_ReadChar(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((void)u, 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((void)u, (0))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)u)
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)k, PyUnicode_ReadChar((PyObject*)(d), i))
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GetLength(u))
#elif PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_READY(op)       (0)
  #else
    #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                                0 : _PyUnicode_Ready((PyObject *)(op)))
  #endif
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         ((int)PyUnicode_KIND(u))
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, (Py_UCS4) ch)
  #if PY_VERSION_HEX >= 0x030C0000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #else
    #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x03090000
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : ((PyCompactUnicodeObject *)(u))->wstr_length))
    #else
    #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
    #endif
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535U : 1114111U)
  #define __Pyx_PyUnicode_KIND(u)         ((int)sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = (Py_UNICODE) ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #if !defined(PyUnicode_DecodeUnicodeEscape)
    #define PyUnicode_DecodeUnicodeEscape(s, size, errors)  PyUnicode_Decode(s, size, "unicode_escape", errors)
  #endif
  #if !defined(PyUnicode_Contains) || (PY_MAJOR_VERSION == 2 && PYPY_VERSION_NUM < 0x07030500)
    #undef PyUnicode_Contains
    #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
  #endif
  #if !defined(PyByteArray_Check)
    #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
  #endif
  #if !defined(PyObject_Format)
    #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
  #endif
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#if CYTHON_COMPILING_IN_CPYTHON
  #define __Pyx_PySequence_ListKeepNew(obj)\
    (likely(PyList_CheckExact(obj) && Py_REFCNT(obj) == 1) ? __Pyx_NewRef(obj) : PySequence_List(obj))
#else
  #define __Pyx_PySequence_ListKeepNew(obj)  PySequence_List(obj)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        __Pyx_IS_TYPE(obj, &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_ITEM(o, i) PySequence_ITEM(o, i)
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) (PyTuple_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyList_SET_ITEM(o, i, v) (PyList_SET_ITEM(o, i, v), (0))
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_GET_SIZE(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_GET_SIZE(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_GET_SIZE(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_GET_SIZE(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_GET_SIZE(o)
#else
  #define __Pyx_PySequence_ITEM(o, i) PySequence_GetItem(o, i)
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
  #define __Pyx_PyTuple_SET_ITEM(o, i, v) PyTuple_SetItem(o, i, v)
  #define __Pyx_PyList_SET_ITEM(o, i, v) PyList_SetItem(o, i, v)
  #define __Pyx_PyTuple_GET_SIZE(o) PyTuple_Size(o)
  #define __Pyx_PyList_GET_SIZE(o) PyList_Size(o)
  #define __Pyx_PySet_GET_SIZE(o) PySet_Size(o)
  #define __Pyx_PyBytes_GET_SIZE(o) PyBytes_Size(o)
  #define __Pyx_PyByteArray_GET_SIZE(o) PyByteArray_Size(o)
#endif
#if PY_VERSION_HEX >= 0x030d00A1
  #define __Pyx_PyImport_AddModuleRef(name) PyImport_AddModuleRef(name)
#else
  static CYTHON_INLINE PyObject *__Pyx_PyImport_AddModuleRef(const char *name) {
      PyObject *module = PyImport_AddModule(name);
      Py_XINCREF(module);
      return module;
  }
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define __Pyx_Py3Int_Check(op)       PyLong_Check(op)
  #define __Pyx_Py3Int_CheckExact(op)  PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#else
  #define __Pyx_Py3Int_Check(op)       (PyLong_Check(op) || PyInt_Check(op))
  #define __Pyx_Py3Int_CheckExact(op)  (PyLong_CheckExact(op) || PyInt_CheckExact(op))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsHash_t
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   __Pyx_PyIndex_AsSsize_t
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(_WIN32) || defined(WIN32) || defined(MS_WINDOWS)
  #if !defined(_USE_MATH_DEFINES)
    #define _USE_MATH_DEFINES
  #endif
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifdef CYTHON_EXTERN_C
    #undef __PYX_EXTERN_C
    #define __PYX_EXTERN_C CYTHON_EXTERN_C
#elif defined(__PYX_EXTERN_C)
    #ifdef _MSC_VER
    #pragma message ("Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.")
    #else
    #warning Please do not define the '__PYX_EXTERN_C' macro externally. Use 'CYTHON_EXTERN_C' instead.
    #endif
#else
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__pandas___libs__hashtable
#define __PYX_HAVE_API__pandas___libs__hashtable
/* Early includes */
#include <string.h>
#include <stdio.h>

    /* Using NumPy API declarations from "numpy/__init__.cython-30.pxd" */
    
#include "numpy/arrayobject.h"
#include "numpy/ndarrayobject.h"
#include "numpy/ndarraytypes.h"
#include "numpy/arrayscalars.h"
#include "numpy/ufuncobject.h"
#include "khash_python.h"
#include <stdlib.h>
#include <stdint.h>
#include "numpy/npy_common.h"
#include "pythread.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s);
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char*);
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*)(__pyx_uintptr_t) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const wchar_t *u)
{
    const wchar_t *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#else
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u)
{
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#endif
#define __Pyx_PyUnicode_FromOrdinal(o)       PyUnicode_FromOrdinal((int)o)
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject*);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #if PY_VERSION_HEX >= 0x030C00A7
  #ifndef _PyLong_SIGN_MASK
    #define _PyLong_SIGN_MASK 3
  #endif
  #ifndef _PyLong_NON_SIZE_BITS
    #define _PyLong_NON_SIZE_BITS 3
  #endif
  #define __Pyx_PyLong_Sign(x)  (((PyLongObject*)x)->long_value.lv_tag & _PyLong_SIGN_MASK)
  #define __Pyx_PyLong_IsNeg(x)  ((__Pyx_PyLong_Sign(x) & 2) != 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (!__Pyx_PyLong_IsNeg(x))
  #define __Pyx_PyLong_IsZero(x)  (__Pyx_PyLong_Sign(x) & 1)
  #define __Pyx_PyLong_IsPos(x)  (__Pyx_PyLong_Sign(x) == 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  (__Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  ((Py_ssize_t) (((PyLongObject*)x)->long_value.lv_tag >> _PyLong_NON_SIZE_BITS))
  #define __Pyx_PyLong_SignedDigitCount(x)\
        ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * __Pyx_PyLong_DigitCount(x))
  #if defined(PyUnstable_Long_IsCompact) && defined(PyUnstable_Long_CompactValue)
    #define __Pyx_PyLong_IsCompact(x)     PyUnstable_Long_IsCompact((PyLongObject*) x)
    #define __Pyx_PyLong_CompactValue(x)  PyUnstable_Long_CompactValue((PyLongObject*) x)
  #else
    #define __Pyx_PyLong_IsCompact(x)     (((PyLongObject*)x)->long_value.lv_tag < (2 << _PyLong_NON_SIZE_BITS))
    #define __Pyx_PyLong_CompactValue(x)  ((1 - (Py_ssize_t) __Pyx_PyLong_Sign(x)) * (Py_ssize_t) __Pyx_PyLong_Digits(x)[0])
  #endif
  typedef Py_ssize_t  __Pyx_compact_pylong;
  typedef size_t  __Pyx_compact_upylong;
  #else
  #define __Pyx_PyLong_IsNeg(x)  (Py_SIZE(x) < 0)
  #define __Pyx_PyLong_IsNonNeg(x)  (Py_SIZE(x) >= 0)
  #define __Pyx_PyLong_IsZero(x)  (Py_SIZE(x) == 0)
  #define __Pyx_PyLong_IsPos(x)  (Py_SIZE(x) > 0)
  #define __Pyx_PyLong_CompactValueUnsigned(x)  ((Py_SIZE(x) == 0) ? 0 : __Pyx_PyLong_Digits(x)[0])
  #define __Pyx_PyLong_DigitCount(x)  __Pyx_sst_abs(Py_SIZE(x))
  #define __Pyx_PyLong_SignedDigitCount(x)  Py_SIZE(x)
  #define __Pyx_PyLong_IsCompact(x)  (Py_SIZE(x) == 0 || Py_SIZE(x) == 1 || Py_SIZE(x) == -1)
  #define __Pyx_PyLong_CompactValue(x)\
        ((Py_SIZE(x) == 0) ? (sdigit) 0 : ((Py_SIZE(x) < 0) ? -(sdigit)__Pyx_PyLong_Digits(x)[0] : (sdigit)__Pyx_PyLong_Digits(x)[0]))
  typedef sdigit  __Pyx_compact_pylong;
  typedef digit  __Pyx_compact_upylong;
  #endif
  #if PY_VERSION_HEX >= 0x030C00A5
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->long_value.ob_digit)
  #else
  #define __Pyx_PyLong_Digits(x)  (((PyLongObject*)x)->ob_digit)
  #endif
#endif
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
#include <string.h>
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = (char) c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#include <string.h>
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

#if !CYTHON_USE_MODULE_STATE
static PyObject *__pyx_m = NULL;
#endif
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm = __FILE__;
static const char *__pyx_filename;

/* Header.proto */
#if !defined(CYTHON_CCOMPLEX)
  #if defined(__cplusplus)
    #define CYTHON_CCOMPLEX 1
  #elif (defined(_Complex_I) && !defined(_MSC_VER)) || ((defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) && !defined(__STDC_NO_COMPLEX__) && !defined(_MSC_VER))
    #define CYTHON_CCOMPLEX 1
  #else
    #define CYTHON_CCOMPLEX 0
  #endif
#endif
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #include <complex>
  #else
    #include <complex.h>
  #endif
#endif
#if CYTHON_CCOMPLEX && !defined(__cplusplus) && defined(__sun__) && defined(__GNUC__)
  #undef _Complex_I
  #define _Complex_I 1.0fj
#endif

/* #### Code section: filename_table ### */

static const char *__pyx_f[] = {
  "pandas/_libs/hashtable.pyx",
  "<stringsource>",
  "pandas/_libs/hashtable_class_helper.pxi",
  "__init__.cython-30.pxd",
  "pandas/_libs/tslibs/util.pxd",
  "pandas/_libs/hashtable_func_helper.pxi",
  "type.pxd",
  "pandas/_libs/missing.pxd",
};
/* #### Code section: utility_code_proto_before_types ### */
/* ForceInitThreads.proto */
#ifndef __PYX_FORCE_INIT_THREADS
  #define __PYX_FORCE_INIT_THREADS 0
#endif

/* NoFastGil.proto */
#define __Pyx_PyGILState_Ensure PyGILState_Ensure
#define __Pyx_PyGILState_Release PyGILState_Release
#define __Pyx_FastGIL_Remember()
#define __Pyx_FastGIL_Forget()
#define __Pyx_FastGilFuncInit()

/* BufferFormatStructs.proto */
struct __Pyx_StructField_;
#define __PYX_BUF_FLAGS_PACKED_STRUCT (1 << 0)
typedef struct {
  const char* name;
  struct __Pyx_StructField_* fields;
  size_t size;
  size_t arraysize[8];
  int ndim;
  char typegroup;
  char is_unsigned;
  int flags;
} __Pyx_TypeInfo;
typedef struct __Pyx_StructField_ {
  __Pyx_TypeInfo* type;
  const char* name;
  size_t offset;
} __Pyx_StructField;
typedef struct {
  __Pyx_StructField* field;
  size_t parent_offset;
} __Pyx_BufFmt_StackElem;
typedef struct {
  __Pyx_StructField root;
  __Pyx_BufFmt_StackElem* head;
  size_t fmt_offset;
  size_t new_count, enc_count;
  size_t struct_alignment;
  int is_complex;
  char enc_type;
  char new_packmode;
  char enc_packmode;
  char is_valid_array;
} __Pyx_BufFmt_Context;

/* Atomics.proto */
#include <pythread.h>
#ifndef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 1
#endif
#define __PYX_CYTHON_ATOMICS_ENABLED() CYTHON_ATOMICS
#define __pyx_atomic_int_type int
#define __pyx_nonatomic_int_type int
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__))
    #include <stdatomic.h>
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)))
    #include <atomic>
#endif
#if CYTHON_ATOMICS && (defined(__STDC_VERSION__) &&\
                        (__STDC_VERSION__ >= 201112L) &&\
                        !defined(__STDC_NO_ATOMICS__) &&\
                       ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type atomic_int
    #define __pyx_atomic_incr_aligned(value) atomic_fetch_add_explicit(value, 1, memory_order_relaxed)
    #define __pyx_atomic_decr_aligned(value) atomic_fetch_sub_explicit(value, 1, memory_order_acq_rel)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C atomics"
    #endif
#elif CYTHON_ATOMICS && (defined(__cplusplus) && (\
                    (__cplusplus >= 201103L) ||\
\
                    (defined(_MSC_VER) && _MSC_VER >= 1700)) &&\
                    ATOMIC_INT_LOCK_FREE == 2)
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type std::atomic_int
    #define __pyx_atomic_incr_aligned(value) std::atomic_fetch_add_explicit(value, 1, std::memory_order_relaxed)
    #define __pyx_atomic_decr_aligned(value) std::atomic_fetch_sub_explicit(value, 1, std::memory_order_acq_rel)
    #if defined(__PYX_DEBUG_ATOMICS) && defined(_MSC_VER)
        #pragma message ("Using standard C++ atomics")
    #elif defined(__PYX_DEBUG_ATOMICS)
        #warning "Using standard C++ atomics"
    #endif
#elif CYTHON_ATOMICS && (__GNUC__ >= 5 || (__GNUC__ == 4 &&\
                    (__GNUC_MINOR__ > 1 ||\
                    (__GNUC_MINOR__ == 1 && __GNUC_PATCHLEVEL__ >= 2))))
    #define __pyx_atomic_incr_aligned(value) __sync_fetch_and_add(value, 1)
    #define __pyx_atomic_decr_aligned(value) __sync_fetch_and_sub(value, 1)
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Using GNU atomics"
    #endif
#elif CYTHON_ATOMICS && defined(_MSC_VER)
    #include <intrin.h>
    #undef __pyx_atomic_int_type
    #define __pyx_atomic_int_type long
    #undef __pyx_nonatomic_int_type
    #define __pyx_nonatomic_int_type long
    #pragma intrinsic (_InterlockedExchangeAdd)
    #define __pyx_atomic_incr_aligned(value) _InterlockedExchangeAdd(value, 1)
    #define __pyx_atomic_decr_aligned(value) _InterlockedExchangeAdd(value, -1)
    #ifdef __PYX_DEBUG_ATOMICS
        #pragma message ("Using MSVC atomics")
    #endif
#else
    #undef CYTHON_ATOMICS
    #define CYTHON_ATOMICS 0
    #ifdef __PYX_DEBUG_ATOMICS
        #warning "Not using atomics"
    #endif
#endif
#if CYTHON_ATOMICS
    #define __pyx_add_acquisition_count(memview)\
             __pyx_atomic_incr_aligned(__pyx_get_slice_count_pointer(memview))
    #define __pyx_sub_acquisition_count(memview)\
            __pyx_atomic_decr_aligned(__pyx_get_slice_count_pointer(memview))
#else
    #define __pyx_add_acquisition_count(memview)\
            __pyx_add_acquisition_count_locked(__pyx_get_slice_count_pointer(memview), memview->lock)
    #define __pyx_sub_acquisition_count(memview)\
            __pyx_sub_acquisition_count_locked(__pyx_get_slice_count_pointer(memview), memview->lock)
#endif

/* MemviewSliceStruct.proto */
struct __pyx_memoryview_obj;
typedef struct {
  struct __pyx_memoryview_obj *memview;
  char *data;
  Py_ssize_t shape[8];
  Py_ssize_t strides[8];
  Py_ssize_t suboffsets[8];
} __Pyx_memviewslice;
#define __Pyx_MemoryView_Len(m)  (m.shape[0])

/* #### Code section: numeric_typedefs ### */

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":730
 * # in Cython to enable them only on the right systems.
 * 
 * ctypedef npy_int8       int8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 */
typedef npy_int8 __pyx_t_5numpy_int8_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":731
 * 
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t
 */
typedef npy_int16 __pyx_t_5numpy_int16_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":732
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int64      int64_t
 * #ctypedef npy_int96      int96_t
 */
typedef npy_int32 __pyx_t_5numpy_int32_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":733
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_int96      int96_t
 * #ctypedef npy_int128     int128_t
 */
typedef npy_int64 __pyx_t_5numpy_int64_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":737
 * #ctypedef npy_int128     int128_t
 * 
 * ctypedef npy_uint8      uint8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 */
typedef npy_uint8 __pyx_t_5numpy_uint8_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":738
 * 
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t
 */
typedef npy_uint16 __pyx_t_5numpy_uint16_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":739
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint64     uint64_t
 * #ctypedef npy_uint96     uint96_t
 */
typedef npy_uint32 __pyx_t_5numpy_uint32_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":740
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_uint96     uint96_t
 * #ctypedef npy_uint128    uint128_t
 */
typedef npy_uint64 __pyx_t_5numpy_uint64_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":744
 * #ctypedef npy_uint128    uint128_t
 * 
 * ctypedef npy_float32    float32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_float64    float64_t
 * #ctypedef npy_float80    float80_t
 */
typedef npy_float32 __pyx_t_5numpy_float32_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":745
 * 
 * ctypedef npy_float32    float32_t
 * ctypedef npy_float64    float64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_float80    float80_t
 * #ctypedef npy_float128   float128_t
 */
typedef npy_float64 __pyx_t_5numpy_float64_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":754
 * # The int types are mapped a bit surprising --
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longlong   longlong_t
 * 
 */
typedef npy_long __pyx_t_5numpy_int_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":755
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t
 * ctypedef npy_longlong   longlong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_ulong      uint_t
 */
typedef npy_longlong __pyx_t_5numpy_longlong_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":757
 * ctypedef npy_longlong   longlong_t
 * 
 * ctypedef npy_ulong      uint_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 */
typedef npy_ulong __pyx_t_5numpy_uint_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":758
 * 
 * ctypedef npy_ulong      uint_t
 * ctypedef npy_ulonglong  ulonglong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_intp       intp_t
 */
typedef npy_ulonglong __pyx_t_5numpy_ulonglong_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":760
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 * ctypedef npy_intp       intp_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uintp      uintp_t
 * 
 */
typedef npy_intp __pyx_t_5numpy_intp_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":761
 * 
 * ctypedef npy_intp       intp_t
 * ctypedef npy_uintp      uintp_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_double     float_t
 */
typedef npy_uintp __pyx_t_5numpy_uintp_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":763
 * ctypedef npy_uintp      uintp_t
 * 
 * ctypedef npy_double     float_t             # <<<<<<<<<<<<<<
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t
 */
typedef npy_double __pyx_t_5numpy_float_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":764
 * 
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longdouble longdouble_t
 * 
 */
typedef npy_double __pyx_t_5numpy_double_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":765
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cfloat      cfloat_t
 */
typedef npy_longdouble __pyx_t_5numpy_longdouble_t;
/* #### Code section: complex_type_declarations ### */
/* Declarations.proto */
#if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
  #ifdef __cplusplus
    typedef ::std::complex< double > __pyx_t_double_complex;
  #else
    typedef double _Complex __pyx_t_double_complex;
  #endif
#else
    typedef struct { double real, imag; } __pyx_t_double_complex;
#endif
static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double, double);

/* Declarations.proto */
#if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
  #ifdef __cplusplus
    typedef ::std::complex< float > __pyx_t_float_complex;
  #else
    typedef float _Complex __pyx_t_float_complex;
  #endif
#else
    typedef struct { float real, imag; } __pyx_t_float_complex;
#endif
static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float, float);

/* #### Code section: type_declarations ### */

/*--- Type declarations ---*/
struct __pyx_obj_6pandas_5_libs_7missing_C_NAType;
struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable;
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable;
struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable;
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable;
struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable;
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable;
struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable;
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable;
struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable;
struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable;
struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable;
struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable;
struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable;
struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable;
struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable;
struct __pyx_obj_6pandas_5_libs_9hashtable_Vector;
struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector;
struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector;
struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector;
struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector;
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector;
struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector;
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector;
struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector;
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector;
struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector;
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector;
struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector;
struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector;
struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector;
struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer;
struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer;
struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer;
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer;
struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer;
struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer;
struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer;
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer;
struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer;
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer;
struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer;
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer;
struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer;
struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer;
struct __pyx_array_obj;
struct __pyx_MemviewEnum_obj;
struct __pyx_memoryview_obj;
struct __pyx_memoryviewslice_obj;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":767
 * ctypedef npy_longdouble longdouble_t
 * 
 * ctypedef npy_cfloat      cfloat_t             # <<<<<<<<<<<<<<
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t
 */
typedef npy_cfloat __pyx_t_5numpy_cfloat_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":768
 * 
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t             # <<<<<<<<<<<<<<
 * ctypedef npy_clongdouble clongdouble_t
 * 
 */
typedef npy_cdouble __pyx_t_5numpy_cdouble_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":769
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cdouble     complex_t
 */
typedef npy_clongdouble __pyx_t_5numpy_clongdouble_t;

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":771
 * ctypedef npy_clongdouble clongdouble_t
 * 
 * ctypedef npy_cdouble     complex_t             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 */
typedef npy_cdouble __pyx_t_5numpy_complex_t;
struct __pyx_opt_args_6pandas_5_libs_7missing_is_matching_na;
struct __pyx_opt_args_6pandas_5_libs_7missing_checknull;
struct __pyx_opt_args_6pandas_5_libs_7missing_isnaobj;

/* "pandas/_libs/missing.pxd":7
 * 
 * 
 * cpdef bint is_matching_na(object left, object right, bint nan_matches_none=*)             # <<<<<<<<<<<<<<
 * cpdef bint check_na_tuples_nonequal(object left, object right)
 * 
 */
struct __pyx_opt_args_6pandas_5_libs_7missing_is_matching_na {
  int __pyx_n;
  int nan_matches_none;
};

/* "pandas/_libs/missing.pxd":10
 * cpdef bint check_na_tuples_nonequal(object left, object right)
 * 
 * cpdef bint checknull(object val, bint inf_as_na=*)             # <<<<<<<<<<<<<<
 * cpdef ndarray[uint8_t] isnaobj(ndarray arr, bint inf_as_na=*)
 * 
 */
struct __pyx_opt_args_6pandas_5_libs_7missing_checknull {
  int __pyx_n;
  int inf_as_na;
};

/* "pandas/_libs/missing.pxd":11
 * 
 * cpdef bint checknull(object val, bint inf_as_na=*)
 * cpdef ndarray[uint8_t] isnaobj(ndarray arr, bint inf_as_na=*)             # <<<<<<<<<<<<<<
 * 
 * cdef bint is_null_datetime64(v)
 */
struct __pyx_opt_args_6pandas_5_libs_7missing_isnaobj {
  int __pyx_n;
  int inf_as_na;
};
struct __pyx_t_6pandas_5_libs_9hashtable_Int64VectorData;
struct __pyx_t_6pandas_5_libs_9hashtable_Complex128VectorData;
typedef struct __pyx_t_6pandas_5_libs_9hashtable_Complex128VectorData __pyx_t_6pandas_5_libs_9hashtable_Complex128VectorData;
struct __pyx_t_6pandas_5_libs_9hashtable_Complex64VectorData;
typedef struct __pyx_t_6pandas_5_libs_9hashtable_Complex64VectorData __pyx_t_6pandas_5_libs_9hashtable_Complex64VectorData;
struct __pyx_t_6pandas_5_libs_9hashtable_Float64VectorData;
typedef struct __pyx_t_6pandas_5_libs_9hashtable_Float64VectorData __pyx_t_6pandas_5_libs_9hashtable_Float64VectorData;
struct __pyx_t_6pandas_5_libs_9hashtable_Float32VectorData;
typedef struct __pyx_t_6pandas_5_libs_9hashtable_Float32VectorData __pyx_t_6pandas_5_libs_9hashtable_Float32VectorData;
struct __pyx_t_6pandas_5_libs_9hashtable_Int32VectorData;
typedef struct __pyx_t_6pandas_5_libs_9hashtable_Int32VectorData __pyx_t_6pandas_5_libs_9hashtable_Int32VectorData;
struct __pyx_t_6pandas_5_libs_9hashtable_Int16VectorData;
typedef struct __pyx_t_6pandas_5_libs_9hashtable_Int16VectorData __pyx_t_6pandas_5_libs_9hashtable_Int16VectorData;
struct __pyx_t_6pandas_5_libs_9hashtable_Int8VectorData;
typedef struct __pyx_t_6pandas_5_libs_9hashtable_Int8VectorData __pyx_t_6pandas_5_libs_9hashtable_Int8VectorData;
struct __pyx_t_6pandas_5_libs_9hashtable_StringVectorData;
typedef struct __pyx_t_6pandas_5_libs_9hashtable_StringVectorData __pyx_t_6pandas_5_libs_9hashtable_StringVectorData;
struct __pyx_t_6pandas_5_libs_9hashtable_UInt64VectorData;
typedef struct __pyx_t_6pandas_5_libs_9hashtable_UInt64VectorData __pyx_t_6pandas_5_libs_9hashtable_UInt64VectorData;
struct __pyx_t_6pandas_5_libs_9hashtable_UInt32VectorData;
typedef struct __pyx_t_6pandas_5_libs_9hashtable_UInt32VectorData __pyx_t_6pandas_5_libs_9hashtable_UInt32VectorData;
struct __pyx_t_6pandas_5_libs_9hashtable_UInt16VectorData;
typedef struct __pyx_t_6pandas_5_libs_9hashtable_UInt16VectorData __pyx_t_6pandas_5_libs_9hashtable_UInt16VectorData;
struct __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData;
typedef struct __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_complex128;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_complex128;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_complex64;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_complex64;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_float64;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_float64;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_float32;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_float32;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_uint64;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_uint64;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_uint32;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_uint32;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_uint16;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_uint16;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_uint8;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_uint8;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_object;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_object;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_int64;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_int64;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_int32;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_int32;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_int16;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_int16;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_int8;
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_int8;
struct __pyx_fuse_0__pyx_opt_args_6pandas_5_libs_9hashtable_value_count;
struct __pyx_fuse_1__pyx_opt_args_6pandas_5_libs_9hashtable_value_count;
struct __pyx_fuse_2__pyx_opt_args_6pandas_5_libs_9hashtable_value_count;
struct __pyx_fuse_3__pyx_opt_args_6pandas_5_libs_9hashtable_value_count;
struct __pyx_fuse_4__pyx_opt_args_6pandas_5_libs_9hashtable_value_count;
struct __pyx_fuse_5__pyx_opt_args_6pandas_5_libs_9hashtable_value_count;
struct __pyx_fuse_6__pyx_opt_args_6pandas_5_libs_9hashtable_value_count;
struct __pyx_fuse_7__pyx_opt_args_6pandas_5_libs_9hashtable_value_count;
struct __pyx_fuse_8__pyx_opt_args_6pandas_5_libs_9hashtable_value_count;
struct __pyx_fuse_9__pyx_opt_args_6pandas_5_libs_9hashtable_value_count;
struct __pyx_fuse_10__pyx_opt_args_6pandas_5_libs_9hashtable_value_count;
struct __pyx_fuse_11__pyx_opt_args_6pandas_5_libs_9hashtable_value_count;
struct __pyx_fuse_12__pyx_opt_args_6pandas_5_libs_9hashtable_value_count;
struct __pyx_fuse_0__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated;
struct __pyx_fuse_1__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated;
struct __pyx_fuse_2__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated;
struct __pyx_fuse_3__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated;
struct __pyx_fuse_4__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated;
struct __pyx_fuse_5__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated;
struct __pyx_fuse_6__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated;
struct __pyx_fuse_7__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated;
struct __pyx_fuse_8__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated;
struct __pyx_fuse_9__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated;
struct __pyx_fuse_10__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated;
struct __pyx_fuse_11__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated;
struct __pyx_fuse_12__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated;
struct __pyx_defaults;
typedef struct __pyx_defaults __pyx_defaults;
struct __pyx_defaults1;
typedef struct __pyx_defaults1 __pyx_defaults1;
struct __pyx_defaults2;
typedef struct __pyx_defaults2 __pyx_defaults2;
struct __pyx_defaults3;
typedef struct __pyx_defaults3 __pyx_defaults3;
struct __pyx_defaults4;
typedef struct __pyx_defaults4 __pyx_defaults4;
struct __pyx_defaults5;
typedef struct __pyx_defaults5 __pyx_defaults5;
struct __pyx_defaults6;
typedef struct __pyx_defaults6 __pyx_defaults6;
struct __pyx_defaults7;
typedef struct __pyx_defaults7 __pyx_defaults7;
struct __pyx_defaults8;
typedef struct __pyx_defaults8 __pyx_defaults8;
struct __pyx_defaults9;
typedef struct __pyx_defaults9 __pyx_defaults9;
struct __pyx_defaults10;
typedef struct __pyx_defaults10 __pyx_defaults10;
struct __pyx_defaults11;
typedef struct __pyx_defaults11 __pyx_defaults11;
struct __pyx_defaults12;
typedef struct __pyx_defaults12 __pyx_defaults12;
struct __pyx_defaults13;
typedef struct __pyx_defaults13 __pyx_defaults13;
struct __pyx_defaults14;
typedef struct __pyx_defaults14 __pyx_defaults14;
struct __pyx_defaults15;
typedef struct __pyx_defaults15 __pyx_defaults15;
struct __pyx_defaults16;
typedef struct __pyx_defaults16 __pyx_defaults16;
struct __pyx_defaults17;
typedef struct __pyx_defaults17 __pyx_defaults17;
struct __pyx_defaults18;
typedef struct __pyx_defaults18 __pyx_defaults18;
struct __pyx_defaults19;
typedef struct __pyx_defaults19 __pyx_defaults19;
struct __pyx_defaults20;
typedef struct __pyx_defaults20 __pyx_defaults20;
struct __pyx_defaults21;
typedef struct __pyx_defaults21 __pyx_defaults21;
struct __pyx_defaults22;
typedef struct __pyx_defaults22 __pyx_defaults22;
struct __pyx_defaults23;
typedef struct __pyx_defaults23 __pyx_defaults23;
struct __pyx_defaults24;
typedef struct __pyx_defaults24 __pyx_defaults24;
struct __pyx_defaults25;
typedef struct __pyx_defaults25 __pyx_defaults25;
struct __pyx_defaults26;
typedef struct __pyx_defaults26 __pyx_defaults26;
struct __pyx_defaults27;
typedef struct __pyx_defaults27 __pyx_defaults27;
struct __pyx_defaults28;
typedef struct __pyx_defaults28 __pyx_defaults28;
struct __pyx_defaults29;
typedef struct __pyx_defaults29 __pyx_defaults29;

/* "pandas/_libs/hashtable.pxd":175
 *     cpdef set_item(self, str key, Py_ssize_t val)
 * 
 * cdef struct Int64VectorData:             # <<<<<<<<<<<<<<
 *     int64_t *data
 *     Py_ssize_t n, m
 */
struct __pyx_t_6pandas_5_libs_9hashtable_Int64VectorData {
  __pyx_t_5numpy_int64_t *data;
  Py_ssize_t n;
  Py_ssize_t m;
};

/* "pandas/_libs/hashtable_class_helper.pxi":204
 * #  by IntervalTree
 * 
 * ctypedef struct Complex128VectorData:             # <<<<<<<<<<<<<<
 *     khcomplex128_t *data
 *     Py_ssize_t n, m
 */
struct __pyx_t_6pandas_5_libs_9hashtable_Complex128VectorData {
  khcomplex128_t *data;
  Py_ssize_t n;
  Py_ssize_t m;
};

/* "pandas/_libs/hashtable_class_helper.pxi":219
 * #  by IntervalTree
 * 
 * ctypedef struct Complex64VectorData:             # <<<<<<<<<<<<<<
 *     khcomplex64_t *data
 *     Py_ssize_t n, m
 */
struct __pyx_t_6pandas_5_libs_9hashtable_Complex64VectorData {
  khcomplex64_t *data;
  Py_ssize_t n;
  Py_ssize_t m;
};

/* "pandas/_libs/hashtable_class_helper.pxi":234
 * #  by IntervalTree
 * 
 * ctypedef struct Float64VectorData:             # <<<<<<<<<<<<<<
 *     float64_t *data
 *     Py_ssize_t n, m
 */
struct __pyx_t_6pandas_5_libs_9hashtable_Float64VectorData {
  __pyx_t_5numpy_float64_t *data;
  Py_ssize_t n;
  Py_ssize_t m;
};

/* "pandas/_libs/hashtable_class_helper.pxi":249
 * #  by IntervalTree
 * 
 * ctypedef struct Float32VectorData:             # <<<<<<<<<<<<<<
 *     float32_t *data
 *     Py_ssize_t n, m
 */
struct __pyx_t_6pandas_5_libs_9hashtable_Float32VectorData {
  __pyx_t_5numpy_float32_t *data;
  Py_ssize_t n;
  Py_ssize_t m;
};

/* "pandas/_libs/hashtable_class_helper.pxi":273
 * #  by IntervalTree
 * 
 * ctypedef struct Int32VectorData:             # <<<<<<<<<<<<<<
 *     int32_t *data
 *     Py_ssize_t n, m
 */
struct __pyx_t_6pandas_5_libs_9hashtable_Int32VectorData {
  __pyx_t_5numpy_int32_t *data;
  Py_ssize_t n;
  Py_ssize_t m;
};

/* "pandas/_libs/hashtable_class_helper.pxi":288
 * #  by IntervalTree
 * 
 * ctypedef struct Int16VectorData:             # <<<<<<<<<<<<<<
 *     int16_t *data
 *     Py_ssize_t n, m
 */
struct __pyx_t_6pandas_5_libs_9hashtable_Int16VectorData {
  __pyx_t_5numpy_int16_t *data;
  Py_ssize_t n;
  Py_ssize_t m;
};

/* "pandas/_libs/hashtable_class_helper.pxi":303
 * #  by IntervalTree
 * 
 * ctypedef struct Int8VectorData:             # <<<<<<<<<<<<<<
 *     int8_t *data
 *     Py_ssize_t n, m
 */
struct __pyx_t_6pandas_5_libs_9hashtable_Int8VectorData {
  __pyx_t_5numpy_int8_t *data;
  Py_ssize_t n;
  Py_ssize_t m;
};

/* "pandas/_libs/hashtable_class_helper.pxi":318
 * #  by IntervalTree
 * 
 * ctypedef struct StringVectorData:             # <<<<<<<<<<<<<<
 *     char * *data
 *     Py_ssize_t n, m
 */
struct __pyx_t_6pandas_5_libs_9hashtable_StringVectorData {
  char **data;
  Py_ssize_t n;
  Py_ssize_t m;
};

/* "pandas/_libs/hashtable_class_helper.pxi":333
 * #  by IntervalTree
 * 
 * ctypedef struct UInt64VectorData:             # <<<<<<<<<<<<<<
 *     uint64_t *data
 *     Py_ssize_t n, m
 */
struct __pyx_t_6pandas_5_libs_9hashtable_UInt64VectorData {
  __pyx_t_5numpy_uint64_t *data;
  Py_ssize_t n;
  Py_ssize_t m;
};

/* "pandas/_libs/hashtable_class_helper.pxi":348
 * #  by IntervalTree
 * 
 * ctypedef struct UInt32VectorData:             # <<<<<<<<<<<<<<
 *     uint32_t *data
 *     Py_ssize_t n, m
 */
struct __pyx_t_6pandas_5_libs_9hashtable_UInt32VectorData {
  __pyx_t_5numpy_uint32_t *data;
  Py_ssize_t n;
  Py_ssize_t m;
};

/* "pandas/_libs/hashtable_class_helper.pxi":363
 * #  by IntervalTree
 * 
 * ctypedef struct UInt16VectorData:             # <<<<<<<<<<<<<<
 *     uint16_t *data
 *     Py_ssize_t n, m
 */
struct __pyx_t_6pandas_5_libs_9hashtable_UInt16VectorData {
  __pyx_t_5numpy_uint16_t *data;
  Py_ssize_t n;
  Py_ssize_t m;
};

/* "pandas/_libs/hashtable_class_helper.pxi":378
 * #  by IntervalTree
 * 
 * ctypedef struct UInt8VectorData:             # <<<<<<<<<<<<<<
 *     uint8_t *data
 *     Py_ssize_t n, m
 */
struct __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData {
  __pyx_t_5numpy_uint8_t *data;
  Py_ssize_t n;
  Py_ssize_t m;
};

/* "pandas/_libs/hashtable_func_helper.pxi":10
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_complex128(const complex128_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_complex128 {
  int __pyx_n;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":71
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_complex128(const complex128_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_complex128 {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":204
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_complex64(const complex64_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_complex64 {
  int __pyx_n;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":265
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_complex64(const complex64_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_complex64 {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":398
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_float64(const float64_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_float64 {
  int __pyx_n;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":459
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_float64(const float64_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_float64 {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":592
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_float32(const float32_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_float32 {
  int __pyx_n;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":653
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_float32(const float32_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_float32 {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":786
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_uint64(const uint64_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_uint64 {
  int __pyx_n;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":847
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_uint64(const uint64_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_uint64 {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":980
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_uint32(const uint32_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_uint32 {
  int __pyx_n;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":1041
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_uint32(const uint32_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_uint32 {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":1174
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_uint16(const uint16_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_uint16 {
  int __pyx_n;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":1235
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_uint16(const uint16_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_uint16 {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":1368
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_uint8(const uint8_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_uint8 {
  int __pyx_n;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":1429
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_uint8(const uint8_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_uint8 {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":1562
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_object(ndarray[object] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_object {
  int __pyx_n;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":1619
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_object(ndarray[object] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_object {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":1752
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_int64(const int64_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_int64 {
  int __pyx_n;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":1813
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_int64(const int64_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_int64 {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":1946
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_int32(const int32_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_int32 {
  int __pyx_n;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":2007
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_int32(const int32_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_int32 {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":2140
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_int16(const int16_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_int16 {
  int __pyx_n;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":2201
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_int16(const int16_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_int16 {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":2334
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_int8(const int8_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_int8 {
  int __pyx_n;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":2395
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_int8(const int8_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_int8 {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":2532
 * 
 * 
 * cpdef value_count(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return value_count_object(values, dropna, mask=mask)
 */
struct __pyx_fuse_0__pyx_opt_args_6pandas_5_libs_9hashtable_value_count {
  int __pyx_n;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_1__pyx_opt_args_6pandas_5_libs_9hashtable_value_count {
  int __pyx_n;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_2__pyx_opt_args_6pandas_5_libs_9hashtable_value_count {
  int __pyx_n;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_3__pyx_opt_args_6pandas_5_libs_9hashtable_value_count {
  int __pyx_n;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_4__pyx_opt_args_6pandas_5_libs_9hashtable_value_count {
  int __pyx_n;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_5__pyx_opt_args_6pandas_5_libs_9hashtable_value_count {
  int __pyx_n;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_6__pyx_opt_args_6pandas_5_libs_9hashtable_value_count {
  int __pyx_n;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_7__pyx_opt_args_6pandas_5_libs_9hashtable_value_count {
  int __pyx_n;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_8__pyx_opt_args_6pandas_5_libs_9hashtable_value_count {
  int __pyx_n;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_9__pyx_opt_args_6pandas_5_libs_9hashtable_value_count {
  int __pyx_n;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_10__pyx_opt_args_6pandas_5_libs_9hashtable_value_count {
  int __pyx_n;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_11__pyx_opt_args_6pandas_5_libs_9hashtable_value_count {
  int __pyx_n;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_12__pyx_opt_args_6pandas_5_libs_9hashtable_value_count {
  int __pyx_n;
  __Pyx_memviewslice mask;
};

/* "pandas/_libs/hashtable_func_helper.pxi":2568
 * 
 * 
 * cpdef duplicated(ndarray[htfunc_t] values, object keep="first", const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return duplicated_object(values, keep, mask=mask)
 */
struct __pyx_fuse_0__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_1__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_2__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_3__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_4__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_5__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_6__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_7__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_8__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_9__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_10__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_11__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};
struct __pyx_fuse_12__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated {
  int __pyx_n;
  PyObject *keep;
  __Pyx_memviewslice mask;
};
struct __pyx_defaults {
  PyObject *__pyx_arg__fused_sigindex;
};
struct __pyx_defaults1 {
  PyObject *__pyx_arg__fused_sigindex;
};
struct __pyx_defaults2 {
  PyObject *__pyx_arg__fused_sigindex;
};
struct __pyx_defaults3 {
  PyObject *__pyx_arg__fused_sigindex;
};
struct __pyx_defaults4 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults5 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults6 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults7 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults8 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults9 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults10 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults11 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults12 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults13 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults14 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults15 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults16 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults17 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults18 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults19 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults20 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults21 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults22 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults23 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults24 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults25 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults26 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults27 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults28 {
  __Pyx_memviewslice __pyx_arg_mask;
};
struct __pyx_defaults29 {
  __Pyx_memviewslice __pyx_arg_mask;
};

/* "pandas/_libs/missing.pxd":17
 * cdef bint checknull_with_nat_and_na(object obj)
 * 
 * cdef class C_NAType:             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct __pyx_obj_6pandas_5_libs_7missing_C_NAType {
  PyObject_HEAD
};


/* "pandas/_libs/hashtable.pxd":39
 * # prototypes for sharing
 * 
 * cdef class HashTable:             # <<<<<<<<<<<<<<
 *     pass
 * 
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable {
  PyObject_HEAD
};


/* "pandas/_libs/hashtable.pxd":42
 *     pass
 * 
 * cdef class UInt64HashTable(HashTable):             # <<<<<<<<<<<<<<
 *     cdef kh_uint64_t *table
 *     cdef int64_t na_position
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable {
  struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_vtab;
  kh_uint64_t *table;
  __pyx_t_5numpy_int64_t na_position;
  int uses_mask;
};


/* "pandas/_libs/hashtable.pxd":52
 *     cpdef set_na(self, Py_ssize_t val)
 * 
 * cdef class Int64HashTable(HashTable):             # <<<<<<<<<<<<<<
 *     cdef kh_int64_t *table
 *     cdef int64_t na_position
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable {
  struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_vtab;
  kh_int64_t *table;
  __pyx_t_5numpy_int64_t na_position;
  int uses_mask;
};


/* "pandas/_libs/hashtable.pxd":62
 *     cpdef set_na(self, Py_ssize_t val)
 * 
 * cdef class UInt32HashTable(HashTable):             # <<<<<<<<<<<<<<
 *     cdef kh_uint32_t *table
 *     cdef int64_t na_position
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable {
  struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_vtab;
  kh_uint32_t *table;
  __pyx_t_5numpy_int64_t na_position;
  int uses_mask;
};


/* "pandas/_libs/hashtable.pxd":72
 *     cpdef set_na(self, Py_ssize_t val)
 * 
 * cdef class Int32HashTable(HashTable):             # <<<<<<<<<<<<<<
 *     cdef kh_int32_t *table
 *     cdef int64_t na_position
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable {
  struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_vtab;
  kh_int32_t *table;
  __pyx_t_5numpy_int64_t na_position;
  int uses_mask;
};


/* "pandas/_libs/hashtable.pxd":82
 *     cpdef set_na(self, Py_ssize_t val)
 * 
 * cdef class UInt16HashTable(HashTable):             # <<<<<<<<<<<<<<
 *     cdef kh_uint16_t *table
 *     cdef int64_t na_position
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable {
  struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_vtab;
  kh_uint16_t *table;
  __pyx_t_5numpy_int64_t na_position;
  int uses_mask;
};


/* "pandas/_libs/hashtable.pxd":92
 *     cpdef set_na(self, Py_ssize_t val)
 * 
 * cdef class Int16HashTable(HashTable):             # <<<<<<<<<<<<<<
 *     cdef kh_int16_t *table
 *     cdef int64_t na_position
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable {
  struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_vtab;
  kh_int16_t *table;
  __pyx_t_5numpy_int64_t na_position;
  int uses_mask;
};


/* "pandas/_libs/hashtable.pxd":102
 *     cpdef set_na(self, Py_ssize_t val)
 * 
 * cdef class UInt8HashTable(HashTable):             # <<<<<<<<<<<<<<
 *     cdef kh_uint8_t *table
 *     cdef int64_t na_position
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable {
  struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_vtab;
  kh_uint8_t *table;
  __pyx_t_5numpy_int64_t na_position;
  int uses_mask;
};


/* "pandas/_libs/hashtable.pxd":112
 *     cpdef set_na(self, Py_ssize_t val)
 * 
 * cdef class Int8HashTable(HashTable):             # <<<<<<<<<<<<<<
 *     cdef kh_int8_t *table
 *     cdef int64_t na_position
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable {
  struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_vtab;
  kh_int8_t *table;
  __pyx_t_5numpy_int64_t na_position;
  int uses_mask;
};


/* "pandas/_libs/hashtable.pxd":122
 *     cpdef set_na(self, Py_ssize_t val)
 * 
 * cdef class Float64HashTable(HashTable):             # <<<<<<<<<<<<<<
 *     cdef kh_float64_t *table
 *     cdef int64_t na_position
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable {
  struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_vtab;
  kh_float64_t *table;
  __pyx_t_5numpy_int64_t na_position;
  int uses_mask;
};


/* "pandas/_libs/hashtable.pxd":132
 *     cpdef set_na(self, Py_ssize_t val)
 * 
 * cdef class Float32HashTable(HashTable):             # <<<<<<<<<<<<<<
 *     cdef kh_float32_t *table
 *     cdef int64_t na_position
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable {
  struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_vtab;
  kh_float32_t *table;
  __pyx_t_5numpy_int64_t na_position;
  int uses_mask;
};


/* "pandas/_libs/hashtable.pxd":142
 *     cpdef set_na(self, Py_ssize_t val)
 * 
 * cdef class Complex64HashTable(HashTable):             # <<<<<<<<<<<<<<
 *     cdef kh_complex64_t *table
 *     cdef int64_t na_position
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable {
  struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_vtab;
  kh_complex64_t *table;
  __pyx_t_5numpy_int64_t na_position;
  int uses_mask;
};


/* "pandas/_libs/hashtable.pxd":152
 *     cpdef set_na(self, Py_ssize_t val)
 * 
 * cdef class Complex128HashTable(HashTable):             # <<<<<<<<<<<<<<
 *     cdef kh_complex128_t *table
 *     cdef int64_t na_position
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable {
  struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_vtab;
  kh_complex128_t *table;
  __pyx_t_5numpy_int64_t na_position;
  int uses_mask;
};


/* "pandas/_libs/hashtable.pxd":162
 *     cpdef set_na(self, Py_ssize_t val)
 * 
 * cdef class PyObjectHashTable(HashTable):             # <<<<<<<<<<<<<<
 *     cdef kh_pymap_t *table
 * 
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable {
  struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_vtab;
  kh_pymap_t *table;
};


/* "pandas/_libs/hashtable.pxd":169
 * 
 * 
 * cdef class StringHashTable(HashTable):             # <<<<<<<<<<<<<<
 *     cdef kh_str_t *table
 * 
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable {
  struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_StringHashTable *__pyx_vtab;
  kh_str_t *table;
};


/* "pandas/_libs/hashtable.pxd":179
 *     Py_ssize_t n, m
 * 
 * cdef class Vector:             # <<<<<<<<<<<<<<
 *     cdef bint external_view_exists
 * 
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Vector {
  PyObject_HEAD
  int external_view_exists;
};


/* "pandas/_libs/hashtable.pxd":182
 *     cdef bint external_view_exists
 * 
 * cdef class Int64Vector(Vector):             # <<<<<<<<<<<<<<
 *     cdef Int64VectorData *data
 *     cdef ndarray ao
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Vector __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int64Vector *__pyx_vtab;
  struct __pyx_t_6pandas_5_libs_9hashtable_Int64VectorData *data;
  PyArrayObject *ao;
};


/* "pandas/_libs/hashtable_class_helper.pxi":421
 * 
 * 
 * cdef class Complex128Vector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     # For int64 we have to put this declaration in the .pxd file;
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Vector __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_vtab;
  __pyx_t_6pandas_5_libs_9hashtable_Complex128VectorData *data;
  PyArrayObject *ao;
};


/* "pandas/_libs/hashtable_class_helper.pxi":476
 *             self.append(x[i])
 * 
 * cdef class Complex64Vector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     # For int64 we have to put this declaration in the .pxd file;
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Vector __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_vtab;
  __pyx_t_6pandas_5_libs_9hashtable_Complex64VectorData *data;
  PyArrayObject *ao;
};


/* "pandas/_libs/hashtable_class_helper.pxi":531
 *             self.append(x[i])
 * 
 * cdef class Float64Vector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     # For int64 we have to put this declaration in the .pxd file;
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Vector __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float64Vector *__pyx_vtab;
  __pyx_t_6pandas_5_libs_9hashtable_Float64VectorData *data;
  PyArrayObject *ao;
};


/* "pandas/_libs/hashtable_class_helper.pxi":586
 *             self.append(x[i])
 * 
 * cdef class UInt64Vector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     # For int64 we have to put this declaration in the .pxd file;
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Vector __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_vtab;
  __pyx_t_6pandas_5_libs_9hashtable_UInt64VectorData *data;
  PyArrayObject *ao;
};


/* "pandas/_libs/hashtable_class_helper.pxi":693
 *             self.append(x[i])
 * 
 * cdef class Float32Vector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     # For int64 we have to put this declaration in the .pxd file;
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Vector __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float32Vector *__pyx_vtab;
  __pyx_t_6pandas_5_libs_9hashtable_Float32VectorData *data;
  PyArrayObject *ao;
};


/* "pandas/_libs/hashtable_class_helper.pxi":748
 *             self.append(x[i])
 * 
 * cdef class UInt32Vector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     # For int64 we have to put this declaration in the .pxd file;
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Vector __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_vtab;
  __pyx_t_6pandas_5_libs_9hashtable_UInt32VectorData *data;
  PyArrayObject *ao;
};


/* "pandas/_libs/hashtable_class_helper.pxi":803
 *             self.append(x[i])
 * 
 * cdef class Int32Vector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     # For int64 we have to put this declaration in the .pxd file;
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Vector __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int32Vector *__pyx_vtab;
  __pyx_t_6pandas_5_libs_9hashtable_Int32VectorData *data;
  PyArrayObject *ao;
};


/* "pandas/_libs/hashtable_class_helper.pxi":858
 *             self.append(x[i])
 * 
 * cdef class UInt16Vector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     # For int64 we have to put this declaration in the .pxd file;
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Vector __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_vtab;
  __pyx_t_6pandas_5_libs_9hashtable_UInt16VectorData *data;
  PyArrayObject *ao;
};


/* "pandas/_libs/hashtable_class_helper.pxi":913
 *             self.append(x[i])
 * 
 * cdef class Int16Vector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     # For int64 we have to put this declaration in the .pxd file;
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Vector __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int16Vector *__pyx_vtab;
  __pyx_t_6pandas_5_libs_9hashtable_Int16VectorData *data;
  PyArrayObject *ao;
};


/* "pandas/_libs/hashtable_class_helper.pxi":968
 *             self.append(x[i])
 * 
 * cdef class UInt8Vector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     # For int64 we have to put this declaration in the .pxd file;
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Vector __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_vtab;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *data;
  PyArrayObject *ao;
};


/* "pandas/_libs/hashtable_class_helper.pxi":1023
 *             self.append(x[i])
 * 
 * cdef class Int8Vector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     # For int64 we have to put this declaration in the .pxd file;
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Vector __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int8Vector *__pyx_vtab;
  __pyx_t_6pandas_5_libs_9hashtable_Int8VectorData *data;
  PyArrayObject *ao;
};


/* "pandas/_libs/hashtable_class_helper.pxi":1078
 *             self.append(x[i])
 * 
 * cdef class StringVector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     cdef:
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Vector __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_StringVector *__pyx_vtab;
  __pyx_t_6pandas_5_libs_9hashtable_StringVectorData *data;
};


/* "pandas/_libs/hashtable_class_helper.pxi":1144
 * 
 * 
 * cdef class ObjectVector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     cdef:
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Vector __pyx_base;
  struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_ObjectVector *__pyx_vtab;
  PyObject **data;
  Py_ssize_t n;
  Py_ssize_t m;
  PyArrayObject *ao;
};


/* "pandas/_libs/hashtable.pyx":72
 * 
 * 
 * cdef class Factorizer:             # <<<<<<<<<<<<<<
 *     cdef readonly:
 *         Py_ssize_t count
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer {
  PyObject_HEAD
  Py_ssize_t count;
};


/* "pandas/_libs/hashtable_class_helper.pxi":1612
 * 
 * 
 * cdef class Complex128Factorizer(Factorizer):             # <<<<<<<<<<<<<<
 *     cdef public:
 *         Complex128HashTable table
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer __pyx_base;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *table;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *uniques;
};


/* "pandas/_libs/hashtable_class_helper.pxi":2066
 * 
 * 
 * cdef class Float64Factorizer(Factorizer):             # <<<<<<<<<<<<<<
 *     cdef public:
 *         Float64HashTable table
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer __pyx_base;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *table;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *uniques;
};


/* "pandas/_libs/hashtable_class_helper.pxi":2520
 * 
 * 
 * cdef class UInt64Factorizer(Factorizer):             # <<<<<<<<<<<<<<
 *     cdef public:
 *         UInt64HashTable table
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer __pyx_base;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *table;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *uniques;
};


/* "pandas/_libs/hashtable_class_helper.pxi":3036
 * 
 * 
 * cdef class Int64Factorizer(Factorizer):             # <<<<<<<<<<<<<<
 *     cdef public:
 *         Int64HashTable table
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer __pyx_base;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *table;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *uniques;
};


/* "pandas/_libs/hashtable_class_helper.pxi":3490
 * 
 * 
 * cdef class Complex64Factorizer(Factorizer):             # <<<<<<<<<<<<<<
 *     cdef public:
 *         Complex64HashTable table
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer __pyx_base;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *table;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *uniques;
};


/* "pandas/_libs/hashtable_class_helper.pxi":3944
 * 
 * 
 * cdef class Float32Factorizer(Factorizer):             # <<<<<<<<<<<<<<
 *     cdef public:
 *         Float32HashTable table
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer __pyx_base;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *table;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *uniques;
};


/* "pandas/_libs/hashtable_class_helper.pxi":4398
 * 
 * 
 * cdef class UInt32Factorizer(Factorizer):             # <<<<<<<<<<<<<<
 *     cdef public:
 *         UInt32HashTable table
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer __pyx_base;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *table;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *uniques;
};


/* "pandas/_libs/hashtable_class_helper.pxi":4852
 * 
 * 
 * cdef class Int32Factorizer(Factorizer):             # <<<<<<<<<<<<<<
 *     cdef public:
 *         Int32HashTable table
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer __pyx_base;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *table;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *uniques;
};


/* "pandas/_libs/hashtable_class_helper.pxi":5306
 * 
 * 
 * cdef class UInt16Factorizer(Factorizer):             # <<<<<<<<<<<<<<
 *     cdef public:
 *         UInt16HashTable table
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer __pyx_base;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *table;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *uniques;
};


/* "pandas/_libs/hashtable_class_helper.pxi":5760
 * 
 * 
 * cdef class Int16Factorizer(Factorizer):             # <<<<<<<<<<<<<<
 *     cdef public:
 *         Int16HashTable table
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer __pyx_base;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *table;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *uniques;
};


/* "pandas/_libs/hashtable_class_helper.pxi":6214
 * 
 * 
 * cdef class UInt8Factorizer(Factorizer):             # <<<<<<<<<<<<<<
 *     cdef public:
 *         UInt8HashTable table
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer __pyx_base;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *table;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *uniques;
};


/* "pandas/_libs/hashtable_class_helper.pxi":6668
 * 
 * 
 * cdef class Int8Factorizer(Factorizer):             # <<<<<<<<<<<<<<
 *     cdef public:
 *         Int8HashTable table
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer __pyx_base;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *table;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *uniques;
};


/* "pandas/_libs/hashtable.pyx":86
 * 
 * 
 * cdef class ObjectFactorizer(Factorizer):             # <<<<<<<<<<<<<<
 *     cdef public:
 *         PyObjectHashTable table
 */
struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer __pyx_base;
  struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *table;
  struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *uniques;
};


/* "View.MemoryView":114
 * @cython.collection_type("sequence")
 * @cname("__pyx_array")
 * cdef class array:             # <<<<<<<<<<<<<<
 * 
 *     cdef:
 */
struct __pyx_array_obj {
  PyObject_HEAD
  struct __pyx_vtabstruct_array *__pyx_vtab;
  char *data;
  Py_ssize_t len;
  char *format;
  int ndim;
  Py_ssize_t *_shape;
  Py_ssize_t *_strides;
  Py_ssize_t itemsize;
  PyObject *mode;
  PyObject *_format;
  void (*callback_free_data)(void *);
  int free_data;
  int dtype_is_object;
};


/* "View.MemoryView":302
 * 
 * @cname('__pyx_MemviewEnum')
 * cdef class Enum(object):             # <<<<<<<<<<<<<<
 *     cdef object name
 *     def __init__(self, name):
 */
struct __pyx_MemviewEnum_obj {
  PyObject_HEAD
  PyObject *name;
};


/* "View.MemoryView":337
 * 
 * @cname('__pyx_memoryview')
 * cdef class memoryview:             # <<<<<<<<<<<<<<
 * 
 *     cdef object obj
 */
struct __pyx_memoryview_obj {
  PyObject_HEAD
  struct __pyx_vtabstruct_memoryview *__pyx_vtab;
  PyObject *obj;
  PyObject *_size;
  PyObject *_array_interface;
  PyThread_type_lock lock;
  __pyx_atomic_int_type acquisition_count;
  Py_buffer view;
  int flags;
  int dtype_is_object;
  __Pyx_TypeInfo *typeinfo;
};


/* "View.MemoryView":952
 * @cython.collection_type("sequence")
 * @cname('__pyx_memoryviewslice')
 * cdef class _memoryviewslice(memoryview):             # <<<<<<<<<<<<<<
 *     "Internal class for passing memoryview slices to Python"
 * 
 */
struct __pyx_memoryviewslice_obj {
  struct __pyx_memoryview_obj __pyx_base;
  __Pyx_memviewslice from_slice;
  PyObject *from_object;
  PyObject *(*to_object_func)(char *);
  int (*to_dtype_func)(char *, PyObject *);
};



/* "pandas/_libs/hashtable_class_helper.pxi":2103
 *         return labels
 * 
 * cdef class UInt64HashTable(HashTable):             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt64HashTable {
  PyObject *(*get_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *, __pyx_t_5numpy_uint64_t, int __pyx_skip_dispatch);
  PyObject *(*set_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *, __pyx_t_5numpy_uint64_t, Py_ssize_t, int __pyx_skip_dispatch);
  PyObject *(*get_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *, int __pyx_skip_dispatch);
  PyObject *(*set_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *, Py_ssize_t, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_vtabptr_6pandas_5_libs_9hashtable_UInt64HashTable;


/* "pandas/_libs/hashtable_class_helper.pxi":2557
 *         return labels
 * 
 * cdef class Int64HashTable(HashTable):             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int64HashTable {
  PyObject *(*get_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *, __pyx_t_5numpy_int64_t, int __pyx_skip_dispatch);
  PyObject *(*set_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *, __pyx_t_5numpy_int64_t, Py_ssize_t, int __pyx_skip_dispatch);
  PyObject *(*get_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *, int __pyx_skip_dispatch);
  PyObject *(*set_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *, Py_ssize_t, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_vtabptr_6pandas_5_libs_9hashtable_Int64HashTable;


/* "pandas/_libs/hashtable_class_helper.pxi":3981
 *         return labels
 * 
 * cdef class UInt32HashTable(HashTable):             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt32HashTable {
  PyObject *(*get_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *, __pyx_t_5numpy_uint32_t, int __pyx_skip_dispatch);
  PyObject *(*set_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *, __pyx_t_5numpy_uint32_t, Py_ssize_t, int __pyx_skip_dispatch);
  PyObject *(*get_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *, int __pyx_skip_dispatch);
  PyObject *(*set_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *, Py_ssize_t, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_vtabptr_6pandas_5_libs_9hashtable_UInt32HashTable;


/* "pandas/_libs/hashtable_class_helper.pxi":4435
 *         return labels
 * 
 * cdef class Int32HashTable(HashTable):             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int32HashTable {
  PyObject *(*get_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *, __pyx_t_5numpy_int32_t, int __pyx_skip_dispatch);
  PyObject *(*set_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *, __pyx_t_5numpy_int32_t, Py_ssize_t, int __pyx_skip_dispatch);
  PyObject *(*get_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *, int __pyx_skip_dispatch);
  PyObject *(*set_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *, Py_ssize_t, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_vtabptr_6pandas_5_libs_9hashtable_Int32HashTable;


/* "pandas/_libs/hashtable_class_helper.pxi":4889
 *         return labels
 * 
 * cdef class UInt16HashTable(HashTable):             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt16HashTable {
  PyObject *(*get_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *, __pyx_t_5numpy_uint16_t, int __pyx_skip_dispatch);
  PyObject *(*set_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *, __pyx_t_5numpy_uint16_t, Py_ssize_t, int __pyx_skip_dispatch);
  PyObject *(*get_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *, int __pyx_skip_dispatch);
  PyObject *(*set_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *, Py_ssize_t, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_vtabptr_6pandas_5_libs_9hashtable_UInt16HashTable;


/* "pandas/_libs/hashtable_class_helper.pxi":5343
 *         return labels
 * 
 * cdef class Int16HashTable(HashTable):             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int16HashTable {
  PyObject *(*get_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *, __pyx_t_5numpy_int16_t, int __pyx_skip_dispatch);
  PyObject *(*set_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *, __pyx_t_5numpy_int16_t, Py_ssize_t, int __pyx_skip_dispatch);
  PyObject *(*get_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *, int __pyx_skip_dispatch);
  PyObject *(*set_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *, Py_ssize_t, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_vtabptr_6pandas_5_libs_9hashtable_Int16HashTable;


/* "pandas/_libs/hashtable_class_helper.pxi":5797
 *         return labels
 * 
 * cdef class UInt8HashTable(HashTable):             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8HashTable {
  PyObject *(*get_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *, __pyx_t_5numpy_uint8_t, int __pyx_skip_dispatch);
  PyObject *(*set_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *, __pyx_t_5numpy_uint8_t, Py_ssize_t, int __pyx_skip_dispatch);
  PyObject *(*get_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *, int __pyx_skip_dispatch);
  PyObject *(*set_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *, Py_ssize_t, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_vtabptr_6pandas_5_libs_9hashtable_UInt8HashTable;


/* "pandas/_libs/hashtable_class_helper.pxi":6251
 *         return labels
 * 
 * cdef class Int8HashTable(HashTable):             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int8HashTable {
  PyObject *(*get_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *, __pyx_t_5numpy_int8_t, int __pyx_skip_dispatch);
  PyObject *(*set_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *, __pyx_t_5numpy_int8_t, Py_ssize_t, int __pyx_skip_dispatch);
  PyObject *(*get_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *, int __pyx_skip_dispatch);
  PyObject *(*set_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *, Py_ssize_t, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_vtabptr_6pandas_5_libs_9hashtable_Int8HashTable;


/* "pandas/_libs/hashtable_class_helper.pxi":1649
 *         return labels
 * 
 * cdef class Float64HashTable(HashTable):             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float64HashTable {
  PyObject *(*get_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *, __pyx_t_5numpy_float64_t, int __pyx_skip_dispatch);
  PyObject *(*set_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *, __pyx_t_5numpy_float64_t, Py_ssize_t, int __pyx_skip_dispatch);
  PyObject *(*get_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *, int __pyx_skip_dispatch);
  PyObject *(*set_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *, Py_ssize_t, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_vtabptr_6pandas_5_libs_9hashtable_Float64HashTable;


/* "pandas/_libs/hashtable_class_helper.pxi":3527
 *         return labels
 * 
 * cdef class Float32HashTable(HashTable):             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float32HashTable {
  PyObject *(*get_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *, __pyx_t_5numpy_float32_t, int __pyx_skip_dispatch);
  PyObject *(*set_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *, __pyx_t_5numpy_float32_t, Py_ssize_t, int __pyx_skip_dispatch);
  PyObject *(*get_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *, int __pyx_skip_dispatch);
  PyObject *(*set_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *, Py_ssize_t, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_vtabptr_6pandas_5_libs_9hashtable_Float32HashTable;


/* "pandas/_libs/hashtable_class_helper.pxi":3073
 *         return labels
 * 
 * cdef class Complex64HashTable(HashTable):             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex64HashTable {
  PyObject *(*get_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *, __pyx_t_float_complex, int __pyx_skip_dispatch);
  PyObject *(*set_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *, __pyx_t_float_complex, Py_ssize_t, int __pyx_skip_dispatch);
  PyObject *(*get_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *, int __pyx_skip_dispatch);
  PyObject *(*set_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *, Py_ssize_t, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_vtabptr_6pandas_5_libs_9hashtable_Complex64HashTable;


/* "pandas/_libs/hashtable_class_helper.pxi":1195
 *     pass
 * 
 * cdef class Complex128HashTable(HashTable):             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex128HashTable {
  PyObject *(*get_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *, __pyx_t_double_complex, int __pyx_skip_dispatch);
  PyObject *(*set_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *, __pyx_t_double_complex, Py_ssize_t, int __pyx_skip_dispatch);
  PyObject *(*get_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *, int __pyx_skip_dispatch);
  PyObject *(*set_na)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *, Py_ssize_t, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_vtabptr_6pandas_5_libs_9hashtable_Complex128HashTable;


/* "pandas/_libs/hashtable_class_helper.pxi":7037
 * 
 * 
 * cdef class PyObjectHashTable(HashTable):             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, int64_t size_hint=1):
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_PyObjectHashTable {
  PyObject *(*get_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*set_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *, PyObject *, Py_ssize_t, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_vtabptr_6pandas_5_libs_9hashtable_PyObjectHashTable;


/* "pandas/_libs/hashtable_class_helper.pxi":6706
 * 
 * 
 * cdef class StringHashTable(HashTable):             # <<<<<<<<<<<<<<
 *     # these by-definition *must* be strings
 *     # or a sentinel np.nan / None missing value
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_StringHashTable {
  PyObject *(*get_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*set_item)(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *, PyObject *, Py_ssize_t, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_StringHashTable *__pyx_vtabptr_6pandas_5_libs_9hashtable_StringHashTable;


/* "pandas/_libs/hashtable_class_helper.pxi":641
 *             self.append(x[i])
 * 
 * cdef class Int64Vector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     # For int64 we have to put this declaration in the .pxd file;
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int64Vector {
  PyObject *(*resize)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *);
  PyArrayObject *(*to_array)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *, int __pyx_skip_dispatch);
  void (*append)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *, __pyx_t_5numpy_int64_t);
  PyObject *(*extend)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *, __Pyx_memviewslice);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int64Vector *__pyx_vtabptr_6pandas_5_libs_9hashtable_Int64Vector;


/* "pandas/_libs/hashtable_class_helper.pxi":421
 * 
 * 
 * cdef class Complex128Vector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     # For int64 we have to put this declaration in the .pxd file;
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex128Vector {
  PyObject *(*resize)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *);
  PyArrayObject *(*to_array)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *, int __pyx_skip_dispatch);
  void (*append)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *, khcomplex128_t);
  PyObject *(*extend)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *, __Pyx_memviewslice);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_vtabptr_6pandas_5_libs_9hashtable_Complex128Vector;


/* "pandas/_libs/hashtable_class_helper.pxi":476
 *             self.append(x[i])
 * 
 * cdef class Complex64Vector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     # For int64 we have to put this declaration in the .pxd file;
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex64Vector {
  PyObject *(*resize)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *);
  PyArrayObject *(*to_array)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *, int __pyx_skip_dispatch);
  void (*append)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *, khcomplex64_t);
  PyObject *(*extend)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *, __Pyx_memviewslice);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_vtabptr_6pandas_5_libs_9hashtable_Complex64Vector;


/* "pandas/_libs/hashtable_class_helper.pxi":531
 *             self.append(x[i])
 * 
 * cdef class Float64Vector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     # For int64 we have to put this declaration in the .pxd file;
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float64Vector {
  PyObject *(*resize)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *);
  PyArrayObject *(*to_array)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *, int __pyx_skip_dispatch);
  void (*append)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *, __pyx_t_5numpy_float64_t);
  PyObject *(*extend)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *, __Pyx_memviewslice);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float64Vector *__pyx_vtabptr_6pandas_5_libs_9hashtable_Float64Vector;


/* "pandas/_libs/hashtable_class_helper.pxi":586
 *             self.append(x[i])
 * 
 * cdef class UInt64Vector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     # For int64 we have to put this declaration in the .pxd file;
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt64Vector {
  PyObject *(*resize)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *);
  PyArrayObject *(*to_array)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *, int __pyx_skip_dispatch);
  void (*append)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *, __pyx_t_5numpy_uint64_t);
  PyObject *(*extend)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *, __Pyx_memviewslice);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_vtabptr_6pandas_5_libs_9hashtable_UInt64Vector;


/* "pandas/_libs/hashtable_class_helper.pxi":693
 *             self.append(x[i])
 * 
 * cdef class Float32Vector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     # For int64 we have to put this declaration in the .pxd file;
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float32Vector {
  PyObject *(*resize)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *);
  PyArrayObject *(*to_array)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *, int __pyx_skip_dispatch);
  void (*append)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *, __pyx_t_5numpy_float32_t);
  PyObject *(*extend)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *, __Pyx_memviewslice);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float32Vector *__pyx_vtabptr_6pandas_5_libs_9hashtable_Float32Vector;


/* "pandas/_libs/hashtable_class_helper.pxi":748
 *             self.append(x[i])
 * 
 * cdef class UInt32Vector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     # For int64 we have to put this declaration in the .pxd file;
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt32Vector {
  PyObject *(*resize)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *);
  PyArrayObject *(*to_array)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *, int __pyx_skip_dispatch);
  void (*append)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *, __pyx_t_5numpy_uint32_t);
  PyObject *(*extend)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *, __Pyx_memviewslice);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_vtabptr_6pandas_5_libs_9hashtable_UInt32Vector;


/* "pandas/_libs/hashtable_class_helper.pxi":803
 *             self.append(x[i])
 * 
 * cdef class Int32Vector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     # For int64 we have to put this declaration in the .pxd file;
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int32Vector {
  PyObject *(*resize)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *);
  PyArrayObject *(*to_array)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *, int __pyx_skip_dispatch);
  void (*append)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *, __pyx_t_5numpy_int32_t);
  PyObject *(*extend)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *, __Pyx_memviewslice);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int32Vector *__pyx_vtabptr_6pandas_5_libs_9hashtable_Int32Vector;


/* "pandas/_libs/hashtable_class_helper.pxi":858
 *             self.append(x[i])
 * 
 * cdef class UInt16Vector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     # For int64 we have to put this declaration in the .pxd file;
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt16Vector {
  PyObject *(*resize)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *);
  PyArrayObject *(*to_array)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *, int __pyx_skip_dispatch);
  void (*append)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *, __pyx_t_5numpy_uint16_t);
  PyObject *(*extend)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *, __Pyx_memviewslice);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_vtabptr_6pandas_5_libs_9hashtable_UInt16Vector;


/* "pandas/_libs/hashtable_class_helper.pxi":913
 *             self.append(x[i])
 * 
 * cdef class Int16Vector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     # For int64 we have to put this declaration in the .pxd file;
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int16Vector {
  PyObject *(*resize)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *);
  PyArrayObject *(*to_array)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *, int __pyx_skip_dispatch);
  void (*append)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *, __pyx_t_5numpy_int16_t);
  PyObject *(*extend)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *, __Pyx_memviewslice);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int16Vector *__pyx_vtabptr_6pandas_5_libs_9hashtable_Int16Vector;


/* "pandas/_libs/hashtable_class_helper.pxi":968
 *             self.append(x[i])
 * 
 * cdef class UInt8Vector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     # For int64 we have to put this declaration in the .pxd file;
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector {
  PyObject *(*resize)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *);
  PyArrayObject *(*to_array)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *, int __pyx_skip_dispatch);
  void (*append)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *, __pyx_t_5numpy_uint8_t);
  PyObject *(*extend)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *, __Pyx_memviewslice);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_vtabptr_6pandas_5_libs_9hashtable_UInt8Vector;


/* "pandas/_libs/hashtable_class_helper.pxi":1023
 *             self.append(x[i])
 * 
 * cdef class Int8Vector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     # For int64 we have to put this declaration in the .pxd file;
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int8Vector {
  PyObject *(*resize)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *);
  PyArrayObject *(*to_array)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *, int __pyx_skip_dispatch);
  void (*append)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *, __pyx_t_5numpy_int8_t);
  PyObject *(*extend)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *, __Pyx_memviewslice);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int8Vector *__pyx_vtabptr_6pandas_5_libs_9hashtable_Int8Vector;


/* "pandas/_libs/hashtable_class_helper.pxi":1078
 *             self.append(x[i])
 * 
 * cdef class StringVector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     cdef:
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_StringVector {
  PyObject *(*resize)(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *);
  PyArrayObject *(*to_array)(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *, int __pyx_skip_dispatch);
  void (*append)(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *, char *);
  PyObject *(*extend)(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *, PyArrayObject *);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_StringVector *__pyx_vtabptr_6pandas_5_libs_9hashtable_StringVector;


/* "pandas/_libs/hashtable_class_helper.pxi":1144
 * 
 * 
 * cdef class ObjectVector(Vector):             # <<<<<<<<<<<<<<
 * 
 *     cdef:
 */

struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_ObjectVector {
  PyObject *(*append)(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *, PyObject *);
  PyArrayObject *(*to_array)(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *, int __pyx_skip_dispatch);
  PyObject *(*extend)(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *, PyArrayObject *);
};
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_ObjectVector *__pyx_vtabptr_6pandas_5_libs_9hashtable_ObjectVector;


/* "View.MemoryView":114
 * @cython.collection_type("sequence")
 * @cname("__pyx_array")
 * cdef class array:             # <<<<<<<<<<<<<<
 * 
 *     cdef:
 */

struct __pyx_vtabstruct_array {
  PyObject *(*get_memview)(struct __pyx_array_obj *);
};
static struct __pyx_vtabstruct_array *__pyx_vtabptr_array;


/* "View.MemoryView":337
 * 
 * @cname('__pyx_memoryview')
 * cdef class memoryview:             # <<<<<<<<<<<<<<
 * 
 *     cdef object obj
 */

struct __pyx_vtabstruct_memoryview {
  char *(*get_item_pointer)(struct __pyx_memoryview_obj *, PyObject *);
  PyObject *(*is_slice)(struct __pyx_memoryview_obj *, PyObject *);
  PyObject *(*setitem_slice_assignment)(struct __pyx_memoryview_obj *, PyObject *, PyObject *);
  PyObject *(*setitem_slice_assign_scalar)(struct __pyx_memoryview_obj *, struct __pyx_memoryview_obj *, PyObject *);
  PyObject *(*setitem_indexed)(struct __pyx_memoryview_obj *, PyObject *, PyObject *);
  PyObject *(*convert_item_to_object)(struct __pyx_memoryview_obj *, char *);
  PyObject *(*assign_item_from_object)(struct __pyx_memoryview_obj *, char *, PyObject *);
  PyObject *(*_get_base)(struct __pyx_memoryview_obj *);
};
static struct __pyx_vtabstruct_memoryview *__pyx_vtabptr_memoryview;


/* "View.MemoryView":952
 * @cython.collection_type("sequence")
 * @cname('__pyx_memoryviewslice')
 * cdef class _memoryviewslice(memoryview):             # <<<<<<<<<<<<<<
 *     "Internal class for passing memoryview slices to Python"
 * 
 */

struct __pyx_vtabstruct__memoryviewslice {
  struct __pyx_vtabstruct_memoryview __pyx_base;
};
static struct __pyx_vtabstruct__memoryviewslice *__pyx_vtabptr__memoryviewslice;
/* #### Code section: utility_code_proto ### */

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, Py_ssize_t);
    void (*DECREF)(void*, PyObject*, Py_ssize_t);
    void (*GOTREF)(void*, PyObject*, Py_ssize_t);
    void (*GIVEREF)(void*, PyObject*, Py_ssize_t);
    void* (*SetupContext)(const char*, Py_ssize_t, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__));\
          }
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), (__LINE__), (__FILE__))
  #define __Pyx_RefNannyFinishContextNogil() __Pyx_RefNannyFinishContext()
#endif
  #define __Pyx_RefNannyFinishContextNogil() {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __Pyx_RefNannyFinishContext();\
              PyGILState_Release(__pyx_gilstate_save);\
          }
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), (__LINE__))
  #define __Pyx_XINCREF(r)  do { if((r) == NULL); else {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) == NULL); else {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) == NULL); else {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) == NULL); else {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContextNogil()
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_Py_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; Py_XDECREF(tmp);\
    } while (0)
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#if PY_VERSION_HEX >= 0x030C00A6
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->current_exception != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->current_exception ? (PyObject*) Py_TYPE(__pyx_tstate->current_exception) : (PyObject*) NULL)
#else
#define __Pyx_PyErr_Occurred()  (__pyx_tstate->curexc_type != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  (__pyx_tstate->curexc_type)
#endif
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  (PyErr_Occurred() != NULL)
#define __Pyx_PyErr_CurrentExceptionType()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A6
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* TupleAndListFromArray.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n);
static CYTHON_INLINE PyObject* __Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n);
#endif

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* fastcall.proto */
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_Arg_VARARGS(args, i) PySequence_GetItem(args, i)
#elif CYTHON_ASSUME_SAFE_MACROS
    #define __Pyx_Arg_VARARGS(args, i) PyTuple_GET_ITEM(args, i)
#else
    #define __Pyx_Arg_VARARGS(args, i) PyTuple_GetItem(args, i)
#endif
#if CYTHON_AVOID_BORROWED_REFS
    #define __Pyx_Arg_NewRef_VARARGS(arg) __Pyx_NewRef(arg)
    #define __Pyx_Arg_XDECREF_VARARGS(arg) Py_XDECREF(arg)
#else
    #define __Pyx_Arg_NewRef_VARARGS(arg) arg
    #define __Pyx_Arg_XDECREF_VARARGS(arg)
#endif
#define __Pyx_NumKwargs_VARARGS(kwds) PyDict_Size(kwds)
#define __Pyx_KwValues_VARARGS(args, nargs) NULL
#define __Pyx_GetKwValue_VARARGS(kw, kwvalues, s) __Pyx_PyDict_GetItemStrWithError(kw, s)
#define __Pyx_KwargsAsDict_VARARGS(kw, kwvalues) PyDict_Copy(kw)
#if CYTHON_METH_FASTCALL
    #define __Pyx_Arg_FASTCALL(args, i) args[i]
    #define __Pyx_NumKwargs_FASTCALL(kwds) PyTuple_GET_SIZE(kwds)
    #define __Pyx_KwValues_FASTCALL(args, nargs) ((args) + (nargs))
    static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
    CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues);
  #else
    #define __Pyx_KwargsAsDict_FASTCALL(kw, kwvalues) _PyStack_AsDict(kwvalues, kw)
  #endif
    #define __Pyx_Arg_NewRef_FASTCALL(arg) arg  /* no-op, __Pyx_Arg_FASTCALL is direct and this needs
                                                   to have the same reference counting */
    #define __Pyx_Arg_XDECREF_FASTCALL(arg)
#else
    #define __Pyx_Arg_FASTCALL __Pyx_Arg_VARARGS
    #define __Pyx_NumKwargs_FASTCALL __Pyx_NumKwargs_VARARGS
    #define __Pyx_KwValues_FASTCALL __Pyx_KwValues_VARARGS
    #define __Pyx_GetKwValue_FASTCALL __Pyx_GetKwValue_VARARGS
    #define __Pyx_KwargsAsDict_FASTCALL __Pyx_KwargsAsDict_VARARGS
    #define __Pyx_Arg_NewRef_FASTCALL(arg) __Pyx_Arg_NewRef_VARARGS(arg)
    #define __Pyx_Arg_XDECREF_FASTCALL(arg) __Pyx_Arg_XDECREF_VARARGS(arg)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_VARARGS(args, start), stop - start)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) __Pyx_PyTuple_FromArray(&__Pyx_Arg_FASTCALL(args, start), stop - start)
#else
#define __Pyx_ArgsSlice_VARARGS(args, start, stop) PyTuple_GetSlice(args, start, stop)
#define __Pyx_ArgsSlice_FASTCALL(args, start, stop) PyTuple_GetSlice(args, start, stop)
#endif

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,
    const char* function_name);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely(__Pyx_IS_TYPE(obj, type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#if !CYTHON_VECTORCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
#if !CYTHON_VECTORCALL
#if PY_VERSION_HEX >= 0x03080000
  #include "frameobject.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
  #define __Pxy_PyFrame_Initialize_Offsets()
  #define __Pyx_PyFrame_GetLocalsplus(frame)  ((frame)->f_localsplus)
#else
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif
#endif
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectFastCall.proto */
#define __Pyx_PyObject_FastCall(func, args, nargs)  __Pyx_PyObject_FastCallDict(func, args, (size_t)(nargs), NULL)
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs);

/* RaiseUnexpectedTypeError.proto */
static int __Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj);

/* GCCDiagnostics.proto */
#if !defined(__INTEL_COMPILER) && defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 6))
#define __Pyx_HAS_GCC_DIAGNOSTIC
#endif

/* BuildPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_BuildFromAscii(Py_ssize_t ulength, char* chars, int clength,
                                                int prepend_sign, char padding_char);

/* CIntToPyUnicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_int(int value, Py_ssize_t width, char padding_char, char format_char);

/* CIntToPyUnicode.proto */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_Py_ssize_t(Py_ssize_t value, Py_ssize_t width, char padding_char, char format_char);

/* JoinPyUnicode.proto */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char);

/* StrEquals.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyString_Equals __Pyx_PyUnicode_Equals
#else
#define __Pyx_PyString_Equals __Pyx_PyBytes_Equals
#endif

/* PyObjectFormatSimple.proto */
#if CYTHON_COMPILING_IN_PYPY
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#elif PY_MAJOR_VERSION < 3
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyString_CheckExact(s)) ? PyUnicode_FromEncodedObject(s, NULL, "strict") :\
        PyObject_Format(s, f))
#elif CYTHON_USE_TYPE_SLOTS
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        likely(PyLong_CheckExact(s)) ? PyLong_Type.tp_repr(s) :\
        likely(PyFloat_CheckExact(s)) ? PyFloat_Type.tp_repr(s) :\
        PyObject_Format(s, f))
#else
    #define __Pyx_PyObject_FormatSimple(s, f) (\
        likely(PyUnicode_CheckExact(s)) ? (Py_INCREF(s), s) :\
        PyObject_Format(s, f))
#endif

CYTHON_UNUSED static int __pyx_array_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
static PyObject *__pyx_array_get_memview(struct __pyx_array_obj *); /*proto*/
/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* KeywordStringCheck.proto */
static int __Pyx_CheckKeywordStrings(PyObject *kw, const char* function_name, int kw_allowed);

/* DivInt[Py_ssize_t].proto */
static CYTHON_INLINE Py_ssize_t __Pyx_div_Py_ssize_t(Py_ssize_t, Py_ssize_t);

/* UnaryNegOverflows.proto */
#define __Pyx_UNARY_NEG_WOULD_OVERFLOW(x)\
        (((x) < 0) & ((unsigned long)(x) == 0-(unsigned long)(x)))

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  do {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  do {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
} while(0)
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* AssertionsEnabled.proto */
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define __Pyx_init_assertions_enabled()  (0)
  #define __pyx_assertions_enabled()  (1)
#elif CYTHON_COMPILING_IN_LIMITED_API  ||  (CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030C0000)
  static int __pyx_assertions_enabled_flag;
  #define __pyx_assertions_enabled() (__pyx_assertions_enabled_flag)
  static int __Pyx_init_assertions_enabled(void) {
    PyObject *builtins, *debug, *debug_str;
    int flag;
    builtins = PyEval_GetBuiltins();
    if (!builtins) goto bad;
    debug_str = PyUnicode_FromStringAndSize("__debug__", 9);
    if (!debug_str) goto bad;
    debug = PyObject_GetItem(builtins, debug_str);
    Py_DECREF(debug_str);
    if (!debug) goto bad;
    flag = PyObject_IsTrue(debug);
    Py_DECREF(debug);
    if (flag == -1) goto bad;
    __pyx_assertions_enabled_flag = flag;
    return 0;
  bad:
    __pyx_assertions_enabled_flag = 1;
    return -1;
  }
#else
  #define __Pyx_init_assertions_enabled()  (0)
  #define __pyx_assertions_enabled()  (!Py_OptimizeFlag)
#endif

/* RaiseTooManyValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

/* RaiseNeedMoreValuesToUnpack.proto */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

/* RaiseNoneIterError.proto */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* GetTopmostException.proto */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem * __Pyx_PyErr_GetTopmostException(PyThreadState *tstate);
#endif

/* SaveResetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSave(type, value, tb)  __Pyx__ExceptionSave(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#define __Pyx_ExceptionReset(type, value, tb)  __Pyx__ExceptionReset(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
#else
#define __Pyx_ExceptionSave(type, value, tb)   PyErr_GetExcInfo(type, value, tb)
#define __Pyx_ExceptionReset(type, value, tb)  PyErr_SetExcInfo(type, value, tb)
#endif

/* GetException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_GetException(type, value, tb)  __Pyx__GetException(__pyx_tstate, type, value, tb)
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* SwapException.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_ExceptionSwap(type, value, tb)  __Pyx__ExceptionSwap(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb);
#endif

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportDottedModule.proto */
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple);
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple);
#endif

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) __Pyx_IsAnySubtype2(Py_TYPE(obj), (PyTypeObject *)type1, (PyTypeObject *)type2)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_TypeCheck2(obj, type1, type2) (PyObject_TypeCheck(obj, (PyTypeObject *)type1) || PyObject_TypeCheck(obj, (PyTypeObject *)type2))
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyErr_ExceptionMatches2(err1, err2)  __Pyx_PyErr_GivenExceptionMatches2(__Pyx_PyErr_CurrentExceptionType(), err1, err2)
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

CYTHON_UNUSED static int __pyx_memoryview_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
/* ListCompAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_ListComp_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_ListComp_Append(L,x) PyList_Append(L,x)
#endif

/* PySequenceMultiply.proto */
#define __Pyx_PySequence_Multiply_Left(mul, seq)  __Pyx_PySequence_Multiply(seq, mul)
static CYTHON_INLINE PyObject* __Pyx_PySequence_Multiply(PyObject *seq, Py_ssize_t mul);

/* SetItemInt.proto */
#define __Pyx_SetItemInt(o, i, v, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_SetItemInt_Fast(o, (Py_ssize_t)i, v, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list assignment index out of range"), -1) :\
               __Pyx_SetItemInt_Generic(o, to_py_func(i), v)))
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v);
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v,
                                               int is_list, int wraparound, int boundscheck);

/* RaiseUnboundLocalError.proto */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname);

/* DivInt[long].proto */
static CYTHON_INLINE long __Pyx_div_long(long, long);

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* HasAttr.proto */
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
#define __Pyx_HasAttr(o, n)  PyObject_HasAttrWithError(o, n)
#else
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);
#endif

/* ErrOccurredWithGIL.proto */
static CYTHON_INLINE int __Pyx_ErrOccurredWithGIL(void);

/* BufferIndexError.proto */
static void __Pyx_RaiseBufferIndexError(int axis);

/* IsLittleEndian.proto */
static CYTHON_INLINE int __Pyx_Is_Little_Endian(void);

/* BufferFormatCheck.proto */
static const char* __Pyx_BufFmt_CheckString(__Pyx_BufFmt_Context* ctx, const char* ts);
static void __Pyx_BufFmt_Init(__Pyx_BufFmt_Context* ctx,
                              __Pyx_BufFmt_StackElem* stack,
                              __Pyx_TypeInfo* type);

/* BufferGetAndValidate.proto */
#define __Pyx_GetBufferAndValidate(buf, obj, dtype, flags, nd, cast, stack)\
    ((obj == Py_None || obj == NULL) ?\
    (__Pyx_ZeroBuffer(buf), 0) :\
    __Pyx__GetBufferAndValidate(buf, obj, dtype, flags, nd, cast, stack))
static int  __Pyx__GetBufferAndValidate(Py_buffer* buf, PyObject* obj,
    __Pyx_TypeInfo* dtype, int flags, int nd, int cast, __Pyx_BufFmt_StackElem* stack);
static void __Pyx_ZeroBuffer(Py_buffer* buf);
static CYTHON_INLINE void __Pyx_SafeReleaseBuffer(Py_buffer* info);
static Py_ssize_t __Pyx_minusones[] = { -1, -1, -1, -1, -1, -1, -1, -1 };
static Py_ssize_t __Pyx_zeros[] = { 0, 0, 0, 0, 0, 0, 0, 0 };

#define __Pyx_BufPtrStrided1d(type, buf, i0, s0) (type)((char*)buf + i0 * s0)
/* PyObjectCallNoArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);

/* RaiseUnboundMemoryviewSliceNogil.proto */
static void __Pyx_RaiseUnboundMemoryviewSliceNogil(const char *varname);

/* IterFinish.proto */
static CYTHON_INLINE int __Pyx_IterFinish(void);

/* UnpackItemEndCheck.proto */
static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

/* BufferFallbackError.proto */
static void __Pyx_RaiseBufferFallbackError(void);

/* PyDictContains.proto */
static CYTHON_INLINE int __Pyx_PyDict_ContainsTF(PyObject* item, PyObject* dict, int eq) {
    int result = PyDict_Contains(dict, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* DictGetItem.proto */
#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key);
#define __Pyx_PyObject_Dict_GetItem(obj, name)\
    (likely(PyDict_CheckExact(obj)) ?\
     __Pyx_PyDict_GetItem(obj, name) : PyObject_GetItem(obj, name))
#else
#define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#define __Pyx_PyObject_Dict_GetItem(obj, name)  PyObject_GetItem(obj, name)
#endif

/* UnicodeAsUCS4.proto */
static CYTHON_INLINE Py_UCS4 __Pyx_PyUnicode_AsPy_UCS4(PyObject*);

/* object_ord.proto */
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyObject_Ord(c)\
    (likely(PyUnicode_Check(c)) ? (long)__Pyx_PyUnicode_AsPy_UCS4(c) : __Pyx__PyObject_Ord(c))
#else
#define __Pyx_PyObject_Ord(c) __Pyx__PyObject_Ord(c)
#endif
static long __Pyx__PyObject_Ord(PyObject* c);

/* memoryview_get_from_buffer.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API || CYTHON_LIMITED_API >= 0x030b0000
#define __Pyx_PyMemoryView_Get_itemsize(o) PyMemoryView_GET_BUFFER(o)->itemsize
#else
 // can't get format like this unfortunately. It's unicode via getattr
static Py_ssize_t __Pyx_PyMemoryView_Get_itemsize(PyObject *obj);
#endif

/* memoryview_get_from_buffer.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API || CYTHON_LIMITED_API >= 0x030b0000
#define __Pyx_PyMemoryView_Get_ndim(o) PyMemoryView_GET_BUFFER(o)->ndim
#else
 // can't get format like this unfortunately. It's unicode via getattr
static int __Pyx_PyMemoryView_Get_ndim(PyObject *obj);
#endif

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod0.proto */
static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name);

/* UnpackTupleError.proto */
static void __Pyx_UnpackTupleError(PyObject *, Py_ssize_t index);

/* UnpackTuple2.proto */
#define __Pyx_unpack_tuple2(tuple, value1, value2, is_tuple, has_known_size, decref_tuple)\
    (likely(is_tuple || PyTuple_Check(tuple)) ?\
        (likely(has_known_size || PyTuple_GET_SIZE(tuple) == 2) ?\
            __Pyx_unpack_tuple2_exact(tuple, value1, value2, decref_tuple) :\
            (__Pyx_UnpackTupleError(tuple, 2), -1)) :\
        __Pyx_unpack_tuple2_generic(tuple, value1, value2, has_known_size, decref_tuple))
static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
    PyObject* tuple, PyObject** value1, PyObject** value2, int decref_tuple);
static int __Pyx_unpack_tuple2_generic(
    PyObject* tuple, PyObject** value1, PyObject** value2, int has_known_size, int decref_tuple);

/* dict_iter.proto */
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* dict, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_is_dict);
static CYTHON_INLINE int __Pyx_dict_iter_next(PyObject* dict_or_iter, Py_ssize_t orig_length, Py_ssize_t* ppos,
                                              PyObject** pkey, PyObject** pvalue, PyObject** pitem, int is_dict);

/* ListExtend.proto */
static CYTHON_INLINE int __Pyx_PyList_Extend(PyObject* L, PyObject* v) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030d0000
    PyObject* none = _PyList_Extend((PyListObject*)L, v);
    if (unlikely(!none))
        return -1;
    Py_DECREF(none);
    return 0;
#else
    return PyList_SetSlice(L, PY_SSIZE_T_MAX, PY_SSIZE_T_MAX, v);
#endif
}

/* py_dict_values.proto */
static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d);

/* UnpackUnboundCMethod.proto */
typedef struct {
    PyObject *type;
    PyObject **method_name;
    PyCFunction func;
    PyObject *method;
    int flag;
} __Pyx_CachedCFunction;

/* CallUnboundCMethod0.proto */
static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_CallUnboundCMethod0(cfunc, self)\
    (likely((cfunc)->func) ?\
        (likely((cfunc)->flag == METH_NOARGS) ?  (*((cfunc)->func))(self, NULL) :\
         (PY_VERSION_HEX >= 0x030600B1 && likely((cfunc)->flag == METH_FASTCALL) ?\
            (PY_VERSION_HEX >= 0x030700A0 ?\
                (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0) :\
                (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0, NULL)) :\
          (PY_VERSION_HEX >= 0x030700A0 && (cfunc)->flag == (METH_FASTCALL | METH_KEYWORDS) ?\
            (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, &__pyx_empty_tuple, 0, NULL) :\
            (likely((cfunc)->flag == (METH_VARARGS | METH_KEYWORDS)) ?  ((*(PyCFunctionWithKeywords)(void*)(PyCFunction)(cfunc)->func)(self, __pyx_empty_tuple, NULL)) :\
               ((cfunc)->flag == METH_VARARGS ?  (*((cfunc)->func))(self, __pyx_empty_tuple) :\
               __Pyx__CallUnboundCMethod0(cfunc, self)))))) :\
        __Pyx__CallUnboundCMethod0(cfunc, self))
#else
#define __Pyx_CallUnboundCMethod0(cfunc, self)  __Pyx__CallUnboundCMethod0(cfunc, self)
#endif

/* dict_getitem_default.proto */
static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value);

/* CallUnboundCMethod1.proto */
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg);
#else
#define __Pyx_CallUnboundCMethod1(cfunc, self, arg)  __Pyx__CallUnboundCMethod1(cfunc, self, arg)
#endif

/* CallUnboundCMethod2.proto */
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2);
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030600B1
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2);
#else
#define __Pyx_CallUnboundCMethod2(cfunc, self, arg1, arg2)  __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2)
#endif

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
        L->ob_item[len] = x;
        #else
        PyList_SET_ITEM(list, len, x);
        #endif
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* CallNextTpTraverse.proto */
static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse);

/* CallNextTpClear.proto */
static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_clear);

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* IncludeStructmemberH.proto */
#include <structmember.h>

/* FixUpExtensionType.proto */
#if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type);
#endif

/* ValidateBasesTuple.proto */
#if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases);
#endif

/* PyType_Ready.proto */
CYTHON_UNUSED static int __Pyx_PyType_Ready(PyTypeObject *t);

/* SetupReduce.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_setup_reduce(PyObject* type_obj);
#endif

/* SetVTable.proto */
static int __Pyx_SetVtable(PyTypeObject* typeptr , void* vtable);

/* GetVTable.proto */
static void* __Pyx_GetVtable(PyTypeObject *type);

/* MergeVTables.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_MergeVtables(PyTypeObject *type);
#endif

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto_3_0_8
#define __PYX_HAVE_RT_ImportType_proto_3_0_8
#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L
#include <stdalign.h>
#endif
#if (defined (__STDC_VERSION__) && __STDC_VERSION__ >= 201112L) || __cplusplus >= 201103L
#define __PYX_GET_STRUCT_ALIGNMENT_3_0_8(s) alignof(s)
#else
#define __PYX_GET_STRUCT_ALIGNMENT_3_0_8(s) sizeof(void*)
#endif
enum __Pyx_ImportType_CheckSize_3_0_8 {
   __Pyx_ImportType_CheckSize_Error_3_0_8 = 0,
   __Pyx_ImportType_CheckSize_Warn_3_0_8 = 1,
   __Pyx_ImportType_CheckSize_Ignore_3_0_8 = 2
};
static PyTypeObject *__Pyx_ImportType_3_0_8(PyObject* module, const char *module_name, const char *class_name, size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_0_8 check_size);
#endif

/* FetchSharedCythonModule.proto */
static PyObject *__Pyx_FetchSharedCythonABIModule(void);

/* FetchCommonType.proto */
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);
#else
static PyTypeObject* __Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases);
#endif

/* PyMethodNew.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    PyObject *typesModule=NULL, *methodType=NULL, *result=NULL;
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    typesModule = PyImport_ImportModule("types");
    if (!typesModule) return NULL;
    methodType = PyObject_GetAttrString(typesModule, "MethodType");
    Py_DECREF(typesModule);
    if (!methodType) return NULL;
    result = PyObject_CallFunctionObjArgs(methodType, func, self, NULL);
    Py_DECREF(methodType);
    return result;
}
#elif PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_PyMethod_New(PyObject *func, PyObject *self, PyObject *typ) {
    CYTHON_UNUSED_VAR(typ);
    if (!self)
        return __Pyx_NewRef(func);
    return PyMethod_New(func, self);
}
#else
    #define __Pyx_PyMethod_New PyMethod_New
#endif

/* PyVectorcallFastCallDict.proto */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw);
#endif

/* CythonFunctionShared.proto */
#define __Pyx_CyFunction_USED
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CYFUNCTION_COROUTINE     0x08
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
  #define __Pyx_CyFunction_GetClassObj(f)\
      (((__pyx_CyFunctionObject *) (f))->func_classobj)
#else
  #define __Pyx_CyFunction_GetClassObj(f)\
      ((PyObject*) ((PyCMethodObject *) (f))->mm_class)
#endif
#define __Pyx_CyFunction_SetClassObj(f, classobj)\
    __Pyx__CyFunction_SetClassObj((__pyx_CyFunctionObject *) (f), (classobj))
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject_HEAD
    PyObject *func;
#elif PY_VERSION_HEX < 0x030900B1
    PyCFunctionObject func;
#else
    PyCMethodObject func;
#endif
#if CYTHON_BACKPORT_VECTORCALL
    __pyx_vectorcallfunc func_vectorcall;
#endif
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    PyObject *func_classobj;
#endif
    void *defaults;
    int defaults_pyobjects;
    size_t defaults_size;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
    PyObject *func_is_coroutine;
} __pyx_CyFunctionObject;
#undef __Pyx_CyOrPyCFunction_Check
#define __Pyx_CyFunction_Check(obj)  __Pyx_TypeCheck(obj, __pyx_CyFunctionType)
#define __Pyx_CyOrPyCFunction_Check(obj)  __Pyx_TypeCheck2(obj, __pyx_CyFunctionType, &PyCFunction_Type)
#define __Pyx_CyFunction_CheckExact(obj)  __Pyx_IS_TYPE(obj, __pyx_CyFunctionType)
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc);
#undef __Pyx_IsSameCFunction
#define __Pyx_IsSameCFunction(func, cfunc)   __Pyx__IsSameCyOrCFunction(func, cfunc)
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject* op, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(PyObject *module);
#if CYTHON_METH_FASTCALL
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames);
#if CYTHON_BACKPORT_VECTORCALL
#define __Pyx_CyFunction_func_vectorcall(f) (((__pyx_CyFunctionObject*)f)->func_vectorcall)
#else
#define __Pyx_CyFunction_func_vectorcall(f) (((PyCFunctionObject*)f)->vectorcall)
#endif
#endif

/* CythonFunction.proto */
static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *closure,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);

/* FusedFunction.proto */
typedef struct {
    __pyx_CyFunctionObject func;
    PyObject *__signatures__;
    PyObject *self;
} __pyx_FusedFunctionObject;
static PyObject *__pyx_FusedFunction_New(PyMethodDef *ml, int flags,
                                         PyObject *qualname, PyObject *closure,
                                         PyObject *module, PyObject *globals,
                                         PyObject *code);
static int __pyx_FusedFunction_clear(__pyx_FusedFunctionObject *self);
static int __pyx_FusedFunction_init(PyObject *module);
#define __Pyx_FusedFunction_USED

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
#if !CYTHON_COMPILING_IN_LIMITED_API
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);
#endif

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

#if PY_MAJOR_VERSION < 3
    static int __Pyx_GetBuffer(PyObject *obj, Py_buffer *view, int flags);
    static void __Pyx_ReleaseBuffer(Py_buffer *view);
#else
    #define __Pyx_GetBuffer PyObject_GetBuffer
    #define __Pyx_ReleaseBuffer PyBuffer_Release
#endif


/* BufferStructDeclare.proto */
typedef struct {
  Py_ssize_t shape, strides, suboffsets;
} __Pyx_Buf_DimInfo;
typedef struct {
  size_t refcount;
  Py_buffer pybuffer;
} __Pyx_Buffer;
typedef struct {
  __Pyx_Buffer *rcbuffer;
  char *data;
  __Pyx_Buf_DimInfo diminfo[8];
} __Pyx_LocalBuf_ND;

/* MemviewSliceIsContig.proto */
static int __pyx_memviewslice_is_contig(const __Pyx_memviewslice mvs, char order, int ndim);

/* OverlappingSlices.proto */
static int __pyx_slices_overlap(__Pyx_memviewslice *slice1,
                                __Pyx_memviewslice *slice2,
                                int ndim, size_t itemsize);

/* TypeInfoCompare.proto */
static int __pyx_typeinfo_cmp(__Pyx_TypeInfo *a, __Pyx_TypeInfo *b);

/* MemviewSliceValidateAndInit.proto */
static int __Pyx_ValidateAndInit_memviewslice(
                int *axes_specs,
                int c_or_f_flag,
                int buf_flags,
                int ndim,
                __Pyx_TypeInfo *dtype,
                __Pyx_BufFmt_StackElem stack[],
                __Pyx_memviewslice *memviewslice,
                PyObject *original_obj);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int8_t(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int16_t(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int32_t(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint16_t(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint32_t(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint64_t(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float32_t(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float64_t(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_object(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_double_complex(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_float_complex(PyObject *, int writable_flag);

/* FromPy.proto */
static __pyx_t_double_complex __Pyx_PyComplex_As___pyx_t_double_complex(PyObject*);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_double_complex__const__(PyObject *, int writable_flag);

/* MemviewDtypeToObject.proto */
static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__(const char *itemp);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn_khcomplex128_t__const__(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float64_t__const__(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint64_t__const__(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t__const__(PyObject *, int writable_flag);

/* FromPy.proto */
static __pyx_t_float_complex __Pyx_PyComplex_As___pyx_t_float_complex(PyObject*);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_float_complex__const__(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn_khcomplex64_t__const__(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float32_t__const__(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint32_t__const__(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int32_t__const__(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint16_t__const__(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int16_t__const__(PyObject *, int writable_flag);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int8_t__const__(PyObject *, int writable_flag);

/* RealImag.proto */
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #define __Pyx_CREAL(z) ((z).real())
    #define __Pyx_CIMAG(z) ((z).imag())
  #else
    #define __Pyx_CREAL(z) (__real__(z))
    #define __Pyx_CIMAG(z) (__imag__(z))
  #endif
#else
    #define __Pyx_CREAL(z) ((z).real)
    #define __Pyx_CIMAG(z) ((z).imag)
#endif
#if defined(__cplusplus) && CYTHON_CCOMPLEX\
        && (defined(_WIN32) || defined(__clang__) || (defined(__GNUC__) && (__GNUC__ >= 5 || __GNUC__ == 4 && __GNUC_MINOR__ >= 4 )) || __cplusplus >= 201103)
    #define __Pyx_SET_CREAL(z,x) ((z).real(x))
    #define __Pyx_SET_CIMAG(z,y) ((z).imag(y))
#else
    #define __Pyx_SET_CREAL(z,x) __Pyx_CREAL(z) = (x)
    #define __Pyx_SET_CIMAG(z,y) __Pyx_CIMAG(z) = (y)
#endif

/* Arithmetic.proto */
#if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
    #define __Pyx_c_eq_double(a, b)   ((a)==(b))
    #define __Pyx_c_sum_double(a, b)  ((a)+(b))
    #define __Pyx_c_diff_double(a, b) ((a)-(b))
    #define __Pyx_c_prod_double(a, b) ((a)*(b))
    #define __Pyx_c_quot_double(a, b) ((a)/(b))
    #define __Pyx_c_neg_double(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero_double(z) ((z)==(double)0)
    #define __Pyx_c_conj_double(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs_double(z)     (::std::abs(z))
        #define __Pyx_c_pow_double(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero_double(z) ((z)==0)
    #define __Pyx_c_conj_double(z)    (conj(z))
    #if 1
        #define __Pyx_c_abs_double(z)     (cabs(z))
        #define __Pyx_c_pow_double(a, b)  (cpow(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg_double(__pyx_t_double_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero_double(__pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj_double(__pyx_t_double_complex);
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs_double(__pyx_t_double_complex);
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow_double(__pyx_t_double_complex, __pyx_t_double_complex);
    #endif
#endif

/* Arithmetic.proto */
#if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
    #define __Pyx_c_eq_float(a, b)   ((a)==(b))
    #define __Pyx_c_sum_float(a, b)  ((a)+(b))
    #define __Pyx_c_diff_float(a, b) ((a)-(b))
    #define __Pyx_c_prod_float(a, b) ((a)*(b))
    #define __Pyx_c_quot_float(a, b) ((a)/(b))
    #define __Pyx_c_neg_float(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero_float(z) ((z)==(float)0)
    #define __Pyx_c_conj_float(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs_float(z)     (::std::abs(z))
        #define __Pyx_c_pow_float(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero_float(z) ((z)==0)
    #define __Pyx_c_conj_float(z)    (conjf(z))
    #if 1
        #define __Pyx_c_abs_float(z)     (cabsf(z))
        #define __Pyx_c_pow_float(a, b)  (cpowf(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sum_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_diff_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prod_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_neg_float(__pyx_t_float_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero_float(__pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conj_float(__pyx_t_float_complex);
    #if 1
        static CYTHON_INLINE float __Pyx_c_abs_float(__pyx_t_float_complex);
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_pow_float(__pyx_t_float_complex, __pyx_t_float_complex);
    #endif
#endif

static PyObject* __pyx_convert__to_py_khcomplex128_t(khcomplex128_t s);
/* MemviewDtypeToObject.proto */
static CYTHON_INLINE PyObject *__pyx_memview_get_nn_khcomplex128_t__const__(const char *itemp);

static PyObject* __pyx_convert__to_py_khcomplex64_t(khcomplex64_t s);
/* MemviewDtypeToObject.proto */
static CYTHON_INLINE PyObject *__pyx_memview_get_nn_khcomplex64_t__const__(const char *itemp);

/* MemviewDtypeToObject.proto */
static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_float64_t__const__(const char *itemp);

/* MemviewDtypeToObject.proto */
static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_uint64_t__const__(const char *itemp);

/* MemviewDtypeToObject.proto */
static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_int64_t__const__(const char *itemp);

/* MemviewDtypeToObject.proto */
static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_float32_t__const__(const char *itemp);

/* MemviewDtypeToObject.proto */
static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_uint32_t__const__(const char *itemp);

/* MemviewDtypeToObject.proto */
static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_int32_t__const__(const char *itemp);

/* MemviewDtypeToObject.proto */
static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_uint16_t__const__(const char *itemp);

/* MemviewDtypeToObject.proto */
static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_int16_t__const__(const char *itemp);

/* MemviewDtypeToObject.proto */
static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_int8_t__const__(const char *itemp);

/* ToPy.proto */
#define __pyx_PyComplex_FromComplex(z)\
        PyComplex_FromDoubles((double)__Pyx_CREAL(z),\
                              (double)__Pyx_CIMAG(z))

/* MemviewDtypeToObject.proto */
static CYTHON_INLINE PyObject *__pyx_memview_get___pyx_t_double_complex__const__(const char *itemp);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(PyObject *, int writable_flag);

/* MemviewDtypeToObject.proto */
static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_intp_t(const char *itemp);
static CYTHON_INLINE int __pyx_memview_set_nn___pyx_t_5numpy_intp_t(const char *itemp, PyObject *obj);

/* MemviewDtypeToObject.proto */
static CYTHON_INLINE PyObject *__pyx_memview_get___pyx_t_float_complex__const__(const char *itemp);

/* ObjectToMemviewSlice.proto */
static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(PyObject *, int writable_flag);

/* MemviewDtypeToObject.proto */
static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_int64_t(const char *itemp);
static CYTHON_INLINE int __pyx_memview_set_nn___pyx_t_5numpy_int64_t(const char *itemp, PyObject *obj);

/* PyUCS4InUnicode.proto */
static CYTHON_INLINE int __Pyx_UnicodeContainsUCS4(PyObject* unicode, Py_UCS4 character);

/* MemviewSliceCopyTemplate.proto */
static __Pyx_memviewslice
__pyx_memoryview_copy_new_contig(const __Pyx_memviewslice *from_mvs,
                                 const char *mode, int ndim,
                                 size_t sizeof_dtype, int contig_flag,
                                 int dtype_is_object);

/* MemviewSliceInit.proto */
#define __Pyx_BUF_MAX_NDIMS %(BUF_MAX_NDIMS)d
#define __Pyx_MEMVIEW_DIRECT   1
#define __Pyx_MEMVIEW_PTR      2
#define __Pyx_MEMVIEW_FULL     4
#define __Pyx_MEMVIEW_CONTIG   8
#define __Pyx_MEMVIEW_STRIDED  16
#define __Pyx_MEMVIEW_FOLLOW   32
#define __Pyx_IS_C_CONTIG 1
#define __Pyx_IS_F_CONTIG 2
static int __Pyx_init_memviewslice(
                struct __pyx_memoryview_obj *memview,
                int ndim,
                __Pyx_memviewslice *memviewslice,
                int memview_is_new_reference);
static CYTHON_INLINE int __pyx_add_acquisition_count_locked(
    __pyx_atomic_int_type *acquisition_count, PyThread_type_lock lock);
static CYTHON_INLINE int __pyx_sub_acquisition_count_locked(
    __pyx_atomic_int_type *acquisition_count, PyThread_type_lock lock);
#define __pyx_get_slice_count_pointer(memview) (&memview->acquisition_count)
#define __PYX_INC_MEMVIEW(slice, have_gil) __Pyx_INC_MEMVIEW(slice, have_gil, __LINE__)
#define __PYX_XCLEAR_MEMVIEW(slice, have_gil) __Pyx_XCLEAR_MEMVIEW(slice, have_gil, __LINE__)
static CYTHON_INLINE void __Pyx_INC_MEMVIEW(__Pyx_memviewslice *, int, int);
static CYTHON_INLINE void __Pyx_XCLEAR_MEMVIEW(__Pyx_memviewslice *, int, int);

/* CIntFromPy.proto */
static CYTHON_INLINE npy_int64 __Pyx_PyInt_As_npy_int64(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_uint8(npy_uint8 value);

/* CIntFromPy.proto */
static CYTHON_INLINE npy_uint64 __Pyx_PyInt_As_npy_uint64(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE npy_uint32 __Pyx_PyInt_As_npy_uint32(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE npy_int32 __Pyx_PyInt_As_npy_int32(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE npy_uint16 __Pyx_PyInt_As_npy_uint16(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE npy_int16 __Pyx_PyInt_As_npy_int16(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE npy_uint8 __Pyx_PyInt_As_npy_uint8(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE npy_int8 __Pyx_PyInt_As_npy_int8(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_uint32(npy_uint32 value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_uint64(npy_uint64 value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_int64(npy_int64 value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_int32(npy_int32 value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_uint16(npy_uint16 value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_int16(npy_int16 value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_int8(npy_int8 value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_Py_intptr_t(Py_intptr_t value);

/* CIntFromPy.proto */
static CYTHON_INLINE Py_intptr_t __Pyx_PyInt_As_Py_intptr_t(PyObject *);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* ImportNumPyArray.proto */
static PyObject *__pyx_numpy_ndarray = NULL;
static PyObject* __Pyx_ImportNumPyArrayTypeIfAvailable(void);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE char __Pyx_PyInt_As_char(PyObject *);

/* FormatTypeName.proto */
#if CYTHON_COMPILING_IN_LIMITED_API
typedef PyObject *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%U"
static __Pyx_TypeName __Pyx_PyType_GetName(PyTypeObject* tp);
#define __Pyx_DECREF_TypeName(obj) Py_XDECREF(obj)
#else
typedef const char *__Pyx_TypeName;
#define __Pyx_FMT_TYPENAME "%.200s"
#define __Pyx_PyType_GetName(tp) ((tp)->tp_name)
#define __Pyx_DECREF_TypeName(obj)
#endif

/* CheckBinaryVersion.proto */
static unsigned long __Pyx_get_runtime_version(void);
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer);

/* VoidPtrImport.proto */
static int __Pyx_ImportVoidPtr_3_0_8(PyObject *module, const char *name, void **p, const char *sig);

/* FunctionImport.proto */
static int __Pyx_ImportFunction_3_0_8(PyObject *module, const char *funcname, void (**f)(void), const char *sig);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

/* #### Code section: module_declarations ### */
static PyObject *__pyx_array_get_memview(struct __pyx_array_obj *__pyx_v_self); /* proto*/
static char *__pyx_memoryview_get_item_pointer(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index); /* proto*/
static PyObject *__pyx_memoryview_is_slice(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_obj); /* proto*/
static PyObject *__pyx_memoryview_setitem_slice_assignment(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_dst, PyObject *__pyx_v_src); /* proto*/
static PyObject *__pyx_memoryview_setitem_slice_assign_scalar(struct __pyx_memoryview_obj *__pyx_v_self, struct __pyx_memoryview_obj *__pyx_v_dst, PyObject *__pyx_v_value); /* proto*/
static PyObject *__pyx_memoryview_setitem_indexed(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value); /* proto*/
static PyObject *__pyx_memoryview_convert_item_to_object(struct __pyx_memoryview_obj *__pyx_v_self, char *__pyx_v_itemp); /* proto*/
static PyObject *__pyx_memoryview_assign_item_from_object(struct __pyx_memoryview_obj *__pyx_v_self, char *__pyx_v_itemp, PyObject *__pyx_v_value); /* proto*/
static PyObject *__pyx_memoryview__get_base(struct __pyx_memoryview_obj *__pyx_v_self); /* proto*/
static PyObject *__pyx_memoryviewslice_convert_item_to_object(struct __pyx_memoryviewslice_obj *__pyx_v_self, char *__pyx_v_itemp); /* proto*/
static PyObject *__pyx_memoryviewslice_assign_item_from_object(struct __pyx_memoryviewslice_obj *__pyx_v_self, char *__pyx_v_itemp, PyObject *__pyx_v_value); /* proto*/
static PyObject *__pyx_memoryviewslice__get_base(struct __pyx_memoryviewslice_obj *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyObject *__pyx_f_5numpy_7ndarray_4base_base(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE PyArray_Descr *__pyx_f_5numpy_7ndarray_5descr_descr(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE int __pyx_f_5numpy_7ndarray_4ndim_ndim(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE npy_intp *__pyx_f_5numpy_7ndarray_5shape_shape(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE npy_intp *__pyx_f_5numpy_7ndarray_7strides_strides(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE npy_intp __pyx_f_5numpy_7ndarray_4size_size(PyArrayObject *__pyx_v_self); /* proto*/
static CYTHON_INLINE char *__pyx_f_5numpy_7ndarray_4data_data(PyArrayObject *__pyx_v_self); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_16Complex128Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_self); /* proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_16Complex128Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_16Complex128Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_self, khcomplex128_t __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_16Complex128Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15Complex64Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_self); /* proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_15Complex64Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_15Complex64Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_self, khcomplex64_t __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15Complex64Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_13Float64Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_self); /* proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_13Float64Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_13Float64Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_self, __pyx_t_5numpy_float64_t __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_13Float64Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_12UInt64Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_self); /* proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_12UInt64Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_12UInt64Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_self, __pyx_t_5numpy_uint64_t __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_12UInt64Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_11Int64Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_self); /* proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_11Int64Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_11Int64Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_11Int64Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_13Float32Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_self); /* proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_13Float32Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_13Float32Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_self, __pyx_t_5numpy_float32_t __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_13Float32Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_12UInt32Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_self); /* proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_12UInt32Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_12UInt32Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_self, __pyx_t_5numpy_uint32_t __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_12UInt32Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_11Int32Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_self); /* proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_11Int32Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_11Int32Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_self, __pyx_t_5numpy_int32_t __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_11Int32Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_12UInt16Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_self); /* proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_12UInt16Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_12UInt16Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_self, __pyx_t_5numpy_uint16_t __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_12UInt16Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_11Int16Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_self); /* proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_11Int16Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_11Int16Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_self, __pyx_t_5numpy_int16_t __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_11Int16Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_11UInt8Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_self); /* proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_11UInt8Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_11UInt8Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_self, __pyx_t_5numpy_uint8_t __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_11UInt8Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_10Int8Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_self); /* proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_10Int8Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_10Int8Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_self, __pyx_t_5numpy_int8_t __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_10Int8Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_12StringVector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *__pyx_v_self); /* proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_12StringVector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_12StringVector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *__pyx_v_self, char *__pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_12StringVector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *__pyx_v_self, PyArrayObject *__pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_12ObjectVector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_self, PyObject *__pyx_v_obj); /* proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_12ObjectVector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_12ObjectVector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_self, PyArrayObject *__pyx_v_x); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_19Complex128HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, __pyx_t_double_complex __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_19Complex128HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_19Complex128HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, __pyx_t_double_complex __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_19Complex128HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_16Float64HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, __pyx_t_5numpy_float64_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_16Float64HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_16Float64HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, __pyx_t_5numpy_float64_t __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_16Float64HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt64HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, __pyx_t_5numpy_uint64_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt64HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt64HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, __pyx_t_5numpy_uint64_t __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt64HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int64HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int64HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int64HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int64HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_18Complex64HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, __pyx_t_float_complex __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_18Complex64HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_18Complex64HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, __pyx_t_float_complex __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_18Complex64HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_16Float32HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, __pyx_t_5numpy_float32_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_16Float32HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_16Float32HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, __pyx_t_5numpy_float32_t __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_16Float32HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt32HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, __pyx_t_5numpy_uint32_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt32HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt32HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, __pyx_t_5numpy_uint32_t __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt32HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int32HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, __pyx_t_5numpy_int32_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int32HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int32HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, __pyx_t_5numpy_int32_t __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int32HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt16HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, __pyx_t_5numpy_uint16_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt16HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt16HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, __pyx_t_5numpy_uint16_t __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt16HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int16HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, __pyx_t_5numpy_int16_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int16HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int16HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, __pyx_t_5numpy_int16_t __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int16HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14UInt8HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, __pyx_t_5numpy_uint8_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14UInt8HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14UInt8HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, __pyx_t_5numpy_uint8_t __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14UInt8HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_13Int8HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, __pyx_t_5numpy_int8_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_13Int8HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_13Int8HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, __pyx_t_5numpy_int8_t __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_13Int8HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15StringHashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, PyObject *__pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15StringHashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, PyObject *__pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_17PyObjectHashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, PyObject *__pyx_v_val, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_17PyObjectHashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, PyObject *__pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch); /* proto*/

/* Module declarations from "libc.string" */

/* Module declarations from "libc.stdio" */

/* Module declarations from "__builtin__" */

/* Module declarations from "cpython.type" */

/* Module declarations from "cpython" */

/* Module declarations from "cpython.object" */

/* Module declarations from "cpython.ref" */

/* Module declarations from "numpy" */

/* Module declarations from "numpy" */
static CYTHON_INLINE int __pyx_f_5numpy_import_array(void); /*proto*/

/* Module declarations from "pandas._libs.khash" */

/* Module declarations from "cython.view" */

/* Module declarations from "cython.dataclasses" */

/* Module declarations from "cython" */

/* Module declarations from "cpython.mem" */

/* Module declarations from "libc.stdlib" */

/* Module declarations from "pandas._libs" */

/* Module declarations from "libc.stdint" */

/* Module declarations from "pandas._libs.tslibs.util" */
static CYTHON_INLINE __pyx_t_5numpy_int64_t __pyx_f_6pandas_5_libs_6tslibs_4util_get_nat(void); /*proto*/
static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_integer_object(PyObject *); /*proto*/
static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_float_object(PyObject *); /*proto*/
static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_complex_object(PyObject *); /*proto*/
static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_bool_object(PyObject *); /*proto*/
static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_timedelta64_object(PyObject *); /*proto*/
static CYTHON_INLINE char const *__pyx_f_6pandas_5_libs_6tslibs_4util_get_c_string_buf_and_size(PyObject *, Py_ssize_t *); /*proto*/
static CYTHON_INLINE char const *__pyx_f_6pandas_5_libs_6tslibs_4util_get_c_string(PyObject *); /*proto*/

/* Module declarations from "pandas._libs.util" */

/* Module declarations from "pandas._libs.dtypes" */

/* Module declarations from "pandas._libs.missing" */
static struct __pyx_obj_6pandas_5_libs_7missing_C_NAType **__pyx_vp_6pandas_5_libs_7missing_C_NA = 0;
#define __pyx_v_6pandas_5_libs_7missing_C_NA (*__pyx_vp_6pandas_5_libs_7missing_C_NA)
static int (*__pyx_f_6pandas_5_libs_7missing_checknull)(PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_6pandas_5_libs_7missing_checknull *__pyx_optional_args); /*proto*/

/* Module declarations from "pandas._libs.hashtable" */
static __pyx_t_5numpy_int64_t __pyx_v_6pandas_5_libs_9hashtable_NPY_NAT;
static Py_ssize_t __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;
static PyObject *__pyx_collections_abc_Sequence = 0;
static PyObject *generic = 0;
static PyObject *strided = 0;
static PyObject *indirect = 0;
static PyObject *contiguous = 0;
static PyObject *indirect_contiguous = 0;
static int __pyx_memoryview_thread_locks_used;
static PyThread_type_lock __pyx_memoryview_thread_locks[8];
static khcomplex64_t __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex64_t(__pyx_t_float_complex); /*proto*/
static khcomplex128_t __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex128_t(__pyx_t_double_complex); /*proto*/
static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_khcomplex128_t(khcomplex128_t); /*proto*/
static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_khcomplex64_t(khcomplex64_t); /*proto*/
static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_float64_t(__pyx_t_5numpy_float64_t); /*proto*/
static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_float32_t(__pyx_t_5numpy_float32_t); /*proto*/
static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_int64_t(__pyx_t_5numpy_int64_t); /*proto*/
static int __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_int64_t(__pyx_t_5numpy_int64_t, __pyx_t_5numpy_int64_t); /*proto*/
static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_int32_t(__pyx_t_5numpy_int32_t); /*proto*/
static int __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_int32_t(__pyx_t_5numpy_int32_t, __pyx_t_5numpy_int32_t); /*proto*/
static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_int16_t(__pyx_t_5numpy_int16_t); /*proto*/
static int __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_int16_t(__pyx_t_5numpy_int16_t, __pyx_t_5numpy_int16_t); /*proto*/
static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_int8_t(__pyx_t_5numpy_int8_t); /*proto*/
static int __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_int8_t(__pyx_t_5numpy_int8_t, __pyx_t_5numpy_int8_t); /*proto*/
static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_uint64_t(__pyx_t_5numpy_uint64_t); /*proto*/
static int __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_uint64_t(__pyx_t_5numpy_uint64_t, __pyx_t_5numpy_uint64_t); /*proto*/
static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_uint32_t(__pyx_t_5numpy_uint32_t); /*proto*/
static int __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_uint32_t(__pyx_t_5numpy_uint32_t, __pyx_t_5numpy_uint32_t); /*proto*/
static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_uint16_t(__pyx_t_5numpy_uint16_t); /*proto*/
static int __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_uint16_t(__pyx_t_5numpy_uint16_t, __pyx_t_5numpy_uint16_t); /*proto*/
static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_uint8_t(__pyx_t_5numpy_uint8_t); /*proto*/
static int __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_uint8_t(__pyx_t_5numpy_uint8_t, __pyx_t_5numpy_uint8_t); /*proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_append_data_complex128(__pyx_t_6pandas_5_libs_9hashtable_Complex128VectorData *, khcomplex128_t); /*proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_append_data_complex64(__pyx_t_6pandas_5_libs_9hashtable_Complex64VectorData *, khcomplex64_t); /*proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_append_data_float64(__pyx_t_6pandas_5_libs_9hashtable_Float64VectorData *, __pyx_t_5numpy_float64_t); /*proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_append_data_float32(__pyx_t_6pandas_5_libs_9hashtable_Float32VectorData *, __pyx_t_5numpy_float32_t); /*proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_append_data_int64(struct __pyx_t_6pandas_5_libs_9hashtable_Int64VectorData *, __pyx_t_5numpy_int64_t); /*proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_append_data_int32(__pyx_t_6pandas_5_libs_9hashtable_Int32VectorData *, __pyx_t_5numpy_int32_t); /*proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_append_data_int16(__pyx_t_6pandas_5_libs_9hashtable_Int16VectorData *, __pyx_t_5numpy_int16_t); /*proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_append_data_int8(__pyx_t_6pandas_5_libs_9hashtable_Int8VectorData *, __pyx_t_5numpy_int8_t); /*proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_append_data_string(__pyx_t_6pandas_5_libs_9hashtable_StringVectorData *, char *); /*proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_append_data_uint64(__pyx_t_6pandas_5_libs_9hashtable_UInt64VectorData *, __pyx_t_5numpy_uint64_t); /*proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_append_data_uint32(__pyx_t_6pandas_5_libs_9hashtable_UInt32VectorData *, __pyx_t_5numpy_uint32_t); /*proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_append_data_uint16(__pyx_t_6pandas_5_libs_9hashtable_UInt16VectorData *, __pyx_t_5numpy_uint16_t); /*proto*/
static void __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *, __pyx_t_5numpy_uint8_t); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_complex128(__Pyx_memviewslice, int, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_complex128 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_complex128(__Pyx_memviewslice, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_complex128 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_complex128(__Pyx_memviewslice, __Pyx_memviewslice); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_complex64(__Pyx_memviewslice, int, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_complex64 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_complex64(__Pyx_memviewslice, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_complex64 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_complex64(__Pyx_memviewslice, __Pyx_memviewslice); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_float64(__Pyx_memviewslice, int, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_float64 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_float64(__Pyx_memviewslice, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_float64 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_float64(__Pyx_memviewslice, __Pyx_memviewslice); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_float32(__Pyx_memviewslice, int, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_float32 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_float32(__Pyx_memviewslice, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_float32 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_float32(__Pyx_memviewslice, __Pyx_memviewslice); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_uint64(__Pyx_memviewslice, int, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_uint64 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_uint64(__Pyx_memviewslice, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_uint64 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_uint64(__Pyx_memviewslice, __Pyx_memviewslice); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_uint32(__Pyx_memviewslice, int, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_uint32 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_uint32(__Pyx_memviewslice, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_uint32 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_uint32(__Pyx_memviewslice, __Pyx_memviewslice); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_uint16(__Pyx_memviewslice, int, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_uint16 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_uint16(__Pyx_memviewslice, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_uint16 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_uint16(__Pyx_memviewslice, __Pyx_memviewslice); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_uint8(__Pyx_memviewslice, int, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_uint8 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_uint8(__Pyx_memviewslice, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_uint8 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_uint8(__Pyx_memviewslice, __Pyx_memviewslice); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_object(PyArrayObject *, int, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_object *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_object(PyArrayObject *, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_object *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_object(PyArrayObject *, PyArrayObject *); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_int64(__Pyx_memviewslice, int, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_int64 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_int64(__Pyx_memviewslice, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_int64 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_int64(__Pyx_memviewslice, __Pyx_memviewslice); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_int32(__Pyx_memviewslice, int, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_int32 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_int32(__Pyx_memviewslice, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_int32 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_int32(__Pyx_memviewslice, __Pyx_memviewslice); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_int16(__Pyx_memviewslice, int, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_int16 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_int16(__Pyx_memviewslice, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_int16 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_int16(__Pyx_memviewslice, __Pyx_memviewslice); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_int8(__Pyx_memviewslice, int, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_int8 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_int8(__Pyx_memviewslice, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_int8 *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_int8(__Pyx_memviewslice, __Pyx_memviewslice); /*proto*/
static int __pyx_fuse_0__pyx_f_6pandas_5_libs_9hashtable_needs_resize(struct __pyx_t_6pandas_5_libs_9hashtable_Int64VectorData *); /*proto*/
static int __pyx_fuse_1__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_Int32VectorData *); /*proto*/
static int __pyx_fuse_2__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_Int16VectorData *); /*proto*/
static int __pyx_fuse_3__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_Int8VectorData *); /*proto*/
static int __pyx_fuse_4__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_UInt64VectorData *); /*proto*/
static int __pyx_fuse_5__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_UInt32VectorData *); /*proto*/
static int __pyx_fuse_6__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_UInt16VectorData *); /*proto*/
static int __pyx_fuse_7__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *); /*proto*/
static int __pyx_fuse_8__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_Float64VectorData *); /*proto*/
static int __pyx_fuse_9__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_Float32VectorData *); /*proto*/
static int __pyx_fuse_10__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_Complex128VectorData *); /*proto*/
static int __pyx_fuse_11__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_Complex64VectorData *); /*proto*/
static int __pyx_fuse_12__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_StringVectorData *); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable___pyx_unpickle_HashTable__set_state(struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable *, PyObject *); /*proto*/
static PyObject *__pyx_fuse_0__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *, int, int __pyx_skip_dispatch, struct __pyx_fuse_0__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_1__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *, int, int __pyx_skip_dispatch, struct __pyx_fuse_1__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_2__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *, int, int __pyx_skip_dispatch, struct __pyx_fuse_2__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_3__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *, int, int __pyx_skip_dispatch, struct __pyx_fuse_3__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_4__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *, int, int __pyx_skip_dispatch, struct __pyx_fuse_4__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_5__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *, int, int __pyx_skip_dispatch, struct __pyx_fuse_5__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_6__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *, int, int __pyx_skip_dispatch, struct __pyx_fuse_6__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_7__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *, int, int __pyx_skip_dispatch, struct __pyx_fuse_7__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_8__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *, int, int __pyx_skip_dispatch, struct __pyx_fuse_8__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_9__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *, int, int __pyx_skip_dispatch, struct __pyx_fuse_9__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_10__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *, int, int __pyx_skip_dispatch, struct __pyx_fuse_10__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_11__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *, int, int __pyx_skip_dispatch, struct __pyx_fuse_11__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_12__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *, int, int __pyx_skip_dispatch, struct __pyx_fuse_12__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_0__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *, int __pyx_skip_dispatch, struct __pyx_fuse_0__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_1__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *, int __pyx_skip_dispatch, struct __pyx_fuse_1__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_2__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *, int __pyx_skip_dispatch, struct __pyx_fuse_2__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_3__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *, int __pyx_skip_dispatch, struct __pyx_fuse_3__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_4__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *, int __pyx_skip_dispatch, struct __pyx_fuse_4__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_5__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *, int __pyx_skip_dispatch, struct __pyx_fuse_5__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_6__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *, int __pyx_skip_dispatch, struct __pyx_fuse_6__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_7__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *, int __pyx_skip_dispatch, struct __pyx_fuse_7__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_8__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *, int __pyx_skip_dispatch, struct __pyx_fuse_8__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_9__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *, int __pyx_skip_dispatch, struct __pyx_fuse_9__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_10__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *, int __pyx_skip_dispatch, struct __pyx_fuse_10__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_11__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *, int __pyx_skip_dispatch, struct __pyx_fuse_11__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_12__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *, int __pyx_skip_dispatch, struct __pyx_fuse_12__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args); /*proto*/
static PyObject *__pyx_fuse_0__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *, PyArrayObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_fuse_1__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *, PyArrayObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_fuse_2__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *, PyArrayObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_fuse_3__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *, PyArrayObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_fuse_4__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *, PyArrayObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_fuse_5__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *, PyArrayObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_fuse_6__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *, PyArrayObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_fuse_7__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *, PyArrayObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_fuse_8__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *, PyArrayObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_fuse_9__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *, PyArrayObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_fuse_10__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *, PyArrayObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_fuse_11__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *, PyArrayObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_fuse_12__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *, PyArrayObject *, int __pyx_skip_dispatch); /*proto*/
static int __pyx_array_allocate_buffer(struct __pyx_array_obj *); /*proto*/
static struct __pyx_array_obj *__pyx_array_new(PyObject *, Py_ssize_t, char *, char *, char *); /*proto*/
static PyObject *__pyx_memoryview_new(PyObject *, int, int, __Pyx_TypeInfo *); /*proto*/
static CYTHON_INLINE int __pyx_memoryview_check(PyObject *); /*proto*/
static PyObject *_unellipsify(PyObject *, int); /*proto*/
static int assert_direct_dimensions(Py_ssize_t *, int); /*proto*/
static struct __pyx_memoryview_obj *__pyx_memview_slice(struct __pyx_memoryview_obj *, PyObject *); /*proto*/
static int __pyx_memoryview_slice_memviewslice(__Pyx_memviewslice *, Py_ssize_t, Py_ssize_t, Py_ssize_t, int, int, int *, Py_ssize_t, Py_ssize_t, Py_ssize_t, int, int, int, int); /*proto*/
static char *__pyx_pybuffer_index(Py_buffer *, char *, Py_ssize_t, Py_ssize_t); /*proto*/
static int __pyx_memslice_transpose(__Pyx_memviewslice *); /*proto*/
static PyObject *__pyx_memoryview_fromslice(__Pyx_memviewslice, int, PyObject *(*)(char *), int (*)(char *, PyObject *), int); /*proto*/
static __Pyx_memviewslice *__pyx_memoryview_get_slice_from_memoryview(struct __pyx_memoryview_obj *, __Pyx_memviewslice *); /*proto*/
static void __pyx_memoryview_slice_copy(struct __pyx_memoryview_obj *, __Pyx_memviewslice *); /*proto*/
static PyObject *__pyx_memoryview_copy_object(struct __pyx_memoryview_obj *); /*proto*/
static PyObject *__pyx_memoryview_copy_object_from_slice(struct __pyx_memoryview_obj *, __Pyx_memviewslice *); /*proto*/
static Py_ssize_t abs_py_ssize_t(Py_ssize_t); /*proto*/
static char __pyx_get_best_slice_order(__Pyx_memviewslice *, int); /*proto*/
static void _copy_strided_to_strided(char *, Py_ssize_t *, char *, Py_ssize_t *, Py_ssize_t *, Py_ssize_t *, int, size_t); /*proto*/
static void copy_strided_to_strided(__Pyx_memviewslice *, __Pyx_memviewslice *, int, size_t); /*proto*/
static Py_ssize_t __pyx_memoryview_slice_get_size(__Pyx_memviewslice *, int); /*proto*/
static Py_ssize_t __pyx_fill_contig_strides_array(Py_ssize_t *, Py_ssize_t *, Py_ssize_t, int, char); /*proto*/
static void *__pyx_memoryview_copy_data_to_temp(__Pyx_memviewslice *, __Pyx_memviewslice *, char, int); /*proto*/
static int __pyx_memoryview_err_extents(int, Py_ssize_t, Py_ssize_t); /*proto*/
static int __pyx_memoryview_err_dim(PyObject *, PyObject *, int); /*proto*/
static int __pyx_memoryview_err(PyObject *, PyObject *); /*proto*/
static int __pyx_memoryview_err_no_memory(void); /*proto*/
static int __pyx_memoryview_copy_contents(__Pyx_memviewslice, __Pyx_memviewslice, int, int, int); /*proto*/
static void __pyx_memoryview_broadcast_leading(__Pyx_memviewslice *, int, int); /*proto*/
static void __pyx_memoryview_refcount_copying(__Pyx_memviewslice *, int, int, int); /*proto*/
static void __pyx_memoryview_refcount_objects_in_slice_with_gil(char *, Py_ssize_t *, Py_ssize_t *, int, int); /*proto*/
static void __pyx_memoryview_refcount_objects_in_slice(char *, Py_ssize_t *, Py_ssize_t *, int, int); /*proto*/
static void __pyx_memoryview_slice_assign_scalar(__Pyx_memviewslice *, int, size_t, void *, int); /*proto*/
static void __pyx_memoryview__slice_assign_scalar(char *, Py_ssize_t *, Py_ssize_t *, int, size_t, void *); /*proto*/
static PyObject *__pyx_unpickle_Enum__set_state(struct __pyx_MemviewEnum_obj *, PyObject *); /*proto*/
/* #### Code section: typeinfo ### */
static __Pyx_TypeInfo __Pyx_TypeInfo_object = { "Python object", NULL, sizeof(PyObject *), { 0 }, 0, 'O', 0, 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t = { "intp_t", NULL, sizeof(__pyx_t_5numpy_intp_t), { 0 }, 0, __PYX_IS_UNSIGNED(__pyx_t_5numpy_intp_t) ? 'U' : 'I', __PYX_IS_UNSIGNED(__pyx_t_5numpy_intp_t), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t = { "uint8_t", NULL, sizeof(__pyx_t_5numpy_uint8_t), { 0 }, 0, __PYX_IS_UNSIGNED(__pyx_t_5numpy_uint8_t) ? 'U' : 'I', __PYX_IS_UNSIGNED(__pyx_t_5numpy_uint8_t), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_int8_t = { "int8_t", NULL, sizeof(__pyx_t_5numpy_int8_t), { 0 }, 0, __PYX_IS_UNSIGNED(__pyx_t_5numpy_int8_t) ? 'U' : 'I', __PYX_IS_UNSIGNED(__pyx_t_5numpy_int8_t), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t = { "int16_t", NULL, sizeof(__pyx_t_5numpy_int16_t), { 0 }, 0, __PYX_IS_UNSIGNED(__pyx_t_5numpy_int16_t) ? 'U' : 'I', __PYX_IS_UNSIGNED(__pyx_t_5numpy_int16_t), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t = { "int32_t", NULL, sizeof(__pyx_t_5numpy_int32_t), { 0 }, 0, __PYX_IS_UNSIGNED(__pyx_t_5numpy_int32_t) ? 'U' : 'I', __PYX_IS_UNSIGNED(__pyx_t_5numpy_int32_t), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t = { "int64_t", NULL, sizeof(__pyx_t_5numpy_int64_t), { 0 }, 0, __PYX_IS_UNSIGNED(__pyx_t_5numpy_int64_t) ? 'U' : 'I', __PYX_IS_UNSIGNED(__pyx_t_5numpy_int64_t), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_uint16_t = { "uint16_t", NULL, sizeof(__pyx_t_5numpy_uint16_t), { 0 }, 0, __PYX_IS_UNSIGNED(__pyx_t_5numpy_uint16_t) ? 'U' : 'I', __PYX_IS_UNSIGNED(__pyx_t_5numpy_uint16_t), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_uint32_t = { "uint32_t", NULL, sizeof(__pyx_t_5numpy_uint32_t), { 0 }, 0, __PYX_IS_UNSIGNED(__pyx_t_5numpy_uint32_t) ? 'U' : 'I', __PYX_IS_UNSIGNED(__pyx_t_5numpy_uint32_t), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_uint64_t = { "uint64_t", NULL, sizeof(__pyx_t_5numpy_uint64_t), { 0 }, 0, __PYX_IS_UNSIGNED(__pyx_t_5numpy_uint64_t) ? 'U' : 'I', __PYX_IS_UNSIGNED(__pyx_t_5numpy_uint64_t), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t = { "float32_t", NULL, sizeof(__pyx_t_5numpy_float32_t), { 0 }, 0, 'R', 0, 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t = { "float64_t", NULL, sizeof(__pyx_t_5numpy_float64_t), { 0 }, 0, 'R', 0, 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo___pyx_t_double_complex = { "double complex", NULL, sizeof(__pyx_t_double_complex), { 0 }, 0, 'C', 0, 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo___pyx_t_float_complex = { "float complex", NULL, sizeof(__pyx_t_float_complex), { 0 }, 0, 'C', 0, 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t__const__ = { "const uint8_t", NULL, sizeof(__pyx_t_5numpy_uint8_t const ), { 0 }, 0, __PYX_IS_UNSIGNED(__pyx_t_5numpy_uint8_t const ) ? 'U' : 'I', __PYX_IS_UNSIGNED(__pyx_t_5numpy_uint8_t const ), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo___pyx_t_double_complex__const__ = { "const double complex", NULL, sizeof(__pyx_t_double_complex const ), { 0 }, 0, 'C', 0, 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_double = { "double", NULL, sizeof(double), { 0 }, 0, 'R', 0, 0 };
static __Pyx_StructField __Pyx_StructFields_nn_khcomplex128_t__const__[] = {
  {&__Pyx_TypeInfo_double, "real", offsetof(khcomplex128_t, real)},
  {&__Pyx_TypeInfo_double, "imag", offsetof(khcomplex128_t, imag)},
  {NULL, NULL, 0}
};
static __Pyx_TypeInfo __Pyx_TypeInfo_nn_khcomplex128_t__const__ = { "const khcomplex128_t", __Pyx_StructFields_nn_khcomplex128_t__const__, sizeof(khcomplex128_t const ), { 0 }, 0, 'C', 0, 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t__const__ = { "const float64_t", NULL, sizeof(__pyx_t_5numpy_float64_t const ), { 0 }, 0, 'R', 0, 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_uint64_t__const__ = { "const uint64_t", NULL, sizeof(__pyx_t_5numpy_uint64_t const ), { 0 }, 0, __PYX_IS_UNSIGNED(__pyx_t_5numpy_uint64_t const ) ? 'U' : 'I', __PYX_IS_UNSIGNED(__pyx_t_5numpy_uint64_t const ), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t__const__ = { "const int64_t", NULL, sizeof(__pyx_t_5numpy_int64_t const ), { 0 }, 0, __PYX_IS_UNSIGNED(__pyx_t_5numpy_int64_t const ) ? 'U' : 'I', __PYX_IS_UNSIGNED(__pyx_t_5numpy_int64_t const ), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo___pyx_t_float_complex__const__ = { "const float complex", NULL, sizeof(__pyx_t_float_complex const ), { 0 }, 0, 'C', 0, 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_float = { "float", NULL, sizeof(float), { 0 }, 0, 'R', 0, 0 };
static __Pyx_StructField __Pyx_StructFields_nn_khcomplex64_t__const__[] = {
  {&__Pyx_TypeInfo_float, "real", offsetof(khcomplex64_t, real)},
  {&__Pyx_TypeInfo_float, "imag", offsetof(khcomplex64_t, imag)},
  {NULL, NULL, 0}
};
static __Pyx_TypeInfo __Pyx_TypeInfo_nn_khcomplex64_t__const__ = { "const khcomplex64_t", __Pyx_StructFields_nn_khcomplex64_t__const__, sizeof(khcomplex64_t const ), { 0 }, 0, 'C', 0, 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t__const__ = { "const float32_t", NULL, sizeof(__pyx_t_5numpy_float32_t const ), { 0 }, 0, 'R', 0, 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_uint32_t__const__ = { "const uint32_t", NULL, sizeof(__pyx_t_5numpy_uint32_t const ), { 0 }, 0, __PYX_IS_UNSIGNED(__pyx_t_5numpy_uint32_t const ) ? 'U' : 'I', __PYX_IS_UNSIGNED(__pyx_t_5numpy_uint32_t const ), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t__const__ = { "const int32_t", NULL, sizeof(__pyx_t_5numpy_int32_t const ), { 0 }, 0, __PYX_IS_UNSIGNED(__pyx_t_5numpy_int32_t const ) ? 'U' : 'I', __PYX_IS_UNSIGNED(__pyx_t_5numpy_int32_t const ), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_uint16_t__const__ = { "const uint16_t", NULL, sizeof(__pyx_t_5numpy_uint16_t const ), { 0 }, 0, __PYX_IS_UNSIGNED(__pyx_t_5numpy_uint16_t const ) ? 'U' : 'I', __PYX_IS_UNSIGNED(__pyx_t_5numpy_uint16_t const ), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t__const__ = { "const int16_t", NULL, sizeof(__pyx_t_5numpy_int16_t const ), { 0 }, 0, __PYX_IS_UNSIGNED(__pyx_t_5numpy_int16_t const ) ? 'U' : 'I', __PYX_IS_UNSIGNED(__pyx_t_5numpy_int16_t const ), 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_int8_t__const__ = { "const int8_t", NULL, sizeof(__pyx_t_5numpy_int8_t const ), { 0 }, 0, __PYX_IS_UNSIGNED(__pyx_t_5numpy_int8_t const ) ? 'U' : 'I', __PYX_IS_UNSIGNED(__pyx_t_5numpy_int8_t const ), 0 };
/* #### Code section: before_global_var ### */
#define __Pyx_MODULE_NAME "pandas._libs.hashtable"
extern int __pyx_module_is_main_pandas___libs__hashtable;
int __pyx_module_is_main_pandas___libs__hashtable = 0;

/* Implementation of "pandas._libs.hashtable" */
/* #### Code section: global_var ### */
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_TypeError;
static PyObject *__pyx_builtin_MemoryError;
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_object;
static PyObject *__pyx_builtin_KeyError;
static PyObject *__pyx_builtin_NotImplementedError;
static PyObject *__pyx_builtin_UnicodeEncodeError;
static PyObject *__pyx_builtin___import__;
static PyObject *__pyx_builtin_enumerate;
static PyObject *__pyx_builtin_AssertionError;
static PyObject *__pyx_builtin_Ellipsis;
static PyObject *__pyx_builtin_id;
static PyObject *__pyx_builtin_IndexError;
static PyObject *__pyx_builtin_ImportError;
/* #### Code section: string_decls ### */
static const char __pyx_k_[] = ": ";
static const char __pyx_k_O[] = "O";
static const char __pyx_k_a[] = "a";
static const char __pyx_k_b[] = "b";
static const char __pyx_k_c[] = "c";
static const char __pyx_k_i[] = "i";
static const char __pyx_k_j[] = "j";
static const char __pyx_k_k[] = "k";
static const char __pyx_k_n[] = "n";
static const char __pyx_k_s[] = "s";
static const char __pyx_k_v[] = "v";
static const char __pyx_k_NA[] = "NA";
static const char __pyx_k__2[] = ".";
static const char __pyx_k__3[] = "*";
static const char __pyx_k__6[] = "'";
static const char __pyx_k__7[] = ")";
static const char __pyx_k_gc[] = "gc";
static const char __pyx_k_id[] = "id";
static const char __pyx_k_np[] = "np";
static const char __pyx_k_ud[] = "ud";
static const char __pyx_k__69[] = "()";
static const char __pyx_k__70[] = "|";
static const char __pyx_k__86[] = "";
static const char __pyx_k_abc[] = "abc";
static const char __pyx_k_and[] = " and ";
static const char __pyx_k_arr[] = "arr";
static const char __pyx_k_get[] = "get";
static const char __pyx_k_got[] = " (got ";
static const char __pyx_k_idx[] = "idx";
static const char __pyx_k_int[] = "int";
static const char __pyx_k_key[] = "key";
static const char __pyx_k_nan[] = "__nan__";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_obj[] = "obj";
static const char __pyx_k_ret[] = "ret";
static const char __pyx_k_rmd[] = "rmd";
static const char __pyx_k_sys[] = "sys";
static const char __pyx_k_val[] = "val";
static const char __pyx_k_None[] = "None";
static const char __pyx_k__191[] = "_";
static const char __pyx_k__490[] = "?";
static const char __pyx_k_args[] = "args";
static const char __pyx_k_base[] = "base";
static const char __pyx_k_bool[] = "bool";
static const char __pyx_k_deep[] = "deep";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_imag[] = "imag";
static const char __pyx_k_int8[] = "int8";
static const char __pyx_k_intp[] = "intp";
static const char __pyx_k_keep[] = "keep";
static const char __pyx_k_keys[] = "keys";
static const char __pyx_k_kind[] = "kind";
static const char __pyx_k_last[] = "last";
static const char __pyx_k_locs[] = "locs";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_mask[] = "mask";
static const char __pyx_k_mode[] = "mode";
static const char __pyx_k_name[] = "name";
static const char __pyx_k_ndim[] = "ndim";
static const char __pyx_k_pack[] = "pack";
static const char __pyx_k_real[] = "real";
static const char __pyx_k_self[] = "self";
static const char __pyx_k_size[] = "size";
static const char __pyx_k_spec[] = "__spec__";
static const char __pyx_k_step[] = "step";
static const char __pyx_k_stop[] = "stop";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_vecs[] = "vecs";
static const char __pyx_k_view[] = "view";
static const char __pyx_k_ASCII[] = "ASCII";
static const char __pyx_k_class[] = "__class__";
static const char __pyx_k_count[] = "count";
static const char __pyx_k_dtype[] = "dtype";
static const char __pyx_k_empty[] = "empty";
static const char __pyx_k_error[] = "error";
static const char __pyx_k_first[] = "first";
static const char __pyx_k_flags[] = "flags";
static const char __pyx_k_index[] = "index";
static const char __pyx_k_int16[] = "int16";
static const char __pyx_k_int32[] = "int32";
static const char __pyx_k_int64[] = "int64";
static const char __pyx_k_modes[] = "modes";
static const char __pyx_k_nkeys[] = "nkeys";
static const char __pyx_k_numpy[] = "numpy";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_shape[] = "shape";
static const char __pyx_k_split[] = "split";
static const char __pyx_k_start[] = "start";
static const char __pyx_k_state[] = "state";
static const char __pyx_k_strip[] = "strip";
static const char __pyx_k_table[] = "table";
static const char __pyx_k_uint8[] = "uint8";
static const char __pyx_k_zeros[] = "zeros";
static const char __pyx_k_Vector[] = "Vector";
static const char __pyx_k_bool_2[] = "bool_";
static const char __pyx_k_counts[] = "counts";
static const char __pyx_k_dict_2[] = "_dict";
static const char __pyx_k_dropna[] = "dropna";
static const char __pyx_k_enable[] = "enable";
static const char __pyx_k_encode[] = "encode";
static const char __pyx_k_format[] = "format";
static const char __pyx_k_get_na[] = "get_na";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_int8_t[] = "int8_t";
static const char __pyx_k_kwargs[] = "kwargs";
static const char __pyx_k_labels[] = "labels";
static const char __pyx_k_lookup[] = "lookup";
static const char __pyx_k_name_2[] = "__name__";
static const char __pyx_k_object[] = "object";
static const char __pyx_k_pickle[] = "pickle";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_resbuf[] = "resbuf";
static const char __pyx_k_resize[] = "resize";
static const char __pyx_k_return[] = "return";
static const char __pyx_k_set_na[] = "set_na";
static const char __pyx_k_sizeof[] = "sizeof";
static const char __pyx_k_struct[] = "struct";
static const char __pyx_k_uint16[] = "uint16";
static const char __pyx_k_uint32[] = "uint32";
static const char __pyx_k_uint64[] = "uint64";
static const char __pyx_k_unique[] = "_unique";
static const char __pyx_k_unpack[] = "unpack";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_values[] = "values";
static const char __pyx_k_argsort[] = "argsort";
static const char __pyx_k_asarray[] = "asarray";
static const char __pyx_k_disable[] = "disable";
static const char __pyx_k_float32[] = "float32";
static const char __pyx_k_float64[] = "float64";
static const char __pyx_k_fortran[] = "fortran";
static const char __pyx_k_int16_t[] = "int16_t";
static const char __pyx_k_int32_t[] = "int32_t";
static const char __pyx_k_int64_t[] = "int64_t";
static const char __pyx_k_memview[] = "memview";
static const char __pyx_k_ndarray[] = "ndarray";
static const char __pyx_k_seen_na[] = "seen_na";
static const char __pyx_k_uint8_t[] = "uint8_t";
static const char __pyx_k_uniques[] = "uniques";
static const char __pyx_k_Ellipsis[] = "Ellipsis";
static const char __pyx_k_KeyError[] = "KeyError";
static const char __pyx_k_Sequence[] = "Sequence";
static const char __pyx_k_defaults[] = "defaults";
static const char __pyx_k_get_item[] = "get_item";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_ismember[] = "ismember";
static const char __pyx_k_itemsize[] = "itemsize";
static const char __pyx_k_na_value[] = "na_value";
static const char __pyx_k_overhead[] = "overhead";
static const char __pyx_k_pyx_type[] = "__pyx_type";
static const char __pyx_k_refcheck[] = "refcheck";
static const char __pyx_k_register[] = "register";
static const char __pyx_k_set_item[] = "set_item";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_to_array[] = "to_array";
static const char __pyx_k_uindexer[] = "uindexer";
static const char __pyx_k_uint16_t[] = "uint16_t";
static const char __pyx_k_uint32_t[] = "uint32_t";
static const char __pyx_k_uint64_t[] = "uint64_t";
static const char __pyx_k_unique_2[] = "unique";
static const char __pyx_k_use_mask[] = "use_mask";
static const char __pyx_k_HashTable[] = "HashTable";
static const char __pyx_k_TypeError[] = "TypeError";
static const char __pyx_k_complex64[] = "complex64";
static const char __pyx_k_enumerate[] = "enumerate";
static const char __pyx_k_factorize[] = "factorize";
static const char __pyx_k_float32_t[] = "float32_t";
static const char __pyx_k_float64_t[] = "float64_t";
static const char __pyx_k_for_flags[] = "for_flags";
static const char __pyx_k_for_pairs[] = "for_pairs";
static const char __pyx_k_get_count[] = "get_count";
static const char __pyx_k_get_state[] = "get_state";
static const char __pyx_k_ignore_na[] = "ignore_na";
static const char __pyx_k_isenabled[] = "isenabled";
static const char __pyx_k_max_count[] = "max_count";
static const char __pyx_k_n_buckets[] = "n_buckets";
static const char __pyx_k_na_value2[] = "na_value2";
static const char __pyx_k_pyx_state[] = "__pyx_state";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_size_hint[] = "size_hint";
static const char __pyx_k_uses_mask[] = "uses_mask";
static const char __pyx_k_Factorizer[] = "Factorizer";
static const char __pyx_k_IndexError[] = "IndexError";
static const char __pyx_k_Int8Vector[] = "Int8Vector";
static const char __pyx_k_ValueError[] = "ValueError";
static const char __pyx_k_complex128[] = "complex128";
static const char __pyx_k_duplicated[] = "duplicated";
static const char __pyx_k_get_labels[] = "get_labels";
static const char __pyx_k_n_occupied[] = "n_occupied";
static const char __pyx_k_np_ndarray[] = "np.ndarray";
static const char __pyx_k_pyx_result[] = "__pyx_result";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_signatures[] = "signatures";
static const char __pyx_k_ImportError[] = "ImportError";
static const char __pyx_k_Int16Vector[] = "Int16Vector";
static const char __pyx_k_Int32Vector[] = "Int32Vector";
static const char __pyx_k_Int64Vector[] = "Int64Vector";
static const char __pyx_k_MemoryError[] = "MemoryError";
static const char __pyx_k_PickleError[] = "PickleError";
static const char __pyx_k_UInt8Vector[] = "UInt8Vector";
static const char __pyx_k_arr_uniques[] = "arr_uniques";
static const char __pyx_k_collections[] = "collections";
static const char __pyx_k_count_prior[] = "count_prior";
static const char __pyx_k_get_indexer[] = "get_indexer";
static const char __pyx_k_mask_values[] = "mask_values";
static const char __pyx_k_na_position[] = "na_position";
static const char __pyx_k_na_sentinel[] = "na_sentinel";
static const char __pyx_k_object_hash[] = "object_hash";
static const char __pyx_k_result_mask[] = "result_mask";
static const char __pyx_k_upper_bound[] = "upper_bound";
static const char __pyx_k_value_count[] = "value_count";
static const char __pyx_k_ObjectVector[] = "ObjectVector";
static const char __pyx_k_StringVector[] = "StringVector";
static const char __pyx_k_UInt16Vector[] = "UInt16Vector";
static const char __pyx_k_UInt32Vector[] = "UInt32Vector";
static const char __pyx_k_UInt64Vector[] = "UInt64Vector";
static const char __pyx_k_dict_str_int[] = "dict[str, int]";
static const char __pyx_k_initializing[] = "_initializing";
static const char __pyx_k_is_coroutine[] = "_is_coroutine";
static const char __pyx_k_pyx_checksum[] = "__pyx_checksum";
static const char __pyx_k_stringsource[] = "<stringsource>";
static const char __pyx_k_use_na_value[] = "use_na_value";
static const char __pyx_k_use_setstate[] = "use_setstate";
static const char __pyx_k_version_info[] = "version_info";
static const char __pyx_k_Float32Vector[] = "Float32Vector";
static const char __pyx_k_Float64Vector[] = "Float64Vector";
static const char __pyx_k_Int8HashTable[] = "Int8HashTable";
static const char __pyx_k_IntpHashTable[] = "IntpHashTable";
static const char __pyx_k_class_getitem[] = "__class_getitem__";
static const char __pyx_k_float_complex[] = "float complex";
static const char __pyx_k_map_locations[] = "map_locations";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_AssertionError[] = "AssertionError";
static const char __pyx_k_Int16HashTable[] = "Int16HashTable";
static const char __pyx_k_Int32HashTable[] = "Int32HashTable";
static const char __pyx_k_Int64HashTable[] = "Int64HashTable";
static const char __pyx_k_Int8Factorizer[] = "Int8Factorizer";
static const char __pyx_k_UInt8HashTable[] = "UInt8HashTable";
static const char __pyx_k_double_complex[] = "double complex";
static const char __pyx_k_fused_sigindex[] = "_fused_sigindex";
static const char __pyx_k_return_inverse[] = "return_inverse";
static const char __pyx_k_uniques_vector[] = "uniques_vector";
static const char __pyx_k_Complex64Vector[] = "Complex64Vector";
static const char __pyx_k_Int16Factorizer[] = "Int16Factorizer";
static const char __pyx_k_Int32Factorizer[] = "Int32Factorizer";
static const char __pyx_k_Int64Factorizer[] = "Int64Factorizer";
static const char __pyx_k_SIZE_HINT_LIMIT[] = "SIZE_HINT_LIMIT";
static const char __pyx_k_StringHashTable[] = "StringHashTable";
static const char __pyx_k_UInt16HashTable[] = "UInt16HashTable";
static const char __pyx_k_UInt32HashTable[] = "UInt32HashTable";
static const char __pyx_k_UInt64HashTable[] = "UInt64HashTable";
static const char __pyx_k_UInt8Factorizer[] = "UInt8Factorizer";
static const char __pyx_k_View_MemoryView[] = "View.MemoryView";
static const char __pyx_k_allocate_buffer[] = "allocate_buffer";
static const char __pyx_k_collections_abc[] = "collections.abc";
static const char __pyx_k_dtype_is_object[] = "dtype_is_object";
static const char __pyx_k_pyx_PickleError[] = "__pyx_PickleError";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_use_result_mask[] = "use_result_mask";
static const char __pyx_k_Complex128Vector[] = "Complex128Vector";
static const char __pyx_k_Float32HashTable[] = "Float32HashTable";
static const char __pyx_k_Float64HashTable[] = "Float64HashTable";
static const char __pyx_k_ObjectFactorizer[] = "ObjectFactorizer";
static const char __pyx_k_UInt16Factorizer[] = "UInt16Factorizer";
static const char __pyx_k_UInt32Factorizer[] = "UInt32Factorizer";
static const char __pyx_k_UInt64Factorizer[] = "UInt64Factorizer";
static const char __pyx_k_Float32Factorizer[] = "Float32Factorizer";
static const char __pyx_k_Float64Factorizer[] = "Float64Factorizer";
static const char __pyx_k_PyObjectHashTable[] = "PyObjectHashTable";
static const char __pyx_k_objects_are_equal[] = "objects_are_equal";
static const char __pyx_k_pyx_unpickle_Enum[] = "__pyx_unpickle_Enum";
static const char __pyx_k_Complex64HashTable[] = "Complex64HashTable";
static const char __pyx_k_UnicodeEncodeError[] = "UnicodeEncodeError";
static const char __pyx_k_asyncio_coroutines[] = "asyncio.coroutines";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_get_labels_groupby[] = "get_labels_groupby";
static const char __pyx_k_map_keys_to_values[] = "map_keys_to_values";
static const char __pyx_k_na_string_sentinel[] = "na_string_sentinel";
static const char __pyx_k_pyx_fuse_0ismember[] = "__pyx_fuse_0ismember";
static const char __pyx_k_pyx_fuse_1ismember[] = "__pyx_fuse_1ismember";
static const char __pyx_k_pyx_fuse_2ismember[] = "__pyx_fuse_2ismember";
static const char __pyx_k_pyx_fuse_3ismember[] = "__pyx_fuse_3ismember";
static const char __pyx_k_pyx_fuse_4ismember[] = "__pyx_fuse_4ismember";
static const char __pyx_k_pyx_fuse_5ismember[] = "__pyx_fuse_5ismember";
static const char __pyx_k_pyx_fuse_6ismember[] = "__pyx_fuse_6ismember";
static const char __pyx_k_pyx_fuse_7ismember[] = "__pyx_fuse_7ismember";
static const char __pyx_k_pyx_fuse_8ismember[] = "__pyx_fuse_8ismember";
static const char __pyx_k_pyx_fuse_9ismember[] = "__pyx_fuse_9ismember";
static const char __pyx_k_strided_and_direct[] = "<strided and direct>";
static const char __pyx_k_Complex128HashTable[] = "Complex128HashTable";
static const char __pyx_k_Complex64Factorizer[] = "Complex64Factorizer";
static const char __pyx_k_Int8Vector_to_array[] = "Int8Vector.to_array";
static const char __pyx_k_NotImplementedError[] = "NotImplementedError";
static const char __pyx_k_pyx_fuse_10ismember[] = "__pyx_fuse_10ismember";
static const char __pyx_k_pyx_fuse_11ismember[] = "__pyx_fuse_11ismember";
static const char __pyx_k_pyx_fuse_12ismember[] = "__pyx_fuse_12ismember";
static const char __pyx_k_Complex128Factorizer[] = "Complex128Factorizer";
static const char __pyx_k_Factorizer_factorize[] = "Factorizer.factorize";
static const char __pyx_k_Factorizer_get_count[] = "Factorizer.get_count";
static const char __pyx_k_Int16Vector_to_array[] = "Int16Vector.to_array";
static const char __pyx_k_Int32Vector_to_array[] = "Int32Vector.to_array";
static const char __pyx_k_Int64Vector_to_array[] = "Int64Vector.to_array";
static const char __pyx_k_Int8HashTable_get_na[] = "Int8HashTable.get_na";
static const char __pyx_k_Int8HashTable_lookup[] = "Int8HashTable.lookup";
static const char __pyx_k_Int8HashTable_set_na[] = "Int8HashTable.set_na";
static const char __pyx_k_Int8HashTable_sizeof[] = "Int8HashTable.sizeof";
static const char __pyx_k_Int8HashTable_unique[] = "Int8HashTable.unique";
static const char __pyx_k_UInt8Vector_to_array[] = "UInt8Vector.to_array";
static const char __pyx_k_pyx_fuse_0duplicated[] = "__pyx_fuse_0duplicated";
static const char __pyx_k_pyx_fuse_1duplicated[] = "__pyx_fuse_1duplicated";
static const char __pyx_k_pyx_fuse_2duplicated[] = "__pyx_fuse_2duplicated";
static const char __pyx_k_pyx_fuse_3duplicated[] = "__pyx_fuse_3duplicated";
static const char __pyx_k_pyx_fuse_4duplicated[] = "__pyx_fuse_4duplicated";
static const char __pyx_k_pyx_fuse_5duplicated[] = "__pyx_fuse_5duplicated";
static const char __pyx_k_pyx_fuse_6duplicated[] = "__pyx_fuse_6duplicated";
static const char __pyx_k_pyx_fuse_7duplicated[] = "__pyx_fuse_7duplicated";
static const char __pyx_k_pyx_fuse_8duplicated[] = "__pyx_fuse_8duplicated";
static const char __pyx_k_pyx_fuse_9duplicated[] = "__pyx_fuse_9duplicated";
static const char __pyx_k_strided_and_indirect[] = "<strided and indirect>";
static const char __pyx_k_unique_label_indices[] = "unique_label_indices";
static const char __pyx_k_Int16HashTable_get_na[] = "Int16HashTable.get_na";
static const char __pyx_k_Int16HashTable_lookup[] = "Int16HashTable.lookup";
static const char __pyx_k_Int16HashTable_set_na[] = "Int16HashTable.set_na";
static const char __pyx_k_Int16HashTable_sizeof[] = "Int16HashTable.sizeof";
static const char __pyx_k_Int16HashTable_unique[] = "Int16HashTable.unique";
static const char __pyx_k_Int32HashTable_get_na[] = "Int32HashTable.get_na";
static const char __pyx_k_Int32HashTable_lookup[] = "Int32HashTable.lookup";
static const char __pyx_k_Int32HashTable_set_na[] = "Int32HashTable.set_na";
static const char __pyx_k_Int32HashTable_sizeof[] = "Int32HashTable.sizeof";
static const char __pyx_k_Int32HashTable_unique[] = "Int32HashTable.unique";
static const char __pyx_k_Int64HashTable_get_na[] = "Int64HashTable.get_na";
static const char __pyx_k_Int64HashTable_lookup[] = "Int64HashTable.lookup";
static const char __pyx_k_Int64HashTable_set_na[] = "Int64HashTable.set_na";
static const char __pyx_k_Int64HashTable_sizeof[] = "Int64HashTable.sizeof";
static const char __pyx_k_Int64HashTable_unique[] = "Int64HashTable.unique";
static const char __pyx_k_Int8HashTable__unique[] = "Int8HashTable._unique";
static const char __pyx_k_Invalid_shape_in_axis[] = "Invalid shape in axis ";
static const char __pyx_k_ObjectVector_to_array[] = "ObjectVector.to_array";
static const char __pyx_k_StringVector_to_array[] = "StringVector.to_array";
static const char __pyx_k_UInt16Vector_to_array[] = "UInt16Vector.to_array";
static const char __pyx_k_UInt32Vector_to_array[] = "UInt32Vector.to_array";
static const char __pyx_k_UInt64Vector_to_array[] = "UInt64Vector.to_array";
static const char __pyx_k_UInt8HashTable_get_na[] = "UInt8HashTable.get_na";
static const char __pyx_k_UInt8HashTable_lookup[] = "UInt8HashTable.lookup";
static const char __pyx_k_UInt8HashTable_set_na[] = "UInt8HashTable.set_na";
static const char __pyx_k_UInt8HashTable_sizeof[] = "UInt8HashTable.sizeof";
static const char __pyx_k_UInt8HashTable_unique[] = "UInt8HashTable.unique";
static const char __pyx_k_contiguous_and_direct[] = "<contiguous and direct>";
static const char __pyx_k_pyx_fuse_0value_count[] = "__pyx_fuse_0value_count";
static const char __pyx_k_pyx_fuse_10duplicated[] = "__pyx_fuse_10duplicated";
static const char __pyx_k_pyx_fuse_11duplicated[] = "__pyx_fuse_11duplicated";
static const char __pyx_k_pyx_fuse_12duplicated[] = "__pyx_fuse_12duplicated";
static const char __pyx_k_pyx_fuse_1value_count[] = "__pyx_fuse_1value_count";
static const char __pyx_k_pyx_fuse_2value_count[] = "__pyx_fuse_2value_count";
static const char __pyx_k_pyx_fuse_3value_count[] = "__pyx_fuse_3value_count";
static const char __pyx_k_pyx_fuse_4value_count[] = "__pyx_fuse_4value_count";
static const char __pyx_k_pyx_fuse_5value_count[] = "__pyx_fuse_5value_count";
static const char __pyx_k_pyx_fuse_6value_count[] = "__pyx_fuse_6value_count";
static const char __pyx_k_pyx_fuse_7value_count[] = "__pyx_fuse_7value_count";
static const char __pyx_k_pyx_fuse_8value_count[] = "__pyx_fuse_8value_count";
static const char __pyx_k_pyx_fuse_9value_count[] = "__pyx_fuse_9value_count";
static const char __pyx_k_tuple_ndarray_ndarray[] = "tuple[ndarray, ndarray]";
static const char __pyx_k_Cannot_index_with_type[] = "Cannot index with type '";
static const char __pyx_k_Float32Vector_to_array[] = "Float32Vector.to_array";
static const char __pyx_k_Float64Vector_to_array[] = "Float64Vector.to_array";
static const char __pyx_k_Int16HashTable__unique[] = "Int16HashTable._unique";
static const char __pyx_k_Int32HashTable__unique[] = "Int32HashTable._unique";
static const char __pyx_k_Int64HashTable__unique[] = "Int64HashTable._unique";
static const char __pyx_k_Int8HashTable_get_item[] = "Int8HashTable.get_item";
static const char __pyx_k_Int8HashTable_set_item[] = "Int8HashTable.set_item";
static const char __pyx_k_MemoryView_of_r_object[] = "<MemoryView of %r object>";
static const char __pyx_k_StringHashTable_lookup[] = "StringHashTable.lookup";
static const char __pyx_k_StringHashTable_sizeof[] = "StringHashTable.sizeof";
static const char __pyx_k_StringHashTable_unique[] = "StringHashTable.unique";
static const char __pyx_k_UInt16HashTable_get_na[] = "UInt16HashTable.get_na";
static const char __pyx_k_UInt16HashTable_lookup[] = "UInt16HashTable.lookup";
static const char __pyx_k_UInt16HashTable_set_na[] = "UInt16HashTable.set_na";
static const char __pyx_k_UInt16HashTable_sizeof[] = "UInt16HashTable.sizeof";
static const char __pyx_k_UInt16HashTable_unique[] = "UInt16HashTable.unique";
static const char __pyx_k_UInt32HashTable_get_na[] = "UInt32HashTable.get_na";
static const char __pyx_k_UInt32HashTable_lookup[] = "UInt32HashTable.lookup";
static const char __pyx_k_UInt32HashTable_set_na[] = "UInt32HashTable.set_na";
static const char __pyx_k_UInt32HashTable_sizeof[] = "UInt32HashTable.sizeof";
static const char __pyx_k_UInt32HashTable_unique[] = "UInt32HashTable.unique";
static const char __pyx_k_UInt64HashTable_get_na[] = "UInt64HashTable.get_na";
static const char __pyx_k_UInt64HashTable_lookup[] = "UInt64HashTable.lookup";
static const char __pyx_k_UInt64HashTable_set_na[] = "UInt64HashTable.set_na";
static const char __pyx_k_UInt64HashTable_sizeof[] = "UInt64HashTable.sizeof";
static const char __pyx_k_UInt64HashTable_unique[] = "UInt64HashTable.unique";
static const char __pyx_k_UInt8HashTable__unique[] = "UInt8HashTable._unique";
static const char __pyx_k_Vector___reduce_cython[] = "Vector.__reduce_cython__";
static const char __pyx_k_pandas__libs_hashtable[] = "pandas._libs.hashtable";
static const char __pyx_k_pyx_fuse_10value_count[] = "__pyx_fuse_10value_count";
static const char __pyx_k_pyx_fuse_11value_count[] = "__pyx_fuse_11value_count";
static const char __pyx_k_pyx_fuse_12value_count[] = "__pyx_fuse_12value_count";
static const char __pyx_k_pyx_unpickle_HashTable[] = "__pyx_unpickle_HashTable";
static const char __pyx_k_Float32HashTable_get_na[] = "Float32HashTable.get_na";
static const char __pyx_k_Float32HashTable_lookup[] = "Float32HashTable.lookup";
static const char __pyx_k_Float32HashTable_set_na[] = "Float32HashTable.set_na";
static const char __pyx_k_Float32HashTable_sizeof[] = "Float32HashTable.sizeof";
static const char __pyx_k_Float32HashTable_unique[] = "Float32HashTable.unique";
static const char __pyx_k_Float64HashTable_get_na[] = "Float64HashTable.get_na";
static const char __pyx_k_Float64HashTable_lookup[] = "Float64HashTable.lookup";
static const char __pyx_k_Float64HashTable_set_na[] = "Float64HashTable.set_na";
static const char __pyx_k_Float64HashTable_sizeof[] = "Float64HashTable.sizeof";
static const char __pyx_k_Float64HashTable_unique[] = "Float64HashTable.unique";
static const char __pyx_k_Int16HashTable_get_item[] = "Int16HashTable.get_item";
static const char __pyx_k_Int16HashTable_set_item[] = "Int16HashTable.set_item";
static const char __pyx_k_Int32HashTable_get_item[] = "Int32HashTable.get_item";
static const char __pyx_k_Int32HashTable_set_item[] = "Int32HashTable.set_item";
static const char __pyx_k_Int64HashTable_get_item[] = "Int64HashTable.get_item";
static const char __pyx_k_Int64HashTable_set_item[] = "Int64HashTable.set_item";
static const char __pyx_k_Int8HashTable_factorize[] = "Int8HashTable.factorize";
static const char __pyx_k_Int8HashTable_get_state[] = "Int8HashTable.get_state";
static const char __pyx_k_MemoryView_of_r_at_0x_x[] = "<MemoryView of %r at 0x%x>";
static const char __pyx_k_StringHashTable__unique[] = "StringHashTable._unique";
static const char __pyx_k_UInt16HashTable__unique[] = "UInt16HashTable._unique";
static const char __pyx_k_UInt32HashTable__unique[] = "UInt32HashTable._unique";
static const char __pyx_k_UInt64HashTable__unique[] = "UInt64HashTable._unique";
static const char __pyx_k_UInt8HashTable_get_item[] = "UInt8HashTable.get_item";
static const char __pyx_k_UInt8HashTable_set_item[] = "UInt8HashTable.set_item";
static const char __pyx_k_contiguous_and_indirect[] = "<contiguous and indirect>";
static const char __pyx_k_Complex64Vector_to_array[] = "Complex64Vector.to_array";
static const char __pyx_k_Float32HashTable__unique[] = "Float32HashTable._unique";
static const char __pyx_k_Float64HashTable__unique[] = "Float64HashTable._unique";
static const char __pyx_k_Int16HashTable_factorize[] = "Int16HashTable.factorize";
static const char __pyx_k_Int16HashTable_get_state[] = "Int16HashTable.get_state";
static const char __pyx_k_Int32HashTable_factorize[] = "Int32HashTable.factorize";
static const char __pyx_k_Int32HashTable_get_state[] = "Int32HashTable.get_state";
static const char __pyx_k_Int64HashTable_factorize[] = "Int64HashTable.factorize";
static const char __pyx_k_Int64HashTable_get_state[] = "Int64HashTable.get_state";
static const char __pyx_k_Int8Factorizer_factorize[] = "Int8Factorizer.factorize";
static const char __pyx_k_Int8HashTable_get_labels[] = "Int8HashTable.get_labels";
static const char __pyx_k_PyObjectHashTable_lookup[] = "PyObjectHashTable.lookup";
static const char __pyx_k_PyObjectHashTable_sizeof[] = "PyObjectHashTable.sizeof";
static const char __pyx_k_PyObjectHashTable_unique[] = "PyObjectHashTable.unique";
static const char __pyx_k_StringHashTable_get_item[] = "StringHashTable.get_item";
static const char __pyx_k_StringHashTable_set_item[] = "StringHashTable.set_item";
static const char __pyx_k_UInt16HashTable_get_item[] = "UInt16HashTable.get_item";
static const char __pyx_k_UInt16HashTable_set_item[] = "UInt16HashTable.set_item";
static const char __pyx_k_UInt32HashTable_get_item[] = "UInt32HashTable.get_item";
static const char __pyx_k_UInt32HashTable_set_item[] = "UInt32HashTable.set_item";
static const char __pyx_k_UInt64HashTable_get_item[] = "UInt64HashTable.get_item";
static const char __pyx_k_UInt64HashTable_set_item[] = "UInt64HashTable.set_item";
static const char __pyx_k_UInt8HashTable_factorize[] = "UInt8HashTable.factorize";
static const char __pyx_k_UInt8HashTable_get_state[] = "UInt8HashTable.get_state";
static const char __pyx_k_Vector___setstate_cython[] = "Vector.__setstate_cython__";
static const char __pyx_k_Complex128Vector_to_array[] = "Complex128Vector.to_array";
static const char __pyx_k_Complex64HashTable_get_na[] = "Complex64HashTable.get_na";
static const char __pyx_k_Complex64HashTable_lookup[] = "Complex64HashTable.lookup";
static const char __pyx_k_Complex64HashTable_set_na[] = "Complex64HashTable.set_na";
static const char __pyx_k_Complex64HashTable_sizeof[] = "Complex64HashTable.sizeof";
static const char __pyx_k_Complex64HashTable_unique[] = "Complex64HashTable.unique";
static const char __pyx_k_Dimension_d_is_not_direct[] = "Dimension %d is not direct";
static const char __pyx_k_Float32HashTable_get_item[] = "Float32HashTable.get_item";
static const char __pyx_k_Float32HashTable_set_item[] = "Float32HashTable.set_item";
static const char __pyx_k_Float64HashTable_get_item[] = "Float64HashTable.get_item";
static const char __pyx_k_Float64HashTable_set_item[] = "Float64HashTable.set_item";
static const char __pyx_k_HashTable___reduce_cython[] = "HashTable.__reduce_cython__";
static const char __pyx_k_Int16Factorizer_factorize[] = "Int16Factorizer.factorize";
static const char __pyx_k_Int16HashTable_get_labels[] = "Int16HashTable.get_labels";
static const char __pyx_k_Int32Factorizer_factorize[] = "Int32Factorizer.factorize";
static const char __pyx_k_Int32HashTable_get_labels[] = "Int32HashTable.get_labels";
static const char __pyx_k_Int64Factorizer_factorize[] = "Int64Factorizer.factorize";
static const char __pyx_k_Int64HashTable_get_labels[] = "Int64HashTable.get_labels";
static const char __pyx_k_PyObjectHashTable__unique[] = "PyObjectHashTable._unique";
static const char __pyx_k_StringHashTable_factorize[] = "StringHashTable.factorize";
static const char __pyx_k_StringHashTable_get_state[] = "StringHashTable.get_state";
static const char __pyx_k_UInt16HashTable_factorize[] = "UInt16HashTable.factorize";
static const char __pyx_k_UInt16HashTable_get_state[] = "UInt16HashTable.get_state";
static const char __pyx_k_UInt32HashTable_factorize[] = "UInt32HashTable.factorize";
static const char __pyx_k_UInt32HashTable_get_state[] = "UInt32HashTable.get_state";
static const char __pyx_k_UInt64HashTable_factorize[] = "UInt64HashTable.factorize";
static const char __pyx_k_UInt64HashTable_get_state[] = "UInt64HashTable.get_state";
static const char __pyx_k_UInt8Factorizer_factorize[] = "UInt8Factorizer.factorize";
static const char __pyx_k_UInt8HashTable_get_labels[] = "UInt8HashTable.get_labels";
static const char __pyx_k_Complex128HashTable_get_na[] = "Complex128HashTable.get_na";
static const char __pyx_k_Complex128HashTable_lookup[] = "Complex128HashTable.lookup";
static const char __pyx_k_Complex128HashTable_set_na[] = "Complex128HashTable.set_na";
static const char __pyx_k_Complex128HashTable_sizeof[] = "Complex128HashTable.sizeof";
static const char __pyx_k_Complex128HashTable_unique[] = "Complex128HashTable.unique";
static const char __pyx_k_Complex64HashTable__unique[] = "Complex64HashTable._unique";
static const char __pyx_k_Factorizer___reduce_cython[] = "Factorizer.__reduce_cython__";
static const char __pyx_k_Float32HashTable_factorize[] = "Float32HashTable.factorize";
static const char __pyx_k_Float32HashTable_get_state[] = "Float32HashTable.get_state";
static const char __pyx_k_Float64HashTable_factorize[] = "Float64HashTable.factorize";
static const char __pyx_k_Float64HashTable_get_state[] = "Float64HashTable.get_state";
static const char __pyx_k_Index_out_of_bounds_axis_d[] = "Index out of bounds (axis %d)";
static const char __pyx_k_Int8Vector___reduce_cython[] = "Int8Vector.__reduce_cython__";
static const char __pyx_k_ObjectFactorizer_factorize[] = "ObjectFactorizer.factorize";
static const char __pyx_k_PyObjectHashTable_get_item[] = "PyObjectHashTable.get_item";
static const char __pyx_k_PyObjectHashTable_set_item[] = "PyObjectHashTable.set_item";
static const char __pyx_k_StringHashTable_get_labels[] = "StringHashTable.get_labels";
static const char __pyx_k_UInt16Factorizer_factorize[] = "UInt16Factorizer.factorize";
static const char __pyx_k_UInt16HashTable_get_labels[] = "UInt16HashTable.get_labels";
static const char __pyx_k_UInt32Factorizer_factorize[] = "UInt32Factorizer.factorize";
static const char __pyx_k_UInt32HashTable_get_labels[] = "UInt32HashTable.get_labels";
static const char __pyx_k_UInt64Factorizer_factorize[] = "UInt64Factorizer.factorize";
static const char __pyx_k_UInt64HashTable_get_labels[] = "UInt64HashTable.get_labels";
static const char __pyx_k_get_hashtable_trace_domain[] = "get_hashtable_trace_domain";
static const char __pyx_k_pandas__libs_hashtable_pyx[] = "pandas/_libs/hashtable.pyx";
static const char __pyx_k_unique_label_indices_int32[] = "_unique_label_indices_int32";
static const char __pyx_k_unique_label_indices_int64[] = "_unique_label_indices_int64";
static const char __pyx_k_Complex128HashTable__unique[] = "Complex128HashTable._unique";
static const char __pyx_k_Complex64HashTable_get_item[] = "Complex64HashTable.get_item";
static const char __pyx_k_Complex64HashTable_set_item[] = "Complex64HashTable.set_item";
static const char __pyx_k_Float32Factorizer_factorize[] = "Float32Factorizer.factorize";
static const char __pyx_k_Float32HashTable_get_labels[] = "Float32HashTable.get_labels";
static const char __pyx_k_Float64Factorizer_factorize[] = "Float64Factorizer.factorize";
static const char __pyx_k_Float64HashTable_get_labels[] = "Float64HashTable.get_labels";
static const char __pyx_k_HashTable___setstate_cython[] = "HashTable.__setstate_cython__";
static const char __pyx_k_Int16Vector___reduce_cython[] = "Int16Vector.__reduce_cython__";
static const char __pyx_k_Int32Vector___reduce_cython[] = "Int32Vector.__reduce_cython__";
static const char __pyx_k_Int64Vector___reduce_cython[] = "Int64Vector.__reduce_cython__";
static const char __pyx_k_Int8HashTable_map_locations[] = "Int8HashTable.map_locations";
static const char __pyx_k_No_matching_signature_found[] = "No matching signature found";
static const char __pyx_k_PyObjectHashTable_factorize[] = "PyObjectHashTable.factorize";
static const char __pyx_k_PyObjectHashTable_get_state[] = "PyObjectHashTable.get_state";
static const char __pyx_k_Step_may_not_be_zero_axis_d[] = "Step may not be zero (axis %d)";
static const char __pyx_k_StringHashTable_get_indexer[] = "StringHashTable.get_indexer";
static const char __pyx_k_UInt8Vector___reduce_cython[] = "UInt8Vector.__reduce_cython__";
static const char __pyx_k_itemsize_0_for_cython_array[] = "itemsize <= 0 for cython.array";
static const char __pyx_k_Complex128HashTable_get_item[] = "Complex128HashTable.get_item";
static const char __pyx_k_Complex128HashTable_set_item[] = "Complex128HashTable.set_item";
static const char __pyx_k_Complex64HashTable_factorize[] = "Complex64HashTable.factorize";
static const char __pyx_k_Complex64HashTable_get_state[] = "Complex64HashTable.get_state";
static const char __pyx_k_Factorizer___setstate_cython[] = "Factorizer.__setstate_cython__";
static const char __pyx_k_Int16HashTable_map_locations[] = "Int16HashTable.map_locations";
static const char __pyx_k_Int32HashTable_map_locations[] = "Int32HashTable.map_locations";
static const char __pyx_k_Int64HashTable_map_locations[] = "Int64HashTable.map_locations";
static const char __pyx_k_Int8Vector___setstate_cython[] = "Int8Vector.__setstate_cython__";
static const char __pyx_k_ObjectVector___reduce_cython[] = "ObjectVector.__reduce_cython__";
static const char __pyx_k_PyObjectHashTable_get_labels[] = "PyObjectHashTable.get_labels";
static const char __pyx_k_StringVector___reduce_cython[] = "StringVector.__reduce_cython__";
static const char __pyx_k_UInt16Vector___reduce_cython[] = "UInt16Vector.__reduce_cython__";
static const char __pyx_k_UInt32Vector___reduce_cython[] = "UInt32Vector.__reduce_cython__";
static const char __pyx_k_UInt64Vector___reduce_cython[] = "UInt64Vector.__reduce_cython__";
static const char __pyx_k_UInt8HashTable_map_locations[] = "UInt8HashTable.map_locations";
static const char __pyx_k_should_have_raised_on_append[] = "should have raised on append()";
static const char __pyx_k_Complex128HashTable_factorize[] = "Complex128HashTable.factorize";
static const char __pyx_k_Complex128HashTable_get_state[] = "Complex128HashTable.get_state";
static const char __pyx_k_Complex64Factorizer_factorize[] = "Complex64Factorizer.factorize";
static const char __pyx_k_Complex64HashTable_get_labels[] = "Complex64HashTable.get_labels";
static const char __pyx_k_Float32Vector___reduce_cython[] = "Float32Vector.__reduce_cython__";
static const char __pyx_k_Float64Vector___reduce_cython[] = "Float64Vector.__reduce_cython__";
static const char __pyx_k_Int16Vector___setstate_cython[] = "Int16Vector.__setstate_cython__";
static const char __pyx_k_Int32Vector___setstate_cython[] = "Int32Vector.__setstate_cython__";
static const char __pyx_k_Int64Vector___setstate_cython[] = "Int64Vector.__setstate_cython__";
static const char __pyx_k_Int8HashTable___reduce_cython[] = "Int8HashTable.__reduce_cython__";
static const char __pyx_k_StringHashTable_map_locations[] = "StringHashTable.map_locations";
static const char __pyx_k_UInt16HashTable_map_locations[] = "UInt16HashTable.map_locations";
static const char __pyx_k_UInt32HashTable_map_locations[] = "UInt32HashTable.map_locations";
static const char __pyx_k_UInt64HashTable_map_locations[] = "UInt64HashTable.map_locations";
static const char __pyx_k_UInt8Vector___setstate_cython[] = "UInt8Vector.__setstate_cython__";
static const char __pyx_k_unable_to_allocate_array_data[] = "unable to allocate array data.";
static const char __pyx_k_Complex128Factorizer_factorize[] = "Complex128Factorizer.factorize";
static const char __pyx_k_Complex128HashTable_get_labels[] = "Complex128HashTable.get_labels";
static const char __pyx_k_Float32HashTable_map_locations[] = "Float32HashTable.map_locations";
static const char __pyx_k_Float64HashTable_map_locations[] = "Float64HashTable.map_locations";
static const char __pyx_k_Int16HashTable___reduce_cython[] = "Int16HashTable.__reduce_cython__";
static const char __pyx_k_Int32HashTable___reduce_cython[] = "Int32HashTable.__reduce_cython__";
static const char __pyx_k_Int64HashTable___reduce_cython[] = "Int64HashTable.__reduce_cython__";
static const char __pyx_k_Int8Factorizer___reduce_cython[] = "Int8Factorizer.__reduce_cython__";
static const char __pyx_k_ObjectVector___setstate_cython[] = "ObjectVector.__setstate_cython__";
static const char __pyx_k_StringVector___setstate_cython[] = "StringVector.__setstate_cython__";
static const char __pyx_k_UInt16Vector___setstate_cython[] = "UInt16Vector.__setstate_cython__";
static const char __pyx_k_UInt32Vector___setstate_cython[] = "UInt32Vector.__setstate_cython__";
static const char __pyx_k_UInt64Vector___setstate_cython[] = "UInt64Vector.__setstate_cython__";
static const char __pyx_k_UInt8HashTable___reduce_cython[] = "UInt8HashTable.__reduce_cython__";
static const char __pyx_k_strided_and_direct_or_indirect[] = "<strided and direct or indirect>";
static const char __pyx_k_Complex128Factorizer___setstate[] = "Complex128Factorizer.__setstate_cython__";
static const char __pyx_k_Complex64Vector___reduce_cython[] = "Complex64Vector.__reduce_cython__";
static const char __pyx_k_Float32Vector___setstate_cython[] = "Float32Vector.__setstate_cython__";
static const char __pyx_k_Float64Vector___setstate_cython[] = "Float64Vector.__setstate_cython__";
static const char __pyx_k_Int16Factorizer___reduce_cython[] = "Int16Factorizer.__reduce_cython__";
static const char __pyx_k_Int32Factorizer___reduce_cython[] = "Int32Factorizer.__reduce_cython__";
static const char __pyx_k_Int64Factorizer___reduce_cython[] = "Int64Factorizer.__reduce_cython__";
static const char __pyx_k_Int8HashTable___setstate_cython[] = "Int8HashTable.__setstate_cython__";
static const char __pyx_k_ObjectFactorizer_factorize_line[] = "ObjectFactorizer.factorize (line 95)";
static const char __pyx_k_PyObjectHashTable_map_locations[] = "PyObjectHashTable.map_locations";
static const char __pyx_k_Returns_ndarray_intp_t_Examples[] = "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = Complex128Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"complex128\"), na_sentinel=20)\n        array([0, 1, 2])\n        ";
static const char __pyx_k_Returns_np_ndarray_np_intp_Exam[] = "\n\n        Returns\n        -------\n        np.ndarray[np.intp]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = ObjectFactorizer(3)\n        >>> fac.factorize(np.array([1,2,np.nan], dtype='O'), na_sentinel=20)\n        array([ 0,  1, 20])\n        ";
static const char __pyx_k_StringHashTable___reduce_cython[] = "StringHashTable.__reduce_cython__";
static const char __pyx_k_UInt16Factorizer_factorize_line[] = "UInt16Factorizer.factorize (line 5315)";
static const char __pyx_k_UInt16HashTable___reduce_cython[] = "UInt16HashTable.__reduce_cython__";
static const char __pyx_k_UInt32Factorizer_factorize_line[] = "UInt32Factorizer.factorize (line 4407)";
static const char __pyx_k_UInt32HashTable___reduce_cython[] = "UInt32HashTable.__reduce_cython__";
static const char __pyx_k_UInt64Factorizer_factorize_line[] = "UInt64Factorizer.factorize (line 2529)";
static const char __pyx_k_UInt64HashTable___reduce_cython[] = "UInt64HashTable.__reduce_cython__";
static const char __pyx_k_UInt8Factorizer___reduce_cython[] = "UInt8Factorizer.__reduce_cython__";
static const char __pyx_k_numpy_core_multiarray_failed_to[] = "numpy.core.multiarray failed to import";
static const char __pyx_k_All_dimensions_preceding_dimensi[] = "All dimensions preceding dimension %d must be indexed and not sliced";
static const char __pyx_k_Buffer_view_does_not_expose_stri[] = "Buffer view does not expose strides";
static const char __pyx_k_Can_only_create_a_buffer_that_is[] = "Can only create a buffer that is contiguous in memory.";
static const char __pyx_k_Cannot_assign_to_read_only_memor[] = "Cannot assign to read-only memoryview";
static const char __pyx_k_Cannot_create_writable_memory_vi[] = "Cannot create writable memory view from read-only memoryview";
static const char __pyx_k_Cannot_transpose_memoryview_with[] = "Cannot transpose memoryview with indirect dimensions";
static const char __pyx_k_Complex128Factorizer___reduce_cy[] = "Complex128Factorizer.__reduce_cython__";
static const char __pyx_k_Complex128Factorizer_factorize_l[] = "Complex128Factorizer.factorize (line 1621)";
static const char __pyx_k_Complex128HashTable___reduce_cyt[] = "Complex128HashTable.__reduce_cython__";
static const char __pyx_k_Complex128HashTable___setstate_c[] = "Complex128HashTable.__setstate_cython__";
static const char __pyx_k_Complex128HashTable_map_location[] = "Complex128HashTable.map_locations";
static const char __pyx_k_Complex128Vector___reduce_cython[] = "Complex128Vector.__reduce_cython__";
static const char __pyx_k_Complex128Vector___setstate_cyth[] = "Complex128Vector.__setstate_cython__";
static const char __pyx_k_Complex64Factorizer___reduce_cyt[] = "Complex64Factorizer.__reduce_cython__";
static const char __pyx_k_Complex64Factorizer___setstate_c[] = "Complex64Factorizer.__setstate_cython__";
static const char __pyx_k_Complex64Factorizer_factorize_li[] = "Complex64Factorizer.factorize (line 3499)";
static const char __pyx_k_Complex64HashTable___reduce_cyth[] = "Complex64HashTable.__reduce_cython__";
static const char __pyx_k_Complex64HashTable___setstate_cy[] = "Complex64HashTable.__setstate_cython__";
static const char __pyx_k_Complex64HashTable_map_locations[] = "Complex64HashTable.map_locations";
static const char __pyx_k_Complex64Vector___setstate_cytho[] = "Complex64Vector.__setstate_cython__";
static const char __pyx_k_Empty_shape_tuple_for_cython_arr[] = "Empty shape tuple for cython.array";
static const char __pyx_k_Expected_at_least_d_argument_s_g[] = "Expected at least %d argument%s, got %d";
static const char __pyx_k_Float32Factorizer___reduce_cytho[] = "Float32Factorizer.__reduce_cython__";
static const char __pyx_k_Float32Factorizer___setstate_cyt[] = "Float32Factorizer.__setstate_cython__";
static const char __pyx_k_Float32Factorizer_factorize_line[] = "Float32Factorizer.factorize (line 3953)";
static const char __pyx_k_Float32HashTable___reduce_cython[] = "Float32HashTable.__reduce_cython__";
static const char __pyx_k_Float32HashTable___setstate_cyth[] = "Float32HashTable.__setstate_cython__";
static const char __pyx_k_Float64Factorizer___reduce_cytho[] = "Float64Factorizer.__reduce_cython__";
static const char __pyx_k_Float64Factorizer___setstate_cyt[] = "Float64Factorizer.__setstate_cython__";
static const char __pyx_k_Float64Factorizer_factorize_line[] = "Float64Factorizer.factorize (line 2075)";
static const char __pyx_k_Float64HashTable___reduce_cython[] = "Float64HashTable.__reduce_cython__";
static const char __pyx_k_Float64HashTable___setstate_cyth[] = "Float64HashTable.__setstate_cython__";
static const char __pyx_k_Function_call_with_ambiguous_arg[] = "Function call with ambiguous argument types";
static const char __pyx_k_Incompatible_checksums_0x_x_vs_0[] = "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))";
static const char __pyx_k_Indirect_dimensions_not_supporte[] = "Indirect dimensions not supported";
static const char __pyx_k_Int16Factorizer___setstate_cytho[] = "Int16Factorizer.__setstate_cython__";
static const char __pyx_k_Int16Factorizer_factorize_line_5[] = "Int16Factorizer.factorize (line 5769)";
static const char __pyx_k_Int16HashTable___setstate_cython[] = "Int16HashTable.__setstate_cython__";
static const char __pyx_k_Int32Factorizer___setstate_cytho[] = "Int32Factorizer.__setstate_cython__";
static const char __pyx_k_Int32Factorizer_factorize_line_4[] = "Int32Factorizer.factorize (line 4861)";
static const char __pyx_k_Int32HashTable___setstate_cython[] = "Int32HashTable.__setstate_cython__";
static const char __pyx_k_Int64Factorizer___setstate_cytho[] = "Int64Factorizer.__setstate_cython__";
static const char __pyx_k_Int64Factorizer_factorize_line_3[] = "Int64Factorizer.factorize (line 3045)";
static const char __pyx_k_Int64HashTable___setstate_cython[] = "Int64HashTable.__setstate_cython__";
static const char __pyx_k_Int64HashTable_get_labels_groupb[] = "Int64HashTable.get_labels_groupby";
static const char __pyx_k_Int64HashTable_map_keys_to_value[] = "Int64HashTable.map_keys_to_values";
static const char __pyx_k_Int8Factorizer___setstate_cython[] = "Int8Factorizer.__setstate_cython__";
static const char __pyx_k_Int8Factorizer_factorize_line_66[] = "Int8Factorizer.factorize (line 6677)";
static const char __pyx_k_Invalid_mode_expected_c_or_fortr[] = "Invalid mode, expected 'c' or 'fortran', got ";
static const char __pyx_k_ObjectFactorizer___reduce_cython[] = "ObjectFactorizer.__reduce_cython__";
static const char __pyx_k_ObjectFactorizer___setstate_cyth[] = "ObjectFactorizer.__setstate_cython__";
static const char __pyx_k_Out_of_bounds_on_buffer_access_a[] = "Out of bounds on buffer access (axis ";
static const char __pyx_k_PyObjectHashTable___reduce_cytho[] = "PyObjectHashTable.__reduce_cython__";
static const char __pyx_k_PyObjectHashTable___setstate_cyt[] = "PyObjectHashTable.__setstate_cython__";
static const char __pyx_k_StringHashTable___setstate_cytho[] = "StringHashTable.__setstate_cython__";
static const char __pyx_k_UInt16Factorizer___reduce_cython[] = "UInt16Factorizer.__reduce_cython__";
static const char __pyx_k_UInt16Factorizer___setstate_cyth[] = "UInt16Factorizer.__setstate_cython__";
static const char __pyx_k_UInt16HashTable___setstate_cytho[] = "UInt16HashTable.__setstate_cython__";
static const char __pyx_k_UInt32Factorizer___reduce_cython[] = "UInt32Factorizer.__reduce_cython__";
static const char __pyx_k_UInt32Factorizer___setstate_cyth[] = "UInt32Factorizer.__setstate_cython__";
static const char __pyx_k_UInt32HashTable___setstate_cytho[] = "UInt32HashTable.__setstate_cython__";
static const char __pyx_k_UInt64Factorizer___reduce_cython[] = "UInt64Factorizer.__reduce_cython__";
static const char __pyx_k_UInt64Factorizer___setstate_cyth[] = "UInt64Factorizer.__setstate_cython__";
static const char __pyx_k_UInt64HashTable___setstate_cytho[] = "UInt64HashTable.__setstate_cython__";
static const char __pyx_k_UInt8Factorizer___setstate_cytho[] = "UInt8Factorizer.__setstate_cython__";
static const char __pyx_k_UInt8Factorizer_factorize_line_6[] = "UInt8Factorizer.factorize (line 6223)";
static const char __pyx_k_UInt8HashTable___setstate_cython[] = "UInt8HashTable.__setstate_cython__";
static const char __pyx_k_Unable_to_convert_item_to_object[] = "Unable to convert item to object";
static const char __pyx_k_external_reference_but_Vector_re[] = "external reference but Vector.resize() needed";
static const char __pyx_k_external_reference_to_result_mas[] = "external reference to result_mask held, but Vector.resize() needed";
static const char __pyx_k_external_reference_to_uniques_he[] = "external reference to uniques held, but Vector.resize() needed";
static const char __pyx_k_got_differing_extents_in_dimensi[] = "got differing extents in dimension ";
static const char __pyx_k_keep_must_be_either_first_last_o[] = "keep must be either \"first\", \"last\" or False";
static const char __pyx_k_mask_not_supported_for_ObjectFac[] = "mask not supported for ObjectFactorizer.";
static const char __pyx_k_no_default___reduce___due_to_non[] = "no default __reduce__ due to non-trivial __cinit__";
static const char __pyx_k_numpy_core_umath_failed_to_impor[] = "numpy.core.umath failed to import";
static const char __pyx_k_pandas__libs_hashtable_class_hel[] = "pandas/_libs/hashtable_class_helper.pxi";
static const char __pyx_k_pandas__libs_hashtable_func_help[] = "pandas/_libs/hashtable_func_helper.pxi";
static const char __pyx_k_self_table_cannot_be_converted_t[] = "self.table cannot be converted to a Python object for pickling";
static const char __pyx_k_unable_to_allocate_shape_and_str[] = "unable to allocate shape and strides.";
static const char __pyx_k_uses_mask_not_implemented_with_d[] = "uses_mask not implemented with dropna=False";
static const char __pyx_k_uses_mask_not_implemented_with_o[] = "uses_mask not implemented with object dtype";
static const char __pyx_k_Returns_ndarray_intp_t_Examples_2[] = "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = Float64Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"float64\"), na_sentinel=20)\n        array([0, 1, 2])\n        ";
static const char __pyx_k_Returns_ndarray_intp_t_Examples_3[] = "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = UInt64Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"uint64\"), na_sentinel=20)\n        array([0, 1, 2])\n        ";
static const char __pyx_k_Returns_ndarray_intp_t_Examples_4[] = "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = Int64Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"int64\"), na_sentinel=20)\n        array([0, 1, 2])\n        ";
static const char __pyx_k_Returns_ndarray_intp_t_Examples_5[] = "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = Complex64Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"complex64\"), na_sentinel=20)\n        array([0, 1, 2])\n        ";
static const char __pyx_k_Returns_ndarray_intp_t_Examples_6[] = "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = Float32Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"float32\"), na_sentinel=20)\n        array([0, 1, 2])\n        ";
static const char __pyx_k_Returns_ndarray_intp_t_Examples_7[] = "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = UInt32Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"uint32\"), na_sentinel=20)\n        array([0, 1, 2])\n        ";
static const char __pyx_k_Returns_ndarray_intp_t_Examples_8[] = "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = Int32Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"int32\"), na_sentinel=20)\n        array([0, 1, 2])\n        ";
static const char __pyx_k_Returns_ndarray_intp_t_Examples_9[] = "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = UInt16Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"uint16\"), na_sentinel=20)\n        array([0, 1, 2])\n        ";
static const char __pyx_k_Incompatible_checksums_0x_x_vs_0_2[] = "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())";
static const char __pyx_k_Returns_ndarray_intp_t_Examples_10[] = "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = Int16Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"int16\"), na_sentinel=20)\n        array([0, 1, 2])\n        ";
static const char __pyx_k_Returns_ndarray_intp_t_Examples_11[] = "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = UInt8Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"uint8\"), na_sentinel=20)\n        array([0, 1, 2])\n        ";
static const char __pyx_k_Returns_ndarray_intp_t_Examples_12[] = "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = Int8Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"int8\"), na_sentinel=20)\n        array([0, 1, 2])\n        ";
/* #### Code section: decls ### */
static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array___cinit__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_shape, Py_ssize_t __pyx_v_itemsize, PyObject *__pyx_v_format, PyObject *__pyx_v_mode, int __pyx_v_allocate_buffer); /* proto */
static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array_2__getbuffer__(struct __pyx_array_obj *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /* proto */
static void __pyx_array___pyx_pf_15View_dot_MemoryView_5array_4__dealloc__(struct __pyx_array_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_5array_7memview___get__(struct __pyx_array_obj *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_array___pyx_pf_15View_dot_MemoryView_5array_6__len__(struct __pyx_array_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_array___pyx_pf_15View_dot_MemoryView_5array_8__getattr__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_attr); /* proto */
static PyObject *__pyx_array___pyx_pf_15View_dot_MemoryView_5array_10__getitem__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_item); /* proto */
static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array_12__setitem__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_item, PyObject *__pyx_v_value); /* proto */
static PyObject *__pyx_pf___pyx_array___reduce_cython__(CYTHON_UNUSED struct __pyx_array_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_array_2__setstate_cython__(CYTHON_UNUSED struct __pyx_array_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum___init__(struct __pyx_MemviewEnum_obj *__pyx_v_self, PyObject *__pyx_v_name); /* proto */
static PyObject *__pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum_2__repr__(struct __pyx_MemviewEnum_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_MemviewEnum___reduce_cython__(struct __pyx_MemviewEnum_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_MemviewEnum_2__setstate_cython__(struct __pyx_MemviewEnum_obj *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview___cinit__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_obj, int __pyx_v_flags, int __pyx_v_dtype_is_object); /* proto */
static void __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_2__dealloc__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_4__getitem__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index); /* proto */
static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_6__setitem__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value); /* proto */
static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_8__getbuffer__(struct __pyx_memoryview_obj *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_1T___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4base___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_5shape___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_7strides___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_10suboffsets___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4ndim___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_8itemsize___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_6nbytes___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4size___get__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_10__len__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_12__repr__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_14__str__(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_16is_c_contig(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_18is_f_contig(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_20copy(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_22copy_fortran(struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_memoryview___reduce_cython__(CYTHON_UNUSED struct __pyx_memoryview_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_memoryview_2__setstate_cython__(CYTHON_UNUSED struct __pyx_memoryview_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static void __pyx_memoryviewslice___pyx_pf_15View_dot_MemoryView_16_memoryviewslice___dealloc__(struct __pyx_memoryviewslice_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_memoryviewslice___reduce_cython__(CYTHON_UNUSED struct __pyx_memoryviewslice_obj *__pyx_v_self); /* proto */
static PyObject *__pyx_pf___pyx_memoryviewslice_2__setstate_cython__(CYTHON_UNUSED struct __pyx_memoryviewslice_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_15View_dot_MemoryView___pyx_unpickle_Enum(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_get_hashtable_trace_domain(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_2object_hash(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_obj); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_4objects_are_equal(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_a, PyObject *__pyx_v_b); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_6Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_6Vector_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_6Vector_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16Complex128Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_16Complex128Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_16Complex128Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Complex128Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Complex128Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Complex128Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15Complex64Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_15Complex64Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_15Complex64Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Complex64Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Complex64Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Complex64Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_13Float64Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_13Float64Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_13Float64Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Float64Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Float64Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Float64Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_12UInt64Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_12UInt64Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_12UInt64Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12UInt64Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12UInt64Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12UInt64Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_11Int64Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_11Int64Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_11Int64Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11Int64Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11Int64Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11Int64Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_13Float32Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_13Float32Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_13Float32Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Float32Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Float32Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Float32Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_12UInt32Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_12UInt32Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_12UInt32Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12UInt32Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12UInt32Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12UInt32Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_11Int32Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_11Int32Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_11Int32Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11Int32Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11Int32Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11Int32Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_12UInt16Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_12UInt16Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_12UInt16Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12UInt16Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12UInt16Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12UInt16Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_11Int16Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_11Int16Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_11Int16Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11Int16Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11Int16Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11Int16Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_11UInt8Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_11UInt8Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_11UInt8Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11UInt8Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11UInt8Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11UInt8Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_10Int8Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_10Int8Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_10Int8Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_10Int8Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_10Int8Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_10Int8Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_12StringVector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_12StringVector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_12StringVector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12StringVector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12StringVector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12StringVector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_12ObjectVector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_12ObjectVector_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12ObjectVector_4to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12ObjectVector_6__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12ObjectVector_8__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_9HashTable___reduce_cython__(struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_9HashTable_2__setstate_cython__(struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, __pyx_t_double_complex __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, __pyx_t_double_complex __pyx_v_key, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_20map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_22lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_24_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_26unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_28factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_30get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_32__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_34__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, __pyx_t_5numpy_float64_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, __pyx_t_5numpy_float64_t __pyx_v_key, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_20map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_22lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_24_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_26unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_28factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_30get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_32__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_34__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, __pyx_t_5numpy_uint64_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, __pyx_t_5numpy_uint64_t __pyx_v_key, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_20map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_22lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_24_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_26unique(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_28factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_30get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_32__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_34__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_key, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_20map_keys_to_values(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_keys, __Pyx_memviewslice __pyx_v_values); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_22map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_24lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_26_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_28unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_30factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_32get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_34get_labels_groupby(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_36__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_38__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, __pyx_t_float_complex __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, __pyx_t_float_complex __pyx_v_key, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_20map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_22lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_24_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_26unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_28factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_30get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_32__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_34__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, __pyx_t_5numpy_float32_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, __pyx_t_5numpy_float32_t __pyx_v_key, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_20map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_22lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_24_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_26unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_28factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_30get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_32__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_34__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, __pyx_t_5numpy_uint32_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, __pyx_t_5numpy_uint32_t __pyx_v_key, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_20map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_22lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_24_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_26unique(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_28factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_30get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_32__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_34__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, __pyx_t_5numpy_int32_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, __pyx_t_5numpy_int32_t __pyx_v_key, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_20map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_22lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_24_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_26unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_28factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_30get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_32__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_34__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, __pyx_t_5numpy_uint16_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, __pyx_t_5numpy_uint16_t __pyx_v_key, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_20map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_22lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_24_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_26unique(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_28factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_30get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_32__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_34__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, __pyx_t_5numpy_int16_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, __pyx_t_5numpy_int16_t __pyx_v_key, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_20map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_22lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_24_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_26unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_28factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_30get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_32__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_34__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, __pyx_t_5numpy_uint8_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, __pyx_t_5numpy_uint8_t __pyx_v_key, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_20map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_22lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_24_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_26unique(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_28factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_30get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_32__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_34__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, __pyx_t_5numpy_int8_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, __pyx_t_5numpy_int8_t __pyx_v_key, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_20map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_22lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_24_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_26unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_28factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_30get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_32__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_34__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable___init__(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_4sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_6get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_8get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, PyObject *__pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_10set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, PyObject *__pyx_v_key, Py_ssize_t __pyx_v_val); /* proto */
static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_12get_indexer(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values); /* proto */
static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_14lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, CYTHON_UNUSED PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_16map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, CYTHON_UNUSED PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_18_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, int __pyx_v_return_inverse); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_20unique(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, int __pyx_v_return_inverse, CYTHON_UNUSED PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_22factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, CYTHON_UNUSED PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_24get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_26__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_28__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable___init__(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint); /* proto */
static void __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self); /* proto */
static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, PyObject *__pyx_v_key); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, PyObject *__pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_14set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, PyObject *__pyx_v_key, Py_ssize_t __pyx_v_val); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_16map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, CYTHON_UNUSED PyObject *__pyx_v_mask); /* proto */
static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_18lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, CYTHON_UNUSED PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_20_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, int __pyx_v_return_inverse); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_22unique(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, int __pyx_v_return_inverse, CYTHON_UNUSED PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_24factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, CYTHON_UNUSED PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_26get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_28__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_30__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_6value_count(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_signatures, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs, CYTHON_UNUSED PyObject *__pyx_v_defaults, PyObject *__pyx_v__fused_sigindex); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_20__pyx_fuse_0value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_22__pyx_fuse_1value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_24__pyx_fuse_2value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_26__pyx_fuse_3value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_28__pyx_fuse_4value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_30__pyx_fuse_5value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_32__pyx_fuse_6value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_34__pyx_fuse_7value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_36__pyx_fuse_8value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_38__pyx_fuse_9value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_40__pyx_fuse_10value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_42__pyx_fuse_11value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_44__pyx_fuse_12value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_8duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_signatures, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs, CYTHON_UNUSED PyObject *__pyx_v_defaults, PyObject *__pyx_v__fused_sigindex); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_48__pyx_fuse_0duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_50__pyx_fuse_1duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_52__pyx_fuse_2duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_54__pyx_fuse_3duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_56__pyx_fuse_4duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_58__pyx_fuse_5duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_60__pyx_fuse_6duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_62__pyx_fuse_7duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_64__pyx_fuse_8duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_66__pyx_fuse_9duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_68__pyx_fuse_10duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_70__pyx_fuse_11duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_72__pyx_fuse_12duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_10ismember(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_signatures, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs, CYTHON_UNUSED PyObject *__pyx_v_defaults, PyObject *__pyx_v__fused_sigindex); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_76__pyx_fuse_0ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_78__pyx_fuse_1ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_80__pyx_fuse_2ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_82__pyx_fuse_3ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_84__pyx_fuse_4ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_86__pyx_fuse_5ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_88__pyx_fuse_6ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_90__pyx_fuse_7ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_92__pyx_fuse_8ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_94__pyx_fuse_9ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_96__pyx_fuse_10ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_98__pyx_fuse_11ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_100__pyx_fuse_12ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12mode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_signatures, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs, CYTHON_UNUSED PyObject *__pyx_v_defaults, PyObject *__pyx_v__fused_sigindex); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_158__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_104mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_160__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_106mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_162__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_108mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_164__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_110mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_166__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_112mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_168__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_114mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_170__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_116mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_172__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_118mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_174__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_120mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_176__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_122mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_178__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_124mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_180__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_126mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_182__defaults__(CYTHON_UNUSED PyObject *__pyx_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_128mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask); /* proto */
static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_14_unique_label_indices_int64(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_labels); /* proto */
static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_16_unique_label_indices_int32(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_labels); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_10Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_size_hint); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_10Factorizer_2get_count(struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_10Factorizer_4factorize(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_values, CYTHON_UNUSED PyObject *__pyx_v_na_sentinel, CYTHON_UNUSED PyObject *__pyx_v_na_value, CYTHON_UNUSED PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_10Factorizer_5count___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_10Factorizer_6__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_10Factorizer_8__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *__pyx_v_self, PyObject *__pyx_v_size_hint); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *__pyx_v_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *__pyx_v_self); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *__pyx_v_self, PyObject *__pyx_v_value); /* proto */
static int __pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18__pyx_unpickle_HashTable(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_HashTable(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt64HashTable(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int64HashTable(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt32HashTable(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int32HashTable(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt16HashTable(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int16HashTable(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt8HashTable(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int8HashTable(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Float64HashTable(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Float32HashTable(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Complex64HashTable(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Complex128HashTable(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_PyObjectHashTable(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_StringHashTable(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Vector(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int64Vector(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Complex128Vector(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Complex64Vector(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Float64Vector(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt64Vector(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Float32Vector(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt32Vector(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int32Vector(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt16Vector(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int16Vector(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt8Vector(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int8Vector(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_StringVector(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_ObjectVector(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Factorizer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int8Factorizer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt8Factorizer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int16Factorizer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt16Factorizer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int32Factorizer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt32Factorizer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Float32Factorizer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Complex64Factorizer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int64Factorizer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt64Factorizer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Float64Factorizer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Complex128Factorizer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_ObjectFactorizer(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_array(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_Enum(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_memoryview(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new__memoryviewslice(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_get = {0, 0, 0, 0, 0};
static __Pyx_CachedCFunction __pyx_umethod_PyDict_Type_values = {0, 0, 0, 0, 0};
/* #### Code section: late_includes ### */
/* #### Code section: module_state ### */
typedef struct {
  PyObject *__pyx_d;
  PyObject *__pyx_b;
  PyObject *__pyx_cython_runtime;
  PyObject *__pyx_empty_tuple;
  PyObject *__pyx_empty_bytes;
  PyObject *__pyx_empty_unicode;
  #ifdef __Pyx_CyFunction_USED
  PyTypeObject *__pyx_CyFunctionType;
  #endif
  #ifdef __Pyx_FusedFunction_USED
  PyTypeObject *__pyx_FusedFunctionType;
  #endif
  #ifdef __Pyx_Generator_USED
  PyTypeObject *__pyx_GeneratorType;
  #endif
  #ifdef __Pyx_IterableCoroutine_USED
  PyTypeObject *__pyx_IterableCoroutineType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineAwaitType;
  #endif
  #ifdef __Pyx_Coroutine_USED
  PyTypeObject *__pyx_CoroutineType;
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_7cpython_4type_type;
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_5numpy_dtype;
  PyTypeObject *__pyx_ptype_5numpy_flatiter;
  PyTypeObject *__pyx_ptype_5numpy_broadcast;
  PyTypeObject *__pyx_ptype_5numpy_ndarray;
  PyTypeObject *__pyx_ptype_5numpy_generic;
  PyTypeObject *__pyx_ptype_5numpy_number;
  PyTypeObject *__pyx_ptype_5numpy_integer;
  PyTypeObject *__pyx_ptype_5numpy_signedinteger;
  PyTypeObject *__pyx_ptype_5numpy_unsignedinteger;
  PyTypeObject *__pyx_ptype_5numpy_inexact;
  PyTypeObject *__pyx_ptype_5numpy_floating;
  PyTypeObject *__pyx_ptype_5numpy_complexfloating;
  PyTypeObject *__pyx_ptype_5numpy_flexible;
  PyTypeObject *__pyx_ptype_5numpy_character;
  PyTypeObject *__pyx_ptype_5numpy_ufunc;
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  #if CYTHON_USE_MODULE_STATE
  #endif
  PyTypeObject *__pyx_ptype_6pandas_5_libs_7missing_C_NAType;
  #if CYTHON_USE_MODULE_STATE
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_HashTable;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_UInt64HashTable;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Int64HashTable;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_UInt32HashTable;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Int32HashTable;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_UInt16HashTable;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Int16HashTable;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_UInt8HashTable;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Int8HashTable;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Float64HashTable;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Float32HashTable;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Complex64HashTable;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Complex128HashTable;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_PyObjectHashTable;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_StringHashTable;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Vector;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Int64Vector;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Complex128Vector;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Complex64Vector;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Float64Vector;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_UInt64Vector;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Float32Vector;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_UInt32Vector;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Int32Vector;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_UInt16Vector;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Int16Vector;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_UInt8Vector;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Int8Vector;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_StringVector;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_ObjectVector;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Factorizer;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Int8Factorizer;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_UInt8Factorizer;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Int16Factorizer;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_UInt16Factorizer;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Int32Factorizer;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_UInt32Factorizer;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Float32Factorizer;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Complex64Factorizer;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Int64Factorizer;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_UInt64Factorizer;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Float64Factorizer;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_Complex128Factorizer;
  PyObject *__pyx_type_6pandas_5_libs_9hashtable_ObjectFactorizer;
  PyObject *__pyx_type___pyx_array;
  PyObject *__pyx_type___pyx_MemviewEnum;
  PyObject *__pyx_type___pyx_memoryview;
  PyObject *__pyx_type___pyx_memoryviewslice;
  #endif
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_HashTable;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Vector;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_StringVector;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Int8Factorizer;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Factorizer;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Int16Factorizer;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Factorizer;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Int32Factorizer;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Factorizer;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Float32Factorizer;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Factorizer;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Int64Factorizer;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Factorizer;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Float64Factorizer;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Factorizer;
  PyTypeObject *__pyx_ptype_6pandas_5_libs_9hashtable_ObjectFactorizer;
  PyTypeObject *__pyx_array_type;
  PyTypeObject *__pyx_MemviewEnum_type;
  PyTypeObject *__pyx_memoryview_type;
  PyTypeObject *__pyx_memoryviewslice_type;
  PyObject *__pyx_kp_u_;
  PyObject *__pyx_n_s_ASCII;
  PyObject *__pyx_kp_s_All_dimensions_preceding_dimensi;
  PyObject *__pyx_n_s_AssertionError;
  PyObject *__pyx_kp_s_Buffer_view_does_not_expose_stri;
  PyObject *__pyx_kp_s_Can_only_create_a_buffer_that_is;
  PyObject *__pyx_kp_s_Cannot_assign_to_read_only_memor;
  PyObject *__pyx_kp_s_Cannot_create_writable_memory_vi;
  PyObject *__pyx_kp_u_Cannot_index_with_type;
  PyObject *__pyx_kp_s_Cannot_transpose_memoryview_with;
  PyObject *__pyx_n_s_Complex128Factorizer;
  PyObject *__pyx_n_s_Complex128Factorizer___reduce_cy;
  PyObject *__pyx_n_s_Complex128Factorizer___setstate;
  PyObject *__pyx_n_s_Complex128Factorizer_factorize;
  PyObject *__pyx_kp_u_Complex128Factorizer_factorize_l;
  PyObject *__pyx_n_s_Complex128HashTable;
  PyObject *__pyx_n_s_Complex128HashTable___reduce_cyt;
  PyObject *__pyx_n_s_Complex128HashTable___setstate_c;
  PyObject *__pyx_n_s_Complex128HashTable__unique;
  PyObject *__pyx_n_s_Complex128HashTable_factorize;
  PyObject *__pyx_n_s_Complex128HashTable_get_item;
  PyObject *__pyx_n_s_Complex128HashTable_get_labels;
  PyObject *__pyx_n_s_Complex128HashTable_get_na;
  PyObject *__pyx_n_s_Complex128HashTable_get_state;
  PyObject *__pyx_n_s_Complex128HashTable_lookup;
  PyObject *__pyx_n_s_Complex128HashTable_map_location;
  PyObject *__pyx_n_s_Complex128HashTable_set_item;
  PyObject *__pyx_n_s_Complex128HashTable_set_na;
  PyObject *__pyx_n_s_Complex128HashTable_sizeof;
  PyObject *__pyx_n_s_Complex128HashTable_unique;
  PyObject *__pyx_n_s_Complex128Vector;
  PyObject *__pyx_n_s_Complex128Vector___reduce_cython;
  PyObject *__pyx_n_s_Complex128Vector___setstate_cyth;
  PyObject *__pyx_n_s_Complex128Vector_to_array;
  PyObject *__pyx_n_s_Complex64Factorizer;
  PyObject *__pyx_n_s_Complex64Factorizer___reduce_cyt;
  PyObject *__pyx_n_s_Complex64Factorizer___setstate_c;
  PyObject *__pyx_n_s_Complex64Factorizer_factorize;
  PyObject *__pyx_kp_u_Complex64Factorizer_factorize_li;
  PyObject *__pyx_n_s_Complex64HashTable;
  PyObject *__pyx_n_s_Complex64HashTable___reduce_cyth;
  PyObject *__pyx_n_s_Complex64HashTable___setstate_cy;
  PyObject *__pyx_n_s_Complex64HashTable__unique;
  PyObject *__pyx_n_s_Complex64HashTable_factorize;
  PyObject *__pyx_n_s_Complex64HashTable_get_item;
  PyObject *__pyx_n_s_Complex64HashTable_get_labels;
  PyObject *__pyx_n_s_Complex64HashTable_get_na;
  PyObject *__pyx_n_s_Complex64HashTable_get_state;
  PyObject *__pyx_n_s_Complex64HashTable_lookup;
  PyObject *__pyx_n_s_Complex64HashTable_map_locations;
  PyObject *__pyx_n_s_Complex64HashTable_set_item;
  PyObject *__pyx_n_s_Complex64HashTable_set_na;
  PyObject *__pyx_n_s_Complex64HashTable_sizeof;
  PyObject *__pyx_n_s_Complex64HashTable_unique;
  PyObject *__pyx_n_s_Complex64Vector;
  PyObject *__pyx_n_s_Complex64Vector___reduce_cython;
  PyObject *__pyx_n_s_Complex64Vector___setstate_cytho;
  PyObject *__pyx_n_s_Complex64Vector_to_array;
  PyObject *__pyx_kp_s_Dimension_d_is_not_direct;
  PyObject *__pyx_n_s_Ellipsis;
  PyObject *__pyx_kp_s_Empty_shape_tuple_for_cython_arr;
  PyObject *__pyx_kp_s_Expected_at_least_d_argument_s_g;
  PyObject *__pyx_n_s_Factorizer;
  PyObject *__pyx_n_s_Factorizer___reduce_cython;
  PyObject *__pyx_n_s_Factorizer___setstate_cython;
  PyObject *__pyx_n_s_Factorizer_factorize;
  PyObject *__pyx_n_s_Factorizer_get_count;
  PyObject *__pyx_n_s_Float32Factorizer;
  PyObject *__pyx_n_s_Float32Factorizer___reduce_cytho;
  PyObject *__pyx_n_s_Float32Factorizer___setstate_cyt;
  PyObject *__pyx_n_s_Float32Factorizer_factorize;
  PyObject *__pyx_kp_u_Float32Factorizer_factorize_line;
  PyObject *__pyx_n_s_Float32HashTable;
  PyObject *__pyx_n_s_Float32HashTable___reduce_cython;
  PyObject *__pyx_n_s_Float32HashTable___setstate_cyth;
  PyObject *__pyx_n_s_Float32HashTable__unique;
  PyObject *__pyx_n_s_Float32HashTable_factorize;
  PyObject *__pyx_n_s_Float32HashTable_get_item;
  PyObject *__pyx_n_s_Float32HashTable_get_labels;
  PyObject *__pyx_n_s_Float32HashTable_get_na;
  PyObject *__pyx_n_s_Float32HashTable_get_state;
  PyObject *__pyx_n_s_Float32HashTable_lookup;
  PyObject *__pyx_n_s_Float32HashTable_map_locations;
  PyObject *__pyx_n_s_Float32HashTable_set_item;
  PyObject *__pyx_n_s_Float32HashTable_set_na;
  PyObject *__pyx_n_s_Float32HashTable_sizeof;
  PyObject *__pyx_n_s_Float32HashTable_unique;
  PyObject *__pyx_n_s_Float32Vector;
  PyObject *__pyx_n_s_Float32Vector___reduce_cython;
  PyObject *__pyx_n_s_Float32Vector___setstate_cython;
  PyObject *__pyx_n_s_Float32Vector_to_array;
  PyObject *__pyx_n_s_Float64Factorizer;
  PyObject *__pyx_n_s_Float64Factorizer___reduce_cytho;
  PyObject *__pyx_n_s_Float64Factorizer___setstate_cyt;
  PyObject *__pyx_n_s_Float64Factorizer_factorize;
  PyObject *__pyx_kp_u_Float64Factorizer_factorize_line;
  PyObject *__pyx_n_s_Float64HashTable;
  PyObject *__pyx_n_s_Float64HashTable___reduce_cython;
  PyObject *__pyx_n_s_Float64HashTable___setstate_cyth;
  PyObject *__pyx_n_s_Float64HashTable__unique;
  PyObject *__pyx_n_s_Float64HashTable_factorize;
  PyObject *__pyx_n_s_Float64HashTable_get_item;
  PyObject *__pyx_n_s_Float64HashTable_get_labels;
  PyObject *__pyx_n_s_Float64HashTable_get_na;
  PyObject *__pyx_n_s_Float64HashTable_get_state;
  PyObject *__pyx_n_s_Float64HashTable_lookup;
  PyObject *__pyx_n_s_Float64HashTable_map_locations;
  PyObject *__pyx_n_s_Float64HashTable_set_item;
  PyObject *__pyx_n_s_Float64HashTable_set_na;
  PyObject *__pyx_n_s_Float64HashTable_sizeof;
  PyObject *__pyx_n_s_Float64HashTable_unique;
  PyObject *__pyx_n_s_Float64Vector;
  PyObject *__pyx_n_s_Float64Vector___reduce_cython;
  PyObject *__pyx_n_s_Float64Vector___setstate_cython;
  PyObject *__pyx_n_s_Float64Vector_to_array;
  PyObject *__pyx_kp_s_Function_call_with_ambiguous_arg;
  PyObject *__pyx_n_s_HashTable;
  PyObject *__pyx_n_s_HashTable___reduce_cython;
  PyObject *__pyx_n_s_HashTable___setstate_cython;
  PyObject *__pyx_n_s_ImportError;
  PyObject *__pyx_kp_s_Incompatible_checksums_0x_x_vs_0;
  PyObject *__pyx_kp_s_Incompatible_checksums_0x_x_vs_0_2;
  PyObject *__pyx_n_s_IndexError;
  PyObject *__pyx_kp_s_Index_out_of_bounds_axis_d;
  PyObject *__pyx_kp_s_Indirect_dimensions_not_supporte;
  PyObject *__pyx_n_s_Int16Factorizer;
  PyObject *__pyx_n_s_Int16Factorizer___reduce_cython;
  PyObject *__pyx_n_s_Int16Factorizer___setstate_cytho;
  PyObject *__pyx_n_s_Int16Factorizer_factorize;
  PyObject *__pyx_kp_u_Int16Factorizer_factorize_line_5;
  PyObject *__pyx_n_s_Int16HashTable;
  PyObject *__pyx_n_s_Int16HashTable___reduce_cython;
  PyObject *__pyx_n_s_Int16HashTable___setstate_cython;
  PyObject *__pyx_n_s_Int16HashTable__unique;
  PyObject *__pyx_n_s_Int16HashTable_factorize;
  PyObject *__pyx_n_s_Int16HashTable_get_item;
  PyObject *__pyx_n_s_Int16HashTable_get_labels;
  PyObject *__pyx_n_s_Int16HashTable_get_na;
  PyObject *__pyx_n_s_Int16HashTable_get_state;
  PyObject *__pyx_n_s_Int16HashTable_lookup;
  PyObject *__pyx_n_s_Int16HashTable_map_locations;
  PyObject *__pyx_n_s_Int16HashTable_set_item;
  PyObject *__pyx_n_s_Int16HashTable_set_na;
  PyObject *__pyx_n_s_Int16HashTable_sizeof;
  PyObject *__pyx_n_s_Int16HashTable_unique;
  PyObject *__pyx_n_s_Int16Vector;
  PyObject *__pyx_n_s_Int16Vector___reduce_cython;
  PyObject *__pyx_n_s_Int16Vector___setstate_cython;
  PyObject *__pyx_n_s_Int16Vector_to_array;
  PyObject *__pyx_n_s_Int32Factorizer;
  PyObject *__pyx_n_s_Int32Factorizer___reduce_cython;
  PyObject *__pyx_n_s_Int32Factorizer___setstate_cytho;
  PyObject *__pyx_n_s_Int32Factorizer_factorize;
  PyObject *__pyx_kp_u_Int32Factorizer_factorize_line_4;
  PyObject *__pyx_n_s_Int32HashTable;
  PyObject *__pyx_n_s_Int32HashTable___reduce_cython;
  PyObject *__pyx_n_s_Int32HashTable___setstate_cython;
  PyObject *__pyx_n_s_Int32HashTable__unique;
  PyObject *__pyx_n_s_Int32HashTable_factorize;
  PyObject *__pyx_n_s_Int32HashTable_get_item;
  PyObject *__pyx_n_s_Int32HashTable_get_labels;
  PyObject *__pyx_n_s_Int32HashTable_get_na;
  PyObject *__pyx_n_s_Int32HashTable_get_state;
  PyObject *__pyx_n_s_Int32HashTable_lookup;
  PyObject *__pyx_n_s_Int32HashTable_map_locations;
  PyObject *__pyx_n_s_Int32HashTable_set_item;
  PyObject *__pyx_n_s_Int32HashTable_set_na;
  PyObject *__pyx_n_s_Int32HashTable_sizeof;
  PyObject *__pyx_n_s_Int32HashTable_unique;
  PyObject *__pyx_n_s_Int32Vector;
  PyObject *__pyx_n_s_Int32Vector___reduce_cython;
  PyObject *__pyx_n_s_Int32Vector___setstate_cython;
  PyObject *__pyx_n_s_Int32Vector_to_array;
  PyObject *__pyx_n_s_Int64Factorizer;
  PyObject *__pyx_n_s_Int64Factorizer___reduce_cython;
  PyObject *__pyx_n_s_Int64Factorizer___setstate_cytho;
  PyObject *__pyx_n_s_Int64Factorizer_factorize;
  PyObject *__pyx_kp_u_Int64Factorizer_factorize_line_3;
  PyObject *__pyx_n_s_Int64HashTable;
  PyObject *__pyx_n_s_Int64HashTable___reduce_cython;
  PyObject *__pyx_n_s_Int64HashTable___setstate_cython;
  PyObject *__pyx_n_s_Int64HashTable__unique;
  PyObject *__pyx_n_s_Int64HashTable_factorize;
  PyObject *__pyx_n_s_Int64HashTable_get_item;
  PyObject *__pyx_n_s_Int64HashTable_get_labels;
  PyObject *__pyx_n_s_Int64HashTable_get_labels_groupb;
  PyObject *__pyx_n_s_Int64HashTable_get_na;
  PyObject *__pyx_n_s_Int64HashTable_get_state;
  PyObject *__pyx_n_s_Int64HashTable_lookup;
  PyObject *__pyx_n_s_Int64HashTable_map_keys_to_value;
  PyObject *__pyx_n_s_Int64HashTable_map_locations;
  PyObject *__pyx_n_s_Int64HashTable_set_item;
  PyObject *__pyx_n_s_Int64HashTable_set_na;
  PyObject *__pyx_n_s_Int64HashTable_sizeof;
  PyObject *__pyx_n_s_Int64HashTable_unique;
  PyObject *__pyx_n_s_Int64Vector;
  PyObject *__pyx_n_s_Int64Vector___reduce_cython;
  PyObject *__pyx_n_s_Int64Vector___setstate_cython;
  PyObject *__pyx_n_s_Int64Vector_to_array;
  PyObject *__pyx_n_s_Int8Factorizer;
  PyObject *__pyx_n_s_Int8Factorizer___reduce_cython;
  PyObject *__pyx_n_s_Int8Factorizer___setstate_cython;
  PyObject *__pyx_n_s_Int8Factorizer_factorize;
  PyObject *__pyx_kp_u_Int8Factorizer_factorize_line_66;
  PyObject *__pyx_n_s_Int8HashTable;
  PyObject *__pyx_n_s_Int8HashTable___reduce_cython;
  PyObject *__pyx_n_s_Int8HashTable___setstate_cython;
  PyObject *__pyx_n_s_Int8HashTable__unique;
  PyObject *__pyx_n_s_Int8HashTable_factorize;
  PyObject *__pyx_n_s_Int8HashTable_get_item;
  PyObject *__pyx_n_s_Int8HashTable_get_labels;
  PyObject *__pyx_n_s_Int8HashTable_get_na;
  PyObject *__pyx_n_s_Int8HashTable_get_state;
  PyObject *__pyx_n_s_Int8HashTable_lookup;
  PyObject *__pyx_n_s_Int8HashTable_map_locations;
  PyObject *__pyx_n_s_Int8HashTable_set_item;
  PyObject *__pyx_n_s_Int8HashTable_set_na;
  PyObject *__pyx_n_s_Int8HashTable_sizeof;
  PyObject *__pyx_n_s_Int8HashTable_unique;
  PyObject *__pyx_n_s_Int8Vector;
  PyObject *__pyx_n_s_Int8Vector___reduce_cython;
  PyObject *__pyx_n_s_Int8Vector___setstate_cython;
  PyObject *__pyx_n_s_Int8Vector_to_array;
  PyObject *__pyx_n_s_IntpHashTable;
  PyObject *__pyx_kp_u_Invalid_mode_expected_c_or_fortr;
  PyObject *__pyx_kp_u_Invalid_shape_in_axis;
  PyObject *__pyx_n_s_KeyError;
  PyObject *__pyx_n_s_MemoryError;
  PyObject *__pyx_kp_s_MemoryView_of_r_at_0x_x;
  PyObject *__pyx_kp_s_MemoryView_of_r_object;
  PyObject *__pyx_n_u_NA;
  PyObject *__pyx_kp_s_No_matching_signature_found;
  PyObject *__pyx_n_s_None;
  PyObject *__pyx_n_s_NotImplementedError;
  PyObject *__pyx_n_b_O;
  PyObject *__pyx_n_s_ObjectFactorizer;
  PyObject *__pyx_n_s_ObjectFactorizer___reduce_cython;
  PyObject *__pyx_n_s_ObjectFactorizer___setstate_cyth;
  PyObject *__pyx_n_s_ObjectFactorizer_factorize;
  PyObject *__pyx_kp_u_ObjectFactorizer_factorize_line;
  PyObject *__pyx_n_s_ObjectVector;
  PyObject *__pyx_n_s_ObjectVector___reduce_cython;
  PyObject *__pyx_n_s_ObjectVector___setstate_cython;
  PyObject *__pyx_n_s_ObjectVector_to_array;
  PyObject *__pyx_kp_u_Out_of_bounds_on_buffer_access_a;
  PyObject *__pyx_n_s_PickleError;
  PyObject *__pyx_n_s_PyObjectHashTable;
  PyObject *__pyx_n_s_PyObjectHashTable___reduce_cytho;
  PyObject *__pyx_n_s_PyObjectHashTable___setstate_cyt;
  PyObject *__pyx_n_s_PyObjectHashTable__unique;
  PyObject *__pyx_n_s_PyObjectHashTable_factorize;
  PyObject *__pyx_n_s_PyObjectHashTable_get_item;
  PyObject *__pyx_n_s_PyObjectHashTable_get_labels;
  PyObject *__pyx_n_s_PyObjectHashTable_get_state;
  PyObject *__pyx_n_s_PyObjectHashTable_lookup;
  PyObject *__pyx_n_s_PyObjectHashTable_map_locations;
  PyObject *__pyx_n_s_PyObjectHashTable_set_item;
  PyObject *__pyx_n_s_PyObjectHashTable_sizeof;
  PyObject *__pyx_n_s_PyObjectHashTable_unique;
  PyObject *__pyx_kp_u_Returns_ndarray_intp_t_Examples;
  PyObject *__pyx_kp_u_Returns_ndarray_intp_t_Examples_10;
  PyObject *__pyx_kp_u_Returns_ndarray_intp_t_Examples_11;
  PyObject *__pyx_kp_u_Returns_ndarray_intp_t_Examples_12;
  PyObject *__pyx_kp_u_Returns_ndarray_intp_t_Examples_2;
  PyObject *__pyx_kp_u_Returns_ndarray_intp_t_Examples_3;
  PyObject *__pyx_kp_u_Returns_ndarray_intp_t_Examples_4;
  PyObject *__pyx_kp_u_Returns_ndarray_intp_t_Examples_5;
  PyObject *__pyx_kp_u_Returns_ndarray_intp_t_Examples_6;
  PyObject *__pyx_kp_u_Returns_ndarray_intp_t_Examples_7;
  PyObject *__pyx_kp_u_Returns_ndarray_intp_t_Examples_8;
  PyObject *__pyx_kp_u_Returns_ndarray_intp_t_Examples_9;
  PyObject *__pyx_kp_u_Returns_np_ndarray_np_intp_Exam;
  PyObject *__pyx_n_s_SIZE_HINT_LIMIT;
  PyObject *__pyx_n_s_Sequence;
  PyObject *__pyx_kp_s_Step_may_not_be_zero_axis_d;
  PyObject *__pyx_n_s_StringHashTable;
  PyObject *__pyx_n_s_StringHashTable___reduce_cython;
  PyObject *__pyx_n_s_StringHashTable___setstate_cytho;
  PyObject *__pyx_n_s_StringHashTable__unique;
  PyObject *__pyx_n_s_StringHashTable_factorize;
  PyObject *__pyx_n_s_StringHashTable_get_indexer;
  PyObject *__pyx_n_s_StringHashTable_get_item;
  PyObject *__pyx_n_s_StringHashTable_get_labels;
  PyObject *__pyx_n_s_StringHashTable_get_state;
  PyObject *__pyx_n_s_StringHashTable_lookup;
  PyObject *__pyx_n_s_StringHashTable_map_locations;
  PyObject *__pyx_n_s_StringHashTable_set_item;
  PyObject *__pyx_n_s_StringHashTable_sizeof;
  PyObject *__pyx_n_s_StringHashTable_unique;
  PyObject *__pyx_n_s_StringVector;
  PyObject *__pyx_n_s_StringVector___reduce_cython;
  PyObject *__pyx_n_s_StringVector___setstate_cython;
  PyObject *__pyx_n_s_StringVector_to_array;
  PyObject *__pyx_n_s_TypeError;
  PyObject *__pyx_n_s_UInt16Factorizer;
  PyObject *__pyx_n_s_UInt16Factorizer___reduce_cython;
  PyObject *__pyx_n_s_UInt16Factorizer___setstate_cyth;
  PyObject *__pyx_n_s_UInt16Factorizer_factorize;
  PyObject *__pyx_kp_u_UInt16Factorizer_factorize_line;
  PyObject *__pyx_n_s_UInt16HashTable;
  PyObject *__pyx_n_s_UInt16HashTable___reduce_cython;
  PyObject *__pyx_n_s_UInt16HashTable___setstate_cytho;
  PyObject *__pyx_n_s_UInt16HashTable__unique;
  PyObject *__pyx_n_s_UInt16HashTable_factorize;
  PyObject *__pyx_n_s_UInt16HashTable_get_item;
  PyObject *__pyx_n_s_UInt16HashTable_get_labels;
  PyObject *__pyx_n_s_UInt16HashTable_get_na;
  PyObject *__pyx_n_s_UInt16HashTable_get_state;
  PyObject *__pyx_n_s_UInt16HashTable_lookup;
  PyObject *__pyx_n_s_UInt16HashTable_map_locations;
  PyObject *__pyx_n_s_UInt16HashTable_set_item;
  PyObject *__pyx_n_s_UInt16HashTable_set_na;
  PyObject *__pyx_n_s_UInt16HashTable_sizeof;
  PyObject *__pyx_n_s_UInt16HashTable_unique;
  PyObject *__pyx_n_s_UInt16Vector;
  PyObject *__pyx_n_s_UInt16Vector___reduce_cython;
  PyObject *__pyx_n_s_UInt16Vector___setstate_cython;
  PyObject *__pyx_n_s_UInt16Vector_to_array;
  PyObject *__pyx_n_s_UInt32Factorizer;
  PyObject *__pyx_n_s_UInt32Factorizer___reduce_cython;
  PyObject *__pyx_n_s_UInt32Factorizer___setstate_cyth;
  PyObject *__pyx_n_s_UInt32Factorizer_factorize;
  PyObject *__pyx_kp_u_UInt32Factorizer_factorize_line;
  PyObject *__pyx_n_s_UInt32HashTable;
  PyObject *__pyx_n_s_UInt32HashTable___reduce_cython;
  PyObject *__pyx_n_s_UInt32HashTable___setstate_cytho;
  PyObject *__pyx_n_s_UInt32HashTable__unique;
  PyObject *__pyx_n_s_UInt32HashTable_factorize;
  PyObject *__pyx_n_s_UInt32HashTable_get_item;
  PyObject *__pyx_n_s_UInt32HashTable_get_labels;
  PyObject *__pyx_n_s_UInt32HashTable_get_na;
  PyObject *__pyx_n_s_UInt32HashTable_get_state;
  PyObject *__pyx_n_s_UInt32HashTable_lookup;
  PyObject *__pyx_n_s_UInt32HashTable_map_locations;
  PyObject *__pyx_n_s_UInt32HashTable_set_item;
  PyObject *__pyx_n_s_UInt32HashTable_set_na;
  PyObject *__pyx_n_s_UInt32HashTable_sizeof;
  PyObject *__pyx_n_s_UInt32HashTable_unique;
  PyObject *__pyx_n_s_UInt32Vector;
  PyObject *__pyx_n_s_UInt32Vector___reduce_cython;
  PyObject *__pyx_n_s_UInt32Vector___setstate_cython;
  PyObject *__pyx_n_s_UInt32Vector_to_array;
  PyObject *__pyx_n_s_UInt64Factorizer;
  PyObject *__pyx_n_s_UInt64Factorizer___reduce_cython;
  PyObject *__pyx_n_s_UInt64Factorizer___setstate_cyth;
  PyObject *__pyx_n_s_UInt64Factorizer_factorize;
  PyObject *__pyx_kp_u_UInt64Factorizer_factorize_line;
  PyObject *__pyx_n_s_UInt64HashTable;
  PyObject *__pyx_n_s_UInt64HashTable___reduce_cython;
  PyObject *__pyx_n_s_UInt64HashTable___setstate_cytho;
  PyObject *__pyx_n_s_UInt64HashTable__unique;
  PyObject *__pyx_n_s_UInt64HashTable_factorize;
  PyObject *__pyx_n_s_UInt64HashTable_get_item;
  PyObject *__pyx_n_s_UInt64HashTable_get_labels;
  PyObject *__pyx_n_s_UInt64HashTable_get_na;
  PyObject *__pyx_n_s_UInt64HashTable_get_state;
  PyObject *__pyx_n_s_UInt64HashTable_lookup;
  PyObject *__pyx_n_s_UInt64HashTable_map_locations;
  PyObject *__pyx_n_s_UInt64HashTable_set_item;
  PyObject *__pyx_n_s_UInt64HashTable_set_na;
  PyObject *__pyx_n_s_UInt64HashTable_sizeof;
  PyObject *__pyx_n_s_UInt64HashTable_unique;
  PyObject *__pyx_n_s_UInt64Vector;
  PyObject *__pyx_n_s_UInt64Vector___reduce_cython;
  PyObject *__pyx_n_s_UInt64Vector___setstate_cython;
  PyObject *__pyx_n_s_UInt64Vector_to_array;
  PyObject *__pyx_n_s_UInt8Factorizer;
  PyObject *__pyx_n_s_UInt8Factorizer___reduce_cython;
  PyObject *__pyx_n_s_UInt8Factorizer___setstate_cytho;
  PyObject *__pyx_n_s_UInt8Factorizer_factorize;
  PyObject *__pyx_kp_u_UInt8Factorizer_factorize_line_6;
  PyObject *__pyx_n_s_UInt8HashTable;
  PyObject *__pyx_n_s_UInt8HashTable___reduce_cython;
  PyObject *__pyx_n_s_UInt8HashTable___setstate_cython;
  PyObject *__pyx_n_s_UInt8HashTable__unique;
  PyObject *__pyx_n_s_UInt8HashTable_factorize;
  PyObject *__pyx_n_s_UInt8HashTable_get_item;
  PyObject *__pyx_n_s_UInt8HashTable_get_labels;
  PyObject *__pyx_n_s_UInt8HashTable_get_na;
  PyObject *__pyx_n_s_UInt8HashTable_get_state;
  PyObject *__pyx_n_s_UInt8HashTable_lookup;
  PyObject *__pyx_n_s_UInt8HashTable_map_locations;
  PyObject *__pyx_n_s_UInt8HashTable_set_item;
  PyObject *__pyx_n_s_UInt8HashTable_set_na;
  PyObject *__pyx_n_s_UInt8HashTable_sizeof;
  PyObject *__pyx_n_s_UInt8HashTable_unique;
  PyObject *__pyx_n_s_UInt8Vector;
  PyObject *__pyx_n_s_UInt8Vector___reduce_cython;
  PyObject *__pyx_n_s_UInt8Vector___setstate_cython;
  PyObject *__pyx_n_s_UInt8Vector_to_array;
  PyObject *__pyx_kp_s_Unable_to_convert_item_to_object;
  PyObject *__pyx_n_s_UnicodeEncodeError;
  PyObject *__pyx_n_s_ValueError;
  PyObject *__pyx_n_s_Vector;
  PyObject *__pyx_n_s_Vector___reduce_cython;
  PyObject *__pyx_n_s_Vector___setstate_cython;
  PyObject *__pyx_n_s_View_MemoryView;
  PyObject *__pyx_n_s__191;
  PyObject *__pyx_kp_u__2;
  PyObject *__pyx_n_s__3;
  PyObject *__pyx_n_s__490;
  PyObject *__pyx_kp_u__6;
  PyObject *__pyx_kp_s__69;
  PyObject *__pyx_kp_u__7;
  PyObject *__pyx_kp_s__70;
  PyObject *__pyx_kp_u__70;
  PyObject *__pyx_kp_s__86;
  PyObject *__pyx_n_s_a;
  PyObject *__pyx_n_s_abc;
  PyObject *__pyx_n_s_allocate_buffer;
  PyObject *__pyx_kp_u_and;
  PyObject *__pyx_n_s_args;
  PyObject *__pyx_n_s_argsort;
  PyObject *__pyx_n_s_arr;
  PyObject *__pyx_n_s_arr_uniques;
  PyObject *__pyx_n_s_asarray;
  PyObject *__pyx_n_s_asyncio_coroutines;
  PyObject *__pyx_n_s_b;
  PyObject *__pyx_n_s_base;
  PyObject *__pyx_n_s_bool;
  PyObject *__pyx_n_u_bool;
  PyObject *__pyx_n_s_bool_2;
  PyObject *__pyx_n_s_c;
  PyObject *__pyx_n_u_c;
  PyObject *__pyx_n_s_class;
  PyObject *__pyx_n_s_class_getitem;
  PyObject *__pyx_n_s_cline_in_traceback;
  PyObject *__pyx_n_s_collections;
  PyObject *__pyx_kp_s_collections_abc;
  PyObject *__pyx_n_s_complex128;
  PyObject *__pyx_n_s_complex64;
  PyObject *__pyx_kp_s_contiguous_and_direct;
  PyObject *__pyx_kp_s_contiguous_and_indirect;
  PyObject *__pyx_n_s_count;
  PyObject *__pyx_n_s_count_prior;
  PyObject *__pyx_n_s_counts;
  PyObject *__pyx_n_s_deep;
  PyObject *__pyx_n_s_defaults;
  PyObject *__pyx_n_s_dict;
  PyObject *__pyx_n_s_dict_2;
  PyObject *__pyx_kp_s_dict_str_int;
  PyObject *__pyx_kp_u_disable;
  PyObject *__pyx_kp_s_double_complex;
  PyObject *__pyx_n_s_dropna;
  PyObject *__pyx_n_s_dtype;
  PyObject *__pyx_n_s_dtype_is_object;
  PyObject *__pyx_n_s_duplicated;
  PyObject *__pyx_n_s_empty;
  PyObject *__pyx_kp_u_enable;
  PyObject *__pyx_n_s_encode;
  PyObject *__pyx_n_s_enumerate;
  PyObject *__pyx_n_s_error;
  PyObject *__pyx_kp_u_external_reference_but_Vector_re;
  PyObject *__pyx_kp_u_external_reference_to_result_mas;
  PyObject *__pyx_kp_u_external_reference_to_uniques_he;
  PyObject *__pyx_n_s_factorize;
  PyObject *__pyx_n_u_first;
  PyObject *__pyx_n_s_flags;
  PyObject *__pyx_n_s_float32;
  PyObject *__pyx_n_s_float32_t;
  PyObject *__pyx_n_s_float64;
  PyObject *__pyx_n_s_float64_t;
  PyObject *__pyx_kp_s_float_complex;
  PyObject *__pyx_n_s_for_flags;
  PyObject *__pyx_n_s_for_pairs;
  PyObject *__pyx_n_s_format;
  PyObject *__pyx_n_s_fortran;
  PyObject *__pyx_n_u_fortran;
  PyObject *__pyx_n_s_fused_sigindex;
  PyObject *__pyx_kp_u_gc;
  PyObject *__pyx_n_s_get;
  PyObject *__pyx_n_s_get_count;
  PyObject *__pyx_n_s_get_hashtable_trace_domain;
  PyObject *__pyx_n_s_get_indexer;
  PyObject *__pyx_n_s_get_item;
  PyObject *__pyx_n_s_get_labels;
  PyObject *__pyx_n_s_get_labels_groupby;
  PyObject *__pyx_n_s_get_na;
  PyObject *__pyx_n_s_get_state;
  PyObject *__pyx_n_s_getstate;
  PyObject *__pyx_kp_u_got;
  PyObject *__pyx_kp_u_got_differing_extents_in_dimensi;
  PyObject *__pyx_n_s_i;
  PyObject *__pyx_n_s_id;
  PyObject *__pyx_n_s_idx;
  PyObject *__pyx_n_s_ignore_na;
  PyObject *__pyx_n_s_imag;
  PyObject *__pyx_n_s_import;
  PyObject *__pyx_n_s_index;
  PyObject *__pyx_n_s_initializing;
  PyObject *__pyx_n_s_int;
  PyObject *__pyx_n_s_int16;
  PyObject *__pyx_n_s_int16_t;
  PyObject *__pyx_n_s_int32;
  PyObject *__pyx_n_s_int32_t;
  PyObject *__pyx_n_s_int64;
  PyObject *__pyx_n_s_int64_t;
  PyObject *__pyx_n_s_int8;
  PyObject *__pyx_n_s_int8_t;
  PyObject *__pyx_n_s_intp;
  PyObject *__pyx_n_s_is_coroutine;
  PyObject *__pyx_kp_u_isenabled;
  PyObject *__pyx_n_s_ismember;
  PyObject *__pyx_n_s_itemsize;
  PyObject *__pyx_kp_s_itemsize_0_for_cython_array;
  PyObject *__pyx_n_s_j;
  PyObject *__pyx_n_s_k;
  PyObject *__pyx_n_s_keep;
  PyObject *__pyx_kp_u_keep_must_be_either_first_last_o;
  PyObject *__pyx_n_s_key;
  PyObject *__pyx_n_s_keys;
  PyObject *__pyx_n_s_kind;
  PyObject *__pyx_n_s_kwargs;
  PyObject *__pyx_n_s_labels;
  PyObject *__pyx_n_u_last;
  PyObject *__pyx_n_s_locs;
  PyObject *__pyx_n_s_lookup;
  PyObject *__pyx_n_s_main;
  PyObject *__pyx_n_s_map_keys_to_values;
  PyObject *__pyx_n_s_map_locations;
  PyObject *__pyx_n_s_mask;
  PyObject *__pyx_kp_u_mask_not_supported_for_ObjectFac;
  PyObject *__pyx_n_s_mask_values;
  PyObject *__pyx_n_s_max_count;
  PyObject *__pyx_n_s_memview;
  PyObject *__pyx_n_s_mode;
  PyObject *__pyx_n_s_modes;
  PyObject *__pyx_n_s_n;
  PyObject *__pyx_n_u_n_buckets;
  PyObject *__pyx_n_u_n_occupied;
  PyObject *__pyx_n_s_na_position;
  PyObject *__pyx_n_s_na_sentinel;
  PyObject *__pyx_n_s_na_string_sentinel;
  PyObject *__pyx_n_s_na_value;
  PyObject *__pyx_n_s_na_value2;
  PyObject *__pyx_n_s_name;
  PyObject *__pyx_n_s_name_2;
  PyObject *__pyx_n_u_nan;
  PyObject *__pyx_n_s_ndarray;
  PyObject *__pyx_n_s_ndim;
  PyObject *__pyx_n_s_new;
  PyObject *__pyx_n_s_nkeys;
  PyObject *__pyx_kp_s_no_default___reduce___due_to_non;
  PyObject *__pyx_n_s_np;
  PyObject *__pyx_kp_s_np_ndarray;
  PyObject *__pyx_n_s_numpy;
  PyObject *__pyx_kp_u_numpy_core_multiarray_failed_to;
  PyObject *__pyx_kp_u_numpy_core_umath_failed_to_impor;
  PyObject *__pyx_n_s_obj;
  PyObject *__pyx_n_s_object;
  PyObject *__pyx_n_s_object_hash;
  PyObject *__pyx_n_s_objects_are_equal;
  PyObject *__pyx_n_s_overhead;
  PyObject *__pyx_n_s_pack;
  PyObject *__pyx_n_s_pandas__libs_hashtable;
  PyObject *__pyx_kp_s_pandas__libs_hashtable_class_hel;
  PyObject *__pyx_kp_s_pandas__libs_hashtable_func_help;
  PyObject *__pyx_kp_s_pandas__libs_hashtable_pyx;
  PyObject *__pyx_n_s_pickle;
  PyObject *__pyx_n_s_pyx_PickleError;
  PyObject *__pyx_n_s_pyx_checksum;
  PyObject *__pyx_n_s_pyx_fuse_0duplicated;
  PyObject *__pyx_n_s_pyx_fuse_0ismember;
  PyObject *__pyx_n_s_pyx_fuse_0value_count;
  PyObject *__pyx_n_s_pyx_fuse_10duplicated;
  PyObject *__pyx_n_s_pyx_fuse_10ismember;
  PyObject *__pyx_n_s_pyx_fuse_10value_count;
  PyObject *__pyx_n_s_pyx_fuse_11duplicated;
  PyObject *__pyx_n_s_pyx_fuse_11ismember;
  PyObject *__pyx_n_s_pyx_fuse_11value_count;
  PyObject *__pyx_n_s_pyx_fuse_12duplicated;
  PyObject *__pyx_n_s_pyx_fuse_12ismember;
  PyObject *__pyx_n_s_pyx_fuse_12value_count;
  PyObject *__pyx_n_s_pyx_fuse_1duplicated;
  PyObject *__pyx_n_s_pyx_fuse_1ismember;
  PyObject *__pyx_n_s_pyx_fuse_1value_count;
  PyObject *__pyx_n_s_pyx_fuse_2duplicated;
  PyObject *__pyx_n_s_pyx_fuse_2ismember;
  PyObject *__pyx_n_s_pyx_fuse_2value_count;
  PyObject *__pyx_n_s_pyx_fuse_3duplicated;
  PyObject *__pyx_n_s_pyx_fuse_3ismember;
  PyObject *__pyx_n_s_pyx_fuse_3value_count;
  PyObject *__pyx_n_s_pyx_fuse_4duplicated;
  PyObject *__pyx_n_s_pyx_fuse_4ismember;
  PyObject *__pyx_n_s_pyx_fuse_4value_count;
  PyObject *__pyx_n_s_pyx_fuse_5duplicated;
  PyObject *__pyx_n_s_pyx_fuse_5ismember;
  PyObject *__pyx_n_s_pyx_fuse_5value_count;
  PyObject *__pyx_n_s_pyx_fuse_6duplicated;
  PyObject *__pyx_n_s_pyx_fuse_6ismember;
  PyObject *__pyx_n_s_pyx_fuse_6value_count;
  PyObject *__pyx_n_s_pyx_fuse_7duplicated;
  PyObject *__pyx_n_s_pyx_fuse_7ismember;
  PyObject *__pyx_n_s_pyx_fuse_7value_count;
  PyObject *__pyx_n_s_pyx_fuse_8duplicated;
  PyObject *__pyx_n_s_pyx_fuse_8ismember;
  PyObject *__pyx_n_s_pyx_fuse_8value_count;
  PyObject *__pyx_n_s_pyx_fuse_9duplicated;
  PyObject *__pyx_n_s_pyx_fuse_9ismember;
  PyObject *__pyx_n_s_pyx_fuse_9value_count;
  PyObject *__pyx_n_s_pyx_result;
  PyObject *__pyx_n_s_pyx_state;
  PyObject *__pyx_n_s_pyx_type;
  PyObject *__pyx_n_s_pyx_unpickle_Enum;
  PyObject *__pyx_n_s_pyx_unpickle_HashTable;
  PyObject *__pyx_n_s_pyx_vtable;
  PyObject *__pyx_n_s_range;
  PyObject *__pyx_n_s_real;
  PyObject *__pyx_n_s_reduce;
  PyObject *__pyx_n_s_reduce_cython;
  PyObject *__pyx_n_s_reduce_ex;
  PyObject *__pyx_n_s_refcheck;
  PyObject *__pyx_n_s_register;
  PyObject *__pyx_n_s_resbuf;
  PyObject *__pyx_n_s_resize;
  PyObject *__pyx_n_s_result_mask;
  PyObject *__pyx_n_s_ret;
  PyObject *__pyx_n_s_return;
  PyObject *__pyx_n_s_return_inverse;
  PyObject *__pyx_n_s_rmd;
  PyObject *__pyx_n_s_s;
  PyObject *__pyx_n_s_seen_na;
  PyObject *__pyx_n_s_self;
  PyObject *__pyx_kp_s_self_table_cannot_be_converted_t;
  PyObject *__pyx_n_s_set_item;
  PyObject *__pyx_n_s_set_na;
  PyObject *__pyx_n_s_setstate;
  PyObject *__pyx_n_s_setstate_cython;
  PyObject *__pyx_n_s_shape;
  PyObject *__pyx_kp_u_should_have_raised_on_append;
  PyObject *__pyx_n_s_signatures;
  PyObject *__pyx_n_s_size;
  PyObject *__pyx_n_u_size;
  PyObject *__pyx_n_s_size_hint;
  PyObject *__pyx_n_s_sizeof;
  PyObject *__pyx_n_s_spec;
  PyObject *__pyx_n_s_split;
  PyObject *__pyx_n_s_start;
  PyObject *__pyx_n_s_state;
  PyObject *__pyx_n_s_step;
  PyObject *__pyx_n_s_stop;
  PyObject *__pyx_kp_s_strided_and_direct;
  PyObject *__pyx_kp_s_strided_and_direct_or_indirect;
  PyObject *__pyx_kp_s_strided_and_indirect;
  PyObject *__pyx_kp_s_stringsource;
  PyObject *__pyx_n_s_strip;
  PyObject *__pyx_n_s_struct;
  PyObject *__pyx_n_s_sys;
  PyObject *__pyx_n_s_table;
  PyObject *__pyx_n_s_test;
  PyObject *__pyx_n_s_to_array;
  PyObject *__pyx_kp_s_tuple_ndarray_ndarray;
  PyObject *__pyx_n_s_ud;
  PyObject *__pyx_n_s_uindexer;
  PyObject *__pyx_n_s_uint16;
  PyObject *__pyx_n_s_uint16_t;
  PyObject *__pyx_n_s_uint32;
  PyObject *__pyx_n_s_uint32_t;
  PyObject *__pyx_n_s_uint64;
  PyObject *__pyx_n_s_uint64_t;
  PyObject *__pyx_n_s_uint8;
  PyObject *__pyx_n_u_uint8;
  PyObject *__pyx_n_s_uint8_t;
  PyObject *__pyx_kp_s_unable_to_allocate_array_data;
  PyObject *__pyx_kp_s_unable_to_allocate_shape_and_str;
  PyObject *__pyx_n_s_unique;
  PyObject *__pyx_n_s_unique_2;
  PyObject *__pyx_n_s_unique_label_indices;
  PyObject *__pyx_n_s_unique_label_indices_int32;
  PyObject *__pyx_n_s_unique_label_indices_int64;
  PyObject *__pyx_n_s_uniques;
  PyObject *__pyx_n_s_uniques_vector;
  PyObject *__pyx_n_s_unpack;
  PyObject *__pyx_n_s_update;
  PyObject *__pyx_n_u_upper_bound;
  PyObject *__pyx_n_s_use_mask;
  PyObject *__pyx_n_s_use_na_value;
  PyObject *__pyx_n_s_use_result_mask;
  PyObject *__pyx_n_s_use_setstate;
  PyObject *__pyx_n_s_uses_mask;
  PyObject *__pyx_kp_u_uses_mask_not_implemented_with_d;
  PyObject *__pyx_kp_u_uses_mask_not_implemented_with_o;
  PyObject *__pyx_n_s_v;
  PyObject *__pyx_n_s_val;
  PyObject *__pyx_n_s_value_count;
  PyObject *__pyx_n_s_values;
  PyObject *__pyx_n_s_vecs;
  PyObject *__pyx_n_s_version_info;
  PyObject *__pyx_n_s_view;
  PyObject *__pyx_n_s_zeros;
  PyObject *__pyx_int_0;
  PyObject *__pyx_int_1;
  PyObject *__pyx_int_2;
  PyObject *__pyx_int_3;
  PyObject *__pyx_int_1048583;
  PyObject *__pyx_int_112105877;
  PyObject *__pyx_int_136983863;
  PyObject *__pyx_int_184977713;
  PyObject *__pyx_int_222419149;
  PyObject *__pyx_int_228825662;
  PyObject *__pyx_int_238750788;
  PyObject *__pyx_int_neg_1;
  __Pyx_memviewslice __pyx_k__14;
  __Pyx_memviewslice __pyx_k__15;
  __Pyx_memviewslice __pyx_k__18;
  __Pyx_memviewslice __pyx_k__19;
  __Pyx_memviewslice __pyx_k__20;
  __Pyx_memviewslice __pyx_k__21;
  __Pyx_memviewslice __pyx_k__22;
  __Pyx_memviewslice __pyx_k__23;
  __Pyx_memviewslice __pyx_k__24;
  __Pyx_memviewslice __pyx_k__25;
  __Pyx_memviewslice __pyx_k__26;
  __Pyx_memviewslice __pyx_k__27;
  __Pyx_memviewslice __pyx_k__28;
  __Pyx_memviewslice __pyx_k__29;
  __Pyx_memviewslice __pyx_k__30;
  __Pyx_memviewslice __pyx_k__31;
  __Pyx_memviewslice __pyx_k__32;
  __Pyx_memviewslice __pyx_k__33;
  __Pyx_memviewslice __pyx_k__34;
  __Pyx_memviewslice __pyx_k__35;
  __Pyx_memviewslice __pyx_k__36;
  __Pyx_memviewslice __pyx_k__37;
  __Pyx_memviewslice __pyx_k__38;
  __Pyx_memviewslice __pyx_k__39;
  __Pyx_memviewslice __pyx_k__40;
  __Pyx_memviewslice __pyx_k__42;
  __Pyx_memviewslice __pyx_k__44;
  __Pyx_memviewslice __pyx_k__45;
  __Pyx_memviewslice __pyx_k__46;
  __Pyx_memviewslice __pyx_k__47;
  __Pyx_memviewslice __pyx_k__48;
  __Pyx_memviewslice __pyx_k__49;
  __Pyx_memviewslice __pyx_k__50;
  __Pyx_memviewslice __pyx_k__51;
  __Pyx_memviewslice __pyx_k__52;
  __Pyx_memviewslice __pyx_k__53;
  __Pyx_memviewslice __pyx_k__54;
  __Pyx_memviewslice __pyx_k__55;
  __Pyx_memviewslice __pyx_k__56;
  __Pyx_memviewslice __pyx_k__57;
  __Pyx_memviewslice __pyx_k__58;
  __Pyx_memviewslice __pyx_k__60;
  __Pyx_memviewslice __pyx_k__61;
  __Pyx_memviewslice __pyx_k__62;
  __Pyx_memviewslice __pyx_k__63;
  __Pyx_memviewslice __pyx_k__64;
  __Pyx_memviewslice __pyx_k__65;
  __Pyx_memviewslice __pyx_k__66;
  __Pyx_memviewslice __pyx_k__67;
  __Pyx_memviewslice __pyx_k__68;
  __Pyx_memviewslice __pyx_k__73;
  __Pyx_memviewslice __pyx_k__74;
  __Pyx_memviewslice __pyx_k__75;
  __Pyx_memviewslice __pyx_k__76;
  __Pyx_memviewslice __pyx_k__77;
  __Pyx_memviewslice __pyx_k__78;
  __Pyx_memviewslice __pyx_k__79;
  __Pyx_memviewslice __pyx_k__80;
  __Pyx_memviewslice __pyx_k__81;
  __Pyx_memviewslice __pyx_k__82;
  __Pyx_memviewslice __pyx_k__83;
  __Pyx_memviewslice __pyx_k__84;
  __Pyx_memviewslice __pyx_k__85;
  __Pyx_memviewslice __pyx_k__87;
  __Pyx_memviewslice __pyx_k__88;
  __Pyx_memviewslice __pyx_k__89;
  __Pyx_memviewslice __pyx_k__90;
  __Pyx_memviewslice __pyx_k__91;
  __Pyx_memviewslice __pyx_k__92;
  __Pyx_memviewslice __pyx_k__93;
  __Pyx_memviewslice __pyx_k__94;
  __Pyx_memviewslice __pyx_k__95;
  __Pyx_memviewslice __pyx_k__96;
  __Pyx_memviewslice __pyx_k__97;
  __Pyx_memviewslice __pyx_k__98;
  __Pyx_memviewslice __pyx_k__99;
  PyObject *__pyx_slice__5;
  PyObject *__pyx_tuple__4;
  PyObject *__pyx_tuple__8;
  PyObject *__pyx_tuple__9;
  PyObject *__pyx_tuple__10;
  PyObject *__pyx_tuple__11;
  PyObject *__pyx_tuple__12;
  PyObject *__pyx_tuple__13;
  PyObject *__pyx_tuple__16;
  PyObject *__pyx_tuple__17;
  PyObject *__pyx_tuple__41;
  PyObject *__pyx_tuple__43;
  PyObject *__pyx_tuple__59;
  PyObject *__pyx_tuple__71;
  PyObject *__pyx_tuple__72;
  PyObject *__pyx_slice__100;
  PyObject *__pyx_tuple__101;
  PyObject *__pyx_tuple__102;
  PyObject *__pyx_tuple__103;
  PyObject *__pyx_tuple__104;
  PyObject *__pyx_tuple__105;
  PyObject *__pyx_tuple__106;
  PyObject *__pyx_tuple__107;
  PyObject *__pyx_tuple__108;
  PyObject *__pyx_tuple__109;
  PyObject *__pyx_tuple__110;
  PyObject *__pyx_tuple__111;
  PyObject *__pyx_tuple__112;
  PyObject *__pyx_tuple__115;
  PyObject *__pyx_tuple__117;
  PyObject *__pyx_tuple__119;
  PyObject *__pyx_tuple__121;
  PyObject *__pyx_tuple__165;
  PyObject *__pyx_tuple__168;
  PyObject *__pyx_tuple__170;
  PyObject *__pyx_tuple__172;
  PyObject *__pyx_tuple__175;
  PyObject *__pyx_tuple__178;
  PyObject *__pyx_tuple__180;
  PyObject *__pyx_tuple__182;
  PyObject *__pyx_tuple__184;
  PyObject *__pyx_tuple__185;
  PyObject *__pyx_tuple__187;
  PyObject *__pyx_tuple__188;
  PyObject *__pyx_tuple__190;
  PyObject *__pyx_tuple__192;
  PyObject *__pyx_tuple__194;
  PyObject *__pyx_tuple__197;
  PyObject *__pyx_tuple__199;
  PyObject *__pyx_tuple__242;
  PyObject *__pyx_tuple__250;
  PyObject *__pyx_tuple__397;
  PyObject *__pyx_tuple__399;
  PyObject *__pyx_tuple__401;
  PyObject *__pyx_tuple__402;
  PyObject *__pyx_tuple__404;
  PyObject *__pyx_tuple__406;
  PyObject *__pyx_tuple__407;
  PyObject *__pyx_tuple__410;
  PyObject *__pyx_tuple__412;
  PyObject *__pyx_tuple__419;
  PyObject *__pyx_tuple__421;
  PyObject *__pyx_tuple__423;
  PyObject *__pyx_tuple__430;
  PyObject *__pyx_tuple__445;
  PyObject *__pyx_tuple__446;
  PyObject *__pyx_tuple__461;
  PyObject *__pyx_tuple__476;
  PyObject *__pyx_tuple__478;
  PyObject *__pyx_tuple__482;
  PyObject *__pyx_codeobj__113;
  PyObject *__pyx_codeobj__114;
  PyObject *__pyx_codeobj__116;
  PyObject *__pyx_codeobj__118;
  PyObject *__pyx_codeobj__120;
  PyObject *__pyx_codeobj__122;
  PyObject *__pyx_codeobj__123;
  PyObject *__pyx_codeobj__124;
  PyObject *__pyx_codeobj__125;
  PyObject *__pyx_codeobj__126;
  PyObject *__pyx_codeobj__127;
  PyObject *__pyx_codeobj__128;
  PyObject *__pyx_codeobj__129;
  PyObject *__pyx_codeobj__130;
  PyObject *__pyx_codeobj__131;
  PyObject *__pyx_codeobj__132;
  PyObject *__pyx_codeobj__133;
  PyObject *__pyx_codeobj__134;
  PyObject *__pyx_codeobj__135;
  PyObject *__pyx_codeobj__136;
  PyObject *__pyx_codeobj__137;
  PyObject *__pyx_codeobj__138;
  PyObject *__pyx_codeobj__139;
  PyObject *__pyx_codeobj__140;
  PyObject *__pyx_codeobj__141;
  PyObject *__pyx_codeobj__142;
  PyObject *__pyx_codeobj__143;
  PyObject *__pyx_codeobj__144;
  PyObject *__pyx_codeobj__145;
  PyObject *__pyx_codeobj__146;
  PyObject *__pyx_codeobj__147;
  PyObject *__pyx_codeobj__148;
  PyObject *__pyx_codeobj__149;
  PyObject *__pyx_codeobj__150;
  PyObject *__pyx_codeobj__151;
  PyObject *__pyx_codeobj__152;
  PyObject *__pyx_codeobj__153;
  PyObject *__pyx_codeobj__154;
  PyObject *__pyx_codeobj__155;
  PyObject *__pyx_codeobj__156;
  PyObject *__pyx_codeobj__157;
  PyObject *__pyx_codeobj__158;
  PyObject *__pyx_codeobj__159;
  PyObject *__pyx_codeobj__160;
  PyObject *__pyx_codeobj__161;
  PyObject *__pyx_codeobj__162;
  PyObject *__pyx_codeobj__163;
  PyObject *__pyx_codeobj__164;
  PyObject *__pyx_codeobj__166;
  PyObject *__pyx_codeobj__167;
  PyObject *__pyx_codeobj__169;
  PyObject *__pyx_codeobj__171;
  PyObject *__pyx_codeobj__173;
  PyObject *__pyx_codeobj__174;
  PyObject *__pyx_codeobj__176;
  PyObject *__pyx_codeobj__177;
  PyObject *__pyx_codeobj__179;
  PyObject *__pyx_codeobj__181;
  PyObject *__pyx_codeobj__183;
  PyObject *__pyx_codeobj__186;
  PyObject *__pyx_codeobj__189;
  PyObject *__pyx_codeobj__193;
  PyObject *__pyx_codeobj__195;
  PyObject *__pyx_codeobj__196;
  PyObject *__pyx_codeobj__198;
  PyObject *__pyx_codeobj__200;
  PyObject *__pyx_codeobj__201;
  PyObject *__pyx_codeobj__202;
  PyObject *__pyx_codeobj__203;
  PyObject *__pyx_codeobj__204;
  PyObject *__pyx_codeobj__205;
  PyObject *__pyx_codeobj__206;
  PyObject *__pyx_codeobj__207;
  PyObject *__pyx_codeobj__208;
  PyObject *__pyx_codeobj__209;
  PyObject *__pyx_codeobj__210;
  PyObject *__pyx_codeobj__211;
  PyObject *__pyx_codeobj__212;
  PyObject *__pyx_codeobj__213;
  PyObject *__pyx_codeobj__214;
  PyObject *__pyx_codeobj__215;
  PyObject *__pyx_codeobj__216;
  PyObject *__pyx_codeobj__217;
  PyObject *__pyx_codeobj__218;
  PyObject *__pyx_codeobj__219;
  PyObject *__pyx_codeobj__220;
  PyObject *__pyx_codeobj__221;
  PyObject *__pyx_codeobj__222;
  PyObject *__pyx_codeobj__223;
  PyObject *__pyx_codeobj__224;
  PyObject *__pyx_codeobj__225;
  PyObject *__pyx_codeobj__226;
  PyObject *__pyx_codeobj__227;
  PyObject *__pyx_codeobj__228;
  PyObject *__pyx_codeobj__229;
  PyObject *__pyx_codeobj__230;
  PyObject *__pyx_codeobj__231;
  PyObject *__pyx_codeobj__232;
  PyObject *__pyx_codeobj__233;
  PyObject *__pyx_codeobj__234;
  PyObject *__pyx_codeobj__235;
  PyObject *__pyx_codeobj__236;
  PyObject *__pyx_codeobj__237;
  PyObject *__pyx_codeobj__238;
  PyObject *__pyx_codeobj__239;
  PyObject *__pyx_codeobj__240;
  PyObject *__pyx_codeobj__241;
  PyObject *__pyx_codeobj__243;
  PyObject *__pyx_codeobj__244;
  PyObject *__pyx_codeobj__245;
  PyObject *__pyx_codeobj__246;
  PyObject *__pyx_codeobj__247;
  PyObject *__pyx_codeobj__248;
  PyObject *__pyx_codeobj__249;
  PyObject *__pyx_codeobj__251;
  PyObject *__pyx_codeobj__252;
  PyObject *__pyx_codeobj__253;
  PyObject *__pyx_codeobj__254;
  PyObject *__pyx_codeobj__255;
  PyObject *__pyx_codeobj__256;
  PyObject *__pyx_codeobj__257;
  PyObject *__pyx_codeobj__258;
  PyObject *__pyx_codeobj__259;
  PyObject *__pyx_codeobj__260;
  PyObject *__pyx_codeobj__261;
  PyObject *__pyx_codeobj__262;
  PyObject *__pyx_codeobj__263;
  PyObject *__pyx_codeobj__264;
  PyObject *__pyx_codeobj__265;
  PyObject *__pyx_codeobj__266;
  PyObject *__pyx_codeobj__267;
  PyObject *__pyx_codeobj__268;
  PyObject *__pyx_codeobj__269;
  PyObject *__pyx_codeobj__270;
  PyObject *__pyx_codeobj__271;
  PyObject *__pyx_codeobj__272;
  PyObject *__pyx_codeobj__273;
  PyObject *__pyx_codeobj__274;
  PyObject *__pyx_codeobj__275;
  PyObject *__pyx_codeobj__276;
  PyObject *__pyx_codeobj__277;
  PyObject *__pyx_codeobj__278;
  PyObject *__pyx_codeobj__279;
  PyObject *__pyx_codeobj__280;
  PyObject *__pyx_codeobj__281;
  PyObject *__pyx_codeobj__282;
  PyObject *__pyx_codeobj__283;
  PyObject *__pyx_codeobj__284;
  PyObject *__pyx_codeobj__285;
  PyObject *__pyx_codeobj__286;
  PyObject *__pyx_codeobj__287;
  PyObject *__pyx_codeobj__288;
  PyObject *__pyx_codeobj__289;
  PyObject *__pyx_codeobj__290;
  PyObject *__pyx_codeobj__291;
  PyObject *__pyx_codeobj__292;
  PyObject *__pyx_codeobj__293;
  PyObject *__pyx_codeobj__294;
  PyObject *__pyx_codeobj__295;
  PyObject *__pyx_codeobj__296;
  PyObject *__pyx_codeobj__297;
  PyObject *__pyx_codeobj__298;
  PyObject *__pyx_codeobj__299;
  PyObject *__pyx_codeobj__300;
  PyObject *__pyx_codeobj__301;
  PyObject *__pyx_codeobj__302;
  PyObject *__pyx_codeobj__303;
  PyObject *__pyx_codeobj__304;
  PyObject *__pyx_codeobj__305;
  PyObject *__pyx_codeobj__306;
  PyObject *__pyx_codeobj__307;
  PyObject *__pyx_codeobj__308;
  PyObject *__pyx_codeobj__309;
  PyObject *__pyx_codeobj__310;
  PyObject *__pyx_codeobj__311;
  PyObject *__pyx_codeobj__312;
  PyObject *__pyx_codeobj__313;
  PyObject *__pyx_codeobj__314;
  PyObject *__pyx_codeobj__315;
  PyObject *__pyx_codeobj__316;
  PyObject *__pyx_codeobj__317;
  PyObject *__pyx_codeobj__318;
  PyObject *__pyx_codeobj__319;
  PyObject *__pyx_codeobj__320;
  PyObject *__pyx_codeobj__321;
  PyObject *__pyx_codeobj__322;
  PyObject *__pyx_codeobj__323;
  PyObject *__pyx_codeobj__324;
  PyObject *__pyx_codeobj__325;
  PyObject *__pyx_codeobj__326;
  PyObject *__pyx_codeobj__327;
  PyObject *__pyx_codeobj__328;
  PyObject *__pyx_codeobj__329;
  PyObject *__pyx_codeobj__330;
  PyObject *__pyx_codeobj__331;
  PyObject *__pyx_codeobj__332;
  PyObject *__pyx_codeobj__333;
  PyObject *__pyx_codeobj__334;
  PyObject *__pyx_codeobj__335;
  PyObject *__pyx_codeobj__336;
  PyObject *__pyx_codeobj__337;
  PyObject *__pyx_codeobj__338;
  PyObject *__pyx_codeobj__339;
  PyObject *__pyx_codeobj__340;
  PyObject *__pyx_codeobj__341;
  PyObject *__pyx_codeobj__342;
  PyObject *__pyx_codeobj__343;
  PyObject *__pyx_codeobj__344;
  PyObject *__pyx_codeobj__345;
  PyObject *__pyx_codeobj__346;
  PyObject *__pyx_codeobj__347;
  PyObject *__pyx_codeobj__348;
  PyObject *__pyx_codeobj__349;
  PyObject *__pyx_codeobj__350;
  PyObject *__pyx_codeobj__351;
  PyObject *__pyx_codeobj__352;
  PyObject *__pyx_codeobj__353;
  PyObject *__pyx_codeobj__354;
  PyObject *__pyx_codeobj__355;
  PyObject *__pyx_codeobj__356;
  PyObject *__pyx_codeobj__357;
  PyObject *__pyx_codeobj__358;
  PyObject *__pyx_codeobj__359;
  PyObject *__pyx_codeobj__360;
  PyObject *__pyx_codeobj__361;
  PyObject *__pyx_codeobj__362;
  PyObject *__pyx_codeobj__363;
  PyObject *__pyx_codeobj__364;
  PyObject *__pyx_codeobj__365;
  PyObject *__pyx_codeobj__366;
  PyObject *__pyx_codeobj__367;
  PyObject *__pyx_codeobj__368;
  PyObject *__pyx_codeobj__369;
  PyObject *__pyx_codeobj__370;
  PyObject *__pyx_codeobj__371;
  PyObject *__pyx_codeobj__372;
  PyObject *__pyx_codeobj__373;
  PyObject *__pyx_codeobj__374;
  PyObject *__pyx_codeobj__375;
  PyObject *__pyx_codeobj__376;
  PyObject *__pyx_codeobj__377;
  PyObject *__pyx_codeobj__378;
  PyObject *__pyx_codeobj__379;
  PyObject *__pyx_codeobj__380;
  PyObject *__pyx_codeobj__381;
  PyObject *__pyx_codeobj__382;
  PyObject *__pyx_codeobj__383;
  PyObject *__pyx_codeobj__384;
  PyObject *__pyx_codeobj__385;
  PyObject *__pyx_codeobj__386;
  PyObject *__pyx_codeobj__387;
  PyObject *__pyx_codeobj__388;
  PyObject *__pyx_codeobj__389;
  PyObject *__pyx_codeobj__390;
  PyObject *__pyx_codeobj__391;
  PyObject *__pyx_codeobj__392;
  PyObject *__pyx_codeobj__393;
  PyObject *__pyx_codeobj__394;
  PyObject *__pyx_codeobj__395;
  PyObject *__pyx_codeobj__396;
  PyObject *__pyx_codeobj__398;
  PyObject *__pyx_codeobj__400;
  PyObject *__pyx_codeobj__403;
  PyObject *__pyx_codeobj__405;
  PyObject *__pyx_codeobj__408;
  PyObject *__pyx_codeobj__409;
  PyObject *__pyx_codeobj__411;
  PyObject *__pyx_codeobj__413;
  PyObject *__pyx_codeobj__414;
  PyObject *__pyx_codeobj__415;
  PyObject *__pyx_codeobj__416;
  PyObject *__pyx_codeobj__417;
  PyObject *__pyx_codeobj__418;
  PyObject *__pyx_codeobj__420;
  PyObject *__pyx_codeobj__422;
  PyObject *__pyx_codeobj__424;
  PyObject *__pyx_codeobj__425;
  PyObject *__pyx_codeobj__426;
  PyObject *__pyx_codeobj__427;
  PyObject *__pyx_codeobj__428;
  PyObject *__pyx_codeobj__429;
  PyObject *__pyx_codeobj__431;
  PyObject *__pyx_codeobj__432;
  PyObject *__pyx_codeobj__433;
  PyObject *__pyx_codeobj__434;
  PyObject *__pyx_codeobj__435;
  PyObject *__pyx_codeobj__436;
  PyObject *__pyx_codeobj__437;
  PyObject *__pyx_codeobj__438;
  PyObject *__pyx_codeobj__439;
  PyObject *__pyx_codeobj__440;
  PyObject *__pyx_codeobj__441;
  PyObject *__pyx_codeobj__442;
  PyObject *__pyx_codeobj__443;
  PyObject *__pyx_codeobj__444;
  PyObject *__pyx_codeobj__447;
  PyObject *__pyx_codeobj__448;
  PyObject *__pyx_codeobj__449;
  PyObject *__pyx_codeobj__450;
  PyObject *__pyx_codeobj__451;
  PyObject *__pyx_codeobj__452;
  PyObject *__pyx_codeobj__453;
  PyObject *__pyx_codeobj__454;
  PyObject *__pyx_codeobj__455;
  PyObject *__pyx_codeobj__456;
  PyObject *__pyx_codeobj__457;
  PyObject *__pyx_codeobj__458;
  PyObject *__pyx_codeobj__459;
  PyObject *__pyx_codeobj__460;
  PyObject *__pyx_codeobj__462;
  PyObject *__pyx_codeobj__463;
  PyObject *__pyx_codeobj__464;
  PyObject *__pyx_codeobj__465;
  PyObject *__pyx_codeobj__466;
  PyObject *__pyx_codeobj__467;
  PyObject *__pyx_codeobj__468;
  PyObject *__pyx_codeobj__469;
  PyObject *__pyx_codeobj__470;
  PyObject *__pyx_codeobj__471;
  PyObject *__pyx_codeobj__472;
  PyObject *__pyx_codeobj__473;
  PyObject *__pyx_codeobj__474;
  PyObject *__pyx_codeobj__475;
  PyObject *__pyx_codeobj__477;
  PyObject *__pyx_codeobj__479;
  PyObject *__pyx_codeobj__480;
  PyObject *__pyx_codeobj__481;
  PyObject *__pyx_codeobj__483;
  PyObject *__pyx_codeobj__484;
  PyObject *__pyx_codeobj__485;
  PyObject *__pyx_codeobj__486;
  PyObject *__pyx_codeobj__487;
  PyObject *__pyx_codeobj__488;
  PyObject *__pyx_codeobj__489;
} __pyx_mstate;

#if CYTHON_USE_MODULE_STATE
#ifdef __cplusplus
namespace {
  extern struct PyModuleDef __pyx_moduledef;
} /* anonymous namespace */
#else
static struct PyModuleDef __pyx_moduledef;
#endif

#define __pyx_mstate(o) ((__pyx_mstate *)__Pyx_PyModule_GetState(o))

#define __pyx_mstate_global (__pyx_mstate(PyState_FindModule(&__pyx_moduledef)))

#define __pyx_m (PyState_FindModule(&__pyx_moduledef))
#else
static __pyx_mstate __pyx_mstate_global_static =
#ifdef __cplusplus
    {};
#else
    {0};
#endif
static __pyx_mstate *__pyx_mstate_global = &__pyx_mstate_global_static;
#endif
/* #### Code section: module_state_clear ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_clear(PyObject *m) {
  __pyx_mstate *clear_module_state = __pyx_mstate(m);
  if (!clear_module_state) return 0;
  Py_CLEAR(clear_module_state->__pyx_d);
  Py_CLEAR(clear_module_state->__pyx_b);
  Py_CLEAR(clear_module_state->__pyx_cython_runtime);
  Py_CLEAR(clear_module_state->__pyx_empty_tuple);
  Py_CLEAR(clear_module_state->__pyx_empty_bytes);
  Py_CLEAR(clear_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_CLEAR(clear_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_CLEAR(clear_module_state->__pyx_FusedFunctionType);
  #endif
  Py_CLEAR(clear_module_state->__pyx_ptype_7cpython_4type_type);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_dtype);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_flatiter);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_broadcast);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_ndarray);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_generic);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_number);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_integer);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_signedinteger);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_unsignedinteger);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_inexact);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_floating);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_complexfloating);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_flexible);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_character);
  Py_CLEAR(clear_module_state->__pyx_ptype_5numpy_ufunc);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_7missing_C_NAType);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_HashTable);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_HashTable);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt64HashTable);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int64HashTable);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt32HashTable);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int32HashTable);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt16HashTable);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int16HashTable);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt8HashTable);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int8HashTable);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Float64HashTable);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Float32HashTable);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Complex64HashTable);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Complex128HashTable);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_PyObjectHashTable);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_StringHashTable);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Vector);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Vector);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int64Vector);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Complex128Vector);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Complex64Vector);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Float64Vector);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt64Vector);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Float32Vector);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt32Vector);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int32Vector);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt16Vector);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int16Vector);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt8Vector);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int8Vector);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_StringVector);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_StringVector);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_ObjectVector);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Factorizer);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int8Factorizer);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int8Factorizer);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Factorizer);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt8Factorizer);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int16Factorizer);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int16Factorizer);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Factorizer);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt16Factorizer);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int32Factorizer);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int32Factorizer);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Factorizer);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt32Factorizer);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Float32Factorizer);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Float32Factorizer);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Factorizer);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Complex64Factorizer);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int64Factorizer);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int64Factorizer);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Factorizer);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt64Factorizer);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Float64Factorizer);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Float64Factorizer);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Factorizer);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_Complex128Factorizer);
  Py_CLEAR(clear_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_ObjectFactorizer);
  Py_CLEAR(clear_module_state->__pyx_type_6pandas_5_libs_9hashtable_ObjectFactorizer);
  Py_CLEAR(clear_module_state->__pyx_array_type);
  Py_CLEAR(clear_module_state->__pyx_type___pyx_array);
  Py_CLEAR(clear_module_state->__pyx_MemviewEnum_type);
  Py_CLEAR(clear_module_state->__pyx_type___pyx_MemviewEnum);
  Py_CLEAR(clear_module_state->__pyx_memoryview_type);
  Py_CLEAR(clear_module_state->__pyx_type___pyx_memoryview);
  Py_CLEAR(clear_module_state->__pyx_memoryviewslice_type);
  Py_CLEAR(clear_module_state->__pyx_type___pyx_memoryviewslice);
  Py_CLEAR(clear_module_state->__pyx_kp_u_);
  Py_CLEAR(clear_module_state->__pyx_n_s_ASCII);
  Py_CLEAR(clear_module_state->__pyx_kp_s_All_dimensions_preceding_dimensi);
  Py_CLEAR(clear_module_state->__pyx_n_s_AssertionError);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Buffer_view_does_not_expose_stri);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Can_only_create_a_buffer_that_is);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Cannot_assign_to_read_only_memor);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Cannot_create_writable_memory_vi);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Cannot_index_with_type);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Cannot_transpose_memoryview_with);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex128Factorizer);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex128Factorizer___reduce_cy);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex128Factorizer___setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex128Factorizer_factorize);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Complex128Factorizer_factorize_l);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex128HashTable);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex128HashTable___reduce_cyt);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex128HashTable___setstate_c);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex128HashTable__unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex128HashTable_factorize);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex128HashTable_get_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex128HashTable_get_labels);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex128HashTable_get_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex128HashTable_get_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex128HashTable_lookup);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex128HashTable_map_location);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex128HashTable_set_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex128HashTable_set_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex128HashTable_sizeof);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex128HashTable_unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex128Vector);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex128Vector___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex128Vector___setstate_cyth);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex128Vector_to_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex64Factorizer);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex64Factorizer___reduce_cyt);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex64Factorizer___setstate_c);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex64Factorizer_factorize);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Complex64Factorizer_factorize_li);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex64HashTable);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex64HashTable___reduce_cyth);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex64HashTable___setstate_cy);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex64HashTable__unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex64HashTable_factorize);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex64HashTable_get_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex64HashTable_get_labels);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex64HashTable_get_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex64HashTable_get_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex64HashTable_lookup);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex64HashTable_map_locations);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex64HashTable_set_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex64HashTable_set_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex64HashTable_sizeof);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex64HashTable_unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex64Vector);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex64Vector___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex64Vector___setstate_cytho);
  Py_CLEAR(clear_module_state->__pyx_n_s_Complex64Vector_to_array);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Dimension_d_is_not_direct);
  Py_CLEAR(clear_module_state->__pyx_n_s_Ellipsis);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Empty_shape_tuple_for_cython_arr);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Expected_at_least_d_argument_s_g);
  Py_CLEAR(clear_module_state->__pyx_n_s_Factorizer);
  Py_CLEAR(clear_module_state->__pyx_n_s_Factorizer___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Factorizer___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Factorizer_factorize);
  Py_CLEAR(clear_module_state->__pyx_n_s_Factorizer_get_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float32Factorizer);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float32Factorizer___reduce_cytho);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float32Factorizer___setstate_cyt);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float32Factorizer_factorize);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Float32Factorizer_factorize_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float32HashTable);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float32HashTable___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float32HashTable___setstate_cyth);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float32HashTable__unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float32HashTable_factorize);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float32HashTable_get_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float32HashTable_get_labels);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float32HashTable_get_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float32HashTable_get_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float32HashTable_lookup);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float32HashTable_map_locations);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float32HashTable_set_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float32HashTable_set_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float32HashTable_sizeof);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float32HashTable_unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float32Vector);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float32Vector___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float32Vector___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float32Vector_to_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float64Factorizer);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float64Factorizer___reduce_cytho);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float64Factorizer___setstate_cyt);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float64Factorizer_factorize);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Float64Factorizer_factorize_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float64HashTable);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float64HashTable___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float64HashTable___setstate_cyth);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float64HashTable__unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float64HashTable_factorize);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float64HashTable_get_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float64HashTable_get_labels);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float64HashTable_get_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float64HashTable_get_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float64HashTable_lookup);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float64HashTable_map_locations);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float64HashTable_set_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float64HashTable_set_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float64HashTable_sizeof);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float64HashTable_unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float64Vector);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float64Vector___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float64Vector___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Float64Vector_to_array);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Function_call_with_ambiguous_arg);
  Py_CLEAR(clear_module_state->__pyx_n_s_HashTable);
  Py_CLEAR(clear_module_state->__pyx_n_s_HashTable___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_HashTable___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_ImportError);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_IndexError);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Index_out_of_bounds_axis_d);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Indirect_dimensions_not_supporte);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int16Factorizer);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int16Factorizer___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int16Factorizer___setstate_cytho);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int16Factorizer_factorize);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Int16Factorizer_factorize_line_5);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int16HashTable);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int16HashTable___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int16HashTable___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int16HashTable__unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int16HashTable_factorize);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int16HashTable_get_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int16HashTable_get_labels);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int16HashTable_get_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int16HashTable_get_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int16HashTable_lookup);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int16HashTable_map_locations);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int16HashTable_set_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int16HashTable_set_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int16HashTable_sizeof);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int16HashTable_unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int16Vector);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int16Vector___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int16Vector___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int16Vector_to_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int32Factorizer);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int32Factorizer___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int32Factorizer___setstate_cytho);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int32Factorizer_factorize);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Int32Factorizer_factorize_line_4);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int32HashTable);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int32HashTable___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int32HashTable___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int32HashTable__unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int32HashTable_factorize);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int32HashTable_get_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int32HashTable_get_labels);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int32HashTable_get_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int32HashTable_get_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int32HashTable_lookup);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int32HashTable_map_locations);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int32HashTable_set_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int32HashTable_set_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int32HashTable_sizeof);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int32HashTable_unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int32Vector);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int32Vector___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int32Vector___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int32Vector_to_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64Factorizer);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64Factorizer___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64Factorizer___setstate_cytho);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64Factorizer_factorize);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Int64Factorizer_factorize_line_3);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64HashTable);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64HashTable___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64HashTable___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64HashTable__unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64HashTable_factorize);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64HashTable_get_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64HashTable_get_labels);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64HashTable_get_labels_groupb);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64HashTable_get_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64HashTable_get_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64HashTable_lookup);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64HashTable_map_keys_to_value);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64HashTable_map_locations);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64HashTable_set_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64HashTable_set_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64HashTable_sizeof);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64HashTable_unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64Vector);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64Vector___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64Vector___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int64Vector_to_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int8Factorizer);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int8Factorizer___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int8Factorizer___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int8Factorizer_factorize);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Int8Factorizer_factorize_line_66);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int8HashTable);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int8HashTable___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int8HashTable___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int8HashTable__unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int8HashTable_factorize);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int8HashTable_get_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int8HashTable_get_labels);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int8HashTable_get_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int8HashTable_get_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int8HashTable_lookup);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int8HashTable_map_locations);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int8HashTable_set_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int8HashTable_set_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int8HashTable_sizeof);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int8HashTable_unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int8Vector);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int8Vector___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int8Vector___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Int8Vector_to_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_IntpHashTable);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Invalid_mode_expected_c_or_fortr);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Invalid_shape_in_axis);
  Py_CLEAR(clear_module_state->__pyx_n_s_KeyError);
  Py_CLEAR(clear_module_state->__pyx_n_s_MemoryError);
  Py_CLEAR(clear_module_state->__pyx_kp_s_MemoryView_of_r_at_0x_x);
  Py_CLEAR(clear_module_state->__pyx_kp_s_MemoryView_of_r_object);
  Py_CLEAR(clear_module_state->__pyx_n_u_NA);
  Py_CLEAR(clear_module_state->__pyx_kp_s_No_matching_signature_found);
  Py_CLEAR(clear_module_state->__pyx_n_s_None);
  Py_CLEAR(clear_module_state->__pyx_n_s_NotImplementedError);
  Py_CLEAR(clear_module_state->__pyx_n_b_O);
  Py_CLEAR(clear_module_state->__pyx_n_s_ObjectFactorizer);
  Py_CLEAR(clear_module_state->__pyx_n_s_ObjectFactorizer___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_ObjectFactorizer___setstate_cyth);
  Py_CLEAR(clear_module_state->__pyx_n_s_ObjectFactorizer_factorize);
  Py_CLEAR(clear_module_state->__pyx_kp_u_ObjectFactorizer_factorize_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_ObjectVector);
  Py_CLEAR(clear_module_state->__pyx_n_s_ObjectVector___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_ObjectVector___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_ObjectVector_to_array);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Out_of_bounds_on_buffer_access_a);
  Py_CLEAR(clear_module_state->__pyx_n_s_PickleError);
  Py_CLEAR(clear_module_state->__pyx_n_s_PyObjectHashTable);
  Py_CLEAR(clear_module_state->__pyx_n_s_PyObjectHashTable___reduce_cytho);
  Py_CLEAR(clear_module_state->__pyx_n_s_PyObjectHashTable___setstate_cyt);
  Py_CLEAR(clear_module_state->__pyx_n_s_PyObjectHashTable__unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_PyObjectHashTable_factorize);
  Py_CLEAR(clear_module_state->__pyx_n_s_PyObjectHashTable_get_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_PyObjectHashTable_get_labels);
  Py_CLEAR(clear_module_state->__pyx_n_s_PyObjectHashTable_get_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_PyObjectHashTable_lookup);
  Py_CLEAR(clear_module_state->__pyx_n_s_PyObjectHashTable_map_locations);
  Py_CLEAR(clear_module_state->__pyx_n_s_PyObjectHashTable_set_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_PyObjectHashTable_sizeof);
  Py_CLEAR(clear_module_state->__pyx_n_s_PyObjectHashTable_unique);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples_10);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples_11);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples_12);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples_2);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples_3);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples_4);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples_5);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples_6);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples_7);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples_8);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples_9);
  Py_CLEAR(clear_module_state->__pyx_kp_u_Returns_np_ndarray_np_intp_Exam);
  Py_CLEAR(clear_module_state->__pyx_n_s_SIZE_HINT_LIMIT);
  Py_CLEAR(clear_module_state->__pyx_n_s_Sequence);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Step_may_not_be_zero_axis_d);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringHashTable);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringHashTable___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringHashTable___setstate_cytho);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringHashTable__unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringHashTable_factorize);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringHashTable_get_indexer);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringHashTable_get_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringHashTable_get_labels);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringHashTable_get_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringHashTable_lookup);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringHashTable_map_locations);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringHashTable_set_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringHashTable_sizeof);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringHashTable_unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringVector);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringVector___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringVector___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_StringVector_to_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_TypeError);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt16Factorizer);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt16Factorizer___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt16Factorizer___setstate_cyth);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt16Factorizer_factorize);
  Py_CLEAR(clear_module_state->__pyx_kp_u_UInt16Factorizer_factorize_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt16HashTable);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt16HashTable___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt16HashTable___setstate_cytho);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt16HashTable__unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt16HashTable_factorize);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt16HashTable_get_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt16HashTable_get_labels);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt16HashTable_get_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt16HashTable_get_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt16HashTable_lookup);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt16HashTable_map_locations);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt16HashTable_set_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt16HashTable_set_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt16HashTable_sizeof);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt16HashTable_unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt16Vector);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt16Vector___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt16Vector___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt16Vector_to_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt32Factorizer);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt32Factorizer___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt32Factorizer___setstate_cyth);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt32Factorizer_factorize);
  Py_CLEAR(clear_module_state->__pyx_kp_u_UInt32Factorizer_factorize_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt32HashTable);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt32HashTable___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt32HashTable___setstate_cytho);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt32HashTable__unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt32HashTable_factorize);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt32HashTable_get_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt32HashTable_get_labels);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt32HashTable_get_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt32HashTable_get_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt32HashTable_lookup);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt32HashTable_map_locations);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt32HashTable_set_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt32HashTable_set_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt32HashTable_sizeof);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt32HashTable_unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt32Vector);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt32Vector___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt32Vector___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt32Vector_to_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt64Factorizer);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt64Factorizer___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt64Factorizer___setstate_cyth);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt64Factorizer_factorize);
  Py_CLEAR(clear_module_state->__pyx_kp_u_UInt64Factorizer_factorize_line);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt64HashTable);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt64HashTable___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt64HashTable___setstate_cytho);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt64HashTable__unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt64HashTable_factorize);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt64HashTable_get_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt64HashTable_get_labels);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt64HashTable_get_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt64HashTable_get_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt64HashTable_lookup);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt64HashTable_map_locations);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt64HashTable_set_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt64HashTable_set_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt64HashTable_sizeof);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt64HashTable_unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt64Vector);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt64Vector___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt64Vector___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt64Vector_to_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt8Factorizer);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt8Factorizer___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt8Factorizer___setstate_cytho);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt8Factorizer_factorize);
  Py_CLEAR(clear_module_state->__pyx_kp_u_UInt8Factorizer_factorize_line_6);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt8HashTable);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt8HashTable___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt8HashTable___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt8HashTable__unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt8HashTable_factorize);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt8HashTable_get_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt8HashTable_get_labels);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt8HashTable_get_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt8HashTable_get_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt8HashTable_lookup);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt8HashTable_map_locations);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt8HashTable_set_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt8HashTable_set_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt8HashTable_sizeof);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt8HashTable_unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt8Vector);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt8Vector___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt8Vector___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_UInt8Vector_to_array);
  Py_CLEAR(clear_module_state->__pyx_kp_s_Unable_to_convert_item_to_object);
  Py_CLEAR(clear_module_state->__pyx_n_s_UnicodeEncodeError);
  Py_CLEAR(clear_module_state->__pyx_n_s_ValueError);
  Py_CLEAR(clear_module_state->__pyx_n_s_Vector);
  Py_CLEAR(clear_module_state->__pyx_n_s_Vector___reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_Vector___setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_View_MemoryView);
  Py_CLEAR(clear_module_state->__pyx_n_s__191);
  Py_CLEAR(clear_module_state->__pyx_kp_u__2);
  Py_CLEAR(clear_module_state->__pyx_n_s__3);
  Py_CLEAR(clear_module_state->__pyx_n_s__490);
  Py_CLEAR(clear_module_state->__pyx_kp_u__6);
  Py_CLEAR(clear_module_state->__pyx_kp_s__69);
  Py_CLEAR(clear_module_state->__pyx_kp_u__7);
  Py_CLEAR(clear_module_state->__pyx_kp_s__70);
  Py_CLEAR(clear_module_state->__pyx_kp_u__70);
  Py_CLEAR(clear_module_state->__pyx_kp_s__86);
  Py_CLEAR(clear_module_state->__pyx_n_s_a);
  Py_CLEAR(clear_module_state->__pyx_n_s_abc);
  Py_CLEAR(clear_module_state->__pyx_n_s_allocate_buffer);
  Py_CLEAR(clear_module_state->__pyx_kp_u_and);
  Py_CLEAR(clear_module_state->__pyx_n_s_args);
  Py_CLEAR(clear_module_state->__pyx_n_s_argsort);
  Py_CLEAR(clear_module_state->__pyx_n_s_arr);
  Py_CLEAR(clear_module_state->__pyx_n_s_arr_uniques);
  Py_CLEAR(clear_module_state->__pyx_n_s_asarray);
  Py_CLEAR(clear_module_state->__pyx_n_s_asyncio_coroutines);
  Py_CLEAR(clear_module_state->__pyx_n_s_b);
  Py_CLEAR(clear_module_state->__pyx_n_s_base);
  Py_CLEAR(clear_module_state->__pyx_n_s_bool);
  Py_CLEAR(clear_module_state->__pyx_n_u_bool);
  Py_CLEAR(clear_module_state->__pyx_n_s_bool_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_c);
  Py_CLEAR(clear_module_state->__pyx_n_u_c);
  Py_CLEAR(clear_module_state->__pyx_n_s_class);
  Py_CLEAR(clear_module_state->__pyx_n_s_class_getitem);
  Py_CLEAR(clear_module_state->__pyx_n_s_cline_in_traceback);
  Py_CLEAR(clear_module_state->__pyx_n_s_collections);
  Py_CLEAR(clear_module_state->__pyx_kp_s_collections_abc);
  Py_CLEAR(clear_module_state->__pyx_n_s_complex128);
  Py_CLEAR(clear_module_state->__pyx_n_s_complex64);
  Py_CLEAR(clear_module_state->__pyx_kp_s_contiguous_and_direct);
  Py_CLEAR(clear_module_state->__pyx_kp_s_contiguous_and_indirect);
  Py_CLEAR(clear_module_state->__pyx_n_s_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_count_prior);
  Py_CLEAR(clear_module_state->__pyx_n_s_counts);
  Py_CLEAR(clear_module_state->__pyx_n_s_deep);
  Py_CLEAR(clear_module_state->__pyx_n_s_defaults);
  Py_CLEAR(clear_module_state->__pyx_n_s_dict);
  Py_CLEAR(clear_module_state->__pyx_n_s_dict_2);
  Py_CLEAR(clear_module_state->__pyx_kp_s_dict_str_int);
  Py_CLEAR(clear_module_state->__pyx_kp_u_disable);
  Py_CLEAR(clear_module_state->__pyx_kp_s_double_complex);
  Py_CLEAR(clear_module_state->__pyx_n_s_dropna);
  Py_CLEAR(clear_module_state->__pyx_n_s_dtype);
  Py_CLEAR(clear_module_state->__pyx_n_s_dtype_is_object);
  Py_CLEAR(clear_module_state->__pyx_n_s_duplicated);
  Py_CLEAR(clear_module_state->__pyx_n_s_empty);
  Py_CLEAR(clear_module_state->__pyx_kp_u_enable);
  Py_CLEAR(clear_module_state->__pyx_n_s_encode);
  Py_CLEAR(clear_module_state->__pyx_n_s_enumerate);
  Py_CLEAR(clear_module_state->__pyx_n_s_error);
  Py_CLEAR(clear_module_state->__pyx_kp_u_external_reference_but_Vector_re);
  Py_CLEAR(clear_module_state->__pyx_kp_u_external_reference_to_result_mas);
  Py_CLEAR(clear_module_state->__pyx_kp_u_external_reference_to_uniques_he);
  Py_CLEAR(clear_module_state->__pyx_n_s_factorize);
  Py_CLEAR(clear_module_state->__pyx_n_u_first);
  Py_CLEAR(clear_module_state->__pyx_n_s_flags);
  Py_CLEAR(clear_module_state->__pyx_n_s_float32);
  Py_CLEAR(clear_module_state->__pyx_n_s_float32_t);
  Py_CLEAR(clear_module_state->__pyx_n_s_float64);
  Py_CLEAR(clear_module_state->__pyx_n_s_float64_t);
  Py_CLEAR(clear_module_state->__pyx_kp_s_float_complex);
  Py_CLEAR(clear_module_state->__pyx_n_s_for_flags);
  Py_CLEAR(clear_module_state->__pyx_n_s_for_pairs);
  Py_CLEAR(clear_module_state->__pyx_n_s_format);
  Py_CLEAR(clear_module_state->__pyx_n_s_fortran);
  Py_CLEAR(clear_module_state->__pyx_n_u_fortran);
  Py_CLEAR(clear_module_state->__pyx_n_s_fused_sigindex);
  Py_CLEAR(clear_module_state->__pyx_kp_u_gc);
  Py_CLEAR(clear_module_state->__pyx_n_s_get);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_hashtable_trace_domain);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_indexer);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_labels);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_labels_groupby);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_get_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_getstate);
  Py_CLEAR(clear_module_state->__pyx_kp_u_got);
  Py_CLEAR(clear_module_state->__pyx_kp_u_got_differing_extents_in_dimensi);
  Py_CLEAR(clear_module_state->__pyx_n_s_i);
  Py_CLEAR(clear_module_state->__pyx_n_s_id);
  Py_CLEAR(clear_module_state->__pyx_n_s_idx);
  Py_CLEAR(clear_module_state->__pyx_n_s_ignore_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_imag);
  Py_CLEAR(clear_module_state->__pyx_n_s_import);
  Py_CLEAR(clear_module_state->__pyx_n_s_index);
  Py_CLEAR(clear_module_state->__pyx_n_s_initializing);
  Py_CLEAR(clear_module_state->__pyx_n_s_int);
  Py_CLEAR(clear_module_state->__pyx_n_s_int16);
  Py_CLEAR(clear_module_state->__pyx_n_s_int16_t);
  Py_CLEAR(clear_module_state->__pyx_n_s_int32);
  Py_CLEAR(clear_module_state->__pyx_n_s_int32_t);
  Py_CLEAR(clear_module_state->__pyx_n_s_int64);
  Py_CLEAR(clear_module_state->__pyx_n_s_int64_t);
  Py_CLEAR(clear_module_state->__pyx_n_s_int8);
  Py_CLEAR(clear_module_state->__pyx_n_s_int8_t);
  Py_CLEAR(clear_module_state->__pyx_n_s_intp);
  Py_CLEAR(clear_module_state->__pyx_n_s_is_coroutine);
  Py_CLEAR(clear_module_state->__pyx_kp_u_isenabled);
  Py_CLEAR(clear_module_state->__pyx_n_s_ismember);
  Py_CLEAR(clear_module_state->__pyx_n_s_itemsize);
  Py_CLEAR(clear_module_state->__pyx_kp_s_itemsize_0_for_cython_array);
  Py_CLEAR(clear_module_state->__pyx_n_s_j);
  Py_CLEAR(clear_module_state->__pyx_n_s_k);
  Py_CLEAR(clear_module_state->__pyx_n_s_keep);
  Py_CLEAR(clear_module_state->__pyx_kp_u_keep_must_be_either_first_last_o);
  Py_CLEAR(clear_module_state->__pyx_n_s_key);
  Py_CLEAR(clear_module_state->__pyx_n_s_keys);
  Py_CLEAR(clear_module_state->__pyx_n_s_kind);
  Py_CLEAR(clear_module_state->__pyx_n_s_kwargs);
  Py_CLEAR(clear_module_state->__pyx_n_s_labels);
  Py_CLEAR(clear_module_state->__pyx_n_u_last);
  Py_CLEAR(clear_module_state->__pyx_n_s_locs);
  Py_CLEAR(clear_module_state->__pyx_n_s_lookup);
  Py_CLEAR(clear_module_state->__pyx_n_s_main);
  Py_CLEAR(clear_module_state->__pyx_n_s_map_keys_to_values);
  Py_CLEAR(clear_module_state->__pyx_n_s_map_locations);
  Py_CLEAR(clear_module_state->__pyx_n_s_mask);
  Py_CLEAR(clear_module_state->__pyx_kp_u_mask_not_supported_for_ObjectFac);
  Py_CLEAR(clear_module_state->__pyx_n_s_mask_values);
  Py_CLEAR(clear_module_state->__pyx_n_s_max_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_memview);
  Py_CLEAR(clear_module_state->__pyx_n_s_mode);
  Py_CLEAR(clear_module_state->__pyx_n_s_modes);
  Py_CLEAR(clear_module_state->__pyx_n_s_n);
  Py_CLEAR(clear_module_state->__pyx_n_u_n_buckets);
  Py_CLEAR(clear_module_state->__pyx_n_u_n_occupied);
  Py_CLEAR(clear_module_state->__pyx_n_s_na_position);
  Py_CLEAR(clear_module_state->__pyx_n_s_na_sentinel);
  Py_CLEAR(clear_module_state->__pyx_n_s_na_string_sentinel);
  Py_CLEAR(clear_module_state->__pyx_n_s_na_value);
  Py_CLEAR(clear_module_state->__pyx_n_s_na_value2);
  Py_CLEAR(clear_module_state->__pyx_n_s_name);
  Py_CLEAR(clear_module_state->__pyx_n_s_name_2);
  Py_CLEAR(clear_module_state->__pyx_n_u_nan);
  Py_CLEAR(clear_module_state->__pyx_n_s_ndarray);
  Py_CLEAR(clear_module_state->__pyx_n_s_ndim);
  Py_CLEAR(clear_module_state->__pyx_n_s_new);
  Py_CLEAR(clear_module_state->__pyx_n_s_nkeys);
  Py_CLEAR(clear_module_state->__pyx_kp_s_no_default___reduce___due_to_non);
  Py_CLEAR(clear_module_state->__pyx_n_s_np);
  Py_CLEAR(clear_module_state->__pyx_kp_s_np_ndarray);
  Py_CLEAR(clear_module_state->__pyx_n_s_numpy);
  Py_CLEAR(clear_module_state->__pyx_kp_u_numpy_core_multiarray_failed_to);
  Py_CLEAR(clear_module_state->__pyx_kp_u_numpy_core_umath_failed_to_impor);
  Py_CLEAR(clear_module_state->__pyx_n_s_obj);
  Py_CLEAR(clear_module_state->__pyx_n_s_object);
  Py_CLEAR(clear_module_state->__pyx_n_s_object_hash);
  Py_CLEAR(clear_module_state->__pyx_n_s_objects_are_equal);
  Py_CLEAR(clear_module_state->__pyx_n_s_overhead);
  Py_CLEAR(clear_module_state->__pyx_n_s_pack);
  Py_CLEAR(clear_module_state->__pyx_n_s_pandas__libs_hashtable);
  Py_CLEAR(clear_module_state->__pyx_kp_s_pandas__libs_hashtable_class_hel);
  Py_CLEAR(clear_module_state->__pyx_kp_s_pandas__libs_hashtable_func_help);
  Py_CLEAR(clear_module_state->__pyx_kp_s_pandas__libs_hashtable_pyx);
  Py_CLEAR(clear_module_state->__pyx_n_s_pickle);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_PickleError);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_checksum);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_0duplicated);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_0ismember);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_0value_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_10duplicated);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_10ismember);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_10value_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_11duplicated);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_11ismember);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_11value_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_12duplicated);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_12ismember);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_12value_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_1duplicated);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_1ismember);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_1value_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_2duplicated);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_2ismember);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_2value_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_3duplicated);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_3ismember);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_3value_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_4duplicated);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_4ismember);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_4value_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_5duplicated);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_5ismember);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_5value_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_6duplicated);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_6ismember);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_6value_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_7duplicated);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_7ismember);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_7value_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_8duplicated);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_8ismember);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_8value_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_9duplicated);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_9ismember);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_fuse_9value_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_result);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_type);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_unpickle_Enum);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_unpickle_HashTable);
  Py_CLEAR(clear_module_state->__pyx_n_s_pyx_vtable);
  Py_CLEAR(clear_module_state->__pyx_n_s_range);
  Py_CLEAR(clear_module_state->__pyx_n_s_real);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_reduce_ex);
  Py_CLEAR(clear_module_state->__pyx_n_s_refcheck);
  Py_CLEAR(clear_module_state->__pyx_n_s_register);
  Py_CLEAR(clear_module_state->__pyx_n_s_resbuf);
  Py_CLEAR(clear_module_state->__pyx_n_s_resize);
  Py_CLEAR(clear_module_state->__pyx_n_s_result_mask);
  Py_CLEAR(clear_module_state->__pyx_n_s_ret);
  Py_CLEAR(clear_module_state->__pyx_n_s_return);
  Py_CLEAR(clear_module_state->__pyx_n_s_return_inverse);
  Py_CLEAR(clear_module_state->__pyx_n_s_rmd);
  Py_CLEAR(clear_module_state->__pyx_n_s_s);
  Py_CLEAR(clear_module_state->__pyx_n_s_seen_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_self);
  Py_CLEAR(clear_module_state->__pyx_kp_s_self_table_cannot_be_converted_t);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_item);
  Py_CLEAR(clear_module_state->__pyx_n_s_set_na);
  Py_CLEAR(clear_module_state->__pyx_n_s_setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_setstate_cython);
  Py_CLEAR(clear_module_state->__pyx_n_s_shape);
  Py_CLEAR(clear_module_state->__pyx_kp_u_should_have_raised_on_append);
  Py_CLEAR(clear_module_state->__pyx_n_s_signatures);
  Py_CLEAR(clear_module_state->__pyx_n_s_size);
  Py_CLEAR(clear_module_state->__pyx_n_u_size);
  Py_CLEAR(clear_module_state->__pyx_n_s_size_hint);
  Py_CLEAR(clear_module_state->__pyx_n_s_sizeof);
  Py_CLEAR(clear_module_state->__pyx_n_s_spec);
  Py_CLEAR(clear_module_state->__pyx_n_s_split);
  Py_CLEAR(clear_module_state->__pyx_n_s_start);
  Py_CLEAR(clear_module_state->__pyx_n_s_state);
  Py_CLEAR(clear_module_state->__pyx_n_s_step);
  Py_CLEAR(clear_module_state->__pyx_n_s_stop);
  Py_CLEAR(clear_module_state->__pyx_kp_s_strided_and_direct);
  Py_CLEAR(clear_module_state->__pyx_kp_s_strided_and_direct_or_indirect);
  Py_CLEAR(clear_module_state->__pyx_kp_s_strided_and_indirect);
  Py_CLEAR(clear_module_state->__pyx_kp_s_stringsource);
  Py_CLEAR(clear_module_state->__pyx_n_s_strip);
  Py_CLEAR(clear_module_state->__pyx_n_s_struct);
  Py_CLEAR(clear_module_state->__pyx_n_s_sys);
  Py_CLEAR(clear_module_state->__pyx_n_s_table);
  Py_CLEAR(clear_module_state->__pyx_n_s_test);
  Py_CLEAR(clear_module_state->__pyx_n_s_to_array);
  Py_CLEAR(clear_module_state->__pyx_kp_s_tuple_ndarray_ndarray);
  Py_CLEAR(clear_module_state->__pyx_n_s_ud);
  Py_CLEAR(clear_module_state->__pyx_n_s_uindexer);
  Py_CLEAR(clear_module_state->__pyx_n_s_uint16);
  Py_CLEAR(clear_module_state->__pyx_n_s_uint16_t);
  Py_CLEAR(clear_module_state->__pyx_n_s_uint32);
  Py_CLEAR(clear_module_state->__pyx_n_s_uint32_t);
  Py_CLEAR(clear_module_state->__pyx_n_s_uint64);
  Py_CLEAR(clear_module_state->__pyx_n_s_uint64_t);
  Py_CLEAR(clear_module_state->__pyx_n_s_uint8);
  Py_CLEAR(clear_module_state->__pyx_n_u_uint8);
  Py_CLEAR(clear_module_state->__pyx_n_s_uint8_t);
  Py_CLEAR(clear_module_state->__pyx_kp_s_unable_to_allocate_array_data);
  Py_CLEAR(clear_module_state->__pyx_kp_s_unable_to_allocate_shape_and_str);
  Py_CLEAR(clear_module_state->__pyx_n_s_unique);
  Py_CLEAR(clear_module_state->__pyx_n_s_unique_2);
  Py_CLEAR(clear_module_state->__pyx_n_s_unique_label_indices);
  Py_CLEAR(clear_module_state->__pyx_n_s_unique_label_indices_int32);
  Py_CLEAR(clear_module_state->__pyx_n_s_unique_label_indices_int64);
  Py_CLEAR(clear_module_state->__pyx_n_s_uniques);
  Py_CLEAR(clear_module_state->__pyx_n_s_uniques_vector);
  Py_CLEAR(clear_module_state->__pyx_n_s_unpack);
  Py_CLEAR(clear_module_state->__pyx_n_s_update);
  Py_CLEAR(clear_module_state->__pyx_n_u_upper_bound);
  Py_CLEAR(clear_module_state->__pyx_n_s_use_mask);
  Py_CLEAR(clear_module_state->__pyx_n_s_use_na_value);
  Py_CLEAR(clear_module_state->__pyx_n_s_use_result_mask);
  Py_CLEAR(clear_module_state->__pyx_n_s_use_setstate);
  Py_CLEAR(clear_module_state->__pyx_n_s_uses_mask);
  Py_CLEAR(clear_module_state->__pyx_kp_u_uses_mask_not_implemented_with_d);
  Py_CLEAR(clear_module_state->__pyx_kp_u_uses_mask_not_implemented_with_o);
  Py_CLEAR(clear_module_state->__pyx_n_s_v);
  Py_CLEAR(clear_module_state->__pyx_n_s_val);
  Py_CLEAR(clear_module_state->__pyx_n_s_value_count);
  Py_CLEAR(clear_module_state->__pyx_n_s_values);
  Py_CLEAR(clear_module_state->__pyx_n_s_vecs);
  Py_CLEAR(clear_module_state->__pyx_n_s_version_info);
  Py_CLEAR(clear_module_state->__pyx_n_s_view);
  Py_CLEAR(clear_module_state->__pyx_n_s_zeros);
  Py_CLEAR(clear_module_state->__pyx_int_0);
  Py_CLEAR(clear_module_state->__pyx_int_1);
  Py_CLEAR(clear_module_state->__pyx_int_2);
  Py_CLEAR(clear_module_state->__pyx_int_3);
  Py_CLEAR(clear_module_state->__pyx_int_1048583);
  Py_CLEAR(clear_module_state->__pyx_int_112105877);
  Py_CLEAR(clear_module_state->__pyx_int_136983863);
  Py_CLEAR(clear_module_state->__pyx_int_184977713);
  Py_CLEAR(clear_module_state->__pyx_int_222419149);
  Py_CLEAR(clear_module_state->__pyx_int_228825662);
  Py_CLEAR(clear_module_state->__pyx_int_238750788);
  Py_CLEAR(clear_module_state->__pyx_int_neg_1);
  Py_CLEAR(clear_module_state->__pyx_k__14);
  Py_CLEAR(clear_module_state->__pyx_k__15);
  Py_CLEAR(clear_module_state->__pyx_k__18);
  Py_CLEAR(clear_module_state->__pyx_k__19);
  Py_CLEAR(clear_module_state->__pyx_k__20);
  Py_CLEAR(clear_module_state->__pyx_k__21);
  Py_CLEAR(clear_module_state->__pyx_k__22);
  Py_CLEAR(clear_module_state->__pyx_k__23);
  Py_CLEAR(clear_module_state->__pyx_k__24);
  Py_CLEAR(clear_module_state->__pyx_k__25);
  Py_CLEAR(clear_module_state->__pyx_k__26);
  Py_CLEAR(clear_module_state->__pyx_k__27);
  Py_CLEAR(clear_module_state->__pyx_k__28);
  Py_CLEAR(clear_module_state->__pyx_k__29);
  Py_CLEAR(clear_module_state->__pyx_k__30);
  Py_CLEAR(clear_module_state->__pyx_k__31);
  Py_CLEAR(clear_module_state->__pyx_k__32);
  Py_CLEAR(clear_module_state->__pyx_k__33);
  Py_CLEAR(clear_module_state->__pyx_k__34);
  Py_CLEAR(clear_module_state->__pyx_k__35);
  Py_CLEAR(clear_module_state->__pyx_k__36);
  Py_CLEAR(clear_module_state->__pyx_k__37);
  Py_CLEAR(clear_module_state->__pyx_k__38);
  Py_CLEAR(clear_module_state->__pyx_k__39);
  Py_CLEAR(clear_module_state->__pyx_k__40);
  Py_CLEAR(clear_module_state->__pyx_k__42);
  Py_CLEAR(clear_module_state->__pyx_k__44);
  Py_CLEAR(clear_module_state->__pyx_k__45);
  Py_CLEAR(clear_module_state->__pyx_k__46);
  Py_CLEAR(clear_module_state->__pyx_k__47);
  Py_CLEAR(clear_module_state->__pyx_k__48);
  Py_CLEAR(clear_module_state->__pyx_k__49);
  Py_CLEAR(clear_module_state->__pyx_k__50);
  Py_CLEAR(clear_module_state->__pyx_k__51);
  Py_CLEAR(clear_module_state->__pyx_k__52);
  Py_CLEAR(clear_module_state->__pyx_k__53);
  Py_CLEAR(clear_module_state->__pyx_k__54);
  Py_CLEAR(clear_module_state->__pyx_k__55);
  Py_CLEAR(clear_module_state->__pyx_k__56);
  Py_CLEAR(clear_module_state->__pyx_k__57);
  Py_CLEAR(clear_module_state->__pyx_k__58);
  Py_CLEAR(clear_module_state->__pyx_k__60);
  Py_CLEAR(clear_module_state->__pyx_k__61);
  Py_CLEAR(clear_module_state->__pyx_k__62);
  Py_CLEAR(clear_module_state->__pyx_k__63);
  Py_CLEAR(clear_module_state->__pyx_k__64);
  Py_CLEAR(clear_module_state->__pyx_k__65);
  Py_CLEAR(clear_module_state->__pyx_k__66);
  Py_CLEAR(clear_module_state->__pyx_k__67);
  Py_CLEAR(clear_module_state->__pyx_k__68);
  Py_CLEAR(clear_module_state->__pyx_k__73);
  Py_CLEAR(clear_module_state->__pyx_k__74);
  Py_CLEAR(clear_module_state->__pyx_k__75);
  Py_CLEAR(clear_module_state->__pyx_k__76);
  Py_CLEAR(clear_module_state->__pyx_k__77);
  Py_CLEAR(clear_module_state->__pyx_k__78);
  Py_CLEAR(clear_module_state->__pyx_k__79);
  Py_CLEAR(clear_module_state->__pyx_k__80);
  Py_CLEAR(clear_module_state->__pyx_k__81);
  Py_CLEAR(clear_module_state->__pyx_k__82);
  Py_CLEAR(clear_module_state->__pyx_k__83);
  Py_CLEAR(clear_module_state->__pyx_k__84);
  Py_CLEAR(clear_module_state->__pyx_k__85);
  Py_CLEAR(clear_module_state->__pyx_k__87);
  Py_CLEAR(clear_module_state->__pyx_k__88);
  Py_CLEAR(clear_module_state->__pyx_k__89);
  Py_CLEAR(clear_module_state->__pyx_k__90);
  Py_CLEAR(clear_module_state->__pyx_k__91);
  Py_CLEAR(clear_module_state->__pyx_k__92);
  Py_CLEAR(clear_module_state->__pyx_k__93);
  Py_CLEAR(clear_module_state->__pyx_k__94);
  Py_CLEAR(clear_module_state->__pyx_k__95);
  Py_CLEAR(clear_module_state->__pyx_k__96);
  Py_CLEAR(clear_module_state->__pyx_k__97);
  Py_CLEAR(clear_module_state->__pyx_k__98);
  Py_CLEAR(clear_module_state->__pyx_k__99);
  Py_CLEAR(clear_module_state->__pyx_slice__5);
  Py_CLEAR(clear_module_state->__pyx_tuple__4);
  Py_CLEAR(clear_module_state->__pyx_tuple__8);
  Py_CLEAR(clear_module_state->__pyx_tuple__9);
  Py_CLEAR(clear_module_state->__pyx_tuple__10);
  Py_CLEAR(clear_module_state->__pyx_tuple__11);
  Py_CLEAR(clear_module_state->__pyx_tuple__12);
  Py_CLEAR(clear_module_state->__pyx_tuple__13);
  Py_CLEAR(clear_module_state->__pyx_tuple__16);
  Py_CLEAR(clear_module_state->__pyx_tuple__17);
  Py_CLEAR(clear_module_state->__pyx_tuple__41);
  Py_CLEAR(clear_module_state->__pyx_tuple__43);
  Py_CLEAR(clear_module_state->__pyx_tuple__59);
  Py_CLEAR(clear_module_state->__pyx_tuple__71);
  Py_CLEAR(clear_module_state->__pyx_tuple__72);
  Py_CLEAR(clear_module_state->__pyx_slice__100);
  Py_CLEAR(clear_module_state->__pyx_tuple__101);
  Py_CLEAR(clear_module_state->__pyx_tuple__102);
  Py_CLEAR(clear_module_state->__pyx_tuple__103);
  Py_CLEAR(clear_module_state->__pyx_tuple__104);
  Py_CLEAR(clear_module_state->__pyx_tuple__105);
  Py_CLEAR(clear_module_state->__pyx_tuple__106);
  Py_CLEAR(clear_module_state->__pyx_tuple__107);
  Py_CLEAR(clear_module_state->__pyx_tuple__108);
  Py_CLEAR(clear_module_state->__pyx_tuple__109);
  Py_CLEAR(clear_module_state->__pyx_tuple__110);
  Py_CLEAR(clear_module_state->__pyx_tuple__111);
  Py_CLEAR(clear_module_state->__pyx_tuple__112);
  Py_CLEAR(clear_module_state->__pyx_tuple__115);
  Py_CLEAR(clear_module_state->__pyx_tuple__117);
  Py_CLEAR(clear_module_state->__pyx_tuple__119);
  Py_CLEAR(clear_module_state->__pyx_tuple__121);
  Py_CLEAR(clear_module_state->__pyx_tuple__165);
  Py_CLEAR(clear_module_state->__pyx_tuple__168);
  Py_CLEAR(clear_module_state->__pyx_tuple__170);
  Py_CLEAR(clear_module_state->__pyx_tuple__172);
  Py_CLEAR(clear_module_state->__pyx_tuple__175);
  Py_CLEAR(clear_module_state->__pyx_tuple__178);
  Py_CLEAR(clear_module_state->__pyx_tuple__180);
  Py_CLEAR(clear_module_state->__pyx_tuple__182);
  Py_CLEAR(clear_module_state->__pyx_tuple__184);
  Py_CLEAR(clear_module_state->__pyx_tuple__185);
  Py_CLEAR(clear_module_state->__pyx_tuple__187);
  Py_CLEAR(clear_module_state->__pyx_tuple__188);
  Py_CLEAR(clear_module_state->__pyx_tuple__190);
  Py_CLEAR(clear_module_state->__pyx_tuple__192);
  Py_CLEAR(clear_module_state->__pyx_tuple__194);
  Py_CLEAR(clear_module_state->__pyx_tuple__197);
  Py_CLEAR(clear_module_state->__pyx_tuple__199);
  Py_CLEAR(clear_module_state->__pyx_tuple__242);
  Py_CLEAR(clear_module_state->__pyx_tuple__250);
  Py_CLEAR(clear_module_state->__pyx_tuple__397);
  Py_CLEAR(clear_module_state->__pyx_tuple__399);
  Py_CLEAR(clear_module_state->__pyx_tuple__401);
  Py_CLEAR(clear_module_state->__pyx_tuple__402);
  Py_CLEAR(clear_module_state->__pyx_tuple__404);
  Py_CLEAR(clear_module_state->__pyx_tuple__406);
  Py_CLEAR(clear_module_state->__pyx_tuple__407);
  Py_CLEAR(clear_module_state->__pyx_tuple__410);
  Py_CLEAR(clear_module_state->__pyx_tuple__412);
  Py_CLEAR(clear_module_state->__pyx_tuple__419);
  Py_CLEAR(clear_module_state->__pyx_tuple__421);
  Py_CLEAR(clear_module_state->__pyx_tuple__423);
  Py_CLEAR(clear_module_state->__pyx_tuple__430);
  Py_CLEAR(clear_module_state->__pyx_tuple__445);
  Py_CLEAR(clear_module_state->__pyx_tuple__446);
  Py_CLEAR(clear_module_state->__pyx_tuple__461);
  Py_CLEAR(clear_module_state->__pyx_tuple__476);
  Py_CLEAR(clear_module_state->__pyx_tuple__478);
  Py_CLEAR(clear_module_state->__pyx_tuple__482);
  Py_CLEAR(clear_module_state->__pyx_codeobj__113);
  Py_CLEAR(clear_module_state->__pyx_codeobj__114);
  Py_CLEAR(clear_module_state->__pyx_codeobj__116);
  Py_CLEAR(clear_module_state->__pyx_codeobj__118);
  Py_CLEAR(clear_module_state->__pyx_codeobj__120);
  Py_CLEAR(clear_module_state->__pyx_codeobj__122);
  Py_CLEAR(clear_module_state->__pyx_codeobj__123);
  Py_CLEAR(clear_module_state->__pyx_codeobj__124);
  Py_CLEAR(clear_module_state->__pyx_codeobj__125);
  Py_CLEAR(clear_module_state->__pyx_codeobj__126);
  Py_CLEAR(clear_module_state->__pyx_codeobj__127);
  Py_CLEAR(clear_module_state->__pyx_codeobj__128);
  Py_CLEAR(clear_module_state->__pyx_codeobj__129);
  Py_CLEAR(clear_module_state->__pyx_codeobj__130);
  Py_CLEAR(clear_module_state->__pyx_codeobj__131);
  Py_CLEAR(clear_module_state->__pyx_codeobj__132);
  Py_CLEAR(clear_module_state->__pyx_codeobj__133);
  Py_CLEAR(clear_module_state->__pyx_codeobj__134);
  Py_CLEAR(clear_module_state->__pyx_codeobj__135);
  Py_CLEAR(clear_module_state->__pyx_codeobj__136);
  Py_CLEAR(clear_module_state->__pyx_codeobj__137);
  Py_CLEAR(clear_module_state->__pyx_codeobj__138);
  Py_CLEAR(clear_module_state->__pyx_codeobj__139);
  Py_CLEAR(clear_module_state->__pyx_codeobj__140);
  Py_CLEAR(clear_module_state->__pyx_codeobj__141);
  Py_CLEAR(clear_module_state->__pyx_codeobj__142);
  Py_CLEAR(clear_module_state->__pyx_codeobj__143);
  Py_CLEAR(clear_module_state->__pyx_codeobj__144);
  Py_CLEAR(clear_module_state->__pyx_codeobj__145);
  Py_CLEAR(clear_module_state->__pyx_codeobj__146);
  Py_CLEAR(clear_module_state->__pyx_codeobj__147);
  Py_CLEAR(clear_module_state->__pyx_codeobj__148);
  Py_CLEAR(clear_module_state->__pyx_codeobj__149);
  Py_CLEAR(clear_module_state->__pyx_codeobj__150);
  Py_CLEAR(clear_module_state->__pyx_codeobj__151);
  Py_CLEAR(clear_module_state->__pyx_codeobj__152);
  Py_CLEAR(clear_module_state->__pyx_codeobj__153);
  Py_CLEAR(clear_module_state->__pyx_codeobj__154);
  Py_CLEAR(clear_module_state->__pyx_codeobj__155);
  Py_CLEAR(clear_module_state->__pyx_codeobj__156);
  Py_CLEAR(clear_module_state->__pyx_codeobj__157);
  Py_CLEAR(clear_module_state->__pyx_codeobj__158);
  Py_CLEAR(clear_module_state->__pyx_codeobj__159);
  Py_CLEAR(clear_module_state->__pyx_codeobj__160);
  Py_CLEAR(clear_module_state->__pyx_codeobj__161);
  Py_CLEAR(clear_module_state->__pyx_codeobj__162);
  Py_CLEAR(clear_module_state->__pyx_codeobj__163);
  Py_CLEAR(clear_module_state->__pyx_codeobj__164);
  Py_CLEAR(clear_module_state->__pyx_codeobj__166);
  Py_CLEAR(clear_module_state->__pyx_codeobj__167);
  Py_CLEAR(clear_module_state->__pyx_codeobj__169);
  Py_CLEAR(clear_module_state->__pyx_codeobj__171);
  Py_CLEAR(clear_module_state->__pyx_codeobj__173);
  Py_CLEAR(clear_module_state->__pyx_codeobj__174);
  Py_CLEAR(clear_module_state->__pyx_codeobj__176);
  Py_CLEAR(clear_module_state->__pyx_codeobj__177);
  Py_CLEAR(clear_module_state->__pyx_codeobj__179);
  Py_CLEAR(clear_module_state->__pyx_codeobj__181);
  Py_CLEAR(clear_module_state->__pyx_codeobj__183);
  Py_CLEAR(clear_module_state->__pyx_codeobj__186);
  Py_CLEAR(clear_module_state->__pyx_codeobj__189);
  Py_CLEAR(clear_module_state->__pyx_codeobj__193);
  Py_CLEAR(clear_module_state->__pyx_codeobj__195);
  Py_CLEAR(clear_module_state->__pyx_codeobj__196);
  Py_CLEAR(clear_module_state->__pyx_codeobj__198);
  Py_CLEAR(clear_module_state->__pyx_codeobj__200);
  Py_CLEAR(clear_module_state->__pyx_codeobj__201);
  Py_CLEAR(clear_module_state->__pyx_codeobj__202);
  Py_CLEAR(clear_module_state->__pyx_codeobj__203);
  Py_CLEAR(clear_module_state->__pyx_codeobj__204);
  Py_CLEAR(clear_module_state->__pyx_codeobj__205);
  Py_CLEAR(clear_module_state->__pyx_codeobj__206);
  Py_CLEAR(clear_module_state->__pyx_codeobj__207);
  Py_CLEAR(clear_module_state->__pyx_codeobj__208);
  Py_CLEAR(clear_module_state->__pyx_codeobj__209);
  Py_CLEAR(clear_module_state->__pyx_codeobj__210);
  Py_CLEAR(clear_module_state->__pyx_codeobj__211);
  Py_CLEAR(clear_module_state->__pyx_codeobj__212);
  Py_CLEAR(clear_module_state->__pyx_codeobj__213);
  Py_CLEAR(clear_module_state->__pyx_codeobj__214);
  Py_CLEAR(clear_module_state->__pyx_codeobj__215);
  Py_CLEAR(clear_module_state->__pyx_codeobj__216);
  Py_CLEAR(clear_module_state->__pyx_codeobj__217);
  Py_CLEAR(clear_module_state->__pyx_codeobj__218);
  Py_CLEAR(clear_module_state->__pyx_codeobj__219);
  Py_CLEAR(clear_module_state->__pyx_codeobj__220);
  Py_CLEAR(clear_module_state->__pyx_codeobj__221);
  Py_CLEAR(clear_module_state->__pyx_codeobj__222);
  Py_CLEAR(clear_module_state->__pyx_codeobj__223);
  Py_CLEAR(clear_module_state->__pyx_codeobj__224);
  Py_CLEAR(clear_module_state->__pyx_codeobj__225);
  Py_CLEAR(clear_module_state->__pyx_codeobj__226);
  Py_CLEAR(clear_module_state->__pyx_codeobj__227);
  Py_CLEAR(clear_module_state->__pyx_codeobj__228);
  Py_CLEAR(clear_module_state->__pyx_codeobj__229);
  Py_CLEAR(clear_module_state->__pyx_codeobj__230);
  Py_CLEAR(clear_module_state->__pyx_codeobj__231);
  Py_CLEAR(clear_module_state->__pyx_codeobj__232);
  Py_CLEAR(clear_module_state->__pyx_codeobj__233);
  Py_CLEAR(clear_module_state->__pyx_codeobj__234);
  Py_CLEAR(clear_module_state->__pyx_codeobj__235);
  Py_CLEAR(clear_module_state->__pyx_codeobj__236);
  Py_CLEAR(clear_module_state->__pyx_codeobj__237);
  Py_CLEAR(clear_module_state->__pyx_codeobj__238);
  Py_CLEAR(clear_module_state->__pyx_codeobj__239);
  Py_CLEAR(clear_module_state->__pyx_codeobj__240);
  Py_CLEAR(clear_module_state->__pyx_codeobj__241);
  Py_CLEAR(clear_module_state->__pyx_codeobj__243);
  Py_CLEAR(clear_module_state->__pyx_codeobj__244);
  Py_CLEAR(clear_module_state->__pyx_codeobj__245);
  Py_CLEAR(clear_module_state->__pyx_codeobj__246);
  Py_CLEAR(clear_module_state->__pyx_codeobj__247);
  Py_CLEAR(clear_module_state->__pyx_codeobj__248);
  Py_CLEAR(clear_module_state->__pyx_codeobj__249);
  Py_CLEAR(clear_module_state->__pyx_codeobj__251);
  Py_CLEAR(clear_module_state->__pyx_codeobj__252);
  Py_CLEAR(clear_module_state->__pyx_codeobj__253);
  Py_CLEAR(clear_module_state->__pyx_codeobj__254);
  Py_CLEAR(clear_module_state->__pyx_codeobj__255);
  Py_CLEAR(clear_module_state->__pyx_codeobj__256);
  Py_CLEAR(clear_module_state->__pyx_codeobj__257);
  Py_CLEAR(clear_module_state->__pyx_codeobj__258);
  Py_CLEAR(clear_module_state->__pyx_codeobj__259);
  Py_CLEAR(clear_module_state->__pyx_codeobj__260);
  Py_CLEAR(clear_module_state->__pyx_codeobj__261);
  Py_CLEAR(clear_module_state->__pyx_codeobj__262);
  Py_CLEAR(clear_module_state->__pyx_codeobj__263);
  Py_CLEAR(clear_module_state->__pyx_codeobj__264);
  Py_CLEAR(clear_module_state->__pyx_codeobj__265);
  Py_CLEAR(clear_module_state->__pyx_codeobj__266);
  Py_CLEAR(clear_module_state->__pyx_codeobj__267);
  Py_CLEAR(clear_module_state->__pyx_codeobj__268);
  Py_CLEAR(clear_module_state->__pyx_codeobj__269);
  Py_CLEAR(clear_module_state->__pyx_codeobj__270);
  Py_CLEAR(clear_module_state->__pyx_codeobj__271);
  Py_CLEAR(clear_module_state->__pyx_codeobj__272);
  Py_CLEAR(clear_module_state->__pyx_codeobj__273);
  Py_CLEAR(clear_module_state->__pyx_codeobj__274);
  Py_CLEAR(clear_module_state->__pyx_codeobj__275);
  Py_CLEAR(clear_module_state->__pyx_codeobj__276);
  Py_CLEAR(clear_module_state->__pyx_codeobj__277);
  Py_CLEAR(clear_module_state->__pyx_codeobj__278);
  Py_CLEAR(clear_module_state->__pyx_codeobj__279);
  Py_CLEAR(clear_module_state->__pyx_codeobj__280);
  Py_CLEAR(clear_module_state->__pyx_codeobj__281);
  Py_CLEAR(clear_module_state->__pyx_codeobj__282);
  Py_CLEAR(clear_module_state->__pyx_codeobj__283);
  Py_CLEAR(clear_module_state->__pyx_codeobj__284);
  Py_CLEAR(clear_module_state->__pyx_codeobj__285);
  Py_CLEAR(clear_module_state->__pyx_codeobj__286);
  Py_CLEAR(clear_module_state->__pyx_codeobj__287);
  Py_CLEAR(clear_module_state->__pyx_codeobj__288);
  Py_CLEAR(clear_module_state->__pyx_codeobj__289);
  Py_CLEAR(clear_module_state->__pyx_codeobj__290);
  Py_CLEAR(clear_module_state->__pyx_codeobj__291);
  Py_CLEAR(clear_module_state->__pyx_codeobj__292);
  Py_CLEAR(clear_module_state->__pyx_codeobj__293);
  Py_CLEAR(clear_module_state->__pyx_codeobj__294);
  Py_CLEAR(clear_module_state->__pyx_codeobj__295);
  Py_CLEAR(clear_module_state->__pyx_codeobj__296);
  Py_CLEAR(clear_module_state->__pyx_codeobj__297);
  Py_CLEAR(clear_module_state->__pyx_codeobj__298);
  Py_CLEAR(clear_module_state->__pyx_codeobj__299);
  Py_CLEAR(clear_module_state->__pyx_codeobj__300);
  Py_CLEAR(clear_module_state->__pyx_codeobj__301);
  Py_CLEAR(clear_module_state->__pyx_codeobj__302);
  Py_CLEAR(clear_module_state->__pyx_codeobj__303);
  Py_CLEAR(clear_module_state->__pyx_codeobj__304);
  Py_CLEAR(clear_module_state->__pyx_codeobj__305);
  Py_CLEAR(clear_module_state->__pyx_codeobj__306);
  Py_CLEAR(clear_module_state->__pyx_codeobj__307);
  Py_CLEAR(clear_module_state->__pyx_codeobj__308);
  Py_CLEAR(clear_module_state->__pyx_codeobj__309);
  Py_CLEAR(clear_module_state->__pyx_codeobj__310);
  Py_CLEAR(clear_module_state->__pyx_codeobj__311);
  Py_CLEAR(clear_module_state->__pyx_codeobj__312);
  Py_CLEAR(clear_module_state->__pyx_codeobj__313);
  Py_CLEAR(clear_module_state->__pyx_codeobj__314);
  Py_CLEAR(clear_module_state->__pyx_codeobj__315);
  Py_CLEAR(clear_module_state->__pyx_codeobj__316);
  Py_CLEAR(clear_module_state->__pyx_codeobj__317);
  Py_CLEAR(clear_module_state->__pyx_codeobj__318);
  Py_CLEAR(clear_module_state->__pyx_codeobj__319);
  Py_CLEAR(clear_module_state->__pyx_codeobj__320);
  Py_CLEAR(clear_module_state->__pyx_codeobj__321);
  Py_CLEAR(clear_module_state->__pyx_codeobj__322);
  Py_CLEAR(clear_module_state->__pyx_codeobj__323);
  Py_CLEAR(clear_module_state->__pyx_codeobj__324);
  Py_CLEAR(clear_module_state->__pyx_codeobj__325);
  Py_CLEAR(clear_module_state->__pyx_codeobj__326);
  Py_CLEAR(clear_module_state->__pyx_codeobj__327);
  Py_CLEAR(clear_module_state->__pyx_codeobj__328);
  Py_CLEAR(clear_module_state->__pyx_codeobj__329);
  Py_CLEAR(clear_module_state->__pyx_codeobj__330);
  Py_CLEAR(clear_module_state->__pyx_codeobj__331);
  Py_CLEAR(clear_module_state->__pyx_codeobj__332);
  Py_CLEAR(clear_module_state->__pyx_codeobj__333);
  Py_CLEAR(clear_module_state->__pyx_codeobj__334);
  Py_CLEAR(clear_module_state->__pyx_codeobj__335);
  Py_CLEAR(clear_module_state->__pyx_codeobj__336);
  Py_CLEAR(clear_module_state->__pyx_codeobj__337);
  Py_CLEAR(clear_module_state->__pyx_codeobj__338);
  Py_CLEAR(clear_module_state->__pyx_codeobj__339);
  Py_CLEAR(clear_module_state->__pyx_codeobj__340);
  Py_CLEAR(clear_module_state->__pyx_codeobj__341);
  Py_CLEAR(clear_module_state->__pyx_codeobj__342);
  Py_CLEAR(clear_module_state->__pyx_codeobj__343);
  Py_CLEAR(clear_module_state->__pyx_codeobj__344);
  Py_CLEAR(clear_module_state->__pyx_codeobj__345);
  Py_CLEAR(clear_module_state->__pyx_codeobj__346);
  Py_CLEAR(clear_module_state->__pyx_codeobj__347);
  Py_CLEAR(clear_module_state->__pyx_codeobj__348);
  Py_CLEAR(clear_module_state->__pyx_codeobj__349);
  Py_CLEAR(clear_module_state->__pyx_codeobj__350);
  Py_CLEAR(clear_module_state->__pyx_codeobj__351);
  Py_CLEAR(clear_module_state->__pyx_codeobj__352);
  Py_CLEAR(clear_module_state->__pyx_codeobj__353);
  Py_CLEAR(clear_module_state->__pyx_codeobj__354);
  Py_CLEAR(clear_module_state->__pyx_codeobj__355);
  Py_CLEAR(clear_module_state->__pyx_codeobj__356);
  Py_CLEAR(clear_module_state->__pyx_codeobj__357);
  Py_CLEAR(clear_module_state->__pyx_codeobj__358);
  Py_CLEAR(clear_module_state->__pyx_codeobj__359);
  Py_CLEAR(clear_module_state->__pyx_codeobj__360);
  Py_CLEAR(clear_module_state->__pyx_codeobj__361);
  Py_CLEAR(clear_module_state->__pyx_codeobj__362);
  Py_CLEAR(clear_module_state->__pyx_codeobj__363);
  Py_CLEAR(clear_module_state->__pyx_codeobj__364);
  Py_CLEAR(clear_module_state->__pyx_codeobj__365);
  Py_CLEAR(clear_module_state->__pyx_codeobj__366);
  Py_CLEAR(clear_module_state->__pyx_codeobj__367);
  Py_CLEAR(clear_module_state->__pyx_codeobj__368);
  Py_CLEAR(clear_module_state->__pyx_codeobj__369);
  Py_CLEAR(clear_module_state->__pyx_codeobj__370);
  Py_CLEAR(clear_module_state->__pyx_codeobj__371);
  Py_CLEAR(clear_module_state->__pyx_codeobj__372);
  Py_CLEAR(clear_module_state->__pyx_codeobj__373);
  Py_CLEAR(clear_module_state->__pyx_codeobj__374);
  Py_CLEAR(clear_module_state->__pyx_codeobj__375);
  Py_CLEAR(clear_module_state->__pyx_codeobj__376);
  Py_CLEAR(clear_module_state->__pyx_codeobj__377);
  Py_CLEAR(clear_module_state->__pyx_codeobj__378);
  Py_CLEAR(clear_module_state->__pyx_codeobj__379);
  Py_CLEAR(clear_module_state->__pyx_codeobj__380);
  Py_CLEAR(clear_module_state->__pyx_codeobj__381);
  Py_CLEAR(clear_module_state->__pyx_codeobj__382);
  Py_CLEAR(clear_module_state->__pyx_codeobj__383);
  Py_CLEAR(clear_module_state->__pyx_codeobj__384);
  Py_CLEAR(clear_module_state->__pyx_codeobj__385);
  Py_CLEAR(clear_module_state->__pyx_codeobj__386);
  Py_CLEAR(clear_module_state->__pyx_codeobj__387);
  Py_CLEAR(clear_module_state->__pyx_codeobj__388);
  Py_CLEAR(clear_module_state->__pyx_codeobj__389);
  Py_CLEAR(clear_module_state->__pyx_codeobj__390);
  Py_CLEAR(clear_module_state->__pyx_codeobj__391);
  Py_CLEAR(clear_module_state->__pyx_codeobj__392);
  Py_CLEAR(clear_module_state->__pyx_codeobj__393);
  Py_CLEAR(clear_module_state->__pyx_codeobj__394);
  Py_CLEAR(clear_module_state->__pyx_codeobj__395);
  Py_CLEAR(clear_module_state->__pyx_codeobj__396);
  Py_CLEAR(clear_module_state->__pyx_codeobj__398);
  Py_CLEAR(clear_module_state->__pyx_codeobj__400);
  Py_CLEAR(clear_module_state->__pyx_codeobj__403);
  Py_CLEAR(clear_module_state->__pyx_codeobj__405);
  Py_CLEAR(clear_module_state->__pyx_codeobj__408);
  Py_CLEAR(clear_module_state->__pyx_codeobj__409);
  Py_CLEAR(clear_module_state->__pyx_codeobj__411);
  Py_CLEAR(clear_module_state->__pyx_codeobj__413);
  Py_CLEAR(clear_module_state->__pyx_codeobj__414);
  Py_CLEAR(clear_module_state->__pyx_codeobj__415);
  Py_CLEAR(clear_module_state->__pyx_codeobj__416);
  Py_CLEAR(clear_module_state->__pyx_codeobj__417);
  Py_CLEAR(clear_module_state->__pyx_codeobj__418);
  Py_CLEAR(clear_module_state->__pyx_codeobj__420);
  Py_CLEAR(clear_module_state->__pyx_codeobj__422);
  Py_CLEAR(clear_module_state->__pyx_codeobj__424);
  Py_CLEAR(clear_module_state->__pyx_codeobj__425);
  Py_CLEAR(clear_module_state->__pyx_codeobj__426);
  Py_CLEAR(clear_module_state->__pyx_codeobj__427);
  Py_CLEAR(clear_module_state->__pyx_codeobj__428);
  Py_CLEAR(clear_module_state->__pyx_codeobj__429);
  Py_CLEAR(clear_module_state->__pyx_codeobj__431);
  Py_CLEAR(clear_module_state->__pyx_codeobj__432);
  Py_CLEAR(clear_module_state->__pyx_codeobj__433);
  Py_CLEAR(clear_module_state->__pyx_codeobj__434);
  Py_CLEAR(clear_module_state->__pyx_codeobj__435);
  Py_CLEAR(clear_module_state->__pyx_codeobj__436);
  Py_CLEAR(clear_module_state->__pyx_codeobj__437);
  Py_CLEAR(clear_module_state->__pyx_codeobj__438);
  Py_CLEAR(clear_module_state->__pyx_codeobj__439);
  Py_CLEAR(clear_module_state->__pyx_codeobj__440);
  Py_CLEAR(clear_module_state->__pyx_codeobj__441);
  Py_CLEAR(clear_module_state->__pyx_codeobj__442);
  Py_CLEAR(clear_module_state->__pyx_codeobj__443);
  Py_CLEAR(clear_module_state->__pyx_codeobj__444);
  Py_CLEAR(clear_module_state->__pyx_codeobj__447);
  Py_CLEAR(clear_module_state->__pyx_codeobj__448);
  Py_CLEAR(clear_module_state->__pyx_codeobj__449);
  Py_CLEAR(clear_module_state->__pyx_codeobj__450);
  Py_CLEAR(clear_module_state->__pyx_codeobj__451);
  Py_CLEAR(clear_module_state->__pyx_codeobj__452);
  Py_CLEAR(clear_module_state->__pyx_codeobj__453);
  Py_CLEAR(clear_module_state->__pyx_codeobj__454);
  Py_CLEAR(clear_module_state->__pyx_codeobj__455);
  Py_CLEAR(clear_module_state->__pyx_codeobj__456);
  Py_CLEAR(clear_module_state->__pyx_codeobj__457);
  Py_CLEAR(clear_module_state->__pyx_codeobj__458);
  Py_CLEAR(clear_module_state->__pyx_codeobj__459);
  Py_CLEAR(clear_module_state->__pyx_codeobj__460);
  Py_CLEAR(clear_module_state->__pyx_codeobj__462);
  Py_CLEAR(clear_module_state->__pyx_codeobj__463);
  Py_CLEAR(clear_module_state->__pyx_codeobj__464);
  Py_CLEAR(clear_module_state->__pyx_codeobj__465);
  Py_CLEAR(clear_module_state->__pyx_codeobj__466);
  Py_CLEAR(clear_module_state->__pyx_codeobj__467);
  Py_CLEAR(clear_module_state->__pyx_codeobj__468);
  Py_CLEAR(clear_module_state->__pyx_codeobj__469);
  Py_CLEAR(clear_module_state->__pyx_codeobj__470);
  Py_CLEAR(clear_module_state->__pyx_codeobj__471);
  Py_CLEAR(clear_module_state->__pyx_codeobj__472);
  Py_CLEAR(clear_module_state->__pyx_codeobj__473);
  Py_CLEAR(clear_module_state->__pyx_codeobj__474);
  Py_CLEAR(clear_module_state->__pyx_codeobj__475);
  Py_CLEAR(clear_module_state->__pyx_codeobj__477);
  Py_CLEAR(clear_module_state->__pyx_codeobj__479);
  Py_CLEAR(clear_module_state->__pyx_codeobj__480);
  Py_CLEAR(clear_module_state->__pyx_codeobj__481);
  Py_CLEAR(clear_module_state->__pyx_codeobj__483);
  Py_CLEAR(clear_module_state->__pyx_codeobj__484);
  Py_CLEAR(clear_module_state->__pyx_codeobj__485);
  Py_CLEAR(clear_module_state->__pyx_codeobj__486);
  Py_CLEAR(clear_module_state->__pyx_codeobj__487);
  Py_CLEAR(clear_module_state->__pyx_codeobj__488);
  Py_CLEAR(clear_module_state->__pyx_codeobj__489);
  return 0;
}
#endif
/* #### Code section: module_state_traverse ### */
#if CYTHON_USE_MODULE_STATE
static int __pyx_m_traverse(PyObject *m, visitproc visit, void *arg) {
  __pyx_mstate *traverse_module_state = __pyx_mstate(m);
  if (!traverse_module_state) return 0;
  Py_VISIT(traverse_module_state->__pyx_d);
  Py_VISIT(traverse_module_state->__pyx_b);
  Py_VISIT(traverse_module_state->__pyx_cython_runtime);
  Py_VISIT(traverse_module_state->__pyx_empty_tuple);
  Py_VISIT(traverse_module_state->__pyx_empty_bytes);
  Py_VISIT(traverse_module_state->__pyx_empty_unicode);
  #ifdef __Pyx_CyFunction_USED
  Py_VISIT(traverse_module_state->__pyx_CyFunctionType);
  #endif
  #ifdef __Pyx_FusedFunction_USED
  Py_VISIT(traverse_module_state->__pyx_FusedFunctionType);
  #endif
  Py_VISIT(traverse_module_state->__pyx_ptype_7cpython_4type_type);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_dtype);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_flatiter);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_broadcast);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_ndarray);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_generic);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_number);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_integer);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_signedinteger);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_unsignedinteger);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_inexact);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_floating);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_complexfloating);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_flexible);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_character);
  Py_VISIT(traverse_module_state->__pyx_ptype_5numpy_ufunc);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_7missing_C_NAType);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_HashTable);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_HashTable);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt64HashTable);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int64HashTable);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt32HashTable);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int32HashTable);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt16HashTable);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int16HashTable);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt8HashTable);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int8HashTable);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Float64HashTable);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Float32HashTable);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Complex64HashTable);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Complex128HashTable);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_PyObjectHashTable);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_StringHashTable);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Vector);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Vector);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int64Vector);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Complex128Vector);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Complex64Vector);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Float64Vector);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt64Vector);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Float32Vector);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt32Vector);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int32Vector);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt16Vector);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int16Vector);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt8Vector);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int8Vector);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_StringVector);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_StringVector);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_ObjectVector);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Factorizer);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int8Factorizer);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int8Factorizer);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Factorizer);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt8Factorizer);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int16Factorizer);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int16Factorizer);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Factorizer);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt16Factorizer);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int32Factorizer);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int32Factorizer);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Factorizer);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt32Factorizer);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Float32Factorizer);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Float32Factorizer);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Factorizer);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Complex64Factorizer);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Int64Factorizer);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Int64Factorizer);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Factorizer);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_UInt64Factorizer);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Float64Factorizer);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Float64Factorizer);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Factorizer);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_Complex128Factorizer);
  Py_VISIT(traverse_module_state->__pyx_ptype_6pandas_5_libs_9hashtable_ObjectFactorizer);
  Py_VISIT(traverse_module_state->__pyx_type_6pandas_5_libs_9hashtable_ObjectFactorizer);
  Py_VISIT(traverse_module_state->__pyx_array_type);
  Py_VISIT(traverse_module_state->__pyx_type___pyx_array);
  Py_VISIT(traverse_module_state->__pyx_MemviewEnum_type);
  Py_VISIT(traverse_module_state->__pyx_type___pyx_MemviewEnum);
  Py_VISIT(traverse_module_state->__pyx_memoryview_type);
  Py_VISIT(traverse_module_state->__pyx_type___pyx_memoryview);
  Py_VISIT(traverse_module_state->__pyx_memoryviewslice_type);
  Py_VISIT(traverse_module_state->__pyx_type___pyx_memoryviewslice);
  Py_VISIT(traverse_module_state->__pyx_kp_u_);
  Py_VISIT(traverse_module_state->__pyx_n_s_ASCII);
  Py_VISIT(traverse_module_state->__pyx_kp_s_All_dimensions_preceding_dimensi);
  Py_VISIT(traverse_module_state->__pyx_n_s_AssertionError);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Buffer_view_does_not_expose_stri);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Can_only_create_a_buffer_that_is);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Cannot_assign_to_read_only_memor);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Cannot_create_writable_memory_vi);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Cannot_index_with_type);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Cannot_transpose_memoryview_with);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex128Factorizer);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex128Factorizer___reduce_cy);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex128Factorizer___setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex128Factorizer_factorize);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Complex128Factorizer_factorize_l);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex128HashTable);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex128HashTable___reduce_cyt);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex128HashTable___setstate_c);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex128HashTable__unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex128HashTable_factorize);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex128HashTable_get_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex128HashTable_get_labels);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex128HashTable_get_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex128HashTable_get_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex128HashTable_lookup);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex128HashTable_map_location);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex128HashTable_set_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex128HashTable_set_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex128HashTable_sizeof);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex128HashTable_unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex128Vector);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex128Vector___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex128Vector___setstate_cyth);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex128Vector_to_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex64Factorizer);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex64Factorizer___reduce_cyt);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex64Factorizer___setstate_c);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex64Factorizer_factorize);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Complex64Factorizer_factorize_li);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex64HashTable);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex64HashTable___reduce_cyth);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex64HashTable___setstate_cy);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex64HashTable__unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex64HashTable_factorize);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex64HashTable_get_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex64HashTable_get_labels);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex64HashTable_get_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex64HashTable_get_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex64HashTable_lookup);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex64HashTable_map_locations);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex64HashTable_set_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex64HashTable_set_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex64HashTable_sizeof);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex64HashTable_unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex64Vector);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex64Vector___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex64Vector___setstate_cytho);
  Py_VISIT(traverse_module_state->__pyx_n_s_Complex64Vector_to_array);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Dimension_d_is_not_direct);
  Py_VISIT(traverse_module_state->__pyx_n_s_Ellipsis);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Empty_shape_tuple_for_cython_arr);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Expected_at_least_d_argument_s_g);
  Py_VISIT(traverse_module_state->__pyx_n_s_Factorizer);
  Py_VISIT(traverse_module_state->__pyx_n_s_Factorizer___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Factorizer___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Factorizer_factorize);
  Py_VISIT(traverse_module_state->__pyx_n_s_Factorizer_get_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float32Factorizer);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float32Factorizer___reduce_cytho);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float32Factorizer___setstate_cyt);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float32Factorizer_factorize);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Float32Factorizer_factorize_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float32HashTable);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float32HashTable___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float32HashTable___setstate_cyth);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float32HashTable__unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float32HashTable_factorize);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float32HashTable_get_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float32HashTable_get_labels);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float32HashTable_get_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float32HashTable_get_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float32HashTable_lookup);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float32HashTable_map_locations);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float32HashTable_set_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float32HashTable_set_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float32HashTable_sizeof);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float32HashTable_unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float32Vector);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float32Vector___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float32Vector___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float32Vector_to_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float64Factorizer);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float64Factorizer___reduce_cytho);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float64Factorizer___setstate_cyt);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float64Factorizer_factorize);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Float64Factorizer_factorize_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float64HashTable);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float64HashTable___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float64HashTable___setstate_cyth);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float64HashTable__unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float64HashTable_factorize);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float64HashTable_get_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float64HashTable_get_labels);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float64HashTable_get_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float64HashTable_get_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float64HashTable_lookup);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float64HashTable_map_locations);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float64HashTable_set_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float64HashTable_set_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float64HashTable_sizeof);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float64HashTable_unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float64Vector);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float64Vector___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float64Vector___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Float64Vector_to_array);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Function_call_with_ambiguous_arg);
  Py_VISIT(traverse_module_state->__pyx_n_s_HashTable);
  Py_VISIT(traverse_module_state->__pyx_n_s_HashTable___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_HashTable___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_ImportError);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_IndexError);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Index_out_of_bounds_axis_d);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Indirect_dimensions_not_supporte);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int16Factorizer);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int16Factorizer___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int16Factorizer___setstate_cytho);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int16Factorizer_factorize);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Int16Factorizer_factorize_line_5);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int16HashTable);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int16HashTable___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int16HashTable___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int16HashTable__unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int16HashTable_factorize);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int16HashTable_get_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int16HashTable_get_labels);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int16HashTable_get_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int16HashTable_get_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int16HashTable_lookup);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int16HashTable_map_locations);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int16HashTable_set_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int16HashTable_set_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int16HashTable_sizeof);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int16HashTable_unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int16Vector);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int16Vector___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int16Vector___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int16Vector_to_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int32Factorizer);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int32Factorizer___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int32Factorizer___setstate_cytho);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int32Factorizer_factorize);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Int32Factorizer_factorize_line_4);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int32HashTable);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int32HashTable___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int32HashTable___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int32HashTable__unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int32HashTable_factorize);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int32HashTable_get_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int32HashTable_get_labels);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int32HashTable_get_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int32HashTable_get_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int32HashTable_lookup);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int32HashTable_map_locations);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int32HashTable_set_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int32HashTable_set_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int32HashTable_sizeof);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int32HashTable_unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int32Vector);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int32Vector___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int32Vector___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int32Vector_to_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64Factorizer);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64Factorizer___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64Factorizer___setstate_cytho);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64Factorizer_factorize);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Int64Factorizer_factorize_line_3);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64HashTable);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64HashTable___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64HashTable___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64HashTable__unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64HashTable_factorize);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64HashTable_get_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64HashTable_get_labels);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64HashTable_get_labels_groupb);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64HashTable_get_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64HashTable_get_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64HashTable_lookup);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64HashTable_map_keys_to_value);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64HashTable_map_locations);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64HashTable_set_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64HashTable_set_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64HashTable_sizeof);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64HashTable_unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64Vector);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64Vector___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64Vector___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int64Vector_to_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int8Factorizer);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int8Factorizer___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int8Factorizer___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int8Factorizer_factorize);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Int8Factorizer_factorize_line_66);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int8HashTable);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int8HashTable___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int8HashTable___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int8HashTable__unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int8HashTable_factorize);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int8HashTable_get_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int8HashTable_get_labels);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int8HashTable_get_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int8HashTable_get_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int8HashTable_lookup);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int8HashTable_map_locations);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int8HashTable_set_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int8HashTable_set_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int8HashTable_sizeof);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int8HashTable_unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int8Vector);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int8Vector___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int8Vector___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Int8Vector_to_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_IntpHashTable);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Invalid_mode_expected_c_or_fortr);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Invalid_shape_in_axis);
  Py_VISIT(traverse_module_state->__pyx_n_s_KeyError);
  Py_VISIT(traverse_module_state->__pyx_n_s_MemoryError);
  Py_VISIT(traverse_module_state->__pyx_kp_s_MemoryView_of_r_at_0x_x);
  Py_VISIT(traverse_module_state->__pyx_kp_s_MemoryView_of_r_object);
  Py_VISIT(traverse_module_state->__pyx_n_u_NA);
  Py_VISIT(traverse_module_state->__pyx_kp_s_No_matching_signature_found);
  Py_VISIT(traverse_module_state->__pyx_n_s_None);
  Py_VISIT(traverse_module_state->__pyx_n_s_NotImplementedError);
  Py_VISIT(traverse_module_state->__pyx_n_b_O);
  Py_VISIT(traverse_module_state->__pyx_n_s_ObjectFactorizer);
  Py_VISIT(traverse_module_state->__pyx_n_s_ObjectFactorizer___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_ObjectFactorizer___setstate_cyth);
  Py_VISIT(traverse_module_state->__pyx_n_s_ObjectFactorizer_factorize);
  Py_VISIT(traverse_module_state->__pyx_kp_u_ObjectFactorizer_factorize_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_ObjectVector);
  Py_VISIT(traverse_module_state->__pyx_n_s_ObjectVector___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_ObjectVector___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_ObjectVector_to_array);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Out_of_bounds_on_buffer_access_a);
  Py_VISIT(traverse_module_state->__pyx_n_s_PickleError);
  Py_VISIT(traverse_module_state->__pyx_n_s_PyObjectHashTable);
  Py_VISIT(traverse_module_state->__pyx_n_s_PyObjectHashTable___reduce_cytho);
  Py_VISIT(traverse_module_state->__pyx_n_s_PyObjectHashTable___setstate_cyt);
  Py_VISIT(traverse_module_state->__pyx_n_s_PyObjectHashTable__unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_PyObjectHashTable_factorize);
  Py_VISIT(traverse_module_state->__pyx_n_s_PyObjectHashTable_get_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_PyObjectHashTable_get_labels);
  Py_VISIT(traverse_module_state->__pyx_n_s_PyObjectHashTable_get_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_PyObjectHashTable_lookup);
  Py_VISIT(traverse_module_state->__pyx_n_s_PyObjectHashTable_map_locations);
  Py_VISIT(traverse_module_state->__pyx_n_s_PyObjectHashTable_set_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_PyObjectHashTable_sizeof);
  Py_VISIT(traverse_module_state->__pyx_n_s_PyObjectHashTable_unique);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples_10);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples_11);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples_12);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples_2);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples_3);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples_4);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples_5);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples_6);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples_7);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples_8);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Returns_ndarray_intp_t_Examples_9);
  Py_VISIT(traverse_module_state->__pyx_kp_u_Returns_np_ndarray_np_intp_Exam);
  Py_VISIT(traverse_module_state->__pyx_n_s_SIZE_HINT_LIMIT);
  Py_VISIT(traverse_module_state->__pyx_n_s_Sequence);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Step_may_not_be_zero_axis_d);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringHashTable);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringHashTable___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringHashTable___setstate_cytho);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringHashTable__unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringHashTable_factorize);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringHashTable_get_indexer);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringHashTable_get_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringHashTable_get_labels);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringHashTable_get_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringHashTable_lookup);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringHashTable_map_locations);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringHashTable_set_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringHashTable_sizeof);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringHashTable_unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringVector);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringVector___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringVector___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_StringVector_to_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_TypeError);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt16Factorizer);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt16Factorizer___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt16Factorizer___setstate_cyth);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt16Factorizer_factorize);
  Py_VISIT(traverse_module_state->__pyx_kp_u_UInt16Factorizer_factorize_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt16HashTable);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt16HashTable___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt16HashTable___setstate_cytho);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt16HashTable__unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt16HashTable_factorize);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt16HashTable_get_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt16HashTable_get_labels);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt16HashTable_get_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt16HashTable_get_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt16HashTable_lookup);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt16HashTable_map_locations);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt16HashTable_set_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt16HashTable_set_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt16HashTable_sizeof);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt16HashTable_unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt16Vector);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt16Vector___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt16Vector___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt16Vector_to_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt32Factorizer);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt32Factorizer___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt32Factorizer___setstate_cyth);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt32Factorizer_factorize);
  Py_VISIT(traverse_module_state->__pyx_kp_u_UInt32Factorizer_factorize_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt32HashTable);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt32HashTable___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt32HashTable___setstate_cytho);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt32HashTable__unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt32HashTable_factorize);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt32HashTable_get_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt32HashTable_get_labels);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt32HashTable_get_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt32HashTable_get_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt32HashTable_lookup);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt32HashTable_map_locations);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt32HashTable_set_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt32HashTable_set_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt32HashTable_sizeof);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt32HashTable_unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt32Vector);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt32Vector___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt32Vector___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt32Vector_to_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt64Factorizer);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt64Factorizer___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt64Factorizer___setstate_cyth);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt64Factorizer_factorize);
  Py_VISIT(traverse_module_state->__pyx_kp_u_UInt64Factorizer_factorize_line);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt64HashTable);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt64HashTable___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt64HashTable___setstate_cytho);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt64HashTable__unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt64HashTable_factorize);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt64HashTable_get_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt64HashTable_get_labels);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt64HashTable_get_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt64HashTable_get_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt64HashTable_lookup);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt64HashTable_map_locations);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt64HashTable_set_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt64HashTable_set_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt64HashTable_sizeof);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt64HashTable_unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt64Vector);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt64Vector___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt64Vector___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt64Vector_to_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt8Factorizer);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt8Factorizer___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt8Factorizer___setstate_cytho);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt8Factorizer_factorize);
  Py_VISIT(traverse_module_state->__pyx_kp_u_UInt8Factorizer_factorize_line_6);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt8HashTable);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt8HashTable___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt8HashTable___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt8HashTable__unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt8HashTable_factorize);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt8HashTable_get_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt8HashTable_get_labels);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt8HashTable_get_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt8HashTable_get_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt8HashTable_lookup);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt8HashTable_map_locations);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt8HashTable_set_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt8HashTable_set_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt8HashTable_sizeof);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt8HashTable_unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt8Vector);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt8Vector___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt8Vector___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_UInt8Vector_to_array);
  Py_VISIT(traverse_module_state->__pyx_kp_s_Unable_to_convert_item_to_object);
  Py_VISIT(traverse_module_state->__pyx_n_s_UnicodeEncodeError);
  Py_VISIT(traverse_module_state->__pyx_n_s_ValueError);
  Py_VISIT(traverse_module_state->__pyx_n_s_Vector);
  Py_VISIT(traverse_module_state->__pyx_n_s_Vector___reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_Vector___setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_View_MemoryView);
  Py_VISIT(traverse_module_state->__pyx_n_s__191);
  Py_VISIT(traverse_module_state->__pyx_kp_u__2);
  Py_VISIT(traverse_module_state->__pyx_n_s__3);
  Py_VISIT(traverse_module_state->__pyx_n_s__490);
  Py_VISIT(traverse_module_state->__pyx_kp_u__6);
  Py_VISIT(traverse_module_state->__pyx_kp_s__69);
  Py_VISIT(traverse_module_state->__pyx_kp_u__7);
  Py_VISIT(traverse_module_state->__pyx_kp_s__70);
  Py_VISIT(traverse_module_state->__pyx_kp_u__70);
  Py_VISIT(traverse_module_state->__pyx_kp_s__86);
  Py_VISIT(traverse_module_state->__pyx_n_s_a);
  Py_VISIT(traverse_module_state->__pyx_n_s_abc);
  Py_VISIT(traverse_module_state->__pyx_n_s_allocate_buffer);
  Py_VISIT(traverse_module_state->__pyx_kp_u_and);
  Py_VISIT(traverse_module_state->__pyx_n_s_args);
  Py_VISIT(traverse_module_state->__pyx_n_s_argsort);
  Py_VISIT(traverse_module_state->__pyx_n_s_arr);
  Py_VISIT(traverse_module_state->__pyx_n_s_arr_uniques);
  Py_VISIT(traverse_module_state->__pyx_n_s_asarray);
  Py_VISIT(traverse_module_state->__pyx_n_s_asyncio_coroutines);
  Py_VISIT(traverse_module_state->__pyx_n_s_b);
  Py_VISIT(traverse_module_state->__pyx_n_s_base);
  Py_VISIT(traverse_module_state->__pyx_n_s_bool);
  Py_VISIT(traverse_module_state->__pyx_n_u_bool);
  Py_VISIT(traverse_module_state->__pyx_n_s_bool_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_c);
  Py_VISIT(traverse_module_state->__pyx_n_u_c);
  Py_VISIT(traverse_module_state->__pyx_n_s_class);
  Py_VISIT(traverse_module_state->__pyx_n_s_class_getitem);
  Py_VISIT(traverse_module_state->__pyx_n_s_cline_in_traceback);
  Py_VISIT(traverse_module_state->__pyx_n_s_collections);
  Py_VISIT(traverse_module_state->__pyx_kp_s_collections_abc);
  Py_VISIT(traverse_module_state->__pyx_n_s_complex128);
  Py_VISIT(traverse_module_state->__pyx_n_s_complex64);
  Py_VISIT(traverse_module_state->__pyx_kp_s_contiguous_and_direct);
  Py_VISIT(traverse_module_state->__pyx_kp_s_contiguous_and_indirect);
  Py_VISIT(traverse_module_state->__pyx_n_s_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_count_prior);
  Py_VISIT(traverse_module_state->__pyx_n_s_counts);
  Py_VISIT(traverse_module_state->__pyx_n_s_deep);
  Py_VISIT(traverse_module_state->__pyx_n_s_defaults);
  Py_VISIT(traverse_module_state->__pyx_n_s_dict);
  Py_VISIT(traverse_module_state->__pyx_n_s_dict_2);
  Py_VISIT(traverse_module_state->__pyx_kp_s_dict_str_int);
  Py_VISIT(traverse_module_state->__pyx_kp_u_disable);
  Py_VISIT(traverse_module_state->__pyx_kp_s_double_complex);
  Py_VISIT(traverse_module_state->__pyx_n_s_dropna);
  Py_VISIT(traverse_module_state->__pyx_n_s_dtype);
  Py_VISIT(traverse_module_state->__pyx_n_s_dtype_is_object);
  Py_VISIT(traverse_module_state->__pyx_n_s_duplicated);
  Py_VISIT(traverse_module_state->__pyx_n_s_empty);
  Py_VISIT(traverse_module_state->__pyx_kp_u_enable);
  Py_VISIT(traverse_module_state->__pyx_n_s_encode);
  Py_VISIT(traverse_module_state->__pyx_n_s_enumerate);
  Py_VISIT(traverse_module_state->__pyx_n_s_error);
  Py_VISIT(traverse_module_state->__pyx_kp_u_external_reference_but_Vector_re);
  Py_VISIT(traverse_module_state->__pyx_kp_u_external_reference_to_result_mas);
  Py_VISIT(traverse_module_state->__pyx_kp_u_external_reference_to_uniques_he);
  Py_VISIT(traverse_module_state->__pyx_n_s_factorize);
  Py_VISIT(traverse_module_state->__pyx_n_u_first);
  Py_VISIT(traverse_module_state->__pyx_n_s_flags);
  Py_VISIT(traverse_module_state->__pyx_n_s_float32);
  Py_VISIT(traverse_module_state->__pyx_n_s_float32_t);
  Py_VISIT(traverse_module_state->__pyx_n_s_float64);
  Py_VISIT(traverse_module_state->__pyx_n_s_float64_t);
  Py_VISIT(traverse_module_state->__pyx_kp_s_float_complex);
  Py_VISIT(traverse_module_state->__pyx_n_s_for_flags);
  Py_VISIT(traverse_module_state->__pyx_n_s_for_pairs);
  Py_VISIT(traverse_module_state->__pyx_n_s_format);
  Py_VISIT(traverse_module_state->__pyx_n_s_fortran);
  Py_VISIT(traverse_module_state->__pyx_n_u_fortran);
  Py_VISIT(traverse_module_state->__pyx_n_s_fused_sigindex);
  Py_VISIT(traverse_module_state->__pyx_kp_u_gc);
  Py_VISIT(traverse_module_state->__pyx_n_s_get);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_hashtable_trace_domain);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_indexer);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_labels);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_labels_groupby);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_get_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_getstate);
  Py_VISIT(traverse_module_state->__pyx_kp_u_got);
  Py_VISIT(traverse_module_state->__pyx_kp_u_got_differing_extents_in_dimensi);
  Py_VISIT(traverse_module_state->__pyx_n_s_i);
  Py_VISIT(traverse_module_state->__pyx_n_s_id);
  Py_VISIT(traverse_module_state->__pyx_n_s_idx);
  Py_VISIT(traverse_module_state->__pyx_n_s_ignore_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_imag);
  Py_VISIT(traverse_module_state->__pyx_n_s_import);
  Py_VISIT(traverse_module_state->__pyx_n_s_index);
  Py_VISIT(traverse_module_state->__pyx_n_s_initializing);
  Py_VISIT(traverse_module_state->__pyx_n_s_int);
  Py_VISIT(traverse_module_state->__pyx_n_s_int16);
  Py_VISIT(traverse_module_state->__pyx_n_s_int16_t);
  Py_VISIT(traverse_module_state->__pyx_n_s_int32);
  Py_VISIT(traverse_module_state->__pyx_n_s_int32_t);
  Py_VISIT(traverse_module_state->__pyx_n_s_int64);
  Py_VISIT(traverse_module_state->__pyx_n_s_int64_t);
  Py_VISIT(traverse_module_state->__pyx_n_s_int8);
  Py_VISIT(traverse_module_state->__pyx_n_s_int8_t);
  Py_VISIT(traverse_module_state->__pyx_n_s_intp);
  Py_VISIT(traverse_module_state->__pyx_n_s_is_coroutine);
  Py_VISIT(traverse_module_state->__pyx_kp_u_isenabled);
  Py_VISIT(traverse_module_state->__pyx_n_s_ismember);
  Py_VISIT(traverse_module_state->__pyx_n_s_itemsize);
  Py_VISIT(traverse_module_state->__pyx_kp_s_itemsize_0_for_cython_array);
  Py_VISIT(traverse_module_state->__pyx_n_s_j);
  Py_VISIT(traverse_module_state->__pyx_n_s_k);
  Py_VISIT(traverse_module_state->__pyx_n_s_keep);
  Py_VISIT(traverse_module_state->__pyx_kp_u_keep_must_be_either_first_last_o);
  Py_VISIT(traverse_module_state->__pyx_n_s_key);
  Py_VISIT(traverse_module_state->__pyx_n_s_keys);
  Py_VISIT(traverse_module_state->__pyx_n_s_kind);
  Py_VISIT(traverse_module_state->__pyx_n_s_kwargs);
  Py_VISIT(traverse_module_state->__pyx_n_s_labels);
  Py_VISIT(traverse_module_state->__pyx_n_u_last);
  Py_VISIT(traverse_module_state->__pyx_n_s_locs);
  Py_VISIT(traverse_module_state->__pyx_n_s_lookup);
  Py_VISIT(traverse_module_state->__pyx_n_s_main);
  Py_VISIT(traverse_module_state->__pyx_n_s_map_keys_to_values);
  Py_VISIT(traverse_module_state->__pyx_n_s_map_locations);
  Py_VISIT(traverse_module_state->__pyx_n_s_mask);
  Py_VISIT(traverse_module_state->__pyx_kp_u_mask_not_supported_for_ObjectFac);
  Py_VISIT(traverse_module_state->__pyx_n_s_mask_values);
  Py_VISIT(traverse_module_state->__pyx_n_s_max_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_memview);
  Py_VISIT(traverse_module_state->__pyx_n_s_mode);
  Py_VISIT(traverse_module_state->__pyx_n_s_modes);
  Py_VISIT(traverse_module_state->__pyx_n_s_n);
  Py_VISIT(traverse_module_state->__pyx_n_u_n_buckets);
  Py_VISIT(traverse_module_state->__pyx_n_u_n_occupied);
  Py_VISIT(traverse_module_state->__pyx_n_s_na_position);
  Py_VISIT(traverse_module_state->__pyx_n_s_na_sentinel);
  Py_VISIT(traverse_module_state->__pyx_n_s_na_string_sentinel);
  Py_VISIT(traverse_module_state->__pyx_n_s_na_value);
  Py_VISIT(traverse_module_state->__pyx_n_s_na_value2);
  Py_VISIT(traverse_module_state->__pyx_n_s_name);
  Py_VISIT(traverse_module_state->__pyx_n_s_name_2);
  Py_VISIT(traverse_module_state->__pyx_n_u_nan);
  Py_VISIT(traverse_module_state->__pyx_n_s_ndarray);
  Py_VISIT(traverse_module_state->__pyx_n_s_ndim);
  Py_VISIT(traverse_module_state->__pyx_n_s_new);
  Py_VISIT(traverse_module_state->__pyx_n_s_nkeys);
  Py_VISIT(traverse_module_state->__pyx_kp_s_no_default___reduce___due_to_non);
  Py_VISIT(traverse_module_state->__pyx_n_s_np);
  Py_VISIT(traverse_module_state->__pyx_kp_s_np_ndarray);
  Py_VISIT(traverse_module_state->__pyx_n_s_numpy);
  Py_VISIT(traverse_module_state->__pyx_kp_u_numpy_core_multiarray_failed_to);
  Py_VISIT(traverse_module_state->__pyx_kp_u_numpy_core_umath_failed_to_impor);
  Py_VISIT(traverse_module_state->__pyx_n_s_obj);
  Py_VISIT(traverse_module_state->__pyx_n_s_object);
  Py_VISIT(traverse_module_state->__pyx_n_s_object_hash);
  Py_VISIT(traverse_module_state->__pyx_n_s_objects_are_equal);
  Py_VISIT(traverse_module_state->__pyx_n_s_overhead);
  Py_VISIT(traverse_module_state->__pyx_n_s_pack);
  Py_VISIT(traverse_module_state->__pyx_n_s_pandas__libs_hashtable);
  Py_VISIT(traverse_module_state->__pyx_kp_s_pandas__libs_hashtable_class_hel);
  Py_VISIT(traverse_module_state->__pyx_kp_s_pandas__libs_hashtable_func_help);
  Py_VISIT(traverse_module_state->__pyx_kp_s_pandas__libs_hashtable_pyx);
  Py_VISIT(traverse_module_state->__pyx_n_s_pickle);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_PickleError);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_checksum);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_0duplicated);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_0ismember);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_0value_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_10duplicated);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_10ismember);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_10value_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_11duplicated);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_11ismember);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_11value_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_12duplicated);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_12ismember);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_12value_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_1duplicated);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_1ismember);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_1value_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_2duplicated);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_2ismember);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_2value_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_3duplicated);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_3ismember);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_3value_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_4duplicated);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_4ismember);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_4value_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_5duplicated);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_5ismember);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_5value_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_6duplicated);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_6ismember);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_6value_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_7duplicated);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_7ismember);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_7value_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_8duplicated);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_8ismember);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_8value_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_9duplicated);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_9ismember);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_fuse_9value_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_result);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_type);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_unpickle_Enum);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_unpickle_HashTable);
  Py_VISIT(traverse_module_state->__pyx_n_s_pyx_vtable);
  Py_VISIT(traverse_module_state->__pyx_n_s_range);
  Py_VISIT(traverse_module_state->__pyx_n_s_real);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_reduce_ex);
  Py_VISIT(traverse_module_state->__pyx_n_s_refcheck);
  Py_VISIT(traverse_module_state->__pyx_n_s_register);
  Py_VISIT(traverse_module_state->__pyx_n_s_resbuf);
  Py_VISIT(traverse_module_state->__pyx_n_s_resize);
  Py_VISIT(traverse_module_state->__pyx_n_s_result_mask);
  Py_VISIT(traverse_module_state->__pyx_n_s_ret);
  Py_VISIT(traverse_module_state->__pyx_n_s_return);
  Py_VISIT(traverse_module_state->__pyx_n_s_return_inverse);
  Py_VISIT(traverse_module_state->__pyx_n_s_rmd);
  Py_VISIT(traverse_module_state->__pyx_n_s_s);
  Py_VISIT(traverse_module_state->__pyx_n_s_seen_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_self);
  Py_VISIT(traverse_module_state->__pyx_kp_s_self_table_cannot_be_converted_t);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_item);
  Py_VISIT(traverse_module_state->__pyx_n_s_set_na);
  Py_VISIT(traverse_module_state->__pyx_n_s_setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_setstate_cython);
  Py_VISIT(traverse_module_state->__pyx_n_s_shape);
  Py_VISIT(traverse_module_state->__pyx_kp_u_should_have_raised_on_append);
  Py_VISIT(traverse_module_state->__pyx_n_s_signatures);
  Py_VISIT(traverse_module_state->__pyx_n_s_size);
  Py_VISIT(traverse_module_state->__pyx_n_u_size);
  Py_VISIT(traverse_module_state->__pyx_n_s_size_hint);
  Py_VISIT(traverse_module_state->__pyx_n_s_sizeof);
  Py_VISIT(traverse_module_state->__pyx_n_s_spec);
  Py_VISIT(traverse_module_state->__pyx_n_s_split);
  Py_VISIT(traverse_module_state->__pyx_n_s_start);
  Py_VISIT(traverse_module_state->__pyx_n_s_state);
  Py_VISIT(traverse_module_state->__pyx_n_s_step);
  Py_VISIT(traverse_module_state->__pyx_n_s_stop);
  Py_VISIT(traverse_module_state->__pyx_kp_s_strided_and_direct);
  Py_VISIT(traverse_module_state->__pyx_kp_s_strided_and_direct_or_indirect);
  Py_VISIT(traverse_module_state->__pyx_kp_s_strided_and_indirect);
  Py_VISIT(traverse_module_state->__pyx_kp_s_stringsource);
  Py_VISIT(traverse_module_state->__pyx_n_s_strip);
  Py_VISIT(traverse_module_state->__pyx_n_s_struct);
  Py_VISIT(traverse_module_state->__pyx_n_s_sys);
  Py_VISIT(traverse_module_state->__pyx_n_s_table);
  Py_VISIT(traverse_module_state->__pyx_n_s_test);
  Py_VISIT(traverse_module_state->__pyx_n_s_to_array);
  Py_VISIT(traverse_module_state->__pyx_kp_s_tuple_ndarray_ndarray);
  Py_VISIT(traverse_module_state->__pyx_n_s_ud);
  Py_VISIT(traverse_module_state->__pyx_n_s_uindexer);
  Py_VISIT(traverse_module_state->__pyx_n_s_uint16);
  Py_VISIT(traverse_module_state->__pyx_n_s_uint16_t);
  Py_VISIT(traverse_module_state->__pyx_n_s_uint32);
  Py_VISIT(traverse_module_state->__pyx_n_s_uint32_t);
  Py_VISIT(traverse_module_state->__pyx_n_s_uint64);
  Py_VISIT(traverse_module_state->__pyx_n_s_uint64_t);
  Py_VISIT(traverse_module_state->__pyx_n_s_uint8);
  Py_VISIT(traverse_module_state->__pyx_n_u_uint8);
  Py_VISIT(traverse_module_state->__pyx_n_s_uint8_t);
  Py_VISIT(traverse_module_state->__pyx_kp_s_unable_to_allocate_array_data);
  Py_VISIT(traverse_module_state->__pyx_kp_s_unable_to_allocate_shape_and_str);
  Py_VISIT(traverse_module_state->__pyx_n_s_unique);
  Py_VISIT(traverse_module_state->__pyx_n_s_unique_2);
  Py_VISIT(traverse_module_state->__pyx_n_s_unique_label_indices);
  Py_VISIT(traverse_module_state->__pyx_n_s_unique_label_indices_int32);
  Py_VISIT(traverse_module_state->__pyx_n_s_unique_label_indices_int64);
  Py_VISIT(traverse_module_state->__pyx_n_s_uniques);
  Py_VISIT(traverse_module_state->__pyx_n_s_uniques_vector);
  Py_VISIT(traverse_module_state->__pyx_n_s_unpack);
  Py_VISIT(traverse_module_state->__pyx_n_s_update);
  Py_VISIT(traverse_module_state->__pyx_n_u_upper_bound);
  Py_VISIT(traverse_module_state->__pyx_n_s_use_mask);
  Py_VISIT(traverse_module_state->__pyx_n_s_use_na_value);
  Py_VISIT(traverse_module_state->__pyx_n_s_use_result_mask);
  Py_VISIT(traverse_module_state->__pyx_n_s_use_setstate);
  Py_VISIT(traverse_module_state->__pyx_n_s_uses_mask);
  Py_VISIT(traverse_module_state->__pyx_kp_u_uses_mask_not_implemented_with_d);
  Py_VISIT(traverse_module_state->__pyx_kp_u_uses_mask_not_implemented_with_o);
  Py_VISIT(traverse_module_state->__pyx_n_s_v);
  Py_VISIT(traverse_module_state->__pyx_n_s_val);
  Py_VISIT(traverse_module_state->__pyx_n_s_value_count);
  Py_VISIT(traverse_module_state->__pyx_n_s_values);
  Py_VISIT(traverse_module_state->__pyx_n_s_vecs);
  Py_VISIT(traverse_module_state->__pyx_n_s_version_info);
  Py_VISIT(traverse_module_state->__pyx_n_s_view);
  Py_VISIT(traverse_module_state->__pyx_n_s_zeros);
  Py_VISIT(traverse_module_state->__pyx_int_0);
  Py_VISIT(traverse_module_state->__pyx_int_1);
  Py_VISIT(traverse_module_state->__pyx_int_2);
  Py_VISIT(traverse_module_state->__pyx_int_3);
  Py_VISIT(traverse_module_state->__pyx_int_1048583);
  Py_VISIT(traverse_module_state->__pyx_int_112105877);
  Py_VISIT(traverse_module_state->__pyx_int_136983863);
  Py_VISIT(traverse_module_state->__pyx_int_184977713);
  Py_VISIT(traverse_module_state->__pyx_int_222419149);
  Py_VISIT(traverse_module_state->__pyx_int_228825662);
  Py_VISIT(traverse_module_state->__pyx_int_238750788);
  Py_VISIT(traverse_module_state->__pyx_int_neg_1);
  Py_VISIT(traverse_module_state->__pyx_k__14);
  Py_VISIT(traverse_module_state->__pyx_k__15);
  Py_VISIT(traverse_module_state->__pyx_k__18);
  Py_VISIT(traverse_module_state->__pyx_k__19);
  Py_VISIT(traverse_module_state->__pyx_k__20);
  Py_VISIT(traverse_module_state->__pyx_k__21);
  Py_VISIT(traverse_module_state->__pyx_k__22);
  Py_VISIT(traverse_module_state->__pyx_k__23);
  Py_VISIT(traverse_module_state->__pyx_k__24);
  Py_VISIT(traverse_module_state->__pyx_k__25);
  Py_VISIT(traverse_module_state->__pyx_k__26);
  Py_VISIT(traverse_module_state->__pyx_k__27);
  Py_VISIT(traverse_module_state->__pyx_k__28);
  Py_VISIT(traverse_module_state->__pyx_k__29);
  Py_VISIT(traverse_module_state->__pyx_k__30);
  Py_VISIT(traverse_module_state->__pyx_k__31);
  Py_VISIT(traverse_module_state->__pyx_k__32);
  Py_VISIT(traverse_module_state->__pyx_k__33);
  Py_VISIT(traverse_module_state->__pyx_k__34);
  Py_VISIT(traverse_module_state->__pyx_k__35);
  Py_VISIT(traverse_module_state->__pyx_k__36);
  Py_VISIT(traverse_module_state->__pyx_k__37);
  Py_VISIT(traverse_module_state->__pyx_k__38);
  Py_VISIT(traverse_module_state->__pyx_k__39);
  Py_VISIT(traverse_module_state->__pyx_k__40);
  Py_VISIT(traverse_module_state->__pyx_k__42);
  Py_VISIT(traverse_module_state->__pyx_k__44);
  Py_VISIT(traverse_module_state->__pyx_k__45);
  Py_VISIT(traverse_module_state->__pyx_k__46);
  Py_VISIT(traverse_module_state->__pyx_k__47);
  Py_VISIT(traverse_module_state->__pyx_k__48);
  Py_VISIT(traverse_module_state->__pyx_k__49);
  Py_VISIT(traverse_module_state->__pyx_k__50);
  Py_VISIT(traverse_module_state->__pyx_k__51);
  Py_VISIT(traverse_module_state->__pyx_k__52);
  Py_VISIT(traverse_module_state->__pyx_k__53);
  Py_VISIT(traverse_module_state->__pyx_k__54);
  Py_VISIT(traverse_module_state->__pyx_k__55);
  Py_VISIT(traverse_module_state->__pyx_k__56);
  Py_VISIT(traverse_module_state->__pyx_k__57);
  Py_VISIT(traverse_module_state->__pyx_k__58);
  Py_VISIT(traverse_module_state->__pyx_k__60);
  Py_VISIT(traverse_module_state->__pyx_k__61);
  Py_VISIT(traverse_module_state->__pyx_k__62);
  Py_VISIT(traverse_module_state->__pyx_k__63);
  Py_VISIT(traverse_module_state->__pyx_k__64);
  Py_VISIT(traverse_module_state->__pyx_k__65);
  Py_VISIT(traverse_module_state->__pyx_k__66);
  Py_VISIT(traverse_module_state->__pyx_k__67);
  Py_VISIT(traverse_module_state->__pyx_k__68);
  Py_VISIT(traverse_module_state->__pyx_k__73);
  Py_VISIT(traverse_module_state->__pyx_k__74);
  Py_VISIT(traverse_module_state->__pyx_k__75);
  Py_VISIT(traverse_module_state->__pyx_k__76);
  Py_VISIT(traverse_module_state->__pyx_k__77);
  Py_VISIT(traverse_module_state->__pyx_k__78);
  Py_VISIT(traverse_module_state->__pyx_k__79);
  Py_VISIT(traverse_module_state->__pyx_k__80);
  Py_VISIT(traverse_module_state->__pyx_k__81);
  Py_VISIT(traverse_module_state->__pyx_k__82);
  Py_VISIT(traverse_module_state->__pyx_k__83);
  Py_VISIT(traverse_module_state->__pyx_k__84);
  Py_VISIT(traverse_module_state->__pyx_k__85);
  Py_VISIT(traverse_module_state->__pyx_k__87);
  Py_VISIT(traverse_module_state->__pyx_k__88);
  Py_VISIT(traverse_module_state->__pyx_k__89);
  Py_VISIT(traverse_module_state->__pyx_k__90);
  Py_VISIT(traverse_module_state->__pyx_k__91);
  Py_VISIT(traverse_module_state->__pyx_k__92);
  Py_VISIT(traverse_module_state->__pyx_k__93);
  Py_VISIT(traverse_module_state->__pyx_k__94);
  Py_VISIT(traverse_module_state->__pyx_k__95);
  Py_VISIT(traverse_module_state->__pyx_k__96);
  Py_VISIT(traverse_module_state->__pyx_k__97);
  Py_VISIT(traverse_module_state->__pyx_k__98);
  Py_VISIT(traverse_module_state->__pyx_k__99);
  Py_VISIT(traverse_module_state->__pyx_slice__5);
  Py_VISIT(traverse_module_state->__pyx_tuple__4);
  Py_VISIT(traverse_module_state->__pyx_tuple__8);
  Py_VISIT(traverse_module_state->__pyx_tuple__9);
  Py_VISIT(traverse_module_state->__pyx_tuple__10);
  Py_VISIT(traverse_module_state->__pyx_tuple__11);
  Py_VISIT(traverse_module_state->__pyx_tuple__12);
  Py_VISIT(traverse_module_state->__pyx_tuple__13);
  Py_VISIT(traverse_module_state->__pyx_tuple__16);
  Py_VISIT(traverse_module_state->__pyx_tuple__17);
  Py_VISIT(traverse_module_state->__pyx_tuple__41);
  Py_VISIT(traverse_module_state->__pyx_tuple__43);
  Py_VISIT(traverse_module_state->__pyx_tuple__59);
  Py_VISIT(traverse_module_state->__pyx_tuple__71);
  Py_VISIT(traverse_module_state->__pyx_tuple__72);
  Py_VISIT(traverse_module_state->__pyx_slice__100);
  Py_VISIT(traverse_module_state->__pyx_tuple__101);
  Py_VISIT(traverse_module_state->__pyx_tuple__102);
  Py_VISIT(traverse_module_state->__pyx_tuple__103);
  Py_VISIT(traverse_module_state->__pyx_tuple__104);
  Py_VISIT(traverse_module_state->__pyx_tuple__105);
  Py_VISIT(traverse_module_state->__pyx_tuple__106);
  Py_VISIT(traverse_module_state->__pyx_tuple__107);
  Py_VISIT(traverse_module_state->__pyx_tuple__108);
  Py_VISIT(traverse_module_state->__pyx_tuple__109);
  Py_VISIT(traverse_module_state->__pyx_tuple__110);
  Py_VISIT(traverse_module_state->__pyx_tuple__111);
  Py_VISIT(traverse_module_state->__pyx_tuple__112);
  Py_VISIT(traverse_module_state->__pyx_tuple__115);
  Py_VISIT(traverse_module_state->__pyx_tuple__117);
  Py_VISIT(traverse_module_state->__pyx_tuple__119);
  Py_VISIT(traverse_module_state->__pyx_tuple__121);
  Py_VISIT(traverse_module_state->__pyx_tuple__165);
  Py_VISIT(traverse_module_state->__pyx_tuple__168);
  Py_VISIT(traverse_module_state->__pyx_tuple__170);
  Py_VISIT(traverse_module_state->__pyx_tuple__172);
  Py_VISIT(traverse_module_state->__pyx_tuple__175);
  Py_VISIT(traverse_module_state->__pyx_tuple__178);
  Py_VISIT(traverse_module_state->__pyx_tuple__180);
  Py_VISIT(traverse_module_state->__pyx_tuple__182);
  Py_VISIT(traverse_module_state->__pyx_tuple__184);
  Py_VISIT(traverse_module_state->__pyx_tuple__185);
  Py_VISIT(traverse_module_state->__pyx_tuple__187);
  Py_VISIT(traverse_module_state->__pyx_tuple__188);
  Py_VISIT(traverse_module_state->__pyx_tuple__190);
  Py_VISIT(traverse_module_state->__pyx_tuple__192);
  Py_VISIT(traverse_module_state->__pyx_tuple__194);
  Py_VISIT(traverse_module_state->__pyx_tuple__197);
  Py_VISIT(traverse_module_state->__pyx_tuple__199);
  Py_VISIT(traverse_module_state->__pyx_tuple__242);
  Py_VISIT(traverse_module_state->__pyx_tuple__250);
  Py_VISIT(traverse_module_state->__pyx_tuple__397);
  Py_VISIT(traverse_module_state->__pyx_tuple__399);
  Py_VISIT(traverse_module_state->__pyx_tuple__401);
  Py_VISIT(traverse_module_state->__pyx_tuple__402);
  Py_VISIT(traverse_module_state->__pyx_tuple__404);
  Py_VISIT(traverse_module_state->__pyx_tuple__406);
  Py_VISIT(traverse_module_state->__pyx_tuple__407);
  Py_VISIT(traverse_module_state->__pyx_tuple__410);
  Py_VISIT(traverse_module_state->__pyx_tuple__412);
  Py_VISIT(traverse_module_state->__pyx_tuple__419);
  Py_VISIT(traverse_module_state->__pyx_tuple__421);
  Py_VISIT(traverse_module_state->__pyx_tuple__423);
  Py_VISIT(traverse_module_state->__pyx_tuple__430);
  Py_VISIT(traverse_module_state->__pyx_tuple__445);
  Py_VISIT(traverse_module_state->__pyx_tuple__446);
  Py_VISIT(traverse_module_state->__pyx_tuple__461);
  Py_VISIT(traverse_module_state->__pyx_tuple__476);
  Py_VISIT(traverse_module_state->__pyx_tuple__478);
  Py_VISIT(traverse_module_state->__pyx_tuple__482);
  Py_VISIT(traverse_module_state->__pyx_codeobj__113);
  Py_VISIT(traverse_module_state->__pyx_codeobj__114);
  Py_VISIT(traverse_module_state->__pyx_codeobj__116);
  Py_VISIT(traverse_module_state->__pyx_codeobj__118);
  Py_VISIT(traverse_module_state->__pyx_codeobj__120);
  Py_VISIT(traverse_module_state->__pyx_codeobj__122);
  Py_VISIT(traverse_module_state->__pyx_codeobj__123);
  Py_VISIT(traverse_module_state->__pyx_codeobj__124);
  Py_VISIT(traverse_module_state->__pyx_codeobj__125);
  Py_VISIT(traverse_module_state->__pyx_codeobj__126);
  Py_VISIT(traverse_module_state->__pyx_codeobj__127);
  Py_VISIT(traverse_module_state->__pyx_codeobj__128);
  Py_VISIT(traverse_module_state->__pyx_codeobj__129);
  Py_VISIT(traverse_module_state->__pyx_codeobj__130);
  Py_VISIT(traverse_module_state->__pyx_codeobj__131);
  Py_VISIT(traverse_module_state->__pyx_codeobj__132);
  Py_VISIT(traverse_module_state->__pyx_codeobj__133);
  Py_VISIT(traverse_module_state->__pyx_codeobj__134);
  Py_VISIT(traverse_module_state->__pyx_codeobj__135);
  Py_VISIT(traverse_module_state->__pyx_codeobj__136);
  Py_VISIT(traverse_module_state->__pyx_codeobj__137);
  Py_VISIT(traverse_module_state->__pyx_codeobj__138);
  Py_VISIT(traverse_module_state->__pyx_codeobj__139);
  Py_VISIT(traverse_module_state->__pyx_codeobj__140);
  Py_VISIT(traverse_module_state->__pyx_codeobj__141);
  Py_VISIT(traverse_module_state->__pyx_codeobj__142);
  Py_VISIT(traverse_module_state->__pyx_codeobj__143);
  Py_VISIT(traverse_module_state->__pyx_codeobj__144);
  Py_VISIT(traverse_module_state->__pyx_codeobj__145);
  Py_VISIT(traverse_module_state->__pyx_codeobj__146);
  Py_VISIT(traverse_module_state->__pyx_codeobj__147);
  Py_VISIT(traverse_module_state->__pyx_codeobj__148);
  Py_VISIT(traverse_module_state->__pyx_codeobj__149);
  Py_VISIT(traverse_module_state->__pyx_codeobj__150);
  Py_VISIT(traverse_module_state->__pyx_codeobj__151);
  Py_VISIT(traverse_module_state->__pyx_codeobj__152);
  Py_VISIT(traverse_module_state->__pyx_codeobj__153);
  Py_VISIT(traverse_module_state->__pyx_codeobj__154);
  Py_VISIT(traverse_module_state->__pyx_codeobj__155);
  Py_VISIT(traverse_module_state->__pyx_codeobj__156);
  Py_VISIT(traverse_module_state->__pyx_codeobj__157);
  Py_VISIT(traverse_module_state->__pyx_codeobj__158);
  Py_VISIT(traverse_module_state->__pyx_codeobj__159);
  Py_VISIT(traverse_module_state->__pyx_codeobj__160);
  Py_VISIT(traverse_module_state->__pyx_codeobj__161);
  Py_VISIT(traverse_module_state->__pyx_codeobj__162);
  Py_VISIT(traverse_module_state->__pyx_codeobj__163);
  Py_VISIT(traverse_module_state->__pyx_codeobj__164);
  Py_VISIT(traverse_module_state->__pyx_codeobj__166);
  Py_VISIT(traverse_module_state->__pyx_codeobj__167);
  Py_VISIT(traverse_module_state->__pyx_codeobj__169);
  Py_VISIT(traverse_module_state->__pyx_codeobj__171);
  Py_VISIT(traverse_module_state->__pyx_codeobj__173);
  Py_VISIT(traverse_module_state->__pyx_codeobj__174);
  Py_VISIT(traverse_module_state->__pyx_codeobj__176);
  Py_VISIT(traverse_module_state->__pyx_codeobj__177);
  Py_VISIT(traverse_module_state->__pyx_codeobj__179);
  Py_VISIT(traverse_module_state->__pyx_codeobj__181);
  Py_VISIT(traverse_module_state->__pyx_codeobj__183);
  Py_VISIT(traverse_module_state->__pyx_codeobj__186);
  Py_VISIT(traverse_module_state->__pyx_codeobj__189);
  Py_VISIT(traverse_module_state->__pyx_codeobj__193);
  Py_VISIT(traverse_module_state->__pyx_codeobj__195);
  Py_VISIT(traverse_module_state->__pyx_codeobj__196);
  Py_VISIT(traverse_module_state->__pyx_codeobj__198);
  Py_VISIT(traverse_module_state->__pyx_codeobj__200);
  Py_VISIT(traverse_module_state->__pyx_codeobj__201);
  Py_VISIT(traverse_module_state->__pyx_codeobj__202);
  Py_VISIT(traverse_module_state->__pyx_codeobj__203);
  Py_VISIT(traverse_module_state->__pyx_codeobj__204);
  Py_VISIT(traverse_module_state->__pyx_codeobj__205);
  Py_VISIT(traverse_module_state->__pyx_codeobj__206);
  Py_VISIT(traverse_module_state->__pyx_codeobj__207);
  Py_VISIT(traverse_module_state->__pyx_codeobj__208);
  Py_VISIT(traverse_module_state->__pyx_codeobj__209);
  Py_VISIT(traverse_module_state->__pyx_codeobj__210);
  Py_VISIT(traverse_module_state->__pyx_codeobj__211);
  Py_VISIT(traverse_module_state->__pyx_codeobj__212);
  Py_VISIT(traverse_module_state->__pyx_codeobj__213);
  Py_VISIT(traverse_module_state->__pyx_codeobj__214);
  Py_VISIT(traverse_module_state->__pyx_codeobj__215);
  Py_VISIT(traverse_module_state->__pyx_codeobj__216);
  Py_VISIT(traverse_module_state->__pyx_codeobj__217);
  Py_VISIT(traverse_module_state->__pyx_codeobj__218);
  Py_VISIT(traverse_module_state->__pyx_codeobj__219);
  Py_VISIT(traverse_module_state->__pyx_codeobj__220);
  Py_VISIT(traverse_module_state->__pyx_codeobj__221);
  Py_VISIT(traverse_module_state->__pyx_codeobj__222);
  Py_VISIT(traverse_module_state->__pyx_codeobj__223);
  Py_VISIT(traverse_module_state->__pyx_codeobj__224);
  Py_VISIT(traverse_module_state->__pyx_codeobj__225);
  Py_VISIT(traverse_module_state->__pyx_codeobj__226);
  Py_VISIT(traverse_module_state->__pyx_codeobj__227);
  Py_VISIT(traverse_module_state->__pyx_codeobj__228);
  Py_VISIT(traverse_module_state->__pyx_codeobj__229);
  Py_VISIT(traverse_module_state->__pyx_codeobj__230);
  Py_VISIT(traverse_module_state->__pyx_codeobj__231);
  Py_VISIT(traverse_module_state->__pyx_codeobj__232);
  Py_VISIT(traverse_module_state->__pyx_codeobj__233);
  Py_VISIT(traverse_module_state->__pyx_codeobj__234);
  Py_VISIT(traverse_module_state->__pyx_codeobj__235);
  Py_VISIT(traverse_module_state->__pyx_codeobj__236);
  Py_VISIT(traverse_module_state->__pyx_codeobj__237);
  Py_VISIT(traverse_module_state->__pyx_codeobj__238);
  Py_VISIT(traverse_module_state->__pyx_codeobj__239);
  Py_VISIT(traverse_module_state->__pyx_codeobj__240);
  Py_VISIT(traverse_module_state->__pyx_codeobj__241);
  Py_VISIT(traverse_module_state->__pyx_codeobj__243);
  Py_VISIT(traverse_module_state->__pyx_codeobj__244);
  Py_VISIT(traverse_module_state->__pyx_codeobj__245);
  Py_VISIT(traverse_module_state->__pyx_codeobj__246);
  Py_VISIT(traverse_module_state->__pyx_codeobj__247);
  Py_VISIT(traverse_module_state->__pyx_codeobj__248);
  Py_VISIT(traverse_module_state->__pyx_codeobj__249);
  Py_VISIT(traverse_module_state->__pyx_codeobj__251);
  Py_VISIT(traverse_module_state->__pyx_codeobj__252);
  Py_VISIT(traverse_module_state->__pyx_codeobj__253);
  Py_VISIT(traverse_module_state->__pyx_codeobj__254);
  Py_VISIT(traverse_module_state->__pyx_codeobj__255);
  Py_VISIT(traverse_module_state->__pyx_codeobj__256);
  Py_VISIT(traverse_module_state->__pyx_codeobj__257);
  Py_VISIT(traverse_module_state->__pyx_codeobj__258);
  Py_VISIT(traverse_module_state->__pyx_codeobj__259);
  Py_VISIT(traverse_module_state->__pyx_codeobj__260);
  Py_VISIT(traverse_module_state->__pyx_codeobj__261);
  Py_VISIT(traverse_module_state->__pyx_codeobj__262);
  Py_VISIT(traverse_module_state->__pyx_codeobj__263);
  Py_VISIT(traverse_module_state->__pyx_codeobj__264);
  Py_VISIT(traverse_module_state->__pyx_codeobj__265);
  Py_VISIT(traverse_module_state->__pyx_codeobj__266);
  Py_VISIT(traverse_module_state->__pyx_codeobj__267);
  Py_VISIT(traverse_module_state->__pyx_codeobj__268);
  Py_VISIT(traverse_module_state->__pyx_codeobj__269);
  Py_VISIT(traverse_module_state->__pyx_codeobj__270);
  Py_VISIT(traverse_module_state->__pyx_codeobj__271);
  Py_VISIT(traverse_module_state->__pyx_codeobj__272);
  Py_VISIT(traverse_module_state->__pyx_codeobj__273);
  Py_VISIT(traverse_module_state->__pyx_codeobj__274);
  Py_VISIT(traverse_module_state->__pyx_codeobj__275);
  Py_VISIT(traverse_module_state->__pyx_codeobj__276);
  Py_VISIT(traverse_module_state->__pyx_codeobj__277);
  Py_VISIT(traverse_module_state->__pyx_codeobj__278);
  Py_VISIT(traverse_module_state->__pyx_codeobj__279);
  Py_VISIT(traverse_module_state->__pyx_codeobj__280);
  Py_VISIT(traverse_module_state->__pyx_codeobj__281);
  Py_VISIT(traverse_module_state->__pyx_codeobj__282);
  Py_VISIT(traverse_module_state->__pyx_codeobj__283);
  Py_VISIT(traverse_module_state->__pyx_codeobj__284);
  Py_VISIT(traverse_module_state->__pyx_codeobj__285);
  Py_VISIT(traverse_module_state->__pyx_codeobj__286);
  Py_VISIT(traverse_module_state->__pyx_codeobj__287);
  Py_VISIT(traverse_module_state->__pyx_codeobj__288);
  Py_VISIT(traverse_module_state->__pyx_codeobj__289);
  Py_VISIT(traverse_module_state->__pyx_codeobj__290);
  Py_VISIT(traverse_module_state->__pyx_codeobj__291);
  Py_VISIT(traverse_module_state->__pyx_codeobj__292);
  Py_VISIT(traverse_module_state->__pyx_codeobj__293);
  Py_VISIT(traverse_module_state->__pyx_codeobj__294);
  Py_VISIT(traverse_module_state->__pyx_codeobj__295);
  Py_VISIT(traverse_module_state->__pyx_codeobj__296);
  Py_VISIT(traverse_module_state->__pyx_codeobj__297);
  Py_VISIT(traverse_module_state->__pyx_codeobj__298);
  Py_VISIT(traverse_module_state->__pyx_codeobj__299);
  Py_VISIT(traverse_module_state->__pyx_codeobj__300);
  Py_VISIT(traverse_module_state->__pyx_codeobj__301);
  Py_VISIT(traverse_module_state->__pyx_codeobj__302);
  Py_VISIT(traverse_module_state->__pyx_codeobj__303);
  Py_VISIT(traverse_module_state->__pyx_codeobj__304);
  Py_VISIT(traverse_module_state->__pyx_codeobj__305);
  Py_VISIT(traverse_module_state->__pyx_codeobj__306);
  Py_VISIT(traverse_module_state->__pyx_codeobj__307);
  Py_VISIT(traverse_module_state->__pyx_codeobj__308);
  Py_VISIT(traverse_module_state->__pyx_codeobj__309);
  Py_VISIT(traverse_module_state->__pyx_codeobj__310);
  Py_VISIT(traverse_module_state->__pyx_codeobj__311);
  Py_VISIT(traverse_module_state->__pyx_codeobj__312);
  Py_VISIT(traverse_module_state->__pyx_codeobj__313);
  Py_VISIT(traverse_module_state->__pyx_codeobj__314);
  Py_VISIT(traverse_module_state->__pyx_codeobj__315);
  Py_VISIT(traverse_module_state->__pyx_codeobj__316);
  Py_VISIT(traverse_module_state->__pyx_codeobj__317);
  Py_VISIT(traverse_module_state->__pyx_codeobj__318);
  Py_VISIT(traverse_module_state->__pyx_codeobj__319);
  Py_VISIT(traverse_module_state->__pyx_codeobj__320);
  Py_VISIT(traverse_module_state->__pyx_codeobj__321);
  Py_VISIT(traverse_module_state->__pyx_codeobj__322);
  Py_VISIT(traverse_module_state->__pyx_codeobj__323);
  Py_VISIT(traverse_module_state->__pyx_codeobj__324);
  Py_VISIT(traverse_module_state->__pyx_codeobj__325);
  Py_VISIT(traverse_module_state->__pyx_codeobj__326);
  Py_VISIT(traverse_module_state->__pyx_codeobj__327);
  Py_VISIT(traverse_module_state->__pyx_codeobj__328);
  Py_VISIT(traverse_module_state->__pyx_codeobj__329);
  Py_VISIT(traverse_module_state->__pyx_codeobj__330);
  Py_VISIT(traverse_module_state->__pyx_codeobj__331);
  Py_VISIT(traverse_module_state->__pyx_codeobj__332);
  Py_VISIT(traverse_module_state->__pyx_codeobj__333);
  Py_VISIT(traverse_module_state->__pyx_codeobj__334);
  Py_VISIT(traverse_module_state->__pyx_codeobj__335);
  Py_VISIT(traverse_module_state->__pyx_codeobj__336);
  Py_VISIT(traverse_module_state->__pyx_codeobj__337);
  Py_VISIT(traverse_module_state->__pyx_codeobj__338);
  Py_VISIT(traverse_module_state->__pyx_codeobj__339);
  Py_VISIT(traverse_module_state->__pyx_codeobj__340);
  Py_VISIT(traverse_module_state->__pyx_codeobj__341);
  Py_VISIT(traverse_module_state->__pyx_codeobj__342);
  Py_VISIT(traverse_module_state->__pyx_codeobj__343);
  Py_VISIT(traverse_module_state->__pyx_codeobj__344);
  Py_VISIT(traverse_module_state->__pyx_codeobj__345);
  Py_VISIT(traverse_module_state->__pyx_codeobj__346);
  Py_VISIT(traverse_module_state->__pyx_codeobj__347);
  Py_VISIT(traverse_module_state->__pyx_codeobj__348);
  Py_VISIT(traverse_module_state->__pyx_codeobj__349);
  Py_VISIT(traverse_module_state->__pyx_codeobj__350);
  Py_VISIT(traverse_module_state->__pyx_codeobj__351);
  Py_VISIT(traverse_module_state->__pyx_codeobj__352);
  Py_VISIT(traverse_module_state->__pyx_codeobj__353);
  Py_VISIT(traverse_module_state->__pyx_codeobj__354);
  Py_VISIT(traverse_module_state->__pyx_codeobj__355);
  Py_VISIT(traverse_module_state->__pyx_codeobj__356);
  Py_VISIT(traverse_module_state->__pyx_codeobj__357);
  Py_VISIT(traverse_module_state->__pyx_codeobj__358);
  Py_VISIT(traverse_module_state->__pyx_codeobj__359);
  Py_VISIT(traverse_module_state->__pyx_codeobj__360);
  Py_VISIT(traverse_module_state->__pyx_codeobj__361);
  Py_VISIT(traverse_module_state->__pyx_codeobj__362);
  Py_VISIT(traverse_module_state->__pyx_codeobj__363);
  Py_VISIT(traverse_module_state->__pyx_codeobj__364);
  Py_VISIT(traverse_module_state->__pyx_codeobj__365);
  Py_VISIT(traverse_module_state->__pyx_codeobj__366);
  Py_VISIT(traverse_module_state->__pyx_codeobj__367);
  Py_VISIT(traverse_module_state->__pyx_codeobj__368);
  Py_VISIT(traverse_module_state->__pyx_codeobj__369);
  Py_VISIT(traverse_module_state->__pyx_codeobj__370);
  Py_VISIT(traverse_module_state->__pyx_codeobj__371);
  Py_VISIT(traverse_module_state->__pyx_codeobj__372);
  Py_VISIT(traverse_module_state->__pyx_codeobj__373);
  Py_VISIT(traverse_module_state->__pyx_codeobj__374);
  Py_VISIT(traverse_module_state->__pyx_codeobj__375);
  Py_VISIT(traverse_module_state->__pyx_codeobj__376);
  Py_VISIT(traverse_module_state->__pyx_codeobj__377);
  Py_VISIT(traverse_module_state->__pyx_codeobj__378);
  Py_VISIT(traverse_module_state->__pyx_codeobj__379);
  Py_VISIT(traverse_module_state->__pyx_codeobj__380);
  Py_VISIT(traverse_module_state->__pyx_codeobj__381);
  Py_VISIT(traverse_module_state->__pyx_codeobj__382);
  Py_VISIT(traverse_module_state->__pyx_codeobj__383);
  Py_VISIT(traverse_module_state->__pyx_codeobj__384);
  Py_VISIT(traverse_module_state->__pyx_codeobj__385);
  Py_VISIT(traverse_module_state->__pyx_codeobj__386);
  Py_VISIT(traverse_module_state->__pyx_codeobj__387);
  Py_VISIT(traverse_module_state->__pyx_codeobj__388);
  Py_VISIT(traverse_module_state->__pyx_codeobj__389);
  Py_VISIT(traverse_module_state->__pyx_codeobj__390);
  Py_VISIT(traverse_module_state->__pyx_codeobj__391);
  Py_VISIT(traverse_module_state->__pyx_codeobj__392);
  Py_VISIT(traverse_module_state->__pyx_codeobj__393);
  Py_VISIT(traverse_module_state->__pyx_codeobj__394);
  Py_VISIT(traverse_module_state->__pyx_codeobj__395);
  Py_VISIT(traverse_module_state->__pyx_codeobj__396);
  Py_VISIT(traverse_module_state->__pyx_codeobj__398);
  Py_VISIT(traverse_module_state->__pyx_codeobj__400);
  Py_VISIT(traverse_module_state->__pyx_codeobj__403);
  Py_VISIT(traverse_module_state->__pyx_codeobj__405);
  Py_VISIT(traverse_module_state->__pyx_codeobj__408);
  Py_VISIT(traverse_module_state->__pyx_codeobj__409);
  Py_VISIT(traverse_module_state->__pyx_codeobj__411);
  Py_VISIT(traverse_module_state->__pyx_codeobj__413);
  Py_VISIT(traverse_module_state->__pyx_codeobj__414);
  Py_VISIT(traverse_module_state->__pyx_codeobj__415);
  Py_VISIT(traverse_module_state->__pyx_codeobj__416);
  Py_VISIT(traverse_module_state->__pyx_codeobj__417);
  Py_VISIT(traverse_module_state->__pyx_codeobj__418);
  Py_VISIT(traverse_module_state->__pyx_codeobj__420);
  Py_VISIT(traverse_module_state->__pyx_codeobj__422);
  Py_VISIT(traverse_module_state->__pyx_codeobj__424);
  Py_VISIT(traverse_module_state->__pyx_codeobj__425);
  Py_VISIT(traverse_module_state->__pyx_codeobj__426);
  Py_VISIT(traverse_module_state->__pyx_codeobj__427);
  Py_VISIT(traverse_module_state->__pyx_codeobj__428);
  Py_VISIT(traverse_module_state->__pyx_codeobj__429);
  Py_VISIT(traverse_module_state->__pyx_codeobj__431);
  Py_VISIT(traverse_module_state->__pyx_codeobj__432);
  Py_VISIT(traverse_module_state->__pyx_codeobj__433);
  Py_VISIT(traverse_module_state->__pyx_codeobj__434);
  Py_VISIT(traverse_module_state->__pyx_codeobj__435);
  Py_VISIT(traverse_module_state->__pyx_codeobj__436);
  Py_VISIT(traverse_module_state->__pyx_codeobj__437);
  Py_VISIT(traverse_module_state->__pyx_codeobj__438);
  Py_VISIT(traverse_module_state->__pyx_codeobj__439);
  Py_VISIT(traverse_module_state->__pyx_codeobj__440);
  Py_VISIT(traverse_module_state->__pyx_codeobj__441);
  Py_VISIT(traverse_module_state->__pyx_codeobj__442);
  Py_VISIT(traverse_module_state->__pyx_codeobj__443);
  Py_VISIT(traverse_module_state->__pyx_codeobj__444);
  Py_VISIT(traverse_module_state->__pyx_codeobj__447);
  Py_VISIT(traverse_module_state->__pyx_codeobj__448);
  Py_VISIT(traverse_module_state->__pyx_codeobj__449);
  Py_VISIT(traverse_module_state->__pyx_codeobj__450);
  Py_VISIT(traverse_module_state->__pyx_codeobj__451);
  Py_VISIT(traverse_module_state->__pyx_codeobj__452);
  Py_VISIT(traverse_module_state->__pyx_codeobj__453);
  Py_VISIT(traverse_module_state->__pyx_codeobj__454);
  Py_VISIT(traverse_module_state->__pyx_codeobj__455);
  Py_VISIT(traverse_module_state->__pyx_codeobj__456);
  Py_VISIT(traverse_module_state->__pyx_codeobj__457);
  Py_VISIT(traverse_module_state->__pyx_codeobj__458);
  Py_VISIT(traverse_module_state->__pyx_codeobj__459);
  Py_VISIT(traverse_module_state->__pyx_codeobj__460);
  Py_VISIT(traverse_module_state->__pyx_codeobj__462);
  Py_VISIT(traverse_module_state->__pyx_codeobj__463);
  Py_VISIT(traverse_module_state->__pyx_codeobj__464);
  Py_VISIT(traverse_module_state->__pyx_codeobj__465);
  Py_VISIT(traverse_module_state->__pyx_codeobj__466);
  Py_VISIT(traverse_module_state->__pyx_codeobj__467);
  Py_VISIT(traverse_module_state->__pyx_codeobj__468);
  Py_VISIT(traverse_module_state->__pyx_codeobj__469);
  Py_VISIT(traverse_module_state->__pyx_codeobj__470);
  Py_VISIT(traverse_module_state->__pyx_codeobj__471);
  Py_VISIT(traverse_module_state->__pyx_codeobj__472);
  Py_VISIT(traverse_module_state->__pyx_codeobj__473);
  Py_VISIT(traverse_module_state->__pyx_codeobj__474);
  Py_VISIT(traverse_module_state->__pyx_codeobj__475);
  Py_VISIT(traverse_module_state->__pyx_codeobj__477);
  Py_VISIT(traverse_module_state->__pyx_codeobj__479);
  Py_VISIT(traverse_module_state->__pyx_codeobj__480);
  Py_VISIT(traverse_module_state->__pyx_codeobj__481);
  Py_VISIT(traverse_module_state->__pyx_codeobj__483);
  Py_VISIT(traverse_module_state->__pyx_codeobj__484);
  Py_VISIT(traverse_module_state->__pyx_codeobj__485);
  Py_VISIT(traverse_module_state->__pyx_codeobj__486);
  Py_VISIT(traverse_module_state->__pyx_codeobj__487);
  Py_VISIT(traverse_module_state->__pyx_codeobj__488);
  Py_VISIT(traverse_module_state->__pyx_codeobj__489);
  return 0;
}
#endif
/* #### Code section: module_state_defines ### */
#define __pyx_d __pyx_mstate_global->__pyx_d
#define __pyx_b __pyx_mstate_global->__pyx_b
#define __pyx_cython_runtime __pyx_mstate_global->__pyx_cython_runtime
#define __pyx_empty_tuple __pyx_mstate_global->__pyx_empty_tuple
#define __pyx_empty_bytes __pyx_mstate_global->__pyx_empty_bytes
#define __pyx_empty_unicode __pyx_mstate_global->__pyx_empty_unicode
#ifdef __Pyx_CyFunction_USED
#define __pyx_CyFunctionType __pyx_mstate_global->__pyx_CyFunctionType
#endif
#ifdef __Pyx_FusedFunction_USED
#define __pyx_FusedFunctionType __pyx_mstate_global->__pyx_FusedFunctionType
#endif
#ifdef __Pyx_Generator_USED
#define __pyx_GeneratorType __pyx_mstate_global->__pyx_GeneratorType
#endif
#ifdef __Pyx_IterableCoroutine_USED
#define __pyx_IterableCoroutineType __pyx_mstate_global->__pyx_IterableCoroutineType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineAwaitType __pyx_mstate_global->__pyx_CoroutineAwaitType
#endif
#ifdef __Pyx_Coroutine_USED
#define __pyx_CoroutineType __pyx_mstate_global->__pyx_CoroutineType
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_7cpython_4type_type __pyx_mstate_global->__pyx_ptype_7cpython_4type_type
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_5numpy_dtype __pyx_mstate_global->__pyx_ptype_5numpy_dtype
#define __pyx_ptype_5numpy_flatiter __pyx_mstate_global->__pyx_ptype_5numpy_flatiter
#define __pyx_ptype_5numpy_broadcast __pyx_mstate_global->__pyx_ptype_5numpy_broadcast
#define __pyx_ptype_5numpy_ndarray __pyx_mstate_global->__pyx_ptype_5numpy_ndarray
#define __pyx_ptype_5numpy_generic __pyx_mstate_global->__pyx_ptype_5numpy_generic
#define __pyx_ptype_5numpy_number __pyx_mstate_global->__pyx_ptype_5numpy_number
#define __pyx_ptype_5numpy_integer __pyx_mstate_global->__pyx_ptype_5numpy_integer
#define __pyx_ptype_5numpy_signedinteger __pyx_mstate_global->__pyx_ptype_5numpy_signedinteger
#define __pyx_ptype_5numpy_unsignedinteger __pyx_mstate_global->__pyx_ptype_5numpy_unsignedinteger
#define __pyx_ptype_5numpy_inexact __pyx_mstate_global->__pyx_ptype_5numpy_inexact
#define __pyx_ptype_5numpy_floating __pyx_mstate_global->__pyx_ptype_5numpy_floating
#define __pyx_ptype_5numpy_complexfloating __pyx_mstate_global->__pyx_ptype_5numpy_complexfloating
#define __pyx_ptype_5numpy_flexible __pyx_mstate_global->__pyx_ptype_5numpy_flexible
#define __pyx_ptype_5numpy_character __pyx_mstate_global->__pyx_ptype_5numpy_character
#define __pyx_ptype_5numpy_ufunc __pyx_mstate_global->__pyx_ptype_5numpy_ufunc
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#if CYTHON_USE_MODULE_STATE
#endif
#define __pyx_ptype_6pandas_5_libs_7missing_C_NAType __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_7missing_C_NAType
#if CYTHON_USE_MODULE_STATE
#define __pyx_type_6pandas_5_libs_9hashtable_HashTable __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_HashTable
#define __pyx_type_6pandas_5_libs_9hashtable_UInt64HashTable __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_UInt64HashTable
#define __pyx_type_6pandas_5_libs_9hashtable_Int64HashTable __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Int64HashTable
#define __pyx_type_6pandas_5_libs_9hashtable_UInt32HashTable __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_UInt32HashTable
#define __pyx_type_6pandas_5_libs_9hashtable_Int32HashTable __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Int32HashTable
#define __pyx_type_6pandas_5_libs_9hashtable_UInt16HashTable __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_UInt16HashTable
#define __pyx_type_6pandas_5_libs_9hashtable_Int16HashTable __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Int16HashTable
#define __pyx_type_6pandas_5_libs_9hashtable_UInt8HashTable __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_UInt8HashTable
#define __pyx_type_6pandas_5_libs_9hashtable_Int8HashTable __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Int8HashTable
#define __pyx_type_6pandas_5_libs_9hashtable_Float64HashTable __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Float64HashTable
#define __pyx_type_6pandas_5_libs_9hashtable_Float32HashTable __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Float32HashTable
#define __pyx_type_6pandas_5_libs_9hashtable_Complex64HashTable __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Complex64HashTable
#define __pyx_type_6pandas_5_libs_9hashtable_Complex128HashTable __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Complex128HashTable
#define __pyx_type_6pandas_5_libs_9hashtable_PyObjectHashTable __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_PyObjectHashTable
#define __pyx_type_6pandas_5_libs_9hashtable_StringHashTable __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_StringHashTable
#define __pyx_type_6pandas_5_libs_9hashtable_Vector __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Vector
#define __pyx_type_6pandas_5_libs_9hashtable_Int64Vector __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Int64Vector
#define __pyx_type_6pandas_5_libs_9hashtable_Complex128Vector __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Complex128Vector
#define __pyx_type_6pandas_5_libs_9hashtable_Complex64Vector __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Complex64Vector
#define __pyx_type_6pandas_5_libs_9hashtable_Float64Vector __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Float64Vector
#define __pyx_type_6pandas_5_libs_9hashtable_UInt64Vector __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_UInt64Vector
#define __pyx_type_6pandas_5_libs_9hashtable_Float32Vector __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Float32Vector
#define __pyx_type_6pandas_5_libs_9hashtable_UInt32Vector __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_UInt32Vector
#define __pyx_type_6pandas_5_libs_9hashtable_Int32Vector __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Int32Vector
#define __pyx_type_6pandas_5_libs_9hashtable_UInt16Vector __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_UInt16Vector
#define __pyx_type_6pandas_5_libs_9hashtable_Int16Vector __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Int16Vector
#define __pyx_type_6pandas_5_libs_9hashtable_UInt8Vector __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_UInt8Vector
#define __pyx_type_6pandas_5_libs_9hashtable_Int8Vector __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Int8Vector
#define __pyx_type_6pandas_5_libs_9hashtable_StringVector __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_StringVector
#define __pyx_type_6pandas_5_libs_9hashtable_ObjectVector __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_ObjectVector
#define __pyx_type_6pandas_5_libs_9hashtable_Factorizer __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Factorizer
#define __pyx_type_6pandas_5_libs_9hashtable_Int8Factorizer __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Int8Factorizer
#define __pyx_type_6pandas_5_libs_9hashtable_UInt8Factorizer __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_UInt8Factorizer
#define __pyx_type_6pandas_5_libs_9hashtable_Int16Factorizer __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Int16Factorizer
#define __pyx_type_6pandas_5_libs_9hashtable_UInt16Factorizer __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_UInt16Factorizer
#define __pyx_type_6pandas_5_libs_9hashtable_Int32Factorizer __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Int32Factorizer
#define __pyx_type_6pandas_5_libs_9hashtable_UInt32Factorizer __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_UInt32Factorizer
#define __pyx_type_6pandas_5_libs_9hashtable_Float32Factorizer __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Float32Factorizer
#define __pyx_type_6pandas_5_libs_9hashtable_Complex64Factorizer __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Complex64Factorizer
#define __pyx_type_6pandas_5_libs_9hashtable_Int64Factorizer __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Int64Factorizer
#define __pyx_type_6pandas_5_libs_9hashtable_UInt64Factorizer __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_UInt64Factorizer
#define __pyx_type_6pandas_5_libs_9hashtable_Float64Factorizer __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Float64Factorizer
#define __pyx_type_6pandas_5_libs_9hashtable_Complex128Factorizer __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_Complex128Factorizer
#define __pyx_type_6pandas_5_libs_9hashtable_ObjectFactorizer __pyx_mstate_global->__pyx_type_6pandas_5_libs_9hashtable_ObjectFactorizer
#define __pyx_type___pyx_array __pyx_mstate_global->__pyx_type___pyx_array
#define __pyx_type___pyx_MemviewEnum __pyx_mstate_global->__pyx_type___pyx_MemviewEnum
#define __pyx_type___pyx_memoryview __pyx_mstate_global->__pyx_type___pyx_memoryview
#define __pyx_type___pyx_memoryviewslice __pyx_mstate_global->__pyx_type___pyx_memoryviewslice
#endif
#define __pyx_ptype_6pandas_5_libs_9hashtable_HashTable __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_HashTable
#define __pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable
#define __pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable
#define __pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable
#define __pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable
#define __pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable
#define __pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable
#define __pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable
#define __pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable
#define __pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable
#define __pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable
#define __pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable
#define __pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable
#define __pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable
#define __pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable
#define __pyx_ptype_6pandas_5_libs_9hashtable_Vector __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Vector
#define __pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector
#define __pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector
#define __pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector
#define __pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector
#define __pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector
#define __pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector
#define __pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector
#define __pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector
#define __pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector
#define __pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector
#define __pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector
#define __pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector
#define __pyx_ptype_6pandas_5_libs_9hashtable_StringVector __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_StringVector
#define __pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector
#define __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer
#define __pyx_ptype_6pandas_5_libs_9hashtable_Int8Factorizer __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Int8Factorizer
#define __pyx_ptype_6pandas_5_libs_9hashtable_UInt8Factorizer __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Factorizer
#define __pyx_ptype_6pandas_5_libs_9hashtable_Int16Factorizer __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Int16Factorizer
#define __pyx_ptype_6pandas_5_libs_9hashtable_UInt16Factorizer __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Factorizer
#define __pyx_ptype_6pandas_5_libs_9hashtable_Int32Factorizer __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Int32Factorizer
#define __pyx_ptype_6pandas_5_libs_9hashtable_UInt32Factorizer __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Factorizer
#define __pyx_ptype_6pandas_5_libs_9hashtable_Float32Factorizer __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Float32Factorizer
#define __pyx_ptype_6pandas_5_libs_9hashtable_Complex64Factorizer __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Factorizer
#define __pyx_ptype_6pandas_5_libs_9hashtable_Int64Factorizer __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Int64Factorizer
#define __pyx_ptype_6pandas_5_libs_9hashtable_UInt64Factorizer __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Factorizer
#define __pyx_ptype_6pandas_5_libs_9hashtable_Float64Factorizer __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Float64Factorizer
#define __pyx_ptype_6pandas_5_libs_9hashtable_Complex128Factorizer __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Factorizer
#define __pyx_ptype_6pandas_5_libs_9hashtable_ObjectFactorizer __pyx_mstate_global->__pyx_ptype_6pandas_5_libs_9hashtable_ObjectFactorizer
#define __pyx_array_type __pyx_mstate_global->__pyx_array_type
#define __pyx_MemviewEnum_type __pyx_mstate_global->__pyx_MemviewEnum_type
#define __pyx_memoryview_type __pyx_mstate_global->__pyx_memoryview_type
#define __pyx_memoryviewslice_type __pyx_mstate_global->__pyx_memoryviewslice_type
#define __pyx_kp_u_ __pyx_mstate_global->__pyx_kp_u_
#define __pyx_n_s_ASCII __pyx_mstate_global->__pyx_n_s_ASCII
#define __pyx_kp_s_All_dimensions_preceding_dimensi __pyx_mstate_global->__pyx_kp_s_All_dimensions_preceding_dimensi
#define __pyx_n_s_AssertionError __pyx_mstate_global->__pyx_n_s_AssertionError
#define __pyx_kp_s_Buffer_view_does_not_expose_stri __pyx_mstate_global->__pyx_kp_s_Buffer_view_does_not_expose_stri
#define __pyx_kp_s_Can_only_create_a_buffer_that_is __pyx_mstate_global->__pyx_kp_s_Can_only_create_a_buffer_that_is
#define __pyx_kp_s_Cannot_assign_to_read_only_memor __pyx_mstate_global->__pyx_kp_s_Cannot_assign_to_read_only_memor
#define __pyx_kp_s_Cannot_create_writable_memory_vi __pyx_mstate_global->__pyx_kp_s_Cannot_create_writable_memory_vi
#define __pyx_kp_u_Cannot_index_with_type __pyx_mstate_global->__pyx_kp_u_Cannot_index_with_type
#define __pyx_kp_s_Cannot_transpose_memoryview_with __pyx_mstate_global->__pyx_kp_s_Cannot_transpose_memoryview_with
#define __pyx_n_s_Complex128Factorizer __pyx_mstate_global->__pyx_n_s_Complex128Factorizer
#define __pyx_n_s_Complex128Factorizer___reduce_cy __pyx_mstate_global->__pyx_n_s_Complex128Factorizer___reduce_cy
#define __pyx_n_s_Complex128Factorizer___setstate __pyx_mstate_global->__pyx_n_s_Complex128Factorizer___setstate
#define __pyx_n_s_Complex128Factorizer_factorize __pyx_mstate_global->__pyx_n_s_Complex128Factorizer_factorize
#define __pyx_kp_u_Complex128Factorizer_factorize_l __pyx_mstate_global->__pyx_kp_u_Complex128Factorizer_factorize_l
#define __pyx_n_s_Complex128HashTable __pyx_mstate_global->__pyx_n_s_Complex128HashTable
#define __pyx_n_s_Complex128HashTable___reduce_cyt __pyx_mstate_global->__pyx_n_s_Complex128HashTable___reduce_cyt
#define __pyx_n_s_Complex128HashTable___setstate_c __pyx_mstate_global->__pyx_n_s_Complex128HashTable___setstate_c
#define __pyx_n_s_Complex128HashTable__unique __pyx_mstate_global->__pyx_n_s_Complex128HashTable__unique
#define __pyx_n_s_Complex128HashTable_factorize __pyx_mstate_global->__pyx_n_s_Complex128HashTable_factorize
#define __pyx_n_s_Complex128HashTable_get_item __pyx_mstate_global->__pyx_n_s_Complex128HashTable_get_item
#define __pyx_n_s_Complex128HashTable_get_labels __pyx_mstate_global->__pyx_n_s_Complex128HashTable_get_labels
#define __pyx_n_s_Complex128HashTable_get_na __pyx_mstate_global->__pyx_n_s_Complex128HashTable_get_na
#define __pyx_n_s_Complex128HashTable_get_state __pyx_mstate_global->__pyx_n_s_Complex128HashTable_get_state
#define __pyx_n_s_Complex128HashTable_lookup __pyx_mstate_global->__pyx_n_s_Complex128HashTable_lookup
#define __pyx_n_s_Complex128HashTable_map_location __pyx_mstate_global->__pyx_n_s_Complex128HashTable_map_location
#define __pyx_n_s_Complex128HashTable_set_item __pyx_mstate_global->__pyx_n_s_Complex128HashTable_set_item
#define __pyx_n_s_Complex128HashTable_set_na __pyx_mstate_global->__pyx_n_s_Complex128HashTable_set_na
#define __pyx_n_s_Complex128HashTable_sizeof __pyx_mstate_global->__pyx_n_s_Complex128HashTable_sizeof
#define __pyx_n_s_Complex128HashTable_unique __pyx_mstate_global->__pyx_n_s_Complex128HashTable_unique
#define __pyx_n_s_Complex128Vector __pyx_mstate_global->__pyx_n_s_Complex128Vector
#define __pyx_n_s_Complex128Vector___reduce_cython __pyx_mstate_global->__pyx_n_s_Complex128Vector___reduce_cython
#define __pyx_n_s_Complex128Vector___setstate_cyth __pyx_mstate_global->__pyx_n_s_Complex128Vector___setstate_cyth
#define __pyx_n_s_Complex128Vector_to_array __pyx_mstate_global->__pyx_n_s_Complex128Vector_to_array
#define __pyx_n_s_Complex64Factorizer __pyx_mstate_global->__pyx_n_s_Complex64Factorizer
#define __pyx_n_s_Complex64Factorizer___reduce_cyt __pyx_mstate_global->__pyx_n_s_Complex64Factorizer___reduce_cyt
#define __pyx_n_s_Complex64Factorizer___setstate_c __pyx_mstate_global->__pyx_n_s_Complex64Factorizer___setstate_c
#define __pyx_n_s_Complex64Factorizer_factorize __pyx_mstate_global->__pyx_n_s_Complex64Factorizer_factorize
#define __pyx_kp_u_Complex64Factorizer_factorize_li __pyx_mstate_global->__pyx_kp_u_Complex64Factorizer_factorize_li
#define __pyx_n_s_Complex64HashTable __pyx_mstate_global->__pyx_n_s_Complex64HashTable
#define __pyx_n_s_Complex64HashTable___reduce_cyth __pyx_mstate_global->__pyx_n_s_Complex64HashTable___reduce_cyth
#define __pyx_n_s_Complex64HashTable___setstate_cy __pyx_mstate_global->__pyx_n_s_Complex64HashTable___setstate_cy
#define __pyx_n_s_Complex64HashTable__unique __pyx_mstate_global->__pyx_n_s_Complex64HashTable__unique
#define __pyx_n_s_Complex64HashTable_factorize __pyx_mstate_global->__pyx_n_s_Complex64HashTable_factorize
#define __pyx_n_s_Complex64HashTable_get_item __pyx_mstate_global->__pyx_n_s_Complex64HashTable_get_item
#define __pyx_n_s_Complex64HashTable_get_labels __pyx_mstate_global->__pyx_n_s_Complex64HashTable_get_labels
#define __pyx_n_s_Complex64HashTable_get_na __pyx_mstate_global->__pyx_n_s_Complex64HashTable_get_na
#define __pyx_n_s_Complex64HashTable_get_state __pyx_mstate_global->__pyx_n_s_Complex64HashTable_get_state
#define __pyx_n_s_Complex64HashTable_lookup __pyx_mstate_global->__pyx_n_s_Complex64HashTable_lookup
#define __pyx_n_s_Complex64HashTable_map_locations __pyx_mstate_global->__pyx_n_s_Complex64HashTable_map_locations
#define __pyx_n_s_Complex64HashTable_set_item __pyx_mstate_global->__pyx_n_s_Complex64HashTable_set_item
#define __pyx_n_s_Complex64HashTable_set_na __pyx_mstate_global->__pyx_n_s_Complex64HashTable_set_na
#define __pyx_n_s_Complex64HashTable_sizeof __pyx_mstate_global->__pyx_n_s_Complex64HashTable_sizeof
#define __pyx_n_s_Complex64HashTable_unique __pyx_mstate_global->__pyx_n_s_Complex64HashTable_unique
#define __pyx_n_s_Complex64Vector __pyx_mstate_global->__pyx_n_s_Complex64Vector
#define __pyx_n_s_Complex64Vector___reduce_cython __pyx_mstate_global->__pyx_n_s_Complex64Vector___reduce_cython
#define __pyx_n_s_Complex64Vector___setstate_cytho __pyx_mstate_global->__pyx_n_s_Complex64Vector___setstate_cytho
#define __pyx_n_s_Complex64Vector_to_array __pyx_mstate_global->__pyx_n_s_Complex64Vector_to_array
#define __pyx_kp_s_Dimension_d_is_not_direct __pyx_mstate_global->__pyx_kp_s_Dimension_d_is_not_direct
#define __pyx_n_s_Ellipsis __pyx_mstate_global->__pyx_n_s_Ellipsis
#define __pyx_kp_s_Empty_shape_tuple_for_cython_arr __pyx_mstate_global->__pyx_kp_s_Empty_shape_tuple_for_cython_arr
#define __pyx_kp_s_Expected_at_least_d_argument_s_g __pyx_mstate_global->__pyx_kp_s_Expected_at_least_d_argument_s_g
#define __pyx_n_s_Factorizer __pyx_mstate_global->__pyx_n_s_Factorizer
#define __pyx_n_s_Factorizer___reduce_cython __pyx_mstate_global->__pyx_n_s_Factorizer___reduce_cython
#define __pyx_n_s_Factorizer___setstate_cython __pyx_mstate_global->__pyx_n_s_Factorizer___setstate_cython
#define __pyx_n_s_Factorizer_factorize __pyx_mstate_global->__pyx_n_s_Factorizer_factorize
#define __pyx_n_s_Factorizer_get_count __pyx_mstate_global->__pyx_n_s_Factorizer_get_count
#define __pyx_n_s_Float32Factorizer __pyx_mstate_global->__pyx_n_s_Float32Factorizer
#define __pyx_n_s_Float32Factorizer___reduce_cytho __pyx_mstate_global->__pyx_n_s_Float32Factorizer___reduce_cytho
#define __pyx_n_s_Float32Factorizer___setstate_cyt __pyx_mstate_global->__pyx_n_s_Float32Factorizer___setstate_cyt
#define __pyx_n_s_Float32Factorizer_factorize __pyx_mstate_global->__pyx_n_s_Float32Factorizer_factorize
#define __pyx_kp_u_Float32Factorizer_factorize_line __pyx_mstate_global->__pyx_kp_u_Float32Factorizer_factorize_line
#define __pyx_n_s_Float32HashTable __pyx_mstate_global->__pyx_n_s_Float32HashTable
#define __pyx_n_s_Float32HashTable___reduce_cython __pyx_mstate_global->__pyx_n_s_Float32HashTable___reduce_cython
#define __pyx_n_s_Float32HashTable___setstate_cyth __pyx_mstate_global->__pyx_n_s_Float32HashTable___setstate_cyth
#define __pyx_n_s_Float32HashTable__unique __pyx_mstate_global->__pyx_n_s_Float32HashTable__unique
#define __pyx_n_s_Float32HashTable_factorize __pyx_mstate_global->__pyx_n_s_Float32HashTable_factorize
#define __pyx_n_s_Float32HashTable_get_item __pyx_mstate_global->__pyx_n_s_Float32HashTable_get_item
#define __pyx_n_s_Float32HashTable_get_labels __pyx_mstate_global->__pyx_n_s_Float32HashTable_get_labels
#define __pyx_n_s_Float32HashTable_get_na __pyx_mstate_global->__pyx_n_s_Float32HashTable_get_na
#define __pyx_n_s_Float32HashTable_get_state __pyx_mstate_global->__pyx_n_s_Float32HashTable_get_state
#define __pyx_n_s_Float32HashTable_lookup __pyx_mstate_global->__pyx_n_s_Float32HashTable_lookup
#define __pyx_n_s_Float32HashTable_map_locations __pyx_mstate_global->__pyx_n_s_Float32HashTable_map_locations
#define __pyx_n_s_Float32HashTable_set_item __pyx_mstate_global->__pyx_n_s_Float32HashTable_set_item
#define __pyx_n_s_Float32HashTable_set_na __pyx_mstate_global->__pyx_n_s_Float32HashTable_set_na
#define __pyx_n_s_Float32HashTable_sizeof __pyx_mstate_global->__pyx_n_s_Float32HashTable_sizeof
#define __pyx_n_s_Float32HashTable_unique __pyx_mstate_global->__pyx_n_s_Float32HashTable_unique
#define __pyx_n_s_Float32Vector __pyx_mstate_global->__pyx_n_s_Float32Vector
#define __pyx_n_s_Float32Vector___reduce_cython __pyx_mstate_global->__pyx_n_s_Float32Vector___reduce_cython
#define __pyx_n_s_Float32Vector___setstate_cython __pyx_mstate_global->__pyx_n_s_Float32Vector___setstate_cython
#define __pyx_n_s_Float32Vector_to_array __pyx_mstate_global->__pyx_n_s_Float32Vector_to_array
#define __pyx_n_s_Float64Factorizer __pyx_mstate_global->__pyx_n_s_Float64Factorizer
#define __pyx_n_s_Float64Factorizer___reduce_cytho __pyx_mstate_global->__pyx_n_s_Float64Factorizer___reduce_cytho
#define __pyx_n_s_Float64Factorizer___setstate_cyt __pyx_mstate_global->__pyx_n_s_Float64Factorizer___setstate_cyt
#define __pyx_n_s_Float64Factorizer_factorize __pyx_mstate_global->__pyx_n_s_Float64Factorizer_factorize
#define __pyx_kp_u_Float64Factorizer_factorize_line __pyx_mstate_global->__pyx_kp_u_Float64Factorizer_factorize_line
#define __pyx_n_s_Float64HashTable __pyx_mstate_global->__pyx_n_s_Float64HashTable
#define __pyx_n_s_Float64HashTable___reduce_cython __pyx_mstate_global->__pyx_n_s_Float64HashTable___reduce_cython
#define __pyx_n_s_Float64HashTable___setstate_cyth __pyx_mstate_global->__pyx_n_s_Float64HashTable___setstate_cyth
#define __pyx_n_s_Float64HashTable__unique __pyx_mstate_global->__pyx_n_s_Float64HashTable__unique
#define __pyx_n_s_Float64HashTable_factorize __pyx_mstate_global->__pyx_n_s_Float64HashTable_factorize
#define __pyx_n_s_Float64HashTable_get_item __pyx_mstate_global->__pyx_n_s_Float64HashTable_get_item
#define __pyx_n_s_Float64HashTable_get_labels __pyx_mstate_global->__pyx_n_s_Float64HashTable_get_labels
#define __pyx_n_s_Float64HashTable_get_na __pyx_mstate_global->__pyx_n_s_Float64HashTable_get_na
#define __pyx_n_s_Float64HashTable_get_state __pyx_mstate_global->__pyx_n_s_Float64HashTable_get_state
#define __pyx_n_s_Float64HashTable_lookup __pyx_mstate_global->__pyx_n_s_Float64HashTable_lookup
#define __pyx_n_s_Float64HashTable_map_locations __pyx_mstate_global->__pyx_n_s_Float64HashTable_map_locations
#define __pyx_n_s_Float64HashTable_set_item __pyx_mstate_global->__pyx_n_s_Float64HashTable_set_item
#define __pyx_n_s_Float64HashTable_set_na __pyx_mstate_global->__pyx_n_s_Float64HashTable_set_na
#define __pyx_n_s_Float64HashTable_sizeof __pyx_mstate_global->__pyx_n_s_Float64HashTable_sizeof
#define __pyx_n_s_Float64HashTable_unique __pyx_mstate_global->__pyx_n_s_Float64HashTable_unique
#define __pyx_n_s_Float64Vector __pyx_mstate_global->__pyx_n_s_Float64Vector
#define __pyx_n_s_Float64Vector___reduce_cython __pyx_mstate_global->__pyx_n_s_Float64Vector___reduce_cython
#define __pyx_n_s_Float64Vector___setstate_cython __pyx_mstate_global->__pyx_n_s_Float64Vector___setstate_cython
#define __pyx_n_s_Float64Vector_to_array __pyx_mstate_global->__pyx_n_s_Float64Vector_to_array
#define __pyx_kp_s_Function_call_with_ambiguous_arg __pyx_mstate_global->__pyx_kp_s_Function_call_with_ambiguous_arg
#define __pyx_n_s_HashTable __pyx_mstate_global->__pyx_n_s_HashTable
#define __pyx_n_s_HashTable___reduce_cython __pyx_mstate_global->__pyx_n_s_HashTable___reduce_cython
#define __pyx_n_s_HashTable___setstate_cython __pyx_mstate_global->__pyx_n_s_HashTable___setstate_cython
#define __pyx_n_s_ImportError __pyx_mstate_global->__pyx_n_s_ImportError
#define __pyx_kp_s_Incompatible_checksums_0x_x_vs_0 __pyx_mstate_global->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0
#define __pyx_kp_s_Incompatible_checksums_0x_x_vs_0_2 __pyx_mstate_global->__pyx_kp_s_Incompatible_checksums_0x_x_vs_0_2
#define __pyx_n_s_IndexError __pyx_mstate_global->__pyx_n_s_IndexError
#define __pyx_kp_s_Index_out_of_bounds_axis_d __pyx_mstate_global->__pyx_kp_s_Index_out_of_bounds_axis_d
#define __pyx_kp_s_Indirect_dimensions_not_supporte __pyx_mstate_global->__pyx_kp_s_Indirect_dimensions_not_supporte
#define __pyx_n_s_Int16Factorizer __pyx_mstate_global->__pyx_n_s_Int16Factorizer
#define __pyx_n_s_Int16Factorizer___reduce_cython __pyx_mstate_global->__pyx_n_s_Int16Factorizer___reduce_cython
#define __pyx_n_s_Int16Factorizer___setstate_cytho __pyx_mstate_global->__pyx_n_s_Int16Factorizer___setstate_cytho
#define __pyx_n_s_Int16Factorizer_factorize __pyx_mstate_global->__pyx_n_s_Int16Factorizer_factorize
#define __pyx_kp_u_Int16Factorizer_factorize_line_5 __pyx_mstate_global->__pyx_kp_u_Int16Factorizer_factorize_line_5
#define __pyx_n_s_Int16HashTable __pyx_mstate_global->__pyx_n_s_Int16HashTable
#define __pyx_n_s_Int16HashTable___reduce_cython __pyx_mstate_global->__pyx_n_s_Int16HashTable___reduce_cython
#define __pyx_n_s_Int16HashTable___setstate_cython __pyx_mstate_global->__pyx_n_s_Int16HashTable___setstate_cython
#define __pyx_n_s_Int16HashTable__unique __pyx_mstate_global->__pyx_n_s_Int16HashTable__unique
#define __pyx_n_s_Int16HashTable_factorize __pyx_mstate_global->__pyx_n_s_Int16HashTable_factorize
#define __pyx_n_s_Int16HashTable_get_item __pyx_mstate_global->__pyx_n_s_Int16HashTable_get_item
#define __pyx_n_s_Int16HashTable_get_labels __pyx_mstate_global->__pyx_n_s_Int16HashTable_get_labels
#define __pyx_n_s_Int16HashTable_get_na __pyx_mstate_global->__pyx_n_s_Int16HashTable_get_na
#define __pyx_n_s_Int16HashTable_get_state __pyx_mstate_global->__pyx_n_s_Int16HashTable_get_state
#define __pyx_n_s_Int16HashTable_lookup __pyx_mstate_global->__pyx_n_s_Int16HashTable_lookup
#define __pyx_n_s_Int16HashTable_map_locations __pyx_mstate_global->__pyx_n_s_Int16HashTable_map_locations
#define __pyx_n_s_Int16HashTable_set_item __pyx_mstate_global->__pyx_n_s_Int16HashTable_set_item
#define __pyx_n_s_Int16HashTable_set_na __pyx_mstate_global->__pyx_n_s_Int16HashTable_set_na
#define __pyx_n_s_Int16HashTable_sizeof __pyx_mstate_global->__pyx_n_s_Int16HashTable_sizeof
#define __pyx_n_s_Int16HashTable_unique __pyx_mstate_global->__pyx_n_s_Int16HashTable_unique
#define __pyx_n_s_Int16Vector __pyx_mstate_global->__pyx_n_s_Int16Vector
#define __pyx_n_s_Int16Vector___reduce_cython __pyx_mstate_global->__pyx_n_s_Int16Vector___reduce_cython
#define __pyx_n_s_Int16Vector___setstate_cython __pyx_mstate_global->__pyx_n_s_Int16Vector___setstate_cython
#define __pyx_n_s_Int16Vector_to_array __pyx_mstate_global->__pyx_n_s_Int16Vector_to_array
#define __pyx_n_s_Int32Factorizer __pyx_mstate_global->__pyx_n_s_Int32Factorizer
#define __pyx_n_s_Int32Factorizer___reduce_cython __pyx_mstate_global->__pyx_n_s_Int32Factorizer___reduce_cython
#define __pyx_n_s_Int32Factorizer___setstate_cytho __pyx_mstate_global->__pyx_n_s_Int32Factorizer___setstate_cytho
#define __pyx_n_s_Int32Factorizer_factorize __pyx_mstate_global->__pyx_n_s_Int32Factorizer_factorize
#define __pyx_kp_u_Int32Factorizer_factorize_line_4 __pyx_mstate_global->__pyx_kp_u_Int32Factorizer_factorize_line_4
#define __pyx_n_s_Int32HashTable __pyx_mstate_global->__pyx_n_s_Int32HashTable
#define __pyx_n_s_Int32HashTable___reduce_cython __pyx_mstate_global->__pyx_n_s_Int32HashTable___reduce_cython
#define __pyx_n_s_Int32HashTable___setstate_cython __pyx_mstate_global->__pyx_n_s_Int32HashTable___setstate_cython
#define __pyx_n_s_Int32HashTable__unique __pyx_mstate_global->__pyx_n_s_Int32HashTable__unique
#define __pyx_n_s_Int32HashTable_factorize __pyx_mstate_global->__pyx_n_s_Int32HashTable_factorize
#define __pyx_n_s_Int32HashTable_get_item __pyx_mstate_global->__pyx_n_s_Int32HashTable_get_item
#define __pyx_n_s_Int32HashTable_get_labels __pyx_mstate_global->__pyx_n_s_Int32HashTable_get_labels
#define __pyx_n_s_Int32HashTable_get_na __pyx_mstate_global->__pyx_n_s_Int32HashTable_get_na
#define __pyx_n_s_Int32HashTable_get_state __pyx_mstate_global->__pyx_n_s_Int32HashTable_get_state
#define __pyx_n_s_Int32HashTable_lookup __pyx_mstate_global->__pyx_n_s_Int32HashTable_lookup
#define __pyx_n_s_Int32HashTable_map_locations __pyx_mstate_global->__pyx_n_s_Int32HashTable_map_locations
#define __pyx_n_s_Int32HashTable_set_item __pyx_mstate_global->__pyx_n_s_Int32HashTable_set_item
#define __pyx_n_s_Int32HashTable_set_na __pyx_mstate_global->__pyx_n_s_Int32HashTable_set_na
#define __pyx_n_s_Int32HashTable_sizeof __pyx_mstate_global->__pyx_n_s_Int32HashTable_sizeof
#define __pyx_n_s_Int32HashTable_unique __pyx_mstate_global->__pyx_n_s_Int32HashTable_unique
#define __pyx_n_s_Int32Vector __pyx_mstate_global->__pyx_n_s_Int32Vector
#define __pyx_n_s_Int32Vector___reduce_cython __pyx_mstate_global->__pyx_n_s_Int32Vector___reduce_cython
#define __pyx_n_s_Int32Vector___setstate_cython __pyx_mstate_global->__pyx_n_s_Int32Vector___setstate_cython
#define __pyx_n_s_Int32Vector_to_array __pyx_mstate_global->__pyx_n_s_Int32Vector_to_array
#define __pyx_n_s_Int64Factorizer __pyx_mstate_global->__pyx_n_s_Int64Factorizer
#define __pyx_n_s_Int64Factorizer___reduce_cython __pyx_mstate_global->__pyx_n_s_Int64Factorizer___reduce_cython
#define __pyx_n_s_Int64Factorizer___setstate_cytho __pyx_mstate_global->__pyx_n_s_Int64Factorizer___setstate_cytho
#define __pyx_n_s_Int64Factorizer_factorize __pyx_mstate_global->__pyx_n_s_Int64Factorizer_factorize
#define __pyx_kp_u_Int64Factorizer_factorize_line_3 __pyx_mstate_global->__pyx_kp_u_Int64Factorizer_factorize_line_3
#define __pyx_n_s_Int64HashTable __pyx_mstate_global->__pyx_n_s_Int64HashTable
#define __pyx_n_s_Int64HashTable___reduce_cython __pyx_mstate_global->__pyx_n_s_Int64HashTable___reduce_cython
#define __pyx_n_s_Int64HashTable___setstate_cython __pyx_mstate_global->__pyx_n_s_Int64HashTable___setstate_cython
#define __pyx_n_s_Int64HashTable__unique __pyx_mstate_global->__pyx_n_s_Int64HashTable__unique
#define __pyx_n_s_Int64HashTable_factorize __pyx_mstate_global->__pyx_n_s_Int64HashTable_factorize
#define __pyx_n_s_Int64HashTable_get_item __pyx_mstate_global->__pyx_n_s_Int64HashTable_get_item
#define __pyx_n_s_Int64HashTable_get_labels __pyx_mstate_global->__pyx_n_s_Int64HashTable_get_labels
#define __pyx_n_s_Int64HashTable_get_labels_groupb __pyx_mstate_global->__pyx_n_s_Int64HashTable_get_labels_groupb
#define __pyx_n_s_Int64HashTable_get_na __pyx_mstate_global->__pyx_n_s_Int64HashTable_get_na
#define __pyx_n_s_Int64HashTable_get_state __pyx_mstate_global->__pyx_n_s_Int64HashTable_get_state
#define __pyx_n_s_Int64HashTable_lookup __pyx_mstate_global->__pyx_n_s_Int64HashTable_lookup
#define __pyx_n_s_Int64HashTable_map_keys_to_value __pyx_mstate_global->__pyx_n_s_Int64HashTable_map_keys_to_value
#define __pyx_n_s_Int64HashTable_map_locations __pyx_mstate_global->__pyx_n_s_Int64HashTable_map_locations
#define __pyx_n_s_Int64HashTable_set_item __pyx_mstate_global->__pyx_n_s_Int64HashTable_set_item
#define __pyx_n_s_Int64HashTable_set_na __pyx_mstate_global->__pyx_n_s_Int64HashTable_set_na
#define __pyx_n_s_Int64HashTable_sizeof __pyx_mstate_global->__pyx_n_s_Int64HashTable_sizeof
#define __pyx_n_s_Int64HashTable_unique __pyx_mstate_global->__pyx_n_s_Int64HashTable_unique
#define __pyx_n_s_Int64Vector __pyx_mstate_global->__pyx_n_s_Int64Vector
#define __pyx_n_s_Int64Vector___reduce_cython __pyx_mstate_global->__pyx_n_s_Int64Vector___reduce_cython
#define __pyx_n_s_Int64Vector___setstate_cython __pyx_mstate_global->__pyx_n_s_Int64Vector___setstate_cython
#define __pyx_n_s_Int64Vector_to_array __pyx_mstate_global->__pyx_n_s_Int64Vector_to_array
#define __pyx_n_s_Int8Factorizer __pyx_mstate_global->__pyx_n_s_Int8Factorizer
#define __pyx_n_s_Int8Factorizer___reduce_cython __pyx_mstate_global->__pyx_n_s_Int8Factorizer___reduce_cython
#define __pyx_n_s_Int8Factorizer___setstate_cython __pyx_mstate_global->__pyx_n_s_Int8Factorizer___setstate_cython
#define __pyx_n_s_Int8Factorizer_factorize __pyx_mstate_global->__pyx_n_s_Int8Factorizer_factorize
#define __pyx_kp_u_Int8Factorizer_factorize_line_66 __pyx_mstate_global->__pyx_kp_u_Int8Factorizer_factorize_line_66
#define __pyx_n_s_Int8HashTable __pyx_mstate_global->__pyx_n_s_Int8HashTable
#define __pyx_n_s_Int8HashTable___reduce_cython __pyx_mstate_global->__pyx_n_s_Int8HashTable___reduce_cython
#define __pyx_n_s_Int8HashTable___setstate_cython __pyx_mstate_global->__pyx_n_s_Int8HashTable___setstate_cython
#define __pyx_n_s_Int8HashTable__unique __pyx_mstate_global->__pyx_n_s_Int8HashTable__unique
#define __pyx_n_s_Int8HashTable_factorize __pyx_mstate_global->__pyx_n_s_Int8HashTable_factorize
#define __pyx_n_s_Int8HashTable_get_item __pyx_mstate_global->__pyx_n_s_Int8HashTable_get_item
#define __pyx_n_s_Int8HashTable_get_labels __pyx_mstate_global->__pyx_n_s_Int8HashTable_get_labels
#define __pyx_n_s_Int8HashTable_get_na __pyx_mstate_global->__pyx_n_s_Int8HashTable_get_na
#define __pyx_n_s_Int8HashTable_get_state __pyx_mstate_global->__pyx_n_s_Int8HashTable_get_state
#define __pyx_n_s_Int8HashTable_lookup __pyx_mstate_global->__pyx_n_s_Int8HashTable_lookup
#define __pyx_n_s_Int8HashTable_map_locations __pyx_mstate_global->__pyx_n_s_Int8HashTable_map_locations
#define __pyx_n_s_Int8HashTable_set_item __pyx_mstate_global->__pyx_n_s_Int8HashTable_set_item
#define __pyx_n_s_Int8HashTable_set_na __pyx_mstate_global->__pyx_n_s_Int8HashTable_set_na
#define __pyx_n_s_Int8HashTable_sizeof __pyx_mstate_global->__pyx_n_s_Int8HashTable_sizeof
#define __pyx_n_s_Int8HashTable_unique __pyx_mstate_global->__pyx_n_s_Int8HashTable_unique
#define __pyx_n_s_Int8Vector __pyx_mstate_global->__pyx_n_s_Int8Vector
#define __pyx_n_s_Int8Vector___reduce_cython __pyx_mstate_global->__pyx_n_s_Int8Vector___reduce_cython
#define __pyx_n_s_Int8Vector___setstate_cython __pyx_mstate_global->__pyx_n_s_Int8Vector___setstate_cython
#define __pyx_n_s_Int8Vector_to_array __pyx_mstate_global->__pyx_n_s_Int8Vector_to_array
#define __pyx_n_s_IntpHashTable __pyx_mstate_global->__pyx_n_s_IntpHashTable
#define __pyx_kp_u_Invalid_mode_expected_c_or_fortr __pyx_mstate_global->__pyx_kp_u_Invalid_mode_expected_c_or_fortr
#define __pyx_kp_u_Invalid_shape_in_axis __pyx_mstate_global->__pyx_kp_u_Invalid_shape_in_axis
#define __pyx_n_s_KeyError __pyx_mstate_global->__pyx_n_s_KeyError
#define __pyx_n_s_MemoryError __pyx_mstate_global->__pyx_n_s_MemoryError
#define __pyx_kp_s_MemoryView_of_r_at_0x_x __pyx_mstate_global->__pyx_kp_s_MemoryView_of_r_at_0x_x
#define __pyx_kp_s_MemoryView_of_r_object __pyx_mstate_global->__pyx_kp_s_MemoryView_of_r_object
#define __pyx_n_u_NA __pyx_mstate_global->__pyx_n_u_NA
#define __pyx_kp_s_No_matching_signature_found __pyx_mstate_global->__pyx_kp_s_No_matching_signature_found
#define __pyx_n_s_None __pyx_mstate_global->__pyx_n_s_None
#define __pyx_n_s_NotImplementedError __pyx_mstate_global->__pyx_n_s_NotImplementedError
#define __pyx_n_b_O __pyx_mstate_global->__pyx_n_b_O
#define __pyx_n_s_ObjectFactorizer __pyx_mstate_global->__pyx_n_s_ObjectFactorizer
#define __pyx_n_s_ObjectFactorizer___reduce_cython __pyx_mstate_global->__pyx_n_s_ObjectFactorizer___reduce_cython
#define __pyx_n_s_ObjectFactorizer___setstate_cyth __pyx_mstate_global->__pyx_n_s_ObjectFactorizer___setstate_cyth
#define __pyx_n_s_ObjectFactorizer_factorize __pyx_mstate_global->__pyx_n_s_ObjectFactorizer_factorize
#define __pyx_kp_u_ObjectFactorizer_factorize_line __pyx_mstate_global->__pyx_kp_u_ObjectFactorizer_factorize_line
#define __pyx_n_s_ObjectVector __pyx_mstate_global->__pyx_n_s_ObjectVector
#define __pyx_n_s_ObjectVector___reduce_cython __pyx_mstate_global->__pyx_n_s_ObjectVector___reduce_cython
#define __pyx_n_s_ObjectVector___setstate_cython __pyx_mstate_global->__pyx_n_s_ObjectVector___setstate_cython
#define __pyx_n_s_ObjectVector_to_array __pyx_mstate_global->__pyx_n_s_ObjectVector_to_array
#define __pyx_kp_u_Out_of_bounds_on_buffer_access_a __pyx_mstate_global->__pyx_kp_u_Out_of_bounds_on_buffer_access_a
#define __pyx_n_s_PickleError __pyx_mstate_global->__pyx_n_s_PickleError
#define __pyx_n_s_PyObjectHashTable __pyx_mstate_global->__pyx_n_s_PyObjectHashTable
#define __pyx_n_s_PyObjectHashTable___reduce_cytho __pyx_mstate_global->__pyx_n_s_PyObjectHashTable___reduce_cytho
#define __pyx_n_s_PyObjectHashTable___setstate_cyt __pyx_mstate_global->__pyx_n_s_PyObjectHashTable___setstate_cyt
#define __pyx_n_s_PyObjectHashTable__unique __pyx_mstate_global->__pyx_n_s_PyObjectHashTable__unique
#define __pyx_n_s_PyObjectHashTable_factorize __pyx_mstate_global->__pyx_n_s_PyObjectHashTable_factorize
#define __pyx_n_s_PyObjectHashTable_get_item __pyx_mstate_global->__pyx_n_s_PyObjectHashTable_get_item
#define __pyx_n_s_PyObjectHashTable_get_labels __pyx_mstate_global->__pyx_n_s_PyObjectHashTable_get_labels
#define __pyx_n_s_PyObjectHashTable_get_state __pyx_mstate_global->__pyx_n_s_PyObjectHashTable_get_state
#define __pyx_n_s_PyObjectHashTable_lookup __pyx_mstate_global->__pyx_n_s_PyObjectHashTable_lookup
#define __pyx_n_s_PyObjectHashTable_map_locations __pyx_mstate_global->__pyx_n_s_PyObjectHashTable_map_locations
#define __pyx_n_s_PyObjectHashTable_set_item __pyx_mstate_global->__pyx_n_s_PyObjectHashTable_set_item
#define __pyx_n_s_PyObjectHashTable_sizeof __pyx_mstate_global->__pyx_n_s_PyObjectHashTable_sizeof
#define __pyx_n_s_PyObjectHashTable_unique __pyx_mstate_global->__pyx_n_s_PyObjectHashTable_unique
#define __pyx_kp_u_Returns_ndarray_intp_t_Examples __pyx_mstate_global->__pyx_kp_u_Returns_ndarray_intp_t_Examples
#define __pyx_kp_u_Returns_ndarray_intp_t_Examples_10 __pyx_mstate_global->__pyx_kp_u_Returns_ndarray_intp_t_Examples_10
#define __pyx_kp_u_Returns_ndarray_intp_t_Examples_11 __pyx_mstate_global->__pyx_kp_u_Returns_ndarray_intp_t_Examples_11
#define __pyx_kp_u_Returns_ndarray_intp_t_Examples_12 __pyx_mstate_global->__pyx_kp_u_Returns_ndarray_intp_t_Examples_12
#define __pyx_kp_u_Returns_ndarray_intp_t_Examples_2 __pyx_mstate_global->__pyx_kp_u_Returns_ndarray_intp_t_Examples_2
#define __pyx_kp_u_Returns_ndarray_intp_t_Examples_3 __pyx_mstate_global->__pyx_kp_u_Returns_ndarray_intp_t_Examples_3
#define __pyx_kp_u_Returns_ndarray_intp_t_Examples_4 __pyx_mstate_global->__pyx_kp_u_Returns_ndarray_intp_t_Examples_4
#define __pyx_kp_u_Returns_ndarray_intp_t_Examples_5 __pyx_mstate_global->__pyx_kp_u_Returns_ndarray_intp_t_Examples_5
#define __pyx_kp_u_Returns_ndarray_intp_t_Examples_6 __pyx_mstate_global->__pyx_kp_u_Returns_ndarray_intp_t_Examples_6
#define __pyx_kp_u_Returns_ndarray_intp_t_Examples_7 __pyx_mstate_global->__pyx_kp_u_Returns_ndarray_intp_t_Examples_7
#define __pyx_kp_u_Returns_ndarray_intp_t_Examples_8 __pyx_mstate_global->__pyx_kp_u_Returns_ndarray_intp_t_Examples_8
#define __pyx_kp_u_Returns_ndarray_intp_t_Examples_9 __pyx_mstate_global->__pyx_kp_u_Returns_ndarray_intp_t_Examples_9
#define __pyx_kp_u_Returns_np_ndarray_np_intp_Exam __pyx_mstate_global->__pyx_kp_u_Returns_np_ndarray_np_intp_Exam
#define __pyx_n_s_SIZE_HINT_LIMIT __pyx_mstate_global->__pyx_n_s_SIZE_HINT_LIMIT
#define __pyx_n_s_Sequence __pyx_mstate_global->__pyx_n_s_Sequence
#define __pyx_kp_s_Step_may_not_be_zero_axis_d __pyx_mstate_global->__pyx_kp_s_Step_may_not_be_zero_axis_d
#define __pyx_n_s_StringHashTable __pyx_mstate_global->__pyx_n_s_StringHashTable
#define __pyx_n_s_StringHashTable___reduce_cython __pyx_mstate_global->__pyx_n_s_StringHashTable___reduce_cython
#define __pyx_n_s_StringHashTable___setstate_cytho __pyx_mstate_global->__pyx_n_s_StringHashTable___setstate_cytho
#define __pyx_n_s_StringHashTable__unique __pyx_mstate_global->__pyx_n_s_StringHashTable__unique
#define __pyx_n_s_StringHashTable_factorize __pyx_mstate_global->__pyx_n_s_StringHashTable_factorize
#define __pyx_n_s_StringHashTable_get_indexer __pyx_mstate_global->__pyx_n_s_StringHashTable_get_indexer
#define __pyx_n_s_StringHashTable_get_item __pyx_mstate_global->__pyx_n_s_StringHashTable_get_item
#define __pyx_n_s_StringHashTable_get_labels __pyx_mstate_global->__pyx_n_s_StringHashTable_get_labels
#define __pyx_n_s_StringHashTable_get_state __pyx_mstate_global->__pyx_n_s_StringHashTable_get_state
#define __pyx_n_s_StringHashTable_lookup __pyx_mstate_global->__pyx_n_s_StringHashTable_lookup
#define __pyx_n_s_StringHashTable_map_locations __pyx_mstate_global->__pyx_n_s_StringHashTable_map_locations
#define __pyx_n_s_StringHashTable_set_item __pyx_mstate_global->__pyx_n_s_StringHashTable_set_item
#define __pyx_n_s_StringHashTable_sizeof __pyx_mstate_global->__pyx_n_s_StringHashTable_sizeof
#define __pyx_n_s_StringHashTable_unique __pyx_mstate_global->__pyx_n_s_StringHashTable_unique
#define __pyx_n_s_StringVector __pyx_mstate_global->__pyx_n_s_StringVector
#define __pyx_n_s_StringVector___reduce_cython __pyx_mstate_global->__pyx_n_s_StringVector___reduce_cython
#define __pyx_n_s_StringVector___setstate_cython __pyx_mstate_global->__pyx_n_s_StringVector___setstate_cython
#define __pyx_n_s_StringVector_to_array __pyx_mstate_global->__pyx_n_s_StringVector_to_array
#define __pyx_n_s_TypeError __pyx_mstate_global->__pyx_n_s_TypeError
#define __pyx_n_s_UInt16Factorizer __pyx_mstate_global->__pyx_n_s_UInt16Factorizer
#define __pyx_n_s_UInt16Factorizer___reduce_cython __pyx_mstate_global->__pyx_n_s_UInt16Factorizer___reduce_cython
#define __pyx_n_s_UInt16Factorizer___setstate_cyth __pyx_mstate_global->__pyx_n_s_UInt16Factorizer___setstate_cyth
#define __pyx_n_s_UInt16Factorizer_factorize __pyx_mstate_global->__pyx_n_s_UInt16Factorizer_factorize
#define __pyx_kp_u_UInt16Factorizer_factorize_line __pyx_mstate_global->__pyx_kp_u_UInt16Factorizer_factorize_line
#define __pyx_n_s_UInt16HashTable __pyx_mstate_global->__pyx_n_s_UInt16HashTable
#define __pyx_n_s_UInt16HashTable___reduce_cython __pyx_mstate_global->__pyx_n_s_UInt16HashTable___reduce_cython
#define __pyx_n_s_UInt16HashTable___setstate_cytho __pyx_mstate_global->__pyx_n_s_UInt16HashTable___setstate_cytho
#define __pyx_n_s_UInt16HashTable__unique __pyx_mstate_global->__pyx_n_s_UInt16HashTable__unique
#define __pyx_n_s_UInt16HashTable_factorize __pyx_mstate_global->__pyx_n_s_UInt16HashTable_factorize
#define __pyx_n_s_UInt16HashTable_get_item __pyx_mstate_global->__pyx_n_s_UInt16HashTable_get_item
#define __pyx_n_s_UInt16HashTable_get_labels __pyx_mstate_global->__pyx_n_s_UInt16HashTable_get_labels
#define __pyx_n_s_UInt16HashTable_get_na __pyx_mstate_global->__pyx_n_s_UInt16HashTable_get_na
#define __pyx_n_s_UInt16HashTable_get_state __pyx_mstate_global->__pyx_n_s_UInt16HashTable_get_state
#define __pyx_n_s_UInt16HashTable_lookup __pyx_mstate_global->__pyx_n_s_UInt16HashTable_lookup
#define __pyx_n_s_UInt16HashTable_map_locations __pyx_mstate_global->__pyx_n_s_UInt16HashTable_map_locations
#define __pyx_n_s_UInt16HashTable_set_item __pyx_mstate_global->__pyx_n_s_UInt16HashTable_set_item
#define __pyx_n_s_UInt16HashTable_set_na __pyx_mstate_global->__pyx_n_s_UInt16HashTable_set_na
#define __pyx_n_s_UInt16HashTable_sizeof __pyx_mstate_global->__pyx_n_s_UInt16HashTable_sizeof
#define __pyx_n_s_UInt16HashTable_unique __pyx_mstate_global->__pyx_n_s_UInt16HashTable_unique
#define __pyx_n_s_UInt16Vector __pyx_mstate_global->__pyx_n_s_UInt16Vector
#define __pyx_n_s_UInt16Vector___reduce_cython __pyx_mstate_global->__pyx_n_s_UInt16Vector___reduce_cython
#define __pyx_n_s_UInt16Vector___setstate_cython __pyx_mstate_global->__pyx_n_s_UInt16Vector___setstate_cython
#define __pyx_n_s_UInt16Vector_to_array __pyx_mstate_global->__pyx_n_s_UInt16Vector_to_array
#define __pyx_n_s_UInt32Factorizer __pyx_mstate_global->__pyx_n_s_UInt32Factorizer
#define __pyx_n_s_UInt32Factorizer___reduce_cython __pyx_mstate_global->__pyx_n_s_UInt32Factorizer___reduce_cython
#define __pyx_n_s_UInt32Factorizer___setstate_cyth __pyx_mstate_global->__pyx_n_s_UInt32Factorizer___setstate_cyth
#define __pyx_n_s_UInt32Factorizer_factorize __pyx_mstate_global->__pyx_n_s_UInt32Factorizer_factorize
#define __pyx_kp_u_UInt32Factorizer_factorize_line __pyx_mstate_global->__pyx_kp_u_UInt32Factorizer_factorize_line
#define __pyx_n_s_UInt32HashTable __pyx_mstate_global->__pyx_n_s_UInt32HashTable
#define __pyx_n_s_UInt32HashTable___reduce_cython __pyx_mstate_global->__pyx_n_s_UInt32HashTable___reduce_cython
#define __pyx_n_s_UInt32HashTable___setstate_cytho __pyx_mstate_global->__pyx_n_s_UInt32HashTable___setstate_cytho
#define __pyx_n_s_UInt32HashTable__unique __pyx_mstate_global->__pyx_n_s_UInt32HashTable__unique
#define __pyx_n_s_UInt32HashTable_factorize __pyx_mstate_global->__pyx_n_s_UInt32HashTable_factorize
#define __pyx_n_s_UInt32HashTable_get_item __pyx_mstate_global->__pyx_n_s_UInt32HashTable_get_item
#define __pyx_n_s_UInt32HashTable_get_labels __pyx_mstate_global->__pyx_n_s_UInt32HashTable_get_labels
#define __pyx_n_s_UInt32HashTable_get_na __pyx_mstate_global->__pyx_n_s_UInt32HashTable_get_na
#define __pyx_n_s_UInt32HashTable_get_state __pyx_mstate_global->__pyx_n_s_UInt32HashTable_get_state
#define __pyx_n_s_UInt32HashTable_lookup __pyx_mstate_global->__pyx_n_s_UInt32HashTable_lookup
#define __pyx_n_s_UInt32HashTable_map_locations __pyx_mstate_global->__pyx_n_s_UInt32HashTable_map_locations
#define __pyx_n_s_UInt32HashTable_set_item __pyx_mstate_global->__pyx_n_s_UInt32HashTable_set_item
#define __pyx_n_s_UInt32HashTable_set_na __pyx_mstate_global->__pyx_n_s_UInt32HashTable_set_na
#define __pyx_n_s_UInt32HashTable_sizeof __pyx_mstate_global->__pyx_n_s_UInt32HashTable_sizeof
#define __pyx_n_s_UInt32HashTable_unique __pyx_mstate_global->__pyx_n_s_UInt32HashTable_unique
#define __pyx_n_s_UInt32Vector __pyx_mstate_global->__pyx_n_s_UInt32Vector
#define __pyx_n_s_UInt32Vector___reduce_cython __pyx_mstate_global->__pyx_n_s_UInt32Vector___reduce_cython
#define __pyx_n_s_UInt32Vector___setstate_cython __pyx_mstate_global->__pyx_n_s_UInt32Vector___setstate_cython
#define __pyx_n_s_UInt32Vector_to_array __pyx_mstate_global->__pyx_n_s_UInt32Vector_to_array
#define __pyx_n_s_UInt64Factorizer __pyx_mstate_global->__pyx_n_s_UInt64Factorizer
#define __pyx_n_s_UInt64Factorizer___reduce_cython __pyx_mstate_global->__pyx_n_s_UInt64Factorizer___reduce_cython
#define __pyx_n_s_UInt64Factorizer___setstate_cyth __pyx_mstate_global->__pyx_n_s_UInt64Factorizer___setstate_cyth
#define __pyx_n_s_UInt64Factorizer_factorize __pyx_mstate_global->__pyx_n_s_UInt64Factorizer_factorize
#define __pyx_kp_u_UInt64Factorizer_factorize_line __pyx_mstate_global->__pyx_kp_u_UInt64Factorizer_factorize_line
#define __pyx_n_s_UInt64HashTable __pyx_mstate_global->__pyx_n_s_UInt64HashTable
#define __pyx_n_s_UInt64HashTable___reduce_cython __pyx_mstate_global->__pyx_n_s_UInt64HashTable___reduce_cython
#define __pyx_n_s_UInt64HashTable___setstate_cytho __pyx_mstate_global->__pyx_n_s_UInt64HashTable___setstate_cytho
#define __pyx_n_s_UInt64HashTable__unique __pyx_mstate_global->__pyx_n_s_UInt64HashTable__unique
#define __pyx_n_s_UInt64HashTable_factorize __pyx_mstate_global->__pyx_n_s_UInt64HashTable_factorize
#define __pyx_n_s_UInt64HashTable_get_item __pyx_mstate_global->__pyx_n_s_UInt64HashTable_get_item
#define __pyx_n_s_UInt64HashTable_get_labels __pyx_mstate_global->__pyx_n_s_UInt64HashTable_get_labels
#define __pyx_n_s_UInt64HashTable_get_na __pyx_mstate_global->__pyx_n_s_UInt64HashTable_get_na
#define __pyx_n_s_UInt64HashTable_get_state __pyx_mstate_global->__pyx_n_s_UInt64HashTable_get_state
#define __pyx_n_s_UInt64HashTable_lookup __pyx_mstate_global->__pyx_n_s_UInt64HashTable_lookup
#define __pyx_n_s_UInt64HashTable_map_locations __pyx_mstate_global->__pyx_n_s_UInt64HashTable_map_locations
#define __pyx_n_s_UInt64HashTable_set_item __pyx_mstate_global->__pyx_n_s_UInt64HashTable_set_item
#define __pyx_n_s_UInt64HashTable_set_na __pyx_mstate_global->__pyx_n_s_UInt64HashTable_set_na
#define __pyx_n_s_UInt64HashTable_sizeof __pyx_mstate_global->__pyx_n_s_UInt64HashTable_sizeof
#define __pyx_n_s_UInt64HashTable_unique __pyx_mstate_global->__pyx_n_s_UInt64HashTable_unique
#define __pyx_n_s_UInt64Vector __pyx_mstate_global->__pyx_n_s_UInt64Vector
#define __pyx_n_s_UInt64Vector___reduce_cython __pyx_mstate_global->__pyx_n_s_UInt64Vector___reduce_cython
#define __pyx_n_s_UInt64Vector___setstate_cython __pyx_mstate_global->__pyx_n_s_UInt64Vector___setstate_cython
#define __pyx_n_s_UInt64Vector_to_array __pyx_mstate_global->__pyx_n_s_UInt64Vector_to_array
#define __pyx_n_s_UInt8Factorizer __pyx_mstate_global->__pyx_n_s_UInt8Factorizer
#define __pyx_n_s_UInt8Factorizer___reduce_cython __pyx_mstate_global->__pyx_n_s_UInt8Factorizer___reduce_cython
#define __pyx_n_s_UInt8Factorizer___setstate_cytho __pyx_mstate_global->__pyx_n_s_UInt8Factorizer___setstate_cytho
#define __pyx_n_s_UInt8Factorizer_factorize __pyx_mstate_global->__pyx_n_s_UInt8Factorizer_factorize
#define __pyx_kp_u_UInt8Factorizer_factorize_line_6 __pyx_mstate_global->__pyx_kp_u_UInt8Factorizer_factorize_line_6
#define __pyx_n_s_UInt8HashTable __pyx_mstate_global->__pyx_n_s_UInt8HashTable
#define __pyx_n_s_UInt8HashTable___reduce_cython __pyx_mstate_global->__pyx_n_s_UInt8HashTable___reduce_cython
#define __pyx_n_s_UInt8HashTable___setstate_cython __pyx_mstate_global->__pyx_n_s_UInt8HashTable___setstate_cython
#define __pyx_n_s_UInt8HashTable__unique __pyx_mstate_global->__pyx_n_s_UInt8HashTable__unique
#define __pyx_n_s_UInt8HashTable_factorize __pyx_mstate_global->__pyx_n_s_UInt8HashTable_factorize
#define __pyx_n_s_UInt8HashTable_get_item __pyx_mstate_global->__pyx_n_s_UInt8HashTable_get_item
#define __pyx_n_s_UInt8HashTable_get_labels __pyx_mstate_global->__pyx_n_s_UInt8HashTable_get_labels
#define __pyx_n_s_UInt8HashTable_get_na __pyx_mstate_global->__pyx_n_s_UInt8HashTable_get_na
#define __pyx_n_s_UInt8HashTable_get_state __pyx_mstate_global->__pyx_n_s_UInt8HashTable_get_state
#define __pyx_n_s_UInt8HashTable_lookup __pyx_mstate_global->__pyx_n_s_UInt8HashTable_lookup
#define __pyx_n_s_UInt8HashTable_map_locations __pyx_mstate_global->__pyx_n_s_UInt8HashTable_map_locations
#define __pyx_n_s_UInt8HashTable_set_item __pyx_mstate_global->__pyx_n_s_UInt8HashTable_set_item
#define __pyx_n_s_UInt8HashTable_set_na __pyx_mstate_global->__pyx_n_s_UInt8HashTable_set_na
#define __pyx_n_s_UInt8HashTable_sizeof __pyx_mstate_global->__pyx_n_s_UInt8HashTable_sizeof
#define __pyx_n_s_UInt8HashTable_unique __pyx_mstate_global->__pyx_n_s_UInt8HashTable_unique
#define __pyx_n_s_UInt8Vector __pyx_mstate_global->__pyx_n_s_UInt8Vector
#define __pyx_n_s_UInt8Vector___reduce_cython __pyx_mstate_global->__pyx_n_s_UInt8Vector___reduce_cython
#define __pyx_n_s_UInt8Vector___setstate_cython __pyx_mstate_global->__pyx_n_s_UInt8Vector___setstate_cython
#define __pyx_n_s_UInt8Vector_to_array __pyx_mstate_global->__pyx_n_s_UInt8Vector_to_array
#define __pyx_kp_s_Unable_to_convert_item_to_object __pyx_mstate_global->__pyx_kp_s_Unable_to_convert_item_to_object
#define __pyx_n_s_UnicodeEncodeError __pyx_mstate_global->__pyx_n_s_UnicodeEncodeError
#define __pyx_n_s_ValueError __pyx_mstate_global->__pyx_n_s_ValueError
#define __pyx_n_s_Vector __pyx_mstate_global->__pyx_n_s_Vector
#define __pyx_n_s_Vector___reduce_cython __pyx_mstate_global->__pyx_n_s_Vector___reduce_cython
#define __pyx_n_s_Vector___setstate_cython __pyx_mstate_global->__pyx_n_s_Vector___setstate_cython
#define __pyx_n_s_View_MemoryView __pyx_mstate_global->__pyx_n_s_View_MemoryView
#define __pyx_n_s__191 __pyx_mstate_global->__pyx_n_s__191
#define __pyx_kp_u__2 __pyx_mstate_global->__pyx_kp_u__2
#define __pyx_n_s__3 __pyx_mstate_global->__pyx_n_s__3
#define __pyx_n_s__490 __pyx_mstate_global->__pyx_n_s__490
#define __pyx_kp_u__6 __pyx_mstate_global->__pyx_kp_u__6
#define __pyx_kp_s__69 __pyx_mstate_global->__pyx_kp_s__69
#define __pyx_kp_u__7 __pyx_mstate_global->__pyx_kp_u__7
#define __pyx_kp_s__70 __pyx_mstate_global->__pyx_kp_s__70
#define __pyx_kp_u__70 __pyx_mstate_global->__pyx_kp_u__70
#define __pyx_kp_s__86 __pyx_mstate_global->__pyx_kp_s__86
#define __pyx_n_s_a __pyx_mstate_global->__pyx_n_s_a
#define __pyx_n_s_abc __pyx_mstate_global->__pyx_n_s_abc
#define __pyx_n_s_allocate_buffer __pyx_mstate_global->__pyx_n_s_allocate_buffer
#define __pyx_kp_u_and __pyx_mstate_global->__pyx_kp_u_and
#define __pyx_n_s_args __pyx_mstate_global->__pyx_n_s_args
#define __pyx_n_s_argsort __pyx_mstate_global->__pyx_n_s_argsort
#define __pyx_n_s_arr __pyx_mstate_global->__pyx_n_s_arr
#define __pyx_n_s_arr_uniques __pyx_mstate_global->__pyx_n_s_arr_uniques
#define __pyx_n_s_asarray __pyx_mstate_global->__pyx_n_s_asarray
#define __pyx_n_s_asyncio_coroutines __pyx_mstate_global->__pyx_n_s_asyncio_coroutines
#define __pyx_n_s_b __pyx_mstate_global->__pyx_n_s_b
#define __pyx_n_s_base __pyx_mstate_global->__pyx_n_s_base
#define __pyx_n_s_bool __pyx_mstate_global->__pyx_n_s_bool
#define __pyx_n_u_bool __pyx_mstate_global->__pyx_n_u_bool
#define __pyx_n_s_bool_2 __pyx_mstate_global->__pyx_n_s_bool_2
#define __pyx_n_s_c __pyx_mstate_global->__pyx_n_s_c
#define __pyx_n_u_c __pyx_mstate_global->__pyx_n_u_c
#define __pyx_n_s_class __pyx_mstate_global->__pyx_n_s_class
#define __pyx_n_s_class_getitem __pyx_mstate_global->__pyx_n_s_class_getitem
#define __pyx_n_s_cline_in_traceback __pyx_mstate_global->__pyx_n_s_cline_in_traceback
#define __pyx_n_s_collections __pyx_mstate_global->__pyx_n_s_collections
#define __pyx_kp_s_collections_abc __pyx_mstate_global->__pyx_kp_s_collections_abc
#define __pyx_n_s_complex128 __pyx_mstate_global->__pyx_n_s_complex128
#define __pyx_n_s_complex64 __pyx_mstate_global->__pyx_n_s_complex64
#define __pyx_kp_s_contiguous_and_direct __pyx_mstate_global->__pyx_kp_s_contiguous_and_direct
#define __pyx_kp_s_contiguous_and_indirect __pyx_mstate_global->__pyx_kp_s_contiguous_and_indirect
#define __pyx_n_s_count __pyx_mstate_global->__pyx_n_s_count
#define __pyx_n_s_count_prior __pyx_mstate_global->__pyx_n_s_count_prior
#define __pyx_n_s_counts __pyx_mstate_global->__pyx_n_s_counts
#define __pyx_n_s_deep __pyx_mstate_global->__pyx_n_s_deep
#define __pyx_n_s_defaults __pyx_mstate_global->__pyx_n_s_defaults
#define __pyx_n_s_dict __pyx_mstate_global->__pyx_n_s_dict
#define __pyx_n_s_dict_2 __pyx_mstate_global->__pyx_n_s_dict_2
#define __pyx_kp_s_dict_str_int __pyx_mstate_global->__pyx_kp_s_dict_str_int
#define __pyx_kp_u_disable __pyx_mstate_global->__pyx_kp_u_disable
#define __pyx_kp_s_double_complex __pyx_mstate_global->__pyx_kp_s_double_complex
#define __pyx_n_s_dropna __pyx_mstate_global->__pyx_n_s_dropna
#define __pyx_n_s_dtype __pyx_mstate_global->__pyx_n_s_dtype
#define __pyx_n_s_dtype_is_object __pyx_mstate_global->__pyx_n_s_dtype_is_object
#define __pyx_n_s_duplicated __pyx_mstate_global->__pyx_n_s_duplicated
#define __pyx_n_s_empty __pyx_mstate_global->__pyx_n_s_empty
#define __pyx_kp_u_enable __pyx_mstate_global->__pyx_kp_u_enable
#define __pyx_n_s_encode __pyx_mstate_global->__pyx_n_s_encode
#define __pyx_n_s_enumerate __pyx_mstate_global->__pyx_n_s_enumerate
#define __pyx_n_s_error __pyx_mstate_global->__pyx_n_s_error
#define __pyx_kp_u_external_reference_but_Vector_re __pyx_mstate_global->__pyx_kp_u_external_reference_but_Vector_re
#define __pyx_kp_u_external_reference_to_result_mas __pyx_mstate_global->__pyx_kp_u_external_reference_to_result_mas
#define __pyx_kp_u_external_reference_to_uniques_he __pyx_mstate_global->__pyx_kp_u_external_reference_to_uniques_he
#define __pyx_n_s_factorize __pyx_mstate_global->__pyx_n_s_factorize
#define __pyx_n_u_first __pyx_mstate_global->__pyx_n_u_first
#define __pyx_n_s_flags __pyx_mstate_global->__pyx_n_s_flags
#define __pyx_n_s_float32 __pyx_mstate_global->__pyx_n_s_float32
#define __pyx_n_s_float32_t __pyx_mstate_global->__pyx_n_s_float32_t
#define __pyx_n_s_float64 __pyx_mstate_global->__pyx_n_s_float64
#define __pyx_n_s_float64_t __pyx_mstate_global->__pyx_n_s_float64_t
#define __pyx_kp_s_float_complex __pyx_mstate_global->__pyx_kp_s_float_complex
#define __pyx_n_s_for_flags __pyx_mstate_global->__pyx_n_s_for_flags
#define __pyx_n_s_for_pairs __pyx_mstate_global->__pyx_n_s_for_pairs
#define __pyx_n_s_format __pyx_mstate_global->__pyx_n_s_format
#define __pyx_n_s_fortran __pyx_mstate_global->__pyx_n_s_fortran
#define __pyx_n_u_fortran __pyx_mstate_global->__pyx_n_u_fortran
#define __pyx_n_s_fused_sigindex __pyx_mstate_global->__pyx_n_s_fused_sigindex
#define __pyx_kp_u_gc __pyx_mstate_global->__pyx_kp_u_gc
#define __pyx_n_s_get __pyx_mstate_global->__pyx_n_s_get
#define __pyx_n_s_get_count __pyx_mstate_global->__pyx_n_s_get_count
#define __pyx_n_s_get_hashtable_trace_domain __pyx_mstate_global->__pyx_n_s_get_hashtable_trace_domain
#define __pyx_n_s_get_indexer __pyx_mstate_global->__pyx_n_s_get_indexer
#define __pyx_n_s_get_item __pyx_mstate_global->__pyx_n_s_get_item
#define __pyx_n_s_get_labels __pyx_mstate_global->__pyx_n_s_get_labels
#define __pyx_n_s_get_labels_groupby __pyx_mstate_global->__pyx_n_s_get_labels_groupby
#define __pyx_n_s_get_na __pyx_mstate_global->__pyx_n_s_get_na
#define __pyx_n_s_get_state __pyx_mstate_global->__pyx_n_s_get_state
#define __pyx_n_s_getstate __pyx_mstate_global->__pyx_n_s_getstate
#define __pyx_kp_u_got __pyx_mstate_global->__pyx_kp_u_got
#define __pyx_kp_u_got_differing_extents_in_dimensi __pyx_mstate_global->__pyx_kp_u_got_differing_extents_in_dimensi
#define __pyx_n_s_i __pyx_mstate_global->__pyx_n_s_i
#define __pyx_n_s_id __pyx_mstate_global->__pyx_n_s_id
#define __pyx_n_s_idx __pyx_mstate_global->__pyx_n_s_idx
#define __pyx_n_s_ignore_na __pyx_mstate_global->__pyx_n_s_ignore_na
#define __pyx_n_s_imag __pyx_mstate_global->__pyx_n_s_imag
#define __pyx_n_s_import __pyx_mstate_global->__pyx_n_s_import
#define __pyx_n_s_index __pyx_mstate_global->__pyx_n_s_index
#define __pyx_n_s_initializing __pyx_mstate_global->__pyx_n_s_initializing
#define __pyx_n_s_int __pyx_mstate_global->__pyx_n_s_int
#define __pyx_n_s_int16 __pyx_mstate_global->__pyx_n_s_int16
#define __pyx_n_s_int16_t __pyx_mstate_global->__pyx_n_s_int16_t
#define __pyx_n_s_int32 __pyx_mstate_global->__pyx_n_s_int32
#define __pyx_n_s_int32_t __pyx_mstate_global->__pyx_n_s_int32_t
#define __pyx_n_s_int64 __pyx_mstate_global->__pyx_n_s_int64
#define __pyx_n_s_int64_t __pyx_mstate_global->__pyx_n_s_int64_t
#define __pyx_n_s_int8 __pyx_mstate_global->__pyx_n_s_int8
#define __pyx_n_s_int8_t __pyx_mstate_global->__pyx_n_s_int8_t
#define __pyx_n_s_intp __pyx_mstate_global->__pyx_n_s_intp
#define __pyx_n_s_is_coroutine __pyx_mstate_global->__pyx_n_s_is_coroutine
#define __pyx_kp_u_isenabled __pyx_mstate_global->__pyx_kp_u_isenabled
#define __pyx_n_s_ismember __pyx_mstate_global->__pyx_n_s_ismember
#define __pyx_n_s_itemsize __pyx_mstate_global->__pyx_n_s_itemsize
#define __pyx_kp_s_itemsize_0_for_cython_array __pyx_mstate_global->__pyx_kp_s_itemsize_0_for_cython_array
#define __pyx_n_s_j __pyx_mstate_global->__pyx_n_s_j
#define __pyx_n_s_k __pyx_mstate_global->__pyx_n_s_k
#define __pyx_n_s_keep __pyx_mstate_global->__pyx_n_s_keep
#define __pyx_kp_u_keep_must_be_either_first_last_o __pyx_mstate_global->__pyx_kp_u_keep_must_be_either_first_last_o
#define __pyx_n_s_key __pyx_mstate_global->__pyx_n_s_key
#define __pyx_n_s_keys __pyx_mstate_global->__pyx_n_s_keys
#define __pyx_n_s_kind __pyx_mstate_global->__pyx_n_s_kind
#define __pyx_n_s_kwargs __pyx_mstate_global->__pyx_n_s_kwargs
#define __pyx_n_s_labels __pyx_mstate_global->__pyx_n_s_labels
#define __pyx_n_u_last __pyx_mstate_global->__pyx_n_u_last
#define __pyx_n_s_locs __pyx_mstate_global->__pyx_n_s_locs
#define __pyx_n_s_lookup __pyx_mstate_global->__pyx_n_s_lookup
#define __pyx_n_s_main __pyx_mstate_global->__pyx_n_s_main
#define __pyx_n_s_map_keys_to_values __pyx_mstate_global->__pyx_n_s_map_keys_to_values
#define __pyx_n_s_map_locations __pyx_mstate_global->__pyx_n_s_map_locations
#define __pyx_n_s_mask __pyx_mstate_global->__pyx_n_s_mask
#define __pyx_kp_u_mask_not_supported_for_ObjectFac __pyx_mstate_global->__pyx_kp_u_mask_not_supported_for_ObjectFac
#define __pyx_n_s_mask_values __pyx_mstate_global->__pyx_n_s_mask_values
#define __pyx_n_s_max_count __pyx_mstate_global->__pyx_n_s_max_count
#define __pyx_n_s_memview __pyx_mstate_global->__pyx_n_s_memview
#define __pyx_n_s_mode __pyx_mstate_global->__pyx_n_s_mode
#define __pyx_n_s_modes __pyx_mstate_global->__pyx_n_s_modes
#define __pyx_n_s_n __pyx_mstate_global->__pyx_n_s_n
#define __pyx_n_u_n_buckets __pyx_mstate_global->__pyx_n_u_n_buckets
#define __pyx_n_u_n_occupied __pyx_mstate_global->__pyx_n_u_n_occupied
#define __pyx_n_s_na_position __pyx_mstate_global->__pyx_n_s_na_position
#define __pyx_n_s_na_sentinel __pyx_mstate_global->__pyx_n_s_na_sentinel
#define __pyx_n_s_na_string_sentinel __pyx_mstate_global->__pyx_n_s_na_string_sentinel
#define __pyx_n_s_na_value __pyx_mstate_global->__pyx_n_s_na_value
#define __pyx_n_s_na_value2 __pyx_mstate_global->__pyx_n_s_na_value2
#define __pyx_n_s_name __pyx_mstate_global->__pyx_n_s_name
#define __pyx_n_s_name_2 __pyx_mstate_global->__pyx_n_s_name_2
#define __pyx_n_u_nan __pyx_mstate_global->__pyx_n_u_nan
#define __pyx_n_s_ndarray __pyx_mstate_global->__pyx_n_s_ndarray
#define __pyx_n_s_ndim __pyx_mstate_global->__pyx_n_s_ndim
#define __pyx_n_s_new __pyx_mstate_global->__pyx_n_s_new
#define __pyx_n_s_nkeys __pyx_mstate_global->__pyx_n_s_nkeys
#define __pyx_kp_s_no_default___reduce___due_to_non __pyx_mstate_global->__pyx_kp_s_no_default___reduce___due_to_non
#define __pyx_n_s_np __pyx_mstate_global->__pyx_n_s_np
#define __pyx_kp_s_np_ndarray __pyx_mstate_global->__pyx_kp_s_np_ndarray
#define __pyx_n_s_numpy __pyx_mstate_global->__pyx_n_s_numpy
#define __pyx_kp_u_numpy_core_multiarray_failed_to __pyx_mstate_global->__pyx_kp_u_numpy_core_multiarray_failed_to
#define __pyx_kp_u_numpy_core_umath_failed_to_impor __pyx_mstate_global->__pyx_kp_u_numpy_core_umath_failed_to_impor
#define __pyx_n_s_obj __pyx_mstate_global->__pyx_n_s_obj
#define __pyx_n_s_object __pyx_mstate_global->__pyx_n_s_object
#define __pyx_n_s_object_hash __pyx_mstate_global->__pyx_n_s_object_hash
#define __pyx_n_s_objects_are_equal __pyx_mstate_global->__pyx_n_s_objects_are_equal
#define __pyx_n_s_overhead __pyx_mstate_global->__pyx_n_s_overhead
#define __pyx_n_s_pack __pyx_mstate_global->__pyx_n_s_pack
#define __pyx_n_s_pandas__libs_hashtable __pyx_mstate_global->__pyx_n_s_pandas__libs_hashtable
#define __pyx_kp_s_pandas__libs_hashtable_class_hel __pyx_mstate_global->__pyx_kp_s_pandas__libs_hashtable_class_hel
#define __pyx_kp_s_pandas__libs_hashtable_func_help __pyx_mstate_global->__pyx_kp_s_pandas__libs_hashtable_func_help
#define __pyx_kp_s_pandas__libs_hashtable_pyx __pyx_mstate_global->__pyx_kp_s_pandas__libs_hashtable_pyx
#define __pyx_n_s_pickle __pyx_mstate_global->__pyx_n_s_pickle
#define __pyx_n_s_pyx_PickleError __pyx_mstate_global->__pyx_n_s_pyx_PickleError
#define __pyx_n_s_pyx_checksum __pyx_mstate_global->__pyx_n_s_pyx_checksum
#define __pyx_n_s_pyx_fuse_0duplicated __pyx_mstate_global->__pyx_n_s_pyx_fuse_0duplicated
#define __pyx_n_s_pyx_fuse_0ismember __pyx_mstate_global->__pyx_n_s_pyx_fuse_0ismember
#define __pyx_n_s_pyx_fuse_0value_count __pyx_mstate_global->__pyx_n_s_pyx_fuse_0value_count
#define __pyx_n_s_pyx_fuse_10duplicated __pyx_mstate_global->__pyx_n_s_pyx_fuse_10duplicated
#define __pyx_n_s_pyx_fuse_10ismember __pyx_mstate_global->__pyx_n_s_pyx_fuse_10ismember
#define __pyx_n_s_pyx_fuse_10value_count __pyx_mstate_global->__pyx_n_s_pyx_fuse_10value_count
#define __pyx_n_s_pyx_fuse_11duplicated __pyx_mstate_global->__pyx_n_s_pyx_fuse_11duplicated
#define __pyx_n_s_pyx_fuse_11ismember __pyx_mstate_global->__pyx_n_s_pyx_fuse_11ismember
#define __pyx_n_s_pyx_fuse_11value_count __pyx_mstate_global->__pyx_n_s_pyx_fuse_11value_count
#define __pyx_n_s_pyx_fuse_12duplicated __pyx_mstate_global->__pyx_n_s_pyx_fuse_12duplicated
#define __pyx_n_s_pyx_fuse_12ismember __pyx_mstate_global->__pyx_n_s_pyx_fuse_12ismember
#define __pyx_n_s_pyx_fuse_12value_count __pyx_mstate_global->__pyx_n_s_pyx_fuse_12value_count
#define __pyx_n_s_pyx_fuse_1duplicated __pyx_mstate_global->__pyx_n_s_pyx_fuse_1duplicated
#define __pyx_n_s_pyx_fuse_1ismember __pyx_mstate_global->__pyx_n_s_pyx_fuse_1ismember
#define __pyx_n_s_pyx_fuse_1value_count __pyx_mstate_global->__pyx_n_s_pyx_fuse_1value_count
#define __pyx_n_s_pyx_fuse_2duplicated __pyx_mstate_global->__pyx_n_s_pyx_fuse_2duplicated
#define __pyx_n_s_pyx_fuse_2ismember __pyx_mstate_global->__pyx_n_s_pyx_fuse_2ismember
#define __pyx_n_s_pyx_fuse_2value_count __pyx_mstate_global->__pyx_n_s_pyx_fuse_2value_count
#define __pyx_n_s_pyx_fuse_3duplicated __pyx_mstate_global->__pyx_n_s_pyx_fuse_3duplicated
#define __pyx_n_s_pyx_fuse_3ismember __pyx_mstate_global->__pyx_n_s_pyx_fuse_3ismember
#define __pyx_n_s_pyx_fuse_3value_count __pyx_mstate_global->__pyx_n_s_pyx_fuse_3value_count
#define __pyx_n_s_pyx_fuse_4duplicated __pyx_mstate_global->__pyx_n_s_pyx_fuse_4duplicated
#define __pyx_n_s_pyx_fuse_4ismember __pyx_mstate_global->__pyx_n_s_pyx_fuse_4ismember
#define __pyx_n_s_pyx_fuse_4value_count __pyx_mstate_global->__pyx_n_s_pyx_fuse_4value_count
#define __pyx_n_s_pyx_fuse_5duplicated __pyx_mstate_global->__pyx_n_s_pyx_fuse_5duplicated
#define __pyx_n_s_pyx_fuse_5ismember __pyx_mstate_global->__pyx_n_s_pyx_fuse_5ismember
#define __pyx_n_s_pyx_fuse_5value_count __pyx_mstate_global->__pyx_n_s_pyx_fuse_5value_count
#define __pyx_n_s_pyx_fuse_6duplicated __pyx_mstate_global->__pyx_n_s_pyx_fuse_6duplicated
#define __pyx_n_s_pyx_fuse_6ismember __pyx_mstate_global->__pyx_n_s_pyx_fuse_6ismember
#define __pyx_n_s_pyx_fuse_6value_count __pyx_mstate_global->__pyx_n_s_pyx_fuse_6value_count
#define __pyx_n_s_pyx_fuse_7duplicated __pyx_mstate_global->__pyx_n_s_pyx_fuse_7duplicated
#define __pyx_n_s_pyx_fuse_7ismember __pyx_mstate_global->__pyx_n_s_pyx_fuse_7ismember
#define __pyx_n_s_pyx_fuse_7value_count __pyx_mstate_global->__pyx_n_s_pyx_fuse_7value_count
#define __pyx_n_s_pyx_fuse_8duplicated __pyx_mstate_global->__pyx_n_s_pyx_fuse_8duplicated
#define __pyx_n_s_pyx_fuse_8ismember __pyx_mstate_global->__pyx_n_s_pyx_fuse_8ismember
#define __pyx_n_s_pyx_fuse_8value_count __pyx_mstate_global->__pyx_n_s_pyx_fuse_8value_count
#define __pyx_n_s_pyx_fuse_9duplicated __pyx_mstate_global->__pyx_n_s_pyx_fuse_9duplicated
#define __pyx_n_s_pyx_fuse_9ismember __pyx_mstate_global->__pyx_n_s_pyx_fuse_9ismember
#define __pyx_n_s_pyx_fuse_9value_count __pyx_mstate_global->__pyx_n_s_pyx_fuse_9value_count
#define __pyx_n_s_pyx_result __pyx_mstate_global->__pyx_n_s_pyx_result
#define __pyx_n_s_pyx_state __pyx_mstate_global->__pyx_n_s_pyx_state
#define __pyx_n_s_pyx_type __pyx_mstate_global->__pyx_n_s_pyx_type
#define __pyx_n_s_pyx_unpickle_Enum __pyx_mstate_global->__pyx_n_s_pyx_unpickle_Enum
#define __pyx_n_s_pyx_unpickle_HashTable __pyx_mstate_global->__pyx_n_s_pyx_unpickle_HashTable
#define __pyx_n_s_pyx_vtable __pyx_mstate_global->__pyx_n_s_pyx_vtable
#define __pyx_n_s_range __pyx_mstate_global->__pyx_n_s_range
#define __pyx_n_s_real __pyx_mstate_global->__pyx_n_s_real
#define __pyx_n_s_reduce __pyx_mstate_global->__pyx_n_s_reduce
#define __pyx_n_s_reduce_cython __pyx_mstate_global->__pyx_n_s_reduce_cython
#define __pyx_n_s_reduce_ex __pyx_mstate_global->__pyx_n_s_reduce_ex
#define __pyx_n_s_refcheck __pyx_mstate_global->__pyx_n_s_refcheck
#define __pyx_n_s_register __pyx_mstate_global->__pyx_n_s_register
#define __pyx_n_s_resbuf __pyx_mstate_global->__pyx_n_s_resbuf
#define __pyx_n_s_resize __pyx_mstate_global->__pyx_n_s_resize
#define __pyx_n_s_result_mask __pyx_mstate_global->__pyx_n_s_result_mask
#define __pyx_n_s_ret __pyx_mstate_global->__pyx_n_s_ret
#define __pyx_n_s_return __pyx_mstate_global->__pyx_n_s_return
#define __pyx_n_s_return_inverse __pyx_mstate_global->__pyx_n_s_return_inverse
#define __pyx_n_s_rmd __pyx_mstate_global->__pyx_n_s_rmd
#define __pyx_n_s_s __pyx_mstate_global->__pyx_n_s_s
#define __pyx_n_s_seen_na __pyx_mstate_global->__pyx_n_s_seen_na
#define __pyx_n_s_self __pyx_mstate_global->__pyx_n_s_self
#define __pyx_kp_s_self_table_cannot_be_converted_t __pyx_mstate_global->__pyx_kp_s_self_table_cannot_be_converted_t
#define __pyx_n_s_set_item __pyx_mstate_global->__pyx_n_s_set_item
#define __pyx_n_s_set_na __pyx_mstate_global->__pyx_n_s_set_na
#define __pyx_n_s_setstate __pyx_mstate_global->__pyx_n_s_setstate
#define __pyx_n_s_setstate_cython __pyx_mstate_global->__pyx_n_s_setstate_cython
#define __pyx_n_s_shape __pyx_mstate_global->__pyx_n_s_shape
#define __pyx_kp_u_should_have_raised_on_append __pyx_mstate_global->__pyx_kp_u_should_have_raised_on_append
#define __pyx_n_s_signatures __pyx_mstate_global->__pyx_n_s_signatures
#define __pyx_n_s_size __pyx_mstate_global->__pyx_n_s_size
#define __pyx_n_u_size __pyx_mstate_global->__pyx_n_u_size
#define __pyx_n_s_size_hint __pyx_mstate_global->__pyx_n_s_size_hint
#define __pyx_n_s_sizeof __pyx_mstate_global->__pyx_n_s_sizeof
#define __pyx_n_s_spec __pyx_mstate_global->__pyx_n_s_spec
#define __pyx_n_s_split __pyx_mstate_global->__pyx_n_s_split
#define __pyx_n_s_start __pyx_mstate_global->__pyx_n_s_start
#define __pyx_n_s_state __pyx_mstate_global->__pyx_n_s_state
#define __pyx_n_s_step __pyx_mstate_global->__pyx_n_s_step
#define __pyx_n_s_stop __pyx_mstate_global->__pyx_n_s_stop
#define __pyx_kp_s_strided_and_direct __pyx_mstate_global->__pyx_kp_s_strided_and_direct
#define __pyx_kp_s_strided_and_direct_or_indirect __pyx_mstate_global->__pyx_kp_s_strided_and_direct_or_indirect
#define __pyx_kp_s_strided_and_indirect __pyx_mstate_global->__pyx_kp_s_strided_and_indirect
#define __pyx_kp_s_stringsource __pyx_mstate_global->__pyx_kp_s_stringsource
#define __pyx_n_s_strip __pyx_mstate_global->__pyx_n_s_strip
#define __pyx_n_s_struct __pyx_mstate_global->__pyx_n_s_struct
#define __pyx_n_s_sys __pyx_mstate_global->__pyx_n_s_sys
#define __pyx_n_s_table __pyx_mstate_global->__pyx_n_s_table
#define __pyx_n_s_test __pyx_mstate_global->__pyx_n_s_test
#define __pyx_n_s_to_array __pyx_mstate_global->__pyx_n_s_to_array
#define __pyx_kp_s_tuple_ndarray_ndarray __pyx_mstate_global->__pyx_kp_s_tuple_ndarray_ndarray
#define __pyx_n_s_ud __pyx_mstate_global->__pyx_n_s_ud
#define __pyx_n_s_uindexer __pyx_mstate_global->__pyx_n_s_uindexer
#define __pyx_n_s_uint16 __pyx_mstate_global->__pyx_n_s_uint16
#define __pyx_n_s_uint16_t __pyx_mstate_global->__pyx_n_s_uint16_t
#define __pyx_n_s_uint32 __pyx_mstate_global->__pyx_n_s_uint32
#define __pyx_n_s_uint32_t __pyx_mstate_global->__pyx_n_s_uint32_t
#define __pyx_n_s_uint64 __pyx_mstate_global->__pyx_n_s_uint64
#define __pyx_n_s_uint64_t __pyx_mstate_global->__pyx_n_s_uint64_t
#define __pyx_n_s_uint8 __pyx_mstate_global->__pyx_n_s_uint8
#define __pyx_n_u_uint8 __pyx_mstate_global->__pyx_n_u_uint8
#define __pyx_n_s_uint8_t __pyx_mstate_global->__pyx_n_s_uint8_t
#define __pyx_kp_s_unable_to_allocate_array_data __pyx_mstate_global->__pyx_kp_s_unable_to_allocate_array_data
#define __pyx_kp_s_unable_to_allocate_shape_and_str __pyx_mstate_global->__pyx_kp_s_unable_to_allocate_shape_and_str
#define __pyx_n_s_unique __pyx_mstate_global->__pyx_n_s_unique
#define __pyx_n_s_unique_2 __pyx_mstate_global->__pyx_n_s_unique_2
#define __pyx_n_s_unique_label_indices __pyx_mstate_global->__pyx_n_s_unique_label_indices
#define __pyx_n_s_unique_label_indices_int32 __pyx_mstate_global->__pyx_n_s_unique_label_indices_int32
#define __pyx_n_s_unique_label_indices_int64 __pyx_mstate_global->__pyx_n_s_unique_label_indices_int64
#define __pyx_n_s_uniques __pyx_mstate_global->__pyx_n_s_uniques
#define __pyx_n_s_uniques_vector __pyx_mstate_global->__pyx_n_s_uniques_vector
#define __pyx_n_s_unpack __pyx_mstate_global->__pyx_n_s_unpack
#define __pyx_n_s_update __pyx_mstate_global->__pyx_n_s_update
#define __pyx_n_u_upper_bound __pyx_mstate_global->__pyx_n_u_upper_bound
#define __pyx_n_s_use_mask __pyx_mstate_global->__pyx_n_s_use_mask
#define __pyx_n_s_use_na_value __pyx_mstate_global->__pyx_n_s_use_na_value
#define __pyx_n_s_use_result_mask __pyx_mstate_global->__pyx_n_s_use_result_mask
#define __pyx_n_s_use_setstate __pyx_mstate_global->__pyx_n_s_use_setstate
#define __pyx_n_s_uses_mask __pyx_mstate_global->__pyx_n_s_uses_mask
#define __pyx_kp_u_uses_mask_not_implemented_with_d __pyx_mstate_global->__pyx_kp_u_uses_mask_not_implemented_with_d
#define __pyx_kp_u_uses_mask_not_implemented_with_o __pyx_mstate_global->__pyx_kp_u_uses_mask_not_implemented_with_o
#define __pyx_n_s_v __pyx_mstate_global->__pyx_n_s_v
#define __pyx_n_s_val __pyx_mstate_global->__pyx_n_s_val
#define __pyx_n_s_value_count __pyx_mstate_global->__pyx_n_s_value_count
#define __pyx_n_s_values __pyx_mstate_global->__pyx_n_s_values
#define __pyx_n_s_vecs __pyx_mstate_global->__pyx_n_s_vecs
#define __pyx_n_s_version_info __pyx_mstate_global->__pyx_n_s_version_info
#define __pyx_n_s_view __pyx_mstate_global->__pyx_n_s_view
#define __pyx_n_s_zeros __pyx_mstate_global->__pyx_n_s_zeros
#define __pyx_int_0 __pyx_mstate_global->__pyx_int_0
#define __pyx_int_1 __pyx_mstate_global->__pyx_int_1
#define __pyx_int_2 __pyx_mstate_global->__pyx_int_2
#define __pyx_int_3 __pyx_mstate_global->__pyx_int_3
#define __pyx_int_1048583 __pyx_mstate_global->__pyx_int_1048583
#define __pyx_int_112105877 __pyx_mstate_global->__pyx_int_112105877
#define __pyx_int_136983863 __pyx_mstate_global->__pyx_int_136983863
#define __pyx_int_184977713 __pyx_mstate_global->__pyx_int_184977713
#define __pyx_int_222419149 __pyx_mstate_global->__pyx_int_222419149
#define __pyx_int_228825662 __pyx_mstate_global->__pyx_int_228825662
#define __pyx_int_238750788 __pyx_mstate_global->__pyx_int_238750788
#define __pyx_int_neg_1 __pyx_mstate_global->__pyx_int_neg_1
#define __pyx_k__14 __pyx_mstate_global->__pyx_k__14
#define __pyx_k__15 __pyx_mstate_global->__pyx_k__15
#define __pyx_k__18 __pyx_mstate_global->__pyx_k__18
#define __pyx_k__19 __pyx_mstate_global->__pyx_k__19
#define __pyx_k__20 __pyx_mstate_global->__pyx_k__20
#define __pyx_k__21 __pyx_mstate_global->__pyx_k__21
#define __pyx_k__22 __pyx_mstate_global->__pyx_k__22
#define __pyx_k__23 __pyx_mstate_global->__pyx_k__23
#define __pyx_k__24 __pyx_mstate_global->__pyx_k__24
#define __pyx_k__25 __pyx_mstate_global->__pyx_k__25
#define __pyx_k__26 __pyx_mstate_global->__pyx_k__26
#define __pyx_k__27 __pyx_mstate_global->__pyx_k__27
#define __pyx_k__28 __pyx_mstate_global->__pyx_k__28
#define __pyx_k__29 __pyx_mstate_global->__pyx_k__29
#define __pyx_k__30 __pyx_mstate_global->__pyx_k__30
#define __pyx_k__31 __pyx_mstate_global->__pyx_k__31
#define __pyx_k__32 __pyx_mstate_global->__pyx_k__32
#define __pyx_k__33 __pyx_mstate_global->__pyx_k__33
#define __pyx_k__34 __pyx_mstate_global->__pyx_k__34
#define __pyx_k__35 __pyx_mstate_global->__pyx_k__35
#define __pyx_k__36 __pyx_mstate_global->__pyx_k__36
#define __pyx_k__37 __pyx_mstate_global->__pyx_k__37
#define __pyx_k__38 __pyx_mstate_global->__pyx_k__38
#define __pyx_k__39 __pyx_mstate_global->__pyx_k__39
#define __pyx_k__40 __pyx_mstate_global->__pyx_k__40
#define __pyx_k__42 __pyx_mstate_global->__pyx_k__42
#define __pyx_k__44 __pyx_mstate_global->__pyx_k__44
#define __pyx_k__45 __pyx_mstate_global->__pyx_k__45
#define __pyx_k__46 __pyx_mstate_global->__pyx_k__46
#define __pyx_k__47 __pyx_mstate_global->__pyx_k__47
#define __pyx_k__48 __pyx_mstate_global->__pyx_k__48
#define __pyx_k__49 __pyx_mstate_global->__pyx_k__49
#define __pyx_k__50 __pyx_mstate_global->__pyx_k__50
#define __pyx_k__51 __pyx_mstate_global->__pyx_k__51
#define __pyx_k__52 __pyx_mstate_global->__pyx_k__52
#define __pyx_k__53 __pyx_mstate_global->__pyx_k__53
#define __pyx_k__54 __pyx_mstate_global->__pyx_k__54
#define __pyx_k__55 __pyx_mstate_global->__pyx_k__55
#define __pyx_k__56 __pyx_mstate_global->__pyx_k__56
#define __pyx_k__57 __pyx_mstate_global->__pyx_k__57
#define __pyx_k__58 __pyx_mstate_global->__pyx_k__58
#define __pyx_k__60 __pyx_mstate_global->__pyx_k__60
#define __pyx_k__61 __pyx_mstate_global->__pyx_k__61
#define __pyx_k__62 __pyx_mstate_global->__pyx_k__62
#define __pyx_k__63 __pyx_mstate_global->__pyx_k__63
#define __pyx_k__64 __pyx_mstate_global->__pyx_k__64
#define __pyx_k__65 __pyx_mstate_global->__pyx_k__65
#define __pyx_k__66 __pyx_mstate_global->__pyx_k__66
#define __pyx_k__67 __pyx_mstate_global->__pyx_k__67
#define __pyx_k__68 __pyx_mstate_global->__pyx_k__68
#define __pyx_k__73 __pyx_mstate_global->__pyx_k__73
#define __pyx_k__74 __pyx_mstate_global->__pyx_k__74
#define __pyx_k__75 __pyx_mstate_global->__pyx_k__75
#define __pyx_k__76 __pyx_mstate_global->__pyx_k__76
#define __pyx_k__77 __pyx_mstate_global->__pyx_k__77
#define __pyx_k__78 __pyx_mstate_global->__pyx_k__78
#define __pyx_k__79 __pyx_mstate_global->__pyx_k__79
#define __pyx_k__80 __pyx_mstate_global->__pyx_k__80
#define __pyx_k__81 __pyx_mstate_global->__pyx_k__81
#define __pyx_k__82 __pyx_mstate_global->__pyx_k__82
#define __pyx_k__83 __pyx_mstate_global->__pyx_k__83
#define __pyx_k__84 __pyx_mstate_global->__pyx_k__84
#define __pyx_k__85 __pyx_mstate_global->__pyx_k__85
#define __pyx_k__87 __pyx_mstate_global->__pyx_k__87
#define __pyx_k__88 __pyx_mstate_global->__pyx_k__88
#define __pyx_k__89 __pyx_mstate_global->__pyx_k__89
#define __pyx_k__90 __pyx_mstate_global->__pyx_k__90
#define __pyx_k__91 __pyx_mstate_global->__pyx_k__91
#define __pyx_k__92 __pyx_mstate_global->__pyx_k__92
#define __pyx_k__93 __pyx_mstate_global->__pyx_k__93
#define __pyx_k__94 __pyx_mstate_global->__pyx_k__94
#define __pyx_k__95 __pyx_mstate_global->__pyx_k__95
#define __pyx_k__96 __pyx_mstate_global->__pyx_k__96
#define __pyx_k__97 __pyx_mstate_global->__pyx_k__97
#define __pyx_k__98 __pyx_mstate_global->__pyx_k__98
#define __pyx_k__99 __pyx_mstate_global->__pyx_k__99
#define __pyx_slice__5 __pyx_mstate_global->__pyx_slice__5
#define __pyx_tuple__4 __pyx_mstate_global->__pyx_tuple__4
#define __pyx_tuple__8 __pyx_mstate_global->__pyx_tuple__8
#define __pyx_tuple__9 __pyx_mstate_global->__pyx_tuple__9
#define __pyx_tuple__10 __pyx_mstate_global->__pyx_tuple__10
#define __pyx_tuple__11 __pyx_mstate_global->__pyx_tuple__11
#define __pyx_tuple__12 __pyx_mstate_global->__pyx_tuple__12
#define __pyx_tuple__13 __pyx_mstate_global->__pyx_tuple__13
#define __pyx_tuple__16 __pyx_mstate_global->__pyx_tuple__16
#define __pyx_tuple__17 __pyx_mstate_global->__pyx_tuple__17
#define __pyx_tuple__41 __pyx_mstate_global->__pyx_tuple__41
#define __pyx_tuple__43 __pyx_mstate_global->__pyx_tuple__43
#define __pyx_tuple__59 __pyx_mstate_global->__pyx_tuple__59
#define __pyx_tuple__71 __pyx_mstate_global->__pyx_tuple__71
#define __pyx_tuple__72 __pyx_mstate_global->__pyx_tuple__72
#define __pyx_slice__100 __pyx_mstate_global->__pyx_slice__100
#define __pyx_tuple__101 __pyx_mstate_global->__pyx_tuple__101
#define __pyx_tuple__102 __pyx_mstate_global->__pyx_tuple__102
#define __pyx_tuple__103 __pyx_mstate_global->__pyx_tuple__103
#define __pyx_tuple__104 __pyx_mstate_global->__pyx_tuple__104
#define __pyx_tuple__105 __pyx_mstate_global->__pyx_tuple__105
#define __pyx_tuple__106 __pyx_mstate_global->__pyx_tuple__106
#define __pyx_tuple__107 __pyx_mstate_global->__pyx_tuple__107
#define __pyx_tuple__108 __pyx_mstate_global->__pyx_tuple__108
#define __pyx_tuple__109 __pyx_mstate_global->__pyx_tuple__109
#define __pyx_tuple__110 __pyx_mstate_global->__pyx_tuple__110
#define __pyx_tuple__111 __pyx_mstate_global->__pyx_tuple__111
#define __pyx_tuple__112 __pyx_mstate_global->__pyx_tuple__112
#define __pyx_tuple__115 __pyx_mstate_global->__pyx_tuple__115
#define __pyx_tuple__117 __pyx_mstate_global->__pyx_tuple__117
#define __pyx_tuple__119 __pyx_mstate_global->__pyx_tuple__119
#define __pyx_tuple__121 __pyx_mstate_global->__pyx_tuple__121
#define __pyx_tuple__165 __pyx_mstate_global->__pyx_tuple__165
#define __pyx_tuple__168 __pyx_mstate_global->__pyx_tuple__168
#define __pyx_tuple__170 __pyx_mstate_global->__pyx_tuple__170
#define __pyx_tuple__172 __pyx_mstate_global->__pyx_tuple__172
#define __pyx_tuple__175 __pyx_mstate_global->__pyx_tuple__175
#define __pyx_tuple__178 __pyx_mstate_global->__pyx_tuple__178
#define __pyx_tuple__180 __pyx_mstate_global->__pyx_tuple__180
#define __pyx_tuple__182 __pyx_mstate_global->__pyx_tuple__182
#define __pyx_tuple__184 __pyx_mstate_global->__pyx_tuple__184
#define __pyx_tuple__185 __pyx_mstate_global->__pyx_tuple__185
#define __pyx_tuple__187 __pyx_mstate_global->__pyx_tuple__187
#define __pyx_tuple__188 __pyx_mstate_global->__pyx_tuple__188
#define __pyx_tuple__190 __pyx_mstate_global->__pyx_tuple__190
#define __pyx_tuple__192 __pyx_mstate_global->__pyx_tuple__192
#define __pyx_tuple__194 __pyx_mstate_global->__pyx_tuple__194
#define __pyx_tuple__197 __pyx_mstate_global->__pyx_tuple__197
#define __pyx_tuple__199 __pyx_mstate_global->__pyx_tuple__199
#define __pyx_tuple__242 __pyx_mstate_global->__pyx_tuple__242
#define __pyx_tuple__250 __pyx_mstate_global->__pyx_tuple__250
#define __pyx_tuple__397 __pyx_mstate_global->__pyx_tuple__397
#define __pyx_tuple__399 __pyx_mstate_global->__pyx_tuple__399
#define __pyx_tuple__401 __pyx_mstate_global->__pyx_tuple__401
#define __pyx_tuple__402 __pyx_mstate_global->__pyx_tuple__402
#define __pyx_tuple__404 __pyx_mstate_global->__pyx_tuple__404
#define __pyx_tuple__406 __pyx_mstate_global->__pyx_tuple__406
#define __pyx_tuple__407 __pyx_mstate_global->__pyx_tuple__407
#define __pyx_tuple__410 __pyx_mstate_global->__pyx_tuple__410
#define __pyx_tuple__412 __pyx_mstate_global->__pyx_tuple__412
#define __pyx_tuple__419 __pyx_mstate_global->__pyx_tuple__419
#define __pyx_tuple__421 __pyx_mstate_global->__pyx_tuple__421
#define __pyx_tuple__423 __pyx_mstate_global->__pyx_tuple__423
#define __pyx_tuple__430 __pyx_mstate_global->__pyx_tuple__430
#define __pyx_tuple__445 __pyx_mstate_global->__pyx_tuple__445
#define __pyx_tuple__446 __pyx_mstate_global->__pyx_tuple__446
#define __pyx_tuple__461 __pyx_mstate_global->__pyx_tuple__461
#define __pyx_tuple__476 __pyx_mstate_global->__pyx_tuple__476
#define __pyx_tuple__478 __pyx_mstate_global->__pyx_tuple__478
#define __pyx_tuple__482 __pyx_mstate_global->__pyx_tuple__482
#define __pyx_codeobj__113 __pyx_mstate_global->__pyx_codeobj__113
#define __pyx_codeobj__114 __pyx_mstate_global->__pyx_codeobj__114
#define __pyx_codeobj__116 __pyx_mstate_global->__pyx_codeobj__116
#define __pyx_codeobj__118 __pyx_mstate_global->__pyx_codeobj__118
#define __pyx_codeobj__120 __pyx_mstate_global->__pyx_codeobj__120
#define __pyx_codeobj__122 __pyx_mstate_global->__pyx_codeobj__122
#define __pyx_codeobj__123 __pyx_mstate_global->__pyx_codeobj__123
#define __pyx_codeobj__124 __pyx_mstate_global->__pyx_codeobj__124
#define __pyx_codeobj__125 __pyx_mstate_global->__pyx_codeobj__125
#define __pyx_codeobj__126 __pyx_mstate_global->__pyx_codeobj__126
#define __pyx_codeobj__127 __pyx_mstate_global->__pyx_codeobj__127
#define __pyx_codeobj__128 __pyx_mstate_global->__pyx_codeobj__128
#define __pyx_codeobj__129 __pyx_mstate_global->__pyx_codeobj__129
#define __pyx_codeobj__130 __pyx_mstate_global->__pyx_codeobj__130
#define __pyx_codeobj__131 __pyx_mstate_global->__pyx_codeobj__131
#define __pyx_codeobj__132 __pyx_mstate_global->__pyx_codeobj__132
#define __pyx_codeobj__133 __pyx_mstate_global->__pyx_codeobj__133
#define __pyx_codeobj__134 __pyx_mstate_global->__pyx_codeobj__134
#define __pyx_codeobj__135 __pyx_mstate_global->__pyx_codeobj__135
#define __pyx_codeobj__136 __pyx_mstate_global->__pyx_codeobj__136
#define __pyx_codeobj__137 __pyx_mstate_global->__pyx_codeobj__137
#define __pyx_codeobj__138 __pyx_mstate_global->__pyx_codeobj__138
#define __pyx_codeobj__139 __pyx_mstate_global->__pyx_codeobj__139
#define __pyx_codeobj__140 __pyx_mstate_global->__pyx_codeobj__140
#define __pyx_codeobj__141 __pyx_mstate_global->__pyx_codeobj__141
#define __pyx_codeobj__142 __pyx_mstate_global->__pyx_codeobj__142
#define __pyx_codeobj__143 __pyx_mstate_global->__pyx_codeobj__143
#define __pyx_codeobj__144 __pyx_mstate_global->__pyx_codeobj__144
#define __pyx_codeobj__145 __pyx_mstate_global->__pyx_codeobj__145
#define __pyx_codeobj__146 __pyx_mstate_global->__pyx_codeobj__146
#define __pyx_codeobj__147 __pyx_mstate_global->__pyx_codeobj__147
#define __pyx_codeobj__148 __pyx_mstate_global->__pyx_codeobj__148
#define __pyx_codeobj__149 __pyx_mstate_global->__pyx_codeobj__149
#define __pyx_codeobj__150 __pyx_mstate_global->__pyx_codeobj__150
#define __pyx_codeobj__151 __pyx_mstate_global->__pyx_codeobj__151
#define __pyx_codeobj__152 __pyx_mstate_global->__pyx_codeobj__152
#define __pyx_codeobj__153 __pyx_mstate_global->__pyx_codeobj__153
#define __pyx_codeobj__154 __pyx_mstate_global->__pyx_codeobj__154
#define __pyx_codeobj__155 __pyx_mstate_global->__pyx_codeobj__155
#define __pyx_codeobj__156 __pyx_mstate_global->__pyx_codeobj__156
#define __pyx_codeobj__157 __pyx_mstate_global->__pyx_codeobj__157
#define __pyx_codeobj__158 __pyx_mstate_global->__pyx_codeobj__158
#define __pyx_codeobj__159 __pyx_mstate_global->__pyx_codeobj__159
#define __pyx_codeobj__160 __pyx_mstate_global->__pyx_codeobj__160
#define __pyx_codeobj__161 __pyx_mstate_global->__pyx_codeobj__161
#define __pyx_codeobj__162 __pyx_mstate_global->__pyx_codeobj__162
#define __pyx_codeobj__163 __pyx_mstate_global->__pyx_codeobj__163
#define __pyx_codeobj__164 __pyx_mstate_global->__pyx_codeobj__164
#define __pyx_codeobj__166 __pyx_mstate_global->__pyx_codeobj__166
#define __pyx_codeobj__167 __pyx_mstate_global->__pyx_codeobj__167
#define __pyx_codeobj__169 __pyx_mstate_global->__pyx_codeobj__169
#define __pyx_codeobj__171 __pyx_mstate_global->__pyx_codeobj__171
#define __pyx_codeobj__173 __pyx_mstate_global->__pyx_codeobj__173
#define __pyx_codeobj__174 __pyx_mstate_global->__pyx_codeobj__174
#define __pyx_codeobj__176 __pyx_mstate_global->__pyx_codeobj__176
#define __pyx_codeobj__177 __pyx_mstate_global->__pyx_codeobj__177
#define __pyx_codeobj__179 __pyx_mstate_global->__pyx_codeobj__179
#define __pyx_codeobj__181 __pyx_mstate_global->__pyx_codeobj__181
#define __pyx_codeobj__183 __pyx_mstate_global->__pyx_codeobj__183
#define __pyx_codeobj__186 __pyx_mstate_global->__pyx_codeobj__186
#define __pyx_codeobj__189 __pyx_mstate_global->__pyx_codeobj__189
#define __pyx_codeobj__193 __pyx_mstate_global->__pyx_codeobj__193
#define __pyx_codeobj__195 __pyx_mstate_global->__pyx_codeobj__195
#define __pyx_codeobj__196 __pyx_mstate_global->__pyx_codeobj__196
#define __pyx_codeobj__198 __pyx_mstate_global->__pyx_codeobj__198
#define __pyx_codeobj__200 __pyx_mstate_global->__pyx_codeobj__200
#define __pyx_codeobj__201 __pyx_mstate_global->__pyx_codeobj__201
#define __pyx_codeobj__202 __pyx_mstate_global->__pyx_codeobj__202
#define __pyx_codeobj__203 __pyx_mstate_global->__pyx_codeobj__203
#define __pyx_codeobj__204 __pyx_mstate_global->__pyx_codeobj__204
#define __pyx_codeobj__205 __pyx_mstate_global->__pyx_codeobj__205
#define __pyx_codeobj__206 __pyx_mstate_global->__pyx_codeobj__206
#define __pyx_codeobj__207 __pyx_mstate_global->__pyx_codeobj__207
#define __pyx_codeobj__208 __pyx_mstate_global->__pyx_codeobj__208
#define __pyx_codeobj__209 __pyx_mstate_global->__pyx_codeobj__209
#define __pyx_codeobj__210 __pyx_mstate_global->__pyx_codeobj__210
#define __pyx_codeobj__211 __pyx_mstate_global->__pyx_codeobj__211
#define __pyx_codeobj__212 __pyx_mstate_global->__pyx_codeobj__212
#define __pyx_codeobj__213 __pyx_mstate_global->__pyx_codeobj__213
#define __pyx_codeobj__214 __pyx_mstate_global->__pyx_codeobj__214
#define __pyx_codeobj__215 __pyx_mstate_global->__pyx_codeobj__215
#define __pyx_codeobj__216 __pyx_mstate_global->__pyx_codeobj__216
#define __pyx_codeobj__217 __pyx_mstate_global->__pyx_codeobj__217
#define __pyx_codeobj__218 __pyx_mstate_global->__pyx_codeobj__218
#define __pyx_codeobj__219 __pyx_mstate_global->__pyx_codeobj__219
#define __pyx_codeobj__220 __pyx_mstate_global->__pyx_codeobj__220
#define __pyx_codeobj__221 __pyx_mstate_global->__pyx_codeobj__221
#define __pyx_codeobj__222 __pyx_mstate_global->__pyx_codeobj__222
#define __pyx_codeobj__223 __pyx_mstate_global->__pyx_codeobj__223
#define __pyx_codeobj__224 __pyx_mstate_global->__pyx_codeobj__224
#define __pyx_codeobj__225 __pyx_mstate_global->__pyx_codeobj__225
#define __pyx_codeobj__226 __pyx_mstate_global->__pyx_codeobj__226
#define __pyx_codeobj__227 __pyx_mstate_global->__pyx_codeobj__227
#define __pyx_codeobj__228 __pyx_mstate_global->__pyx_codeobj__228
#define __pyx_codeobj__229 __pyx_mstate_global->__pyx_codeobj__229
#define __pyx_codeobj__230 __pyx_mstate_global->__pyx_codeobj__230
#define __pyx_codeobj__231 __pyx_mstate_global->__pyx_codeobj__231
#define __pyx_codeobj__232 __pyx_mstate_global->__pyx_codeobj__232
#define __pyx_codeobj__233 __pyx_mstate_global->__pyx_codeobj__233
#define __pyx_codeobj__234 __pyx_mstate_global->__pyx_codeobj__234
#define __pyx_codeobj__235 __pyx_mstate_global->__pyx_codeobj__235
#define __pyx_codeobj__236 __pyx_mstate_global->__pyx_codeobj__236
#define __pyx_codeobj__237 __pyx_mstate_global->__pyx_codeobj__237
#define __pyx_codeobj__238 __pyx_mstate_global->__pyx_codeobj__238
#define __pyx_codeobj__239 __pyx_mstate_global->__pyx_codeobj__239
#define __pyx_codeobj__240 __pyx_mstate_global->__pyx_codeobj__240
#define __pyx_codeobj__241 __pyx_mstate_global->__pyx_codeobj__241
#define __pyx_codeobj__243 __pyx_mstate_global->__pyx_codeobj__243
#define __pyx_codeobj__244 __pyx_mstate_global->__pyx_codeobj__244
#define __pyx_codeobj__245 __pyx_mstate_global->__pyx_codeobj__245
#define __pyx_codeobj__246 __pyx_mstate_global->__pyx_codeobj__246
#define __pyx_codeobj__247 __pyx_mstate_global->__pyx_codeobj__247
#define __pyx_codeobj__248 __pyx_mstate_global->__pyx_codeobj__248
#define __pyx_codeobj__249 __pyx_mstate_global->__pyx_codeobj__249
#define __pyx_codeobj__251 __pyx_mstate_global->__pyx_codeobj__251
#define __pyx_codeobj__252 __pyx_mstate_global->__pyx_codeobj__252
#define __pyx_codeobj__253 __pyx_mstate_global->__pyx_codeobj__253
#define __pyx_codeobj__254 __pyx_mstate_global->__pyx_codeobj__254
#define __pyx_codeobj__255 __pyx_mstate_global->__pyx_codeobj__255
#define __pyx_codeobj__256 __pyx_mstate_global->__pyx_codeobj__256
#define __pyx_codeobj__257 __pyx_mstate_global->__pyx_codeobj__257
#define __pyx_codeobj__258 __pyx_mstate_global->__pyx_codeobj__258
#define __pyx_codeobj__259 __pyx_mstate_global->__pyx_codeobj__259
#define __pyx_codeobj__260 __pyx_mstate_global->__pyx_codeobj__260
#define __pyx_codeobj__261 __pyx_mstate_global->__pyx_codeobj__261
#define __pyx_codeobj__262 __pyx_mstate_global->__pyx_codeobj__262
#define __pyx_codeobj__263 __pyx_mstate_global->__pyx_codeobj__263
#define __pyx_codeobj__264 __pyx_mstate_global->__pyx_codeobj__264
#define __pyx_codeobj__265 __pyx_mstate_global->__pyx_codeobj__265
#define __pyx_codeobj__266 __pyx_mstate_global->__pyx_codeobj__266
#define __pyx_codeobj__267 __pyx_mstate_global->__pyx_codeobj__267
#define __pyx_codeobj__268 __pyx_mstate_global->__pyx_codeobj__268
#define __pyx_codeobj__269 __pyx_mstate_global->__pyx_codeobj__269
#define __pyx_codeobj__270 __pyx_mstate_global->__pyx_codeobj__270
#define __pyx_codeobj__271 __pyx_mstate_global->__pyx_codeobj__271
#define __pyx_codeobj__272 __pyx_mstate_global->__pyx_codeobj__272
#define __pyx_codeobj__273 __pyx_mstate_global->__pyx_codeobj__273
#define __pyx_codeobj__274 __pyx_mstate_global->__pyx_codeobj__274
#define __pyx_codeobj__275 __pyx_mstate_global->__pyx_codeobj__275
#define __pyx_codeobj__276 __pyx_mstate_global->__pyx_codeobj__276
#define __pyx_codeobj__277 __pyx_mstate_global->__pyx_codeobj__277
#define __pyx_codeobj__278 __pyx_mstate_global->__pyx_codeobj__278
#define __pyx_codeobj__279 __pyx_mstate_global->__pyx_codeobj__279
#define __pyx_codeobj__280 __pyx_mstate_global->__pyx_codeobj__280
#define __pyx_codeobj__281 __pyx_mstate_global->__pyx_codeobj__281
#define __pyx_codeobj__282 __pyx_mstate_global->__pyx_codeobj__282
#define __pyx_codeobj__283 __pyx_mstate_global->__pyx_codeobj__283
#define __pyx_codeobj__284 __pyx_mstate_global->__pyx_codeobj__284
#define __pyx_codeobj__285 __pyx_mstate_global->__pyx_codeobj__285
#define __pyx_codeobj__286 __pyx_mstate_global->__pyx_codeobj__286
#define __pyx_codeobj__287 __pyx_mstate_global->__pyx_codeobj__287
#define __pyx_codeobj__288 __pyx_mstate_global->__pyx_codeobj__288
#define __pyx_codeobj__289 __pyx_mstate_global->__pyx_codeobj__289
#define __pyx_codeobj__290 __pyx_mstate_global->__pyx_codeobj__290
#define __pyx_codeobj__291 __pyx_mstate_global->__pyx_codeobj__291
#define __pyx_codeobj__292 __pyx_mstate_global->__pyx_codeobj__292
#define __pyx_codeobj__293 __pyx_mstate_global->__pyx_codeobj__293
#define __pyx_codeobj__294 __pyx_mstate_global->__pyx_codeobj__294
#define __pyx_codeobj__295 __pyx_mstate_global->__pyx_codeobj__295
#define __pyx_codeobj__296 __pyx_mstate_global->__pyx_codeobj__296
#define __pyx_codeobj__297 __pyx_mstate_global->__pyx_codeobj__297
#define __pyx_codeobj__298 __pyx_mstate_global->__pyx_codeobj__298
#define __pyx_codeobj__299 __pyx_mstate_global->__pyx_codeobj__299
#define __pyx_codeobj__300 __pyx_mstate_global->__pyx_codeobj__300
#define __pyx_codeobj__301 __pyx_mstate_global->__pyx_codeobj__301
#define __pyx_codeobj__302 __pyx_mstate_global->__pyx_codeobj__302
#define __pyx_codeobj__303 __pyx_mstate_global->__pyx_codeobj__303
#define __pyx_codeobj__304 __pyx_mstate_global->__pyx_codeobj__304
#define __pyx_codeobj__305 __pyx_mstate_global->__pyx_codeobj__305
#define __pyx_codeobj__306 __pyx_mstate_global->__pyx_codeobj__306
#define __pyx_codeobj__307 __pyx_mstate_global->__pyx_codeobj__307
#define __pyx_codeobj__308 __pyx_mstate_global->__pyx_codeobj__308
#define __pyx_codeobj__309 __pyx_mstate_global->__pyx_codeobj__309
#define __pyx_codeobj__310 __pyx_mstate_global->__pyx_codeobj__310
#define __pyx_codeobj__311 __pyx_mstate_global->__pyx_codeobj__311
#define __pyx_codeobj__312 __pyx_mstate_global->__pyx_codeobj__312
#define __pyx_codeobj__313 __pyx_mstate_global->__pyx_codeobj__313
#define __pyx_codeobj__314 __pyx_mstate_global->__pyx_codeobj__314
#define __pyx_codeobj__315 __pyx_mstate_global->__pyx_codeobj__315
#define __pyx_codeobj__316 __pyx_mstate_global->__pyx_codeobj__316
#define __pyx_codeobj__317 __pyx_mstate_global->__pyx_codeobj__317
#define __pyx_codeobj__318 __pyx_mstate_global->__pyx_codeobj__318
#define __pyx_codeobj__319 __pyx_mstate_global->__pyx_codeobj__319
#define __pyx_codeobj__320 __pyx_mstate_global->__pyx_codeobj__320
#define __pyx_codeobj__321 __pyx_mstate_global->__pyx_codeobj__321
#define __pyx_codeobj__322 __pyx_mstate_global->__pyx_codeobj__322
#define __pyx_codeobj__323 __pyx_mstate_global->__pyx_codeobj__323
#define __pyx_codeobj__324 __pyx_mstate_global->__pyx_codeobj__324
#define __pyx_codeobj__325 __pyx_mstate_global->__pyx_codeobj__325
#define __pyx_codeobj__326 __pyx_mstate_global->__pyx_codeobj__326
#define __pyx_codeobj__327 __pyx_mstate_global->__pyx_codeobj__327
#define __pyx_codeobj__328 __pyx_mstate_global->__pyx_codeobj__328
#define __pyx_codeobj__329 __pyx_mstate_global->__pyx_codeobj__329
#define __pyx_codeobj__330 __pyx_mstate_global->__pyx_codeobj__330
#define __pyx_codeobj__331 __pyx_mstate_global->__pyx_codeobj__331
#define __pyx_codeobj__332 __pyx_mstate_global->__pyx_codeobj__332
#define __pyx_codeobj__333 __pyx_mstate_global->__pyx_codeobj__333
#define __pyx_codeobj__334 __pyx_mstate_global->__pyx_codeobj__334
#define __pyx_codeobj__335 __pyx_mstate_global->__pyx_codeobj__335
#define __pyx_codeobj__336 __pyx_mstate_global->__pyx_codeobj__336
#define __pyx_codeobj__337 __pyx_mstate_global->__pyx_codeobj__337
#define __pyx_codeobj__338 __pyx_mstate_global->__pyx_codeobj__338
#define __pyx_codeobj__339 __pyx_mstate_global->__pyx_codeobj__339
#define __pyx_codeobj__340 __pyx_mstate_global->__pyx_codeobj__340
#define __pyx_codeobj__341 __pyx_mstate_global->__pyx_codeobj__341
#define __pyx_codeobj__342 __pyx_mstate_global->__pyx_codeobj__342
#define __pyx_codeobj__343 __pyx_mstate_global->__pyx_codeobj__343
#define __pyx_codeobj__344 __pyx_mstate_global->__pyx_codeobj__344
#define __pyx_codeobj__345 __pyx_mstate_global->__pyx_codeobj__345
#define __pyx_codeobj__346 __pyx_mstate_global->__pyx_codeobj__346
#define __pyx_codeobj__347 __pyx_mstate_global->__pyx_codeobj__347
#define __pyx_codeobj__348 __pyx_mstate_global->__pyx_codeobj__348
#define __pyx_codeobj__349 __pyx_mstate_global->__pyx_codeobj__349
#define __pyx_codeobj__350 __pyx_mstate_global->__pyx_codeobj__350
#define __pyx_codeobj__351 __pyx_mstate_global->__pyx_codeobj__351
#define __pyx_codeobj__352 __pyx_mstate_global->__pyx_codeobj__352
#define __pyx_codeobj__353 __pyx_mstate_global->__pyx_codeobj__353
#define __pyx_codeobj__354 __pyx_mstate_global->__pyx_codeobj__354
#define __pyx_codeobj__355 __pyx_mstate_global->__pyx_codeobj__355
#define __pyx_codeobj__356 __pyx_mstate_global->__pyx_codeobj__356
#define __pyx_codeobj__357 __pyx_mstate_global->__pyx_codeobj__357
#define __pyx_codeobj__358 __pyx_mstate_global->__pyx_codeobj__358
#define __pyx_codeobj__359 __pyx_mstate_global->__pyx_codeobj__359
#define __pyx_codeobj__360 __pyx_mstate_global->__pyx_codeobj__360
#define __pyx_codeobj__361 __pyx_mstate_global->__pyx_codeobj__361
#define __pyx_codeobj__362 __pyx_mstate_global->__pyx_codeobj__362
#define __pyx_codeobj__363 __pyx_mstate_global->__pyx_codeobj__363
#define __pyx_codeobj__364 __pyx_mstate_global->__pyx_codeobj__364
#define __pyx_codeobj__365 __pyx_mstate_global->__pyx_codeobj__365
#define __pyx_codeobj__366 __pyx_mstate_global->__pyx_codeobj__366
#define __pyx_codeobj__367 __pyx_mstate_global->__pyx_codeobj__367
#define __pyx_codeobj__368 __pyx_mstate_global->__pyx_codeobj__368
#define __pyx_codeobj__369 __pyx_mstate_global->__pyx_codeobj__369
#define __pyx_codeobj__370 __pyx_mstate_global->__pyx_codeobj__370
#define __pyx_codeobj__371 __pyx_mstate_global->__pyx_codeobj__371
#define __pyx_codeobj__372 __pyx_mstate_global->__pyx_codeobj__372
#define __pyx_codeobj__373 __pyx_mstate_global->__pyx_codeobj__373
#define __pyx_codeobj__374 __pyx_mstate_global->__pyx_codeobj__374
#define __pyx_codeobj__375 __pyx_mstate_global->__pyx_codeobj__375
#define __pyx_codeobj__376 __pyx_mstate_global->__pyx_codeobj__376
#define __pyx_codeobj__377 __pyx_mstate_global->__pyx_codeobj__377
#define __pyx_codeobj__378 __pyx_mstate_global->__pyx_codeobj__378
#define __pyx_codeobj__379 __pyx_mstate_global->__pyx_codeobj__379
#define __pyx_codeobj__380 __pyx_mstate_global->__pyx_codeobj__380
#define __pyx_codeobj__381 __pyx_mstate_global->__pyx_codeobj__381
#define __pyx_codeobj__382 __pyx_mstate_global->__pyx_codeobj__382
#define __pyx_codeobj__383 __pyx_mstate_global->__pyx_codeobj__383
#define __pyx_codeobj__384 __pyx_mstate_global->__pyx_codeobj__384
#define __pyx_codeobj__385 __pyx_mstate_global->__pyx_codeobj__385
#define __pyx_codeobj__386 __pyx_mstate_global->__pyx_codeobj__386
#define __pyx_codeobj__387 __pyx_mstate_global->__pyx_codeobj__387
#define __pyx_codeobj__388 __pyx_mstate_global->__pyx_codeobj__388
#define __pyx_codeobj__389 __pyx_mstate_global->__pyx_codeobj__389
#define __pyx_codeobj__390 __pyx_mstate_global->__pyx_codeobj__390
#define __pyx_codeobj__391 __pyx_mstate_global->__pyx_codeobj__391
#define __pyx_codeobj__392 __pyx_mstate_global->__pyx_codeobj__392
#define __pyx_codeobj__393 __pyx_mstate_global->__pyx_codeobj__393
#define __pyx_codeobj__394 __pyx_mstate_global->__pyx_codeobj__394
#define __pyx_codeobj__395 __pyx_mstate_global->__pyx_codeobj__395
#define __pyx_codeobj__396 __pyx_mstate_global->__pyx_codeobj__396
#define __pyx_codeobj__398 __pyx_mstate_global->__pyx_codeobj__398
#define __pyx_codeobj__400 __pyx_mstate_global->__pyx_codeobj__400
#define __pyx_codeobj__403 __pyx_mstate_global->__pyx_codeobj__403
#define __pyx_codeobj__405 __pyx_mstate_global->__pyx_codeobj__405
#define __pyx_codeobj__408 __pyx_mstate_global->__pyx_codeobj__408
#define __pyx_codeobj__409 __pyx_mstate_global->__pyx_codeobj__409
#define __pyx_codeobj__411 __pyx_mstate_global->__pyx_codeobj__411
#define __pyx_codeobj__413 __pyx_mstate_global->__pyx_codeobj__413
#define __pyx_codeobj__414 __pyx_mstate_global->__pyx_codeobj__414
#define __pyx_codeobj__415 __pyx_mstate_global->__pyx_codeobj__415
#define __pyx_codeobj__416 __pyx_mstate_global->__pyx_codeobj__416
#define __pyx_codeobj__417 __pyx_mstate_global->__pyx_codeobj__417
#define __pyx_codeobj__418 __pyx_mstate_global->__pyx_codeobj__418
#define __pyx_codeobj__420 __pyx_mstate_global->__pyx_codeobj__420
#define __pyx_codeobj__422 __pyx_mstate_global->__pyx_codeobj__422
#define __pyx_codeobj__424 __pyx_mstate_global->__pyx_codeobj__424
#define __pyx_codeobj__425 __pyx_mstate_global->__pyx_codeobj__425
#define __pyx_codeobj__426 __pyx_mstate_global->__pyx_codeobj__426
#define __pyx_codeobj__427 __pyx_mstate_global->__pyx_codeobj__427
#define __pyx_codeobj__428 __pyx_mstate_global->__pyx_codeobj__428
#define __pyx_codeobj__429 __pyx_mstate_global->__pyx_codeobj__429
#define __pyx_codeobj__431 __pyx_mstate_global->__pyx_codeobj__431
#define __pyx_codeobj__432 __pyx_mstate_global->__pyx_codeobj__432
#define __pyx_codeobj__433 __pyx_mstate_global->__pyx_codeobj__433
#define __pyx_codeobj__434 __pyx_mstate_global->__pyx_codeobj__434
#define __pyx_codeobj__435 __pyx_mstate_global->__pyx_codeobj__435
#define __pyx_codeobj__436 __pyx_mstate_global->__pyx_codeobj__436
#define __pyx_codeobj__437 __pyx_mstate_global->__pyx_codeobj__437
#define __pyx_codeobj__438 __pyx_mstate_global->__pyx_codeobj__438
#define __pyx_codeobj__439 __pyx_mstate_global->__pyx_codeobj__439
#define __pyx_codeobj__440 __pyx_mstate_global->__pyx_codeobj__440
#define __pyx_codeobj__441 __pyx_mstate_global->__pyx_codeobj__441
#define __pyx_codeobj__442 __pyx_mstate_global->__pyx_codeobj__442
#define __pyx_codeobj__443 __pyx_mstate_global->__pyx_codeobj__443
#define __pyx_codeobj__444 __pyx_mstate_global->__pyx_codeobj__444
#define __pyx_codeobj__447 __pyx_mstate_global->__pyx_codeobj__447
#define __pyx_codeobj__448 __pyx_mstate_global->__pyx_codeobj__448
#define __pyx_codeobj__449 __pyx_mstate_global->__pyx_codeobj__449
#define __pyx_codeobj__450 __pyx_mstate_global->__pyx_codeobj__450
#define __pyx_codeobj__451 __pyx_mstate_global->__pyx_codeobj__451
#define __pyx_codeobj__452 __pyx_mstate_global->__pyx_codeobj__452
#define __pyx_codeobj__453 __pyx_mstate_global->__pyx_codeobj__453
#define __pyx_codeobj__454 __pyx_mstate_global->__pyx_codeobj__454
#define __pyx_codeobj__455 __pyx_mstate_global->__pyx_codeobj__455
#define __pyx_codeobj__456 __pyx_mstate_global->__pyx_codeobj__456
#define __pyx_codeobj__457 __pyx_mstate_global->__pyx_codeobj__457
#define __pyx_codeobj__458 __pyx_mstate_global->__pyx_codeobj__458
#define __pyx_codeobj__459 __pyx_mstate_global->__pyx_codeobj__459
#define __pyx_codeobj__460 __pyx_mstate_global->__pyx_codeobj__460
#define __pyx_codeobj__462 __pyx_mstate_global->__pyx_codeobj__462
#define __pyx_codeobj__463 __pyx_mstate_global->__pyx_codeobj__463
#define __pyx_codeobj__464 __pyx_mstate_global->__pyx_codeobj__464
#define __pyx_codeobj__465 __pyx_mstate_global->__pyx_codeobj__465
#define __pyx_codeobj__466 __pyx_mstate_global->__pyx_codeobj__466
#define __pyx_codeobj__467 __pyx_mstate_global->__pyx_codeobj__467
#define __pyx_codeobj__468 __pyx_mstate_global->__pyx_codeobj__468
#define __pyx_codeobj__469 __pyx_mstate_global->__pyx_codeobj__469
#define __pyx_codeobj__470 __pyx_mstate_global->__pyx_codeobj__470
#define __pyx_codeobj__471 __pyx_mstate_global->__pyx_codeobj__471
#define __pyx_codeobj__472 __pyx_mstate_global->__pyx_codeobj__472
#define __pyx_codeobj__473 __pyx_mstate_global->__pyx_codeobj__473
#define __pyx_codeobj__474 __pyx_mstate_global->__pyx_codeobj__474
#define __pyx_codeobj__475 __pyx_mstate_global->__pyx_codeobj__475
#define __pyx_codeobj__477 __pyx_mstate_global->__pyx_codeobj__477
#define __pyx_codeobj__479 __pyx_mstate_global->__pyx_codeobj__479
#define __pyx_codeobj__480 __pyx_mstate_global->__pyx_codeobj__480
#define __pyx_codeobj__481 __pyx_mstate_global->__pyx_codeobj__481
#define __pyx_codeobj__483 __pyx_mstate_global->__pyx_codeobj__483
#define __pyx_codeobj__484 __pyx_mstate_global->__pyx_codeobj__484
#define __pyx_codeobj__485 __pyx_mstate_global->__pyx_codeobj__485
#define __pyx_codeobj__486 __pyx_mstate_global->__pyx_codeobj__486
#define __pyx_codeobj__487 __pyx_mstate_global->__pyx_codeobj__487
#define __pyx_codeobj__488 __pyx_mstate_global->__pyx_codeobj__488
#define __pyx_codeobj__489 __pyx_mstate_global->__pyx_codeobj__489
/* #### Code section: module_code ### */

/* "View.MemoryView":131
 *         cdef bint dtype_is_object
 * 
 *     def __cinit__(array self, tuple shape, Py_ssize_t itemsize, format not None,             # <<<<<<<<<<<<<<
 *                   mode="c", bint allocate_buffer=True):
 * 
 */

/* Python wrapper */
static int __pyx_array___cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_array___cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_shape = 0;
  Py_ssize_t __pyx_v_itemsize;
  PyObject *__pyx_v_format = 0;
  PyObject *__pyx_v_mode = 0;
  int __pyx_v_allocate_buffer;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_shape,&__pyx_n_s_itemsize,&__pyx_n_s_format,&__pyx_n_s_mode,&__pyx_n_s_allocate_buffer,0};
    values[3] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_n_s_c));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_shape)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 131, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_itemsize)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 131, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 3, 5, 1); __PYX_ERR(1, 131, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_format)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 131, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 3, 5, 2); __PYX_ERR(1, 131, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mode);
          if (value) { values[3] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 131, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_allocate_buffer);
          if (value) { values[4] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 131, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(1, 131, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_shape = ((PyObject*)values[0]);
    __pyx_v_itemsize = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_itemsize == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(1, 131, __pyx_L3_error)
    __pyx_v_format = values[2];
    __pyx_v_mode = values[3];
    if (values[4]) {
      __pyx_v_allocate_buffer = __Pyx_PyObject_IsTrue(values[4]); if (unlikely((__pyx_v_allocate_buffer == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 132, __pyx_L3_error)
    } else {

      /* "View.MemoryView":132
 * 
 *     def __cinit__(array self, tuple shape, Py_ssize_t itemsize, format not None,
 *                   mode="c", bint allocate_buffer=True):             # <<<<<<<<<<<<<<
 * 
 *         cdef int idx
 */
      __pyx_v_allocate_buffer = ((int)1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 3, 5, __pyx_nargs); __PYX_ERR(1, 131, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("View.MemoryView.array.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_shape), (&PyTuple_Type), 1, "shape", 1))) __PYX_ERR(1, 131, __pyx_L1_error)
  if (unlikely(((PyObject *)__pyx_v_format) == Py_None)) {
    PyErr_Format(PyExc_TypeError, "Argument '%.200s' must not be None", "format"); __PYX_ERR(1, 131, __pyx_L1_error)
  }
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array___cinit__(((struct __pyx_array_obj *)__pyx_v_self), __pyx_v_shape, __pyx_v_itemsize, __pyx_v_format, __pyx_v_mode, __pyx_v_allocate_buffer);

  /* "View.MemoryView":131
 *         cdef bint dtype_is_object
 * 
 *     def __cinit__(array self, tuple shape, Py_ssize_t itemsize, format not None,             # <<<<<<<<<<<<<<
 *                   mode="c", bint allocate_buffer=True):
 * 
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array___cinit__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_shape, Py_ssize_t __pyx_v_itemsize, PyObject *__pyx_v_format, PyObject *__pyx_v_mode, int __pyx_v_allocate_buffer) {
  int __pyx_v_idx;
  Py_ssize_t __pyx_v_dim;
  char __pyx_v_order;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  char *__pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_UCS4 __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);
  __Pyx_INCREF(__pyx_v_format);

  /* "View.MemoryView":137
 *         cdef Py_ssize_t dim
 * 
 *         self.ndim = <int> len(shape)             # <<<<<<<<<<<<<<
 *         self.itemsize = itemsize
 * 
 */
  if (unlikely(__pyx_v_shape == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 137, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_PyTuple_GET_SIZE(__pyx_v_shape); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(1, 137, __pyx_L1_error)
  __pyx_v_self->ndim = ((int)__pyx_t_1);

  /* "View.MemoryView":138
 * 
 *         self.ndim = <int> len(shape)
 *         self.itemsize = itemsize             # <<<<<<<<<<<<<<
 * 
 *         if not self.ndim:
 */
  __pyx_v_self->itemsize = __pyx_v_itemsize;

  /* "View.MemoryView":140
 *         self.itemsize = itemsize
 * 
 *         if not self.ndim:             # <<<<<<<<<<<<<<
 *             raise ValueError, "Empty shape tuple for cython.array"
 * 
 */
  __pyx_t_2 = (!(__pyx_v_self->ndim != 0));
  if (unlikely(__pyx_t_2)) {

    /* "View.MemoryView":141
 * 
 *         if not self.ndim:
 *             raise ValueError, "Empty shape tuple for cython.array"             # <<<<<<<<<<<<<<
 * 
 *         if itemsize <= 0:
 */
    __Pyx_Raise(__pyx_builtin_ValueError, __pyx_kp_s_Empty_shape_tuple_for_cython_arr, 0, 0);
    __PYX_ERR(1, 141, __pyx_L1_error)

    /* "View.MemoryView":140
 *         self.itemsize = itemsize
 * 
 *         if not self.ndim:             # <<<<<<<<<<<<<<
 *             raise ValueError, "Empty shape tuple for cython.array"
 * 
 */
  }

  /* "View.MemoryView":143
 *             raise ValueError, "Empty shape tuple for cython.array"
 * 
 *         if itemsize <= 0:             # <<<<<<<<<<<<<<
 *             raise ValueError, "itemsize <= 0 for cython.array"
 * 
 */
  __pyx_t_2 = (__pyx_v_itemsize <= 0);
  if (unlikely(__pyx_t_2)) {

    /* "View.MemoryView":144
 * 
 *         if itemsize <= 0:
 *             raise ValueError, "itemsize <= 0 for cython.array"             # <<<<<<<<<<<<<<
 * 
 *         if not isinstance(format, bytes):
 */
    __Pyx_Raise(__pyx_builtin_ValueError, __pyx_kp_s_itemsize_0_for_cython_array, 0, 0);
    __PYX_ERR(1, 144, __pyx_L1_error)

    /* "View.MemoryView":143
 *             raise ValueError, "Empty shape tuple for cython.array"
 * 
 *         if itemsize <= 0:             # <<<<<<<<<<<<<<
 *             raise ValueError, "itemsize <= 0 for cython.array"
 * 
 */
  }

  /* "View.MemoryView":146
 *             raise ValueError, "itemsize <= 0 for cython.array"
 * 
 *         if not isinstance(format, bytes):             # <<<<<<<<<<<<<<
 *             format = format.encode('ASCII')
 *         self._format = format  # keep a reference to the byte string
 */
  __pyx_t_2 = PyBytes_Check(__pyx_v_format); 
  __pyx_t_3 = (!__pyx_t_2);
  if (__pyx_t_3) {

    /* "View.MemoryView":147
 * 
 *         if not isinstance(format, bytes):
 *             format = format.encode('ASCII')             # <<<<<<<<<<<<<<
 *         self._format = format  # keep a reference to the byte string
 *         self.format = self._format
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_format, __pyx_n_s_encode); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 147, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = NULL;
    __pyx_t_7 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_6)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_6);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_7 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_n_s_ASCII};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 1+__pyx_t_7);
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 147, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    __Pyx_DECREF_SET(__pyx_v_format, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "View.MemoryView":146
 *             raise ValueError, "itemsize <= 0 for cython.array"
 * 
 *         if not isinstance(format, bytes):             # <<<<<<<<<<<<<<
 *             format = format.encode('ASCII')
 *         self._format = format  # keep a reference to the byte string
 */
  }

  /* "View.MemoryView":148
 *         if not isinstance(format, bytes):
 *             format = format.encode('ASCII')
 *         self._format = format  # keep a reference to the byte string             # <<<<<<<<<<<<<<
 *         self.format = self._format
 * 
 */
  if (!(likely(PyBytes_CheckExact(__pyx_v_format))||((__pyx_v_format) == Py_None) || __Pyx_RaiseUnexpectedTypeError("bytes", __pyx_v_format))) __PYX_ERR(1, 148, __pyx_L1_error)
  __pyx_t_4 = __pyx_v_format;
  __Pyx_INCREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF(__pyx_v_self->_format);
  __Pyx_DECREF(__pyx_v_self->_format);
  __pyx_v_self->_format = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "View.MemoryView":149
 *             format = format.encode('ASCII')
 *         self._format = format  # keep a reference to the byte string
 *         self.format = self._format             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (unlikely(__pyx_v_self->_format == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "expected bytes, NoneType found");
    __PYX_ERR(1, 149, __pyx_L1_error)
  }
  __pyx_t_8 = __Pyx_PyBytes_AsWritableString(__pyx_v_self->_format); if (unlikely((!__pyx_t_8) && PyErr_Occurred())) __PYX_ERR(1, 149, __pyx_L1_error)
  __pyx_v_self->format = __pyx_t_8;

  /* "View.MemoryView":152
 * 
 * 
 *         self._shape = <Py_ssize_t *> PyObject_Malloc(sizeof(Py_ssize_t)*self.ndim*2)             # <<<<<<<<<<<<<<
 *         self._strides = self._shape + self.ndim
 * 
 */
  __pyx_v_self->_shape = ((Py_ssize_t *)PyObject_Malloc((((sizeof(Py_ssize_t)) * __pyx_v_self->ndim) * 2)));

  /* "View.MemoryView":153
 * 
 *         self._shape = <Py_ssize_t *> PyObject_Malloc(sizeof(Py_ssize_t)*self.ndim*2)
 *         self._strides = self._shape + self.ndim             # <<<<<<<<<<<<<<
 * 
 *         if not self._shape:
 */
  __pyx_v_self->_strides = (__pyx_v_self->_shape + __pyx_v_self->ndim);

  /* "View.MemoryView":155
 *         self._strides = self._shape + self.ndim
 * 
 *         if not self._shape:             # <<<<<<<<<<<<<<
 *             raise MemoryError, "unable to allocate shape and strides."
 * 
 */
  __pyx_t_3 = (!(__pyx_v_self->_shape != 0));
  if (unlikely(__pyx_t_3)) {

    /* "View.MemoryView":156
 * 
 *         if not self._shape:
 *             raise MemoryError, "unable to allocate shape and strides."             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_Raise(__pyx_builtin_MemoryError, __pyx_kp_s_unable_to_allocate_shape_and_str, 0, 0);
    __PYX_ERR(1, 156, __pyx_L1_error)

    /* "View.MemoryView":155
 *         self._strides = self._shape + self.ndim
 * 
 *         if not self._shape:             # <<<<<<<<<<<<<<
 *             raise MemoryError, "unable to allocate shape and strides."
 * 
 */
  }

  /* "View.MemoryView":159
 * 
 * 
 *         for idx, dim in enumerate(shape):             # <<<<<<<<<<<<<<
 *             if dim <= 0:
 *                 raise ValueError, f"Invalid shape in axis {idx}: {dim}."
 */
  __pyx_t_7 = 0;
  __pyx_t_4 = __pyx_v_shape; __Pyx_INCREF(__pyx_t_4);
  __pyx_t_1 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_4);
      #if !CYTHON_ASSUME_SAFE_MACROS
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(1, 159, __pyx_L1_error)
      #endif
      if (__pyx_t_1 >= __pyx_temp) break;
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_1); __Pyx_INCREF(__pyx_t_5); __pyx_t_1++; if (unlikely((0 < 0))) __PYX_ERR(1, 159, __pyx_L1_error)
    #else
    __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_4, __pyx_t_1); __pyx_t_1++; if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 159, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    #endif
    __pyx_t_9 = __Pyx_PyIndex_AsSsize_t(__pyx_t_5); if (unlikely((__pyx_t_9 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(1, 159, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_v_dim = __pyx_t_9;
    __pyx_v_idx = __pyx_t_7;
    __pyx_t_7 = (__pyx_t_7 + 1);

    /* "View.MemoryView":160
 * 
 *         for idx, dim in enumerate(shape):
 *             if dim <= 0:             # <<<<<<<<<<<<<<
 *                 raise ValueError, f"Invalid shape in axis {idx}: {dim}."
 *             self._shape[idx] = dim
 */
    __pyx_t_3 = (__pyx_v_dim <= 0);
    if (unlikely(__pyx_t_3)) {

      /* "View.MemoryView":161
 *         for idx, dim in enumerate(shape):
 *             if dim <= 0:
 *                 raise ValueError, f"Invalid shape in axis {idx}: {dim}."             # <<<<<<<<<<<<<<
 *             self._shape[idx] = dim
 * 
 */
      __pyx_t_5 = PyTuple_New(5); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 161, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_9 = 0;
      __pyx_t_10 = 127;
      __Pyx_INCREF(__pyx_kp_u_Invalid_shape_in_axis);
      __pyx_t_9 += 22;
      __Pyx_GIVEREF(__pyx_kp_u_Invalid_shape_in_axis);
      PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_kp_u_Invalid_shape_in_axis);
      __pyx_t_6 = __Pyx_PyUnicode_From_int(__pyx_v_idx, 0, ' ', 'd'); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 161, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_9 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_6);
      __pyx_t_6 = 0;
      __Pyx_INCREF(__pyx_kp_u_);
      __pyx_t_9 += 2;
      __Pyx_GIVEREF(__pyx_kp_u_);
      PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_kp_u_);
      __pyx_t_6 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_v_dim, 0, ' ', 'd'); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 161, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_9 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_6);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_t_6);
      __pyx_t_6 = 0;
      __Pyx_INCREF(__pyx_kp_u__2);
      __pyx_t_9 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__2);
      PyTuple_SET_ITEM(__pyx_t_5, 4, __pyx_kp_u__2);
      __pyx_t_6 = __Pyx_PyUnicode_Join(__pyx_t_5, 5, __pyx_t_9, __pyx_t_10); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 161, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_Raise(__pyx_builtin_ValueError, __pyx_t_6, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __PYX_ERR(1, 161, __pyx_L1_error)

      /* "View.MemoryView":160
 * 
 *         for idx, dim in enumerate(shape):
 *             if dim <= 0:             # <<<<<<<<<<<<<<
 *                 raise ValueError, f"Invalid shape in axis {idx}: {dim}."
 *             self._shape[idx] = dim
 */
    }

    /* "View.MemoryView":162
 *             if dim <= 0:
 *                 raise ValueError, f"Invalid shape in axis {idx}: {dim}."
 *             self._shape[idx] = dim             # <<<<<<<<<<<<<<
 * 
 *         cdef char order
 */
    (__pyx_v_self->_shape[__pyx_v_idx]) = __pyx_v_dim;

    /* "View.MemoryView":159
 * 
 * 
 *         for idx, dim in enumerate(shape):             # <<<<<<<<<<<<<<
 *             if dim <= 0:
 *                 raise ValueError, f"Invalid shape in axis {idx}: {dim}."
 */
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "View.MemoryView":165
 * 
 *         cdef char order
 *         if mode == 'c':             # <<<<<<<<<<<<<<
 *             order = b'C'
 *             self.mode = u'c'
 */
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_mode, __pyx_n_s_c, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(1, 165, __pyx_L1_error)
  if (__pyx_t_3) {

    /* "View.MemoryView":166
 *         cdef char order
 *         if mode == 'c':
 *             order = b'C'             # <<<<<<<<<<<<<<
 *             self.mode = u'c'
 *         elif mode == 'fortran':
 */
    __pyx_v_order = 'C';

    /* "View.MemoryView":167
 *         if mode == 'c':
 *             order = b'C'
 *             self.mode = u'c'             # <<<<<<<<<<<<<<
 *         elif mode == 'fortran':
 *             order = b'F'
 */
    __Pyx_INCREF(__pyx_n_u_c);
    __Pyx_GIVEREF(__pyx_n_u_c);
    __Pyx_GOTREF(__pyx_v_self->mode);
    __Pyx_DECREF(__pyx_v_self->mode);
    __pyx_v_self->mode = __pyx_n_u_c;

    /* "View.MemoryView":165
 * 
 *         cdef char order
 *         if mode == 'c':             # <<<<<<<<<<<<<<
 *             order = b'C'
 *             self.mode = u'c'
 */
    goto __pyx_L11;
  }

  /* "View.MemoryView":168
 *             order = b'C'
 *             self.mode = u'c'
 *         elif mode == 'fortran':             # <<<<<<<<<<<<<<
 *             order = b'F'
 *             self.mode = u'fortran'
 */
  __pyx_t_3 = (__Pyx_PyString_Equals(__pyx_v_mode, __pyx_n_s_fortran, Py_EQ)); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(1, 168, __pyx_L1_error)
  if (likely(__pyx_t_3)) {

    /* "View.MemoryView":169
 *             self.mode = u'c'
 *         elif mode == 'fortran':
 *             order = b'F'             # <<<<<<<<<<<<<<
 *             self.mode = u'fortran'
 *         else:
 */
    __pyx_v_order = 'F';

    /* "View.MemoryView":170
 *         elif mode == 'fortran':
 *             order = b'F'
 *             self.mode = u'fortran'             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError, f"Invalid mode, expected 'c' or 'fortran', got {mode}"
 */
    __Pyx_INCREF(__pyx_n_u_fortran);
    __Pyx_GIVEREF(__pyx_n_u_fortran);
    __Pyx_GOTREF(__pyx_v_self->mode);
    __Pyx_DECREF(__pyx_v_self->mode);
    __pyx_v_self->mode = __pyx_n_u_fortran;

    /* "View.MemoryView":168
 *             order = b'C'
 *             self.mode = u'c'
 *         elif mode == 'fortran':             # <<<<<<<<<<<<<<
 *             order = b'F'
 *             self.mode = u'fortran'
 */
    goto __pyx_L11;
  }

  /* "View.MemoryView":172
 *             self.mode = u'fortran'
 *         else:
 *             raise ValueError, f"Invalid mode, expected 'c' or 'fortran', got {mode}"             # <<<<<<<<<<<<<<
 * 
 *         self.len = fill_contig_strides_array(self._shape, self._strides, itemsize, self.ndim, order)
 */
  /*else*/ {
    __pyx_t_4 = __Pyx_PyObject_FormatSimple(__pyx_v_mode, __pyx_empty_unicode); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 172, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = __Pyx_PyUnicode_Concat(__pyx_kp_u_Invalid_mode_expected_c_or_fortr, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 172, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_builtin_ValueError, __pyx_t_6, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(1, 172, __pyx_L1_error)
  }
  __pyx_L11:;

  /* "View.MemoryView":174
 *             raise ValueError, f"Invalid mode, expected 'c' or 'fortran', got {mode}"
 * 
 *         self.len = fill_contig_strides_array(self._shape, self._strides, itemsize, self.ndim, order)             # <<<<<<<<<<<<<<
 * 
 *         self.free_data = allocate_buffer
 */
  __pyx_v_self->len = __pyx_fill_contig_strides_array(__pyx_v_self->_shape, __pyx_v_self->_strides, __pyx_v_itemsize, __pyx_v_self->ndim, __pyx_v_order);

  /* "View.MemoryView":176
 *         self.len = fill_contig_strides_array(self._shape, self._strides, itemsize, self.ndim, order)
 * 
 *         self.free_data = allocate_buffer             # <<<<<<<<<<<<<<
 *         self.dtype_is_object = format == b'O'
 * 
 */
  __pyx_v_self->free_data = __pyx_v_allocate_buffer;

  /* "View.MemoryView":177
 * 
 *         self.free_data = allocate_buffer
 *         self.dtype_is_object = format == b'O'             # <<<<<<<<<<<<<<
 * 
 *         if allocate_buffer:
 */
  __pyx_t_6 = PyObject_RichCompare(__pyx_v_format, __pyx_n_b_O, Py_EQ); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 177, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 177, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_self->dtype_is_object = __pyx_t_3;

  /* "View.MemoryView":179
 *         self.dtype_is_object = format == b'O'
 * 
 *         if allocate_buffer:             # <<<<<<<<<<<<<<
 *             _allocate_buffer(self)
 * 
 */
  if (__pyx_v_allocate_buffer) {

    /* "View.MemoryView":180
 * 
 *         if allocate_buffer:
 *             _allocate_buffer(self)             # <<<<<<<<<<<<<<
 * 
 *     @cname('getbuffer')
 */
    __pyx_t_7 = __pyx_array_allocate_buffer(__pyx_v_self); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(1, 180, __pyx_L1_error)

    /* "View.MemoryView":179
 *         self.dtype_is_object = format == b'O'
 * 
 *         if allocate_buffer:             # <<<<<<<<<<<<<<
 *             _allocate_buffer(self)
 * 
 */
  }

  /* "View.MemoryView":131
 *         cdef bint dtype_is_object
 * 
 *     def __cinit__(array self, tuple shape, Py_ssize_t itemsize, format not None,             # <<<<<<<<<<<<<<
 *                   mode="c", bint allocate_buffer=True):
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("View.MemoryView.array.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_format);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":182
 *             _allocate_buffer(self)
 * 
 *     @cname('getbuffer')             # <<<<<<<<<<<<<<
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         cdef int bufmode = -1
 */

/* Python wrapper */
CYTHON_UNUSED static int __pyx_array_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
CYTHON_UNUSED static int __pyx_array_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getbuffer__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array_2__getbuffer__(((struct __pyx_array_obj *)__pyx_v_self), ((Py_buffer *)__pyx_v_info), ((int)__pyx_v_flags));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array_2__getbuffer__(struct __pyx_array_obj *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_v_bufmode;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  char *__pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t *__pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  if (unlikely(__pyx_v_info == NULL)) {
    PyErr_SetString(PyExc_BufferError, "PyObject_GetBuffer: view==NULL argument is obsolete");
    return -1;
  }
  __Pyx_RefNannySetupContext("__getbuffer__", 0);
  __pyx_v_info->obj = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(__pyx_v_info->obj);

  /* "View.MemoryView":184
 *     @cname('getbuffer')
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         cdef int bufmode = -1             # <<<<<<<<<<<<<<
 *         if flags & (PyBUF_C_CONTIGUOUS | PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS):
 *             if self.mode == u"c":
 */
  __pyx_v_bufmode = -1;

  /* "View.MemoryView":185
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         cdef int bufmode = -1
 *         if flags & (PyBUF_C_CONTIGUOUS | PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS):             # <<<<<<<<<<<<<<
 *             if self.mode == u"c":
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 */
  __pyx_t_1 = ((__pyx_v_flags & ((PyBUF_C_CONTIGUOUS | PyBUF_F_CONTIGUOUS) | PyBUF_ANY_CONTIGUOUS)) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":186
 *         cdef int bufmode = -1
 *         if flags & (PyBUF_C_CONTIGUOUS | PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS):
 *             if self.mode == u"c":             # <<<<<<<<<<<<<<
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             elif self.mode == u"fortran":
 */
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_self->mode, __pyx_n_u_c, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(1, 186, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "View.MemoryView":187
 *         if flags & (PyBUF_C_CONTIGUOUS | PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS):
 *             if self.mode == u"c":
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS             # <<<<<<<<<<<<<<
 *             elif self.mode == u"fortran":
 *                 bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 */
      __pyx_v_bufmode = (PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS);

      /* "View.MemoryView":186
 *         cdef int bufmode = -1
 *         if flags & (PyBUF_C_CONTIGUOUS | PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS):
 *             if self.mode == u"c":             # <<<<<<<<<<<<<<
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             elif self.mode == u"fortran":
 */
      goto __pyx_L4;
    }

    /* "View.MemoryView":188
 *             if self.mode == u"c":
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             elif self.mode == u"fortran":             # <<<<<<<<<<<<<<
 *                 bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             if not (flags & bufmode):
 */
    __pyx_t_1 = (__Pyx_PyUnicode_Equals(__pyx_v_self->mode, __pyx_n_u_fortran, Py_EQ)); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(1, 188, __pyx_L1_error)
    if (__pyx_t_1) {

      /* "View.MemoryView":189
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             elif self.mode == u"fortran":
 *                 bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS             # <<<<<<<<<<<<<<
 *             if not (flags & bufmode):
 *                 raise ValueError, "Can only create a buffer that is contiguous in memory."
 */
      __pyx_v_bufmode = (PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS);

      /* "View.MemoryView":188
 *             if self.mode == u"c":
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             elif self.mode == u"fortran":             # <<<<<<<<<<<<<<
 *                 bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             if not (flags & bufmode):
 */
    }
    __pyx_L4:;

    /* "View.MemoryView":190
 *             elif self.mode == u"fortran":
 *                 bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             if not (flags & bufmode):             # <<<<<<<<<<<<<<
 *                 raise ValueError, "Can only create a buffer that is contiguous in memory."
 *         info.buf = self.data
 */
    __pyx_t_1 = (!((__pyx_v_flags & __pyx_v_bufmode) != 0));
    if (unlikely(__pyx_t_1)) {

      /* "View.MemoryView":191
 *                 bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             if not (flags & bufmode):
 *                 raise ValueError, "Can only create a buffer that is contiguous in memory."             # <<<<<<<<<<<<<<
 *         info.buf = self.data
 *         info.len = self.len
 */
      __Pyx_Raise(__pyx_builtin_ValueError, __pyx_kp_s_Can_only_create_a_buffer_that_is, 0, 0);
      __PYX_ERR(1, 191, __pyx_L1_error)

      /* "View.MemoryView":190
 *             elif self.mode == u"fortran":
 *                 bufmode = PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 *             if not (flags & bufmode):             # <<<<<<<<<<<<<<
 *                 raise ValueError, "Can only create a buffer that is contiguous in memory."
 *         info.buf = self.data
 */
    }

    /* "View.MemoryView":185
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         cdef int bufmode = -1
 *         if flags & (PyBUF_C_CONTIGUOUS | PyBUF_F_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS):             # <<<<<<<<<<<<<<
 *             if self.mode == u"c":
 *                 bufmode = PyBUF_C_CONTIGUOUS | PyBUF_ANY_CONTIGUOUS
 */
  }

  /* "View.MemoryView":192
 *             if not (flags & bufmode):
 *                 raise ValueError, "Can only create a buffer that is contiguous in memory."
 *         info.buf = self.data             # <<<<<<<<<<<<<<
 *         info.len = self.len
 * 
 */
  __pyx_t_2 = __pyx_v_self->data;
  __pyx_v_info->buf = __pyx_t_2;

  /* "View.MemoryView":193
 *                 raise ValueError, "Can only create a buffer that is contiguous in memory."
 *         info.buf = self.data
 *         info.len = self.len             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_STRIDES:
 */
  __pyx_t_3 = __pyx_v_self->len;
  __pyx_v_info->len = __pyx_t_3;

  /* "View.MemoryView":195
 *         info.len = self.len
 * 
 *         if flags & PyBUF_STRIDES:             # <<<<<<<<<<<<<<
 *             info.ndim = self.ndim
 *             info.shape = self._shape
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_STRIDES) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":196
 * 
 *         if flags & PyBUF_STRIDES:
 *             info.ndim = self.ndim             # <<<<<<<<<<<<<<
 *             info.shape = self._shape
 *             info.strides = self._strides
 */
    __pyx_t_4 = __pyx_v_self->ndim;
    __pyx_v_info->ndim = __pyx_t_4;

    /* "View.MemoryView":197
 *         if flags & PyBUF_STRIDES:
 *             info.ndim = self.ndim
 *             info.shape = self._shape             # <<<<<<<<<<<<<<
 *             info.strides = self._strides
 *         else:
 */
    __pyx_t_5 = __pyx_v_self->_shape;
    __pyx_v_info->shape = __pyx_t_5;

    /* "View.MemoryView":198
 *             info.ndim = self.ndim
 *             info.shape = self._shape
 *             info.strides = self._strides             # <<<<<<<<<<<<<<
 *         else:
 *             info.ndim = 1
 */
    __pyx_t_5 = __pyx_v_self->_strides;
    __pyx_v_info->strides = __pyx_t_5;

    /* "View.MemoryView":195
 *         info.len = self.len
 * 
 *         if flags & PyBUF_STRIDES:             # <<<<<<<<<<<<<<
 *             info.ndim = self.ndim
 *             info.shape = self._shape
 */
    goto __pyx_L6;
  }

  /* "View.MemoryView":200
 *             info.strides = self._strides
 *         else:
 *             info.ndim = 1             # <<<<<<<<<<<<<<
 *             info.shape = &self.len if flags & PyBUF_ND else NULL
 *             info.strides = NULL
 */
  /*else*/ {
    __pyx_v_info->ndim = 1;

    /* "View.MemoryView":201
 *         else:
 *             info.ndim = 1
 *             info.shape = &self.len if flags & PyBUF_ND else NULL             # <<<<<<<<<<<<<<
 *             info.strides = NULL
 * 
 */
    __pyx_t_1 = ((__pyx_v_flags & PyBUF_ND) != 0);
    if (__pyx_t_1) {
      __pyx_t_5 = (&__pyx_v_self->len);
    } else {
      __pyx_t_5 = NULL;
    }
    __pyx_v_info->shape = __pyx_t_5;

    /* "View.MemoryView":202
 *             info.ndim = 1
 *             info.shape = &self.len if flags & PyBUF_ND else NULL
 *             info.strides = NULL             # <<<<<<<<<<<<<<
 * 
 *         info.suboffsets = NULL
 */
    __pyx_v_info->strides = NULL;
  }
  __pyx_L6:;

  /* "View.MemoryView":204
 *             info.strides = NULL
 * 
 *         info.suboffsets = NULL             # <<<<<<<<<<<<<<
 *         info.itemsize = self.itemsize
 *         info.readonly = 0
 */
  __pyx_v_info->suboffsets = NULL;

  /* "View.MemoryView":205
 * 
 *         info.suboffsets = NULL
 *         info.itemsize = self.itemsize             # <<<<<<<<<<<<<<
 *         info.readonly = 0
 *         info.format = self.format if flags & PyBUF_FORMAT else NULL
 */
  __pyx_t_3 = __pyx_v_self->itemsize;
  __pyx_v_info->itemsize = __pyx_t_3;

  /* "View.MemoryView":206
 *         info.suboffsets = NULL
 *         info.itemsize = self.itemsize
 *         info.readonly = 0             # <<<<<<<<<<<<<<
 *         info.format = self.format if flags & PyBUF_FORMAT else NULL
 *         info.obj = self
 */
  __pyx_v_info->readonly = 0;

  /* "View.MemoryView":207
 *         info.itemsize = self.itemsize
 *         info.readonly = 0
 *         info.format = self.format if flags & PyBUF_FORMAT else NULL             # <<<<<<<<<<<<<<
 *         info.obj = self
 * 
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_FORMAT) != 0);
  if (__pyx_t_1) {
    __pyx_t_2 = __pyx_v_self->format;
  } else {
    __pyx_t_2 = NULL;
  }
  __pyx_v_info->format = __pyx_t_2;

  /* "View.MemoryView":208
 *         info.readonly = 0
 *         info.format = self.format if flags & PyBUF_FORMAT else NULL
 *         info.obj = self             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(array self):
 */
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  __Pyx_GOTREF(__pyx_v_info->obj);
  __Pyx_DECREF(__pyx_v_info->obj);
  __pyx_v_info->obj = ((PyObject *)__pyx_v_self);

  /* "View.MemoryView":182
 *             _allocate_buffer(self)
 * 
 *     @cname('getbuffer')             # <<<<<<<<<<<<<<
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         cdef int bufmode = -1
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.array.__getbuffer__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  if (__pyx_v_info->obj != NULL) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  goto __pyx_L2;
  __pyx_L0:;
  if (__pyx_v_info->obj == Py_None) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  __pyx_L2:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":210
 *         info.obj = self
 * 
 *     def __dealloc__(array self):             # <<<<<<<<<<<<<<
 *         if self.callback_free_data != NULL:
 *             self.callback_free_data(self.data)
 */

/* Python wrapper */
static void __pyx_array___dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_array___dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_array___pyx_pf_15View_dot_MemoryView_5array_4__dealloc__(((struct __pyx_array_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_array___pyx_pf_15View_dot_MemoryView_5array_4__dealloc__(struct __pyx_array_obj *__pyx_v_self) {
  int __pyx_t_1;
  int __pyx_t_2;

  /* "View.MemoryView":211
 * 
 *     def __dealloc__(array self):
 *         if self.callback_free_data != NULL:             # <<<<<<<<<<<<<<
 *             self.callback_free_data(self.data)
 *         elif self.free_data and self.data is not NULL:
 */
  __pyx_t_1 = (__pyx_v_self->callback_free_data != NULL);
  if (__pyx_t_1) {

    /* "View.MemoryView":212
 *     def __dealloc__(array self):
 *         if self.callback_free_data != NULL:
 *             self.callback_free_data(self.data)             # <<<<<<<<<<<<<<
 *         elif self.free_data and self.data is not NULL:
 *             if self.dtype_is_object:
 */
    __pyx_v_self->callback_free_data(__pyx_v_self->data);

    /* "View.MemoryView":211
 * 
 *     def __dealloc__(array self):
 *         if self.callback_free_data != NULL:             # <<<<<<<<<<<<<<
 *             self.callback_free_data(self.data)
 *         elif self.free_data and self.data is not NULL:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":213
 *         if self.callback_free_data != NULL:
 *             self.callback_free_data(self.data)
 *         elif self.free_data and self.data is not NULL:             # <<<<<<<<<<<<<<
 *             if self.dtype_is_object:
 *                 refcount_objects_in_slice(self.data, self._shape, self._strides, self.ndim, inc=False)
 */
  if (__pyx_v_self->free_data) {
  } else {
    __pyx_t_1 = __pyx_v_self->free_data;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_self->data != NULL);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "View.MemoryView":214
 *             self.callback_free_data(self.data)
 *         elif self.free_data and self.data is not NULL:
 *             if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *                 refcount_objects_in_slice(self.data, self._shape, self._strides, self.ndim, inc=False)
 *             free(self.data)
 */
    if (__pyx_v_self->dtype_is_object) {

      /* "View.MemoryView":215
 *         elif self.free_data and self.data is not NULL:
 *             if self.dtype_is_object:
 *                 refcount_objects_in_slice(self.data, self._shape, self._strides, self.ndim, inc=False)             # <<<<<<<<<<<<<<
 *             free(self.data)
 *         PyObject_Free(self._shape)
 */
      __pyx_memoryview_refcount_objects_in_slice(__pyx_v_self->data, __pyx_v_self->_shape, __pyx_v_self->_strides, __pyx_v_self->ndim, 0);

      /* "View.MemoryView":214
 *             self.callback_free_data(self.data)
 *         elif self.free_data and self.data is not NULL:
 *             if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *                 refcount_objects_in_slice(self.data, self._shape, self._strides, self.ndim, inc=False)
 *             free(self.data)
 */
    }

    /* "View.MemoryView":216
 *             if self.dtype_is_object:
 *                 refcount_objects_in_slice(self.data, self._shape, self._strides, self.ndim, inc=False)
 *             free(self.data)             # <<<<<<<<<<<<<<
 *         PyObject_Free(self._shape)
 * 
 */
    free(__pyx_v_self->data);

    /* "View.MemoryView":213
 *         if self.callback_free_data != NULL:
 *             self.callback_free_data(self.data)
 *         elif self.free_data and self.data is not NULL:             # <<<<<<<<<<<<<<
 *             if self.dtype_is_object:
 *                 refcount_objects_in_slice(self.data, self._shape, self._strides, self.ndim, inc=False)
 */
  }
  __pyx_L3:;

  /* "View.MemoryView":217
 *                 refcount_objects_in_slice(self.data, self._shape, self._strides, self.ndim, inc=False)
 *             free(self.data)
 *         PyObject_Free(self._shape)             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  PyObject_Free(__pyx_v_self->_shape);

  /* "View.MemoryView":210
 *         info.obj = self
 * 
 *     def __dealloc__(array self):             # <<<<<<<<<<<<<<
 *         if self.callback_free_data != NULL:
 *             self.callback_free_data(self.data)
 */

  /* function exit code */
}

/* "View.MemoryView":219
 *         PyObject_Free(self._shape)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def memview(self):
 *         return self.get_memview()
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_5array_7memview_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_5array_7memview_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_5array_7memview___get__(((struct __pyx_array_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_5array_7memview___get__(struct __pyx_array_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "View.MemoryView":221
 *     @property
 *     def memview(self):
 *         return self.get_memview()             # <<<<<<<<<<<<<<
 * 
 *     @cname('get_memview')
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_array *)__pyx_v_self->__pyx_vtab)->get_memview(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":219
 *         PyObject_Free(self._shape)
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def memview(self):
 *         return self.get_memview()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.array.memview.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":224
 * 
 *     @cname('get_memview')
 *     cdef get_memview(self):             # <<<<<<<<<<<<<<
 *         flags =  PyBUF_ANY_CONTIGUOUS|PyBUF_FORMAT|PyBUF_WRITABLE
 *         return  memoryview(self, flags, self.dtype_is_object)
 */

static PyObject *__pyx_array_get_memview(struct __pyx_array_obj *__pyx_v_self) {
  int __pyx_v_flags;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_memview", 1);

  /* "View.MemoryView":225
 *     @cname('get_memview')
 *     cdef get_memview(self):
 *         flags =  PyBUF_ANY_CONTIGUOUS|PyBUF_FORMAT|PyBUF_WRITABLE             # <<<<<<<<<<<<<<
 *         return  memoryview(self, flags, self.dtype_is_object)
 * 
 */
  __pyx_v_flags = ((PyBUF_ANY_CONTIGUOUS | PyBUF_FORMAT) | PyBUF_WRITABLE);

  /* "View.MemoryView":226
 *     cdef get_memview(self):
 *         flags =  PyBUF_ANY_CONTIGUOUS|PyBUF_FORMAT|PyBUF_WRITABLE
 *         return  memoryview(self, flags, self.dtype_is_object)             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_self->dtype_is_object); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_v_self))) __PYX_ERR(1, 226, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1)) __PYX_ERR(1, 226, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_2)) __PYX_ERR(1, 226, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_memoryview_type), __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":224
 * 
 *     @cname('get_memview')
 *     cdef get_memview(self):             # <<<<<<<<<<<<<<
 *         flags =  PyBUF_ANY_CONTIGUOUS|PyBUF_FORMAT|PyBUF_WRITABLE
 *         return  memoryview(self, flags, self.dtype_is_object)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.array.get_memview", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":228
 *         return  memoryview(self, flags, self.dtype_is_object)
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return self._shape[0]
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_array___len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_array___len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array_6__len__(((struct __pyx_array_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_array___pyx_pf_15View_dot_MemoryView_5array_6__len__(struct __pyx_array_obj *__pyx_v_self) {
  Py_ssize_t __pyx_r;

  /* "View.MemoryView":229
 * 
 *     def __len__(self):
 *         return self._shape[0]             # <<<<<<<<<<<<<<
 * 
 *     def __getattr__(self, attr):
 */
  __pyx_r = (__pyx_v_self->_shape[0]);
  goto __pyx_L0;

  /* "View.MemoryView":228
 *         return  memoryview(self, flags, self.dtype_is_object)
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         return self._shape[0]
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":231
 *         return self._shape[0]
 * 
 *     def __getattr__(self, attr):             # <<<<<<<<<<<<<<
 *         return getattr(self.memview, attr)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_array___getattr__(PyObject *__pyx_v_self, PyObject *__pyx_v_attr); /*proto*/
static PyObject *__pyx_array___getattr__(PyObject *__pyx_v_self, PyObject *__pyx_v_attr) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getattr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array_8__getattr__(((struct __pyx_array_obj *)__pyx_v_self), ((PyObject *)__pyx_v_attr));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_array___pyx_pf_15View_dot_MemoryView_5array_8__getattr__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_attr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getattr__", 1);

  /* "View.MemoryView":232
 * 
 *     def __getattr__(self, attr):
 *         return getattr(self.memview, attr)             # <<<<<<<<<<<<<<
 * 
 *     def __getitem__(self, item):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_memview); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_GetAttr(__pyx_t_1, __pyx_v_attr); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 232, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":231
 *         return self._shape[0]
 * 
 *     def __getattr__(self, attr):             # <<<<<<<<<<<<<<
 *         return getattr(self.memview, attr)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.array.__getattr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":234
 *         return getattr(self.memview, attr)
 * 
 *     def __getitem__(self, item):             # <<<<<<<<<<<<<<
 *         return self.memview[item]
 * 
 */

/* Python wrapper */
static PyObject *__pyx_array___getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_item); /*proto*/
static PyObject *__pyx_array___getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_item) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array_10__getitem__(((struct __pyx_array_obj *)__pyx_v_self), ((PyObject *)__pyx_v_item));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_array___pyx_pf_15View_dot_MemoryView_5array_10__getitem__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_item) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 1);

  /* "View.MemoryView":235
 * 
 *     def __getitem__(self, item):
 *         return self.memview[item]             # <<<<<<<<<<<<<<
 * 
 *     def __setitem__(self, item, value):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_memview); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_v_item); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":234
 *         return getattr(self.memview, attr)
 * 
 *     def __getitem__(self, item):             # <<<<<<<<<<<<<<
 *         return self.memview[item]
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.array.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":237
 *         return self.memview[item]
 * 
 *     def __setitem__(self, item, value):             # <<<<<<<<<<<<<<
 *         self.memview[item] = value
 * 
 */

/* Python wrapper */
static int __pyx_array___setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_item, PyObject *__pyx_v_value); /*proto*/
static int __pyx_array___setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_item, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setitem__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_array___pyx_pf_15View_dot_MemoryView_5array_12__setitem__(((struct __pyx_array_obj *)__pyx_v_self), ((PyObject *)__pyx_v_item), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_array___pyx_pf_15View_dot_MemoryView_5array_12__setitem__(struct __pyx_array_obj *__pyx_v_self, PyObject *__pyx_v_item, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setitem__", 1);

  /* "View.MemoryView":238
 * 
 *     def __setitem__(self, item, value):
 *         self.memview[item] = value             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_memview); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (unlikely((PyObject_SetItem(__pyx_t_1, __pyx_v_item, __pyx_v_value) < 0))) __PYX_ERR(1, 238, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "View.MemoryView":237
 *         return self.memview[item]
 * 
 *     def __setitem__(self, item, value):             # <<<<<<<<<<<<<<
 *         self.memview[item] = value
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.array.__setitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_array_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_array_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf___pyx_array___reduce_cython__(((struct __pyx_array_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_array___reduce_cython__(CYTHON_UNUSED struct __pyx_array_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.array.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_array_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_array_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("View.MemoryView.array.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf___pyx_array_2__setstate_cython__(((struct __pyx_array_obj *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_array_2__setstate_cython__(CYTHON_UNUSED struct __pyx_array_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.array.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":248
 * 
 * @cname("__pyx_array_allocate_buffer")
 * cdef int _allocate_buffer(array self) except -1:             # <<<<<<<<<<<<<<
 * 
 * 
 */

static int __pyx_array_allocate_buffer(struct __pyx_array_obj *__pyx_v_self) {
  Py_ssize_t __pyx_v_i;
  PyObject **__pyx_v_p;
  int __pyx_r;
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "View.MemoryView":254
 *     cdef PyObject **p
 * 
 *     self.free_data = True             # <<<<<<<<<<<<<<
 *     self.data = <char *>malloc(self.len)
 *     if not self.data:
 */
  __pyx_v_self->free_data = 1;

  /* "View.MemoryView":255
 * 
 *     self.free_data = True
 *     self.data = <char *>malloc(self.len)             # <<<<<<<<<<<<<<
 *     if not self.data:
 *         raise MemoryError, "unable to allocate array data."
 */
  __pyx_v_self->data = ((char *)malloc(__pyx_v_self->len));

  /* "View.MemoryView":256
 *     self.free_data = True
 *     self.data = <char *>malloc(self.len)
 *     if not self.data:             # <<<<<<<<<<<<<<
 *         raise MemoryError, "unable to allocate array data."
 * 
 */
  __pyx_t_1 = (!(__pyx_v_self->data != 0));
  if (unlikely(__pyx_t_1)) {

    /* "View.MemoryView":257
 *     self.data = <char *>malloc(self.len)
 *     if not self.data:
 *         raise MemoryError, "unable to allocate array data."             # <<<<<<<<<<<<<<
 * 
 *     if self.dtype_is_object:
 */
    __Pyx_Raise(__pyx_builtin_MemoryError, __pyx_kp_s_unable_to_allocate_array_data, 0, 0);
    __PYX_ERR(1, 257, __pyx_L1_error)

    /* "View.MemoryView":256
 *     self.free_data = True
 *     self.data = <char *>malloc(self.len)
 *     if not self.data:             # <<<<<<<<<<<<<<
 *         raise MemoryError, "unable to allocate array data."
 * 
 */
  }

  /* "View.MemoryView":259
 *         raise MemoryError, "unable to allocate array data."
 * 
 *     if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *         p = <PyObject **> self.data
 *         for i in range(self.len // self.itemsize):
 */
  if (__pyx_v_self->dtype_is_object) {

    /* "View.MemoryView":260
 * 
 *     if self.dtype_is_object:
 *         p = <PyObject **> self.data             # <<<<<<<<<<<<<<
 *         for i in range(self.len // self.itemsize):
 *             p[i] = Py_None
 */
    __pyx_v_p = ((PyObject **)__pyx_v_self->data);

    /* "View.MemoryView":261
 *     if self.dtype_is_object:
 *         p = <PyObject **> self.data
 *         for i in range(self.len // self.itemsize):             # <<<<<<<<<<<<<<
 *             p[i] = Py_None
 *             Py_INCREF(Py_None)
 */
    if (unlikely(__pyx_v_self->itemsize == 0)) {
      PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
      __PYX_ERR(1, 261, __pyx_L1_error)
    }
    else if (sizeof(Py_ssize_t) == sizeof(long) && (!(((Py_ssize_t)-1) > 0)) && unlikely(__pyx_v_self->itemsize == (Py_ssize_t)-1)  && unlikely(__Pyx_UNARY_NEG_WOULD_OVERFLOW(__pyx_v_self->len))) {
      PyErr_SetString(PyExc_OverflowError, "value too large to perform division");
      __PYX_ERR(1, 261, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_div_Py_ssize_t(__pyx_v_self->len, __pyx_v_self->itemsize);
    __pyx_t_3 = __pyx_t_2;
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_i = __pyx_t_4;

      /* "View.MemoryView":262
 *         p = <PyObject **> self.data
 *         for i in range(self.len // self.itemsize):
 *             p[i] = Py_None             # <<<<<<<<<<<<<<
 *             Py_INCREF(Py_None)
 *     return 0
 */
      (__pyx_v_p[__pyx_v_i]) = Py_None;

      /* "View.MemoryView":263
 *         for i in range(self.len // self.itemsize):
 *             p[i] = Py_None
 *             Py_INCREF(Py_None)             # <<<<<<<<<<<<<<
 *     return 0
 * 
 */
      Py_INCREF(Py_None);
    }

    /* "View.MemoryView":259
 *         raise MemoryError, "unable to allocate array data."
 * 
 *     if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *         p = <PyObject **> self.data
 *         for i in range(self.len // self.itemsize):
 */
  }

  /* "View.MemoryView":264
 *             p[i] = Py_None
 *             Py_INCREF(Py_None)
 *     return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "View.MemoryView":248
 * 
 * @cname("__pyx_array_allocate_buffer")
 * cdef int _allocate_buffer(array self) except -1:             # <<<<<<<<<<<<<<
 * 
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView._allocate_buffer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":268
 * 
 * @cname("__pyx_array_new")
 * cdef array array_cwrapper(tuple shape, Py_ssize_t itemsize, char *format, char *c_mode, char *buf):             # <<<<<<<<<<<<<<
 *     cdef array result
 *     cdef str mode = "fortran" if c_mode[0] == b'f' else "c"  # this often comes from a constant C string.
 */

static struct __pyx_array_obj *__pyx_array_new(PyObject *__pyx_v_shape, Py_ssize_t __pyx_v_itemsize, char *__pyx_v_format, char *__pyx_v_c_mode, char *__pyx_v_buf) {
  struct __pyx_array_obj *__pyx_v_result = 0;
  PyObject *__pyx_v_mode = 0;
  struct __pyx_array_obj *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("array_cwrapper", 1);

  /* "View.MemoryView":270
 * cdef array array_cwrapper(tuple shape, Py_ssize_t itemsize, char *format, char *c_mode, char *buf):
 *     cdef array result
 *     cdef str mode = "fortran" if c_mode[0] == b'f' else "c"  # this often comes from a constant C string.             # <<<<<<<<<<<<<<
 * 
 *     if buf is NULL:
 */
  __pyx_t_2 = ((__pyx_v_c_mode[0]) == 'f');
  if (__pyx_t_2) {
    __Pyx_INCREF(__pyx_n_s_fortran);
    __pyx_t_1 = __pyx_n_s_fortran;
  } else {
    __Pyx_INCREF(__pyx_n_s_c);
    __pyx_t_1 = __pyx_n_s_c;
  }
  __pyx_v_mode = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "View.MemoryView":272
 *     cdef str mode = "fortran" if c_mode[0] == b'f' else "c"  # this often comes from a constant C string.
 * 
 *     if buf is NULL:             # <<<<<<<<<<<<<<
 *         result = array.__new__(array, shape, itemsize, format, mode)
 *     else:
 */
  __pyx_t_2 = (__pyx_v_buf == NULL);
  if (__pyx_t_2) {

    /* "View.MemoryView":273
 * 
 *     if buf is NULL:
 *         result = array.__new__(array, shape, itemsize, format, mode)             # <<<<<<<<<<<<<<
 *     else:
 *         result = array.__new__(array, shape, itemsize, format, mode, allocate_buffer=False)
 */
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_itemsize); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyBytes_FromString(__pyx_v_format); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_INCREF(__pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_shape)) __PYX_ERR(1, 273, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1)) __PYX_ERR(1, 273, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_t_3)) __PYX_ERR(1, 273, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_mode);
    __Pyx_GIVEREF(__pyx_v_mode);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 3, __pyx_v_mode)) __PYX_ERR(1, 273, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_3 = 0;
    __pyx_t_3 = ((PyObject *)__pyx_tp_new_array(((PyTypeObject *)__pyx_array_type), __pyx_t_4, NULL)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 273, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_result = ((struct __pyx_array_obj *)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "View.MemoryView":272
 *     cdef str mode = "fortran" if c_mode[0] == b'f' else "c"  # this often comes from a constant C string.
 * 
 *     if buf is NULL:             # <<<<<<<<<<<<<<
 *         result = array.__new__(array, shape, itemsize, format, mode)
 *     else:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":275
 *         result = array.__new__(array, shape, itemsize, format, mode)
 *     else:
 *         result = array.__new__(array, shape, itemsize, format, mode, allocate_buffer=False)             # <<<<<<<<<<<<<<
 *         result.data = buf
 * 
 */
  /*else*/ {
    __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_itemsize); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyBytes_FromString(__pyx_v_format); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_shape);
    __Pyx_GIVEREF(__pyx_v_shape);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_shape)) __PYX_ERR(1, 275, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_3)) __PYX_ERR(1, 275, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_t_4)) __PYX_ERR(1, 275, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_mode);
    __Pyx_GIVEREF(__pyx_v_mode);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_v_mode)) __PYX_ERR(1, 275, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_allocate_buffer, Py_False) < 0) __PYX_ERR(1, 275, __pyx_L1_error)
    __pyx_t_3 = ((PyObject *)__pyx_tp_new_array(((PyTypeObject *)__pyx_array_type), __pyx_t_1, __pyx_t_4)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 275, __pyx_L1_error)
    __Pyx_GOTREF((PyObject *)__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_v_result = ((struct __pyx_array_obj *)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "View.MemoryView":276
 *     else:
 *         result = array.__new__(array, shape, itemsize, format, mode, allocate_buffer=False)
 *         result.data = buf             # <<<<<<<<<<<<<<
 * 
 *     return result
 */
    __pyx_v_result->data = __pyx_v_buf;
  }
  __pyx_L3:;

  /* "View.MemoryView":278
 *         result.data = buf
 * 
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "View.MemoryView":268
 * 
 * @cname("__pyx_array_new")
 * cdef array array_cwrapper(tuple shape, Py_ssize_t itemsize, char *format, char *c_mode, char *buf):             # <<<<<<<<<<<<<<
 *     cdef array result
 *     cdef str mode = "fortran" if c_mode[0] == b'f' else "c"  # this often comes from a constant C string.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("View.MemoryView.array_cwrapper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_mode);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":304
 * cdef class Enum(object):
 *     cdef object name
 *     def __init__(self, name):             # <<<<<<<<<<<<<<
 *         self.name = name
 *     def __repr__(self):
 */

/* Python wrapper */
static int __pyx_MemviewEnum___init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_MemviewEnum___init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_name = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_name,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_name)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 304, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(1, 304, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_name = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 304, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("View.MemoryView.Enum.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum___init__(((struct __pyx_MemviewEnum_obj *)__pyx_v_self), __pyx_v_name);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum___init__(struct __pyx_MemviewEnum_obj *__pyx_v_self, PyObject *__pyx_v_name) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "View.MemoryView":305
 *     cdef object name
 *     def __init__(self, name):
 *         self.name = name             # <<<<<<<<<<<<<<
 *     def __repr__(self):
 *         return self.name
 */
  __Pyx_INCREF(__pyx_v_name);
  __Pyx_GIVEREF(__pyx_v_name);
  __Pyx_GOTREF(__pyx_v_self->name);
  __Pyx_DECREF(__pyx_v_self->name);
  __pyx_v_self->name = __pyx_v_name;

  /* "View.MemoryView":304
 * cdef class Enum(object):
 *     cdef object name
 *     def __init__(self, name):             # <<<<<<<<<<<<<<
 *         self.name = name
 *     def __repr__(self):
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":306
 *     def __init__(self, name):
 *         self.name = name
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return self.name
 * 
 */

/* Python wrapper */
static PyObject *__pyx_MemviewEnum___repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_MemviewEnum___repr__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum_2__repr__(((struct __pyx_MemviewEnum_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_MemviewEnum___pyx_pf_15View_dot_MemoryView_4Enum_2__repr__(struct __pyx_MemviewEnum_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__", 1);

  /* "View.MemoryView":307
 *         self.name = name
 *     def __repr__(self):
 *         return self.name             # <<<<<<<<<<<<<<
 * 
 * cdef generic = Enum("<strided and direct or indirect>")
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->name);
  __pyx_r = __pyx_v_self->name;
  goto __pyx_L0;

  /* "View.MemoryView":306
 *     def __init__(self, name):
 *         self.name = name
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return self.name
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_MemviewEnum_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_MemviewEnum_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf___pyx_MemviewEnum___reduce_cython__(((struct __pyx_MemviewEnum_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_MemviewEnum___reduce_cython__(struct __pyx_MemviewEnum_obj *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.name,)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_self->name);
  __Pyx_GIVEREF(__pyx_v_self->name);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->name)) __PYX_ERR(1, 5, __pyx_L1_error);
  __pyx_v_state = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.name,)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = (self.name,)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  if (__pyx_t_2) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict)) __PYX_ERR(1, 8, __pyx_L1_error);
    __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.name is not None
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = (self.name,)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.name is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, None), state
 */
  /*else*/ {
    __pyx_t_2 = (__pyx_v_self->name != Py_None);
    __pyx_v_use_setstate = __pyx_t_2;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.name is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, None), state
 *     else:
 */
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = self.name is not None
 *     if use_setstate:
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pyx_unpickle_Enum); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))))) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_int_136983863);
    __Pyx_GIVEREF(__pyx_int_136983863);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_136983863)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None)) __PYX_ERR(1, 13, __pyx_L1_error);
    __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_v_state)) __PYX_ERR(1, 13, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.name is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, None), state
 *     else:
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Enum__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_Enum); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))))) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_int_136983863);
    __Pyx_GIVEREF(__pyx_int_136983863);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_136983863)) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state)) __PYX_ERR(1, 15, __pyx_L1_error);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("View.MemoryView.Enum.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Enum__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_MemviewEnum_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_MemviewEnum_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 16, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 16, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 16, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("View.MemoryView.Enum.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf___pyx_MemviewEnum_2__setstate_cython__(((struct __pyx_MemviewEnum_obj *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_MemviewEnum_2__setstate_cython__(struct __pyx_MemviewEnum_obj *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_Enum__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_unpickle_Enum__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_Enum, (type(self), 0x82a3537, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_Enum__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.Enum.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":349
 *     cdef __Pyx_TypeInfo *typeinfo
 * 
 *     def __cinit__(memoryview self, object obj, int flags, bint dtype_is_object=False):             # <<<<<<<<<<<<<<
 *         self.obj = obj
 *         self.flags = flags
 */

/* Python wrapper */
static int __pyx_memoryview___cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_memoryview___cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_obj = 0;
  int __pyx_v_flags;
  int __pyx_v_dtype_is_object;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_obj,&__pyx_n_s_flags,&__pyx_n_s_dtype_is_object,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_obj)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 349, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_flags)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 349, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 2, 3, 1); __PYX_ERR(1, 349, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dtype_is_object);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 349, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(1, 349, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_obj = values[0];
    __pyx_v_flags = __Pyx_PyInt_As_int(values[1]); if (unlikely((__pyx_v_flags == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 349, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_dtype_is_object = __Pyx_PyObject_IsTrue(values[2]); if (unlikely((__pyx_v_dtype_is_object == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 349, __pyx_L3_error)
    } else {
      __pyx_v_dtype_is_object = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 2, 3, __pyx_nargs); __PYX_ERR(1, 349, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("View.MemoryView.memoryview.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview___cinit__(((struct __pyx_memoryview_obj *)__pyx_v_self), __pyx_v_obj, __pyx_v_flags, __pyx_v_dtype_is_object);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview___cinit__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_obj, int __pyx_v_flags, int __pyx_v_dtype_is_object) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  Py_intptr_t __pyx_t_4;
  size_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "View.MemoryView":350
 * 
 *     def __cinit__(memoryview self, object obj, int flags, bint dtype_is_object=False):
 *         self.obj = obj             # <<<<<<<<<<<<<<
 *         self.flags = flags
 *         if type(self) is memoryview or obj is not None:
 */
  __Pyx_INCREF(__pyx_v_obj);
  __Pyx_GIVEREF(__pyx_v_obj);
  __Pyx_GOTREF(__pyx_v_self->obj);
  __Pyx_DECREF(__pyx_v_self->obj);
  __pyx_v_self->obj = __pyx_v_obj;

  /* "View.MemoryView":351
 *     def __cinit__(memoryview self, object obj, int flags, bint dtype_is_object=False):
 *         self.obj = obj
 *         self.flags = flags             # <<<<<<<<<<<<<<
 *         if type(self) is memoryview or obj is not None:
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 */
  __pyx_v_self->flags = __pyx_v_flags;

  /* "View.MemoryView":352
 *         self.obj = obj
 *         self.flags = flags
 *         if type(self) is memoryview or obj is not None:             # <<<<<<<<<<<<<<
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 *             if <PyObject *> self.view.obj == NULL:
 */
  __pyx_t_2 = (((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))) == ((PyObject *)__pyx_memoryview_type));
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_obj != Py_None);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "View.MemoryView":353
 *         self.flags = flags
 *         if type(self) is memoryview or obj is not None:
 *             __Pyx_GetBuffer(obj, &self.view, flags)             # <<<<<<<<<<<<<<
 *             if <PyObject *> self.view.obj == NULL:
 *                 (<__pyx_buffer *> &self.view).obj = Py_None
 */
    __pyx_t_3 = __Pyx_GetBuffer(__pyx_v_obj, (&__pyx_v_self->view), __pyx_v_flags); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(1, 353, __pyx_L1_error)

    /* "View.MemoryView":354
 *         if type(self) is memoryview or obj is not None:
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 *             if <PyObject *> self.view.obj == NULL:             # <<<<<<<<<<<<<<
 *                 (<__pyx_buffer *> &self.view).obj = Py_None
 *                 Py_INCREF(Py_None)
 */
    __pyx_t_1 = (((PyObject *)__pyx_v_self->view.obj) == NULL);
    if (__pyx_t_1) {

      /* "View.MemoryView":355
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 *             if <PyObject *> self.view.obj == NULL:
 *                 (<__pyx_buffer *> &self.view).obj = Py_None             # <<<<<<<<<<<<<<
 *                 Py_INCREF(Py_None)
 * 
 */
      ((Py_buffer *)(&__pyx_v_self->view))->obj = Py_None;

      /* "View.MemoryView":356
 *             if <PyObject *> self.view.obj == NULL:
 *                 (<__pyx_buffer *> &self.view).obj = Py_None
 *                 Py_INCREF(Py_None)             # <<<<<<<<<<<<<<
 * 
 *         if not __PYX_CYTHON_ATOMICS_ENABLED():
 */
      Py_INCREF(Py_None);

      /* "View.MemoryView":354
 *         if type(self) is memoryview or obj is not None:
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 *             if <PyObject *> self.view.obj == NULL:             # <<<<<<<<<<<<<<
 *                 (<__pyx_buffer *> &self.view).obj = Py_None
 *                 Py_INCREF(Py_None)
 */
    }

    /* "View.MemoryView":352
 *         self.obj = obj
 *         self.flags = flags
 *         if type(self) is memoryview or obj is not None:             # <<<<<<<<<<<<<<
 *             __Pyx_GetBuffer(obj, &self.view, flags)
 *             if <PyObject *> self.view.obj == NULL:
 */
  }

  /* "View.MemoryView":358
 *                 Py_INCREF(Py_None)
 * 
 *         if not __PYX_CYTHON_ATOMICS_ENABLED():             # <<<<<<<<<<<<<<
 *             global __pyx_memoryview_thread_locks_used
 *             if __pyx_memoryview_thread_locks_used < 8:
 */
  __pyx_t_1 = (!__PYX_CYTHON_ATOMICS_ENABLED());
  if (__pyx_t_1) {

    /* "View.MemoryView":360
 *         if not __PYX_CYTHON_ATOMICS_ENABLED():
 *             global __pyx_memoryview_thread_locks_used
 *             if __pyx_memoryview_thread_locks_used < 8:             # <<<<<<<<<<<<<<
 *                 self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]
 *                 __pyx_memoryview_thread_locks_used += 1
 */
    __pyx_t_1 = (__pyx_memoryview_thread_locks_used < 8);
    if (__pyx_t_1) {

      /* "View.MemoryView":361
 *             global __pyx_memoryview_thread_locks_used
 *             if __pyx_memoryview_thread_locks_used < 8:
 *                 self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]             # <<<<<<<<<<<<<<
 *                 __pyx_memoryview_thread_locks_used += 1
 *             if self.lock is NULL:
 */
      __pyx_v_self->lock = (__pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]);

      /* "View.MemoryView":362
 *             if __pyx_memoryview_thread_locks_used < 8:
 *                 self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]
 *                 __pyx_memoryview_thread_locks_used += 1             # <<<<<<<<<<<<<<
 *             if self.lock is NULL:
 *                 self.lock = PyThread_allocate_lock()
 */
      __pyx_memoryview_thread_locks_used = (__pyx_memoryview_thread_locks_used + 1);

      /* "View.MemoryView":360
 *         if not __PYX_CYTHON_ATOMICS_ENABLED():
 *             global __pyx_memoryview_thread_locks_used
 *             if __pyx_memoryview_thread_locks_used < 8:             # <<<<<<<<<<<<<<
 *                 self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]
 *                 __pyx_memoryview_thread_locks_used += 1
 */
    }

    /* "View.MemoryView":363
 *                 self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]
 *                 __pyx_memoryview_thread_locks_used += 1
 *             if self.lock is NULL:             # <<<<<<<<<<<<<<
 *                 self.lock = PyThread_allocate_lock()
 *                 if self.lock is NULL:
 */
    __pyx_t_1 = (__pyx_v_self->lock == NULL);
    if (__pyx_t_1) {

      /* "View.MemoryView":364
 *                 __pyx_memoryview_thread_locks_used += 1
 *             if self.lock is NULL:
 *                 self.lock = PyThread_allocate_lock()             # <<<<<<<<<<<<<<
 *                 if self.lock is NULL:
 *                     raise MemoryError
 */
      __pyx_v_self->lock = PyThread_allocate_lock();

      /* "View.MemoryView":365
 *             if self.lock is NULL:
 *                 self.lock = PyThread_allocate_lock()
 *                 if self.lock is NULL:             # <<<<<<<<<<<<<<
 *                     raise MemoryError
 * 
 */
      __pyx_t_1 = (__pyx_v_self->lock == NULL);
      if (unlikely(__pyx_t_1)) {

        /* "View.MemoryView":366
 *                 self.lock = PyThread_allocate_lock()
 *                 if self.lock is NULL:
 *                     raise MemoryError             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_FORMAT:
 */
        PyErr_NoMemory(); __PYX_ERR(1, 366, __pyx_L1_error)

        /* "View.MemoryView":365
 *             if self.lock is NULL:
 *                 self.lock = PyThread_allocate_lock()
 *                 if self.lock is NULL:             # <<<<<<<<<<<<<<
 *                     raise MemoryError
 * 
 */
      }

      /* "View.MemoryView":363
 *                 self.lock = __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]
 *                 __pyx_memoryview_thread_locks_used += 1
 *             if self.lock is NULL:             # <<<<<<<<<<<<<<
 *                 self.lock = PyThread_allocate_lock()
 *                 if self.lock is NULL:
 */
    }

    /* "View.MemoryView":358
 *                 Py_INCREF(Py_None)
 * 
 *         if not __PYX_CYTHON_ATOMICS_ENABLED():             # <<<<<<<<<<<<<<
 *             global __pyx_memoryview_thread_locks_used
 *             if __pyx_memoryview_thread_locks_used < 8:
 */
  }

  /* "View.MemoryView":368
 *                     raise MemoryError
 * 
 *         if flags & PyBUF_FORMAT:             # <<<<<<<<<<<<<<
 *             self.dtype_is_object = (self.view.format[0] == b'O' and self.view.format[1] == b'\0')
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_FORMAT) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":369
 * 
 *         if flags & PyBUF_FORMAT:
 *             self.dtype_is_object = (self.view.format[0] == b'O' and self.view.format[1] == b'\0')             # <<<<<<<<<<<<<<
 *         else:
 *             self.dtype_is_object = dtype_is_object
 */
    __pyx_t_2 = ((__pyx_v_self->view.format[0]) == 'O');
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L12_bool_binop_done;
    }
    __pyx_t_2 = ((__pyx_v_self->view.format[1]) == '\x00');
    __pyx_t_1 = __pyx_t_2;
    __pyx_L12_bool_binop_done:;
    __pyx_v_self->dtype_is_object = __pyx_t_1;

    /* "View.MemoryView":368
 *                     raise MemoryError
 * 
 *         if flags & PyBUF_FORMAT:             # <<<<<<<<<<<<<<
 *             self.dtype_is_object = (self.view.format[0] == b'O' and self.view.format[1] == b'\0')
 *         else:
 */
    goto __pyx_L11;
  }

  /* "View.MemoryView":371
 *             self.dtype_is_object = (self.view.format[0] == b'O' and self.view.format[1] == b'\0')
 *         else:
 *             self.dtype_is_object = dtype_is_object             # <<<<<<<<<<<<<<
 * 
 *         assert <Py_intptr_t><void*>(&self.acquisition_count) % sizeof(__pyx_atomic_int_type) == 0
 */
  /*else*/ {
    __pyx_v_self->dtype_is_object = __pyx_v_dtype_is_object;
  }
  __pyx_L11:;

  /* "View.MemoryView":373
 *             self.dtype_is_object = dtype_is_object
 * 
 *         assert <Py_intptr_t><void*>(&self.acquisition_count) % sizeof(__pyx_atomic_int_type) == 0             # <<<<<<<<<<<<<<
 *         self.typeinfo = NULL
 * 
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    __pyx_t_4 = ((Py_intptr_t)((void *)(&__pyx_v_self->acquisition_count)));
    __pyx_t_5 = (sizeof(__pyx_atomic_int_type));
    if (unlikely(__pyx_t_5 == 0)) {
      PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
      __PYX_ERR(1, 373, __pyx_L1_error)
    }
    __pyx_t_1 = ((__pyx_t_4 % __pyx_t_5) == 0);
    if (unlikely(!__pyx_t_1)) {
      __Pyx_Raise(__pyx_builtin_AssertionError, 0, 0, 0);
      __PYX_ERR(1, 373, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(1, 373, __pyx_L1_error)
  #endif

  /* "View.MemoryView":374
 * 
 *         assert <Py_intptr_t><void*>(&self.acquisition_count) % sizeof(__pyx_atomic_int_type) == 0
 *         self.typeinfo = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(memoryview self):
 */
  __pyx_v_self->typeinfo = NULL;

  /* "View.MemoryView":349
 *     cdef __Pyx_TypeInfo *typeinfo
 * 
 *     def __cinit__(memoryview self, object obj, int flags, bint dtype_is_object=False):             # <<<<<<<<<<<<<<
 *         self.obj = obj
 *         self.flags = flags
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.memoryview.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":376
 *         self.typeinfo = NULL
 * 
 *     def __dealloc__(memoryview self):             # <<<<<<<<<<<<<<
 *         if self.obj is not None:
 *             __Pyx_ReleaseBuffer(&self.view)
 */

/* Python wrapper */
static void __pyx_memoryview___dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_memoryview___dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_2__dealloc__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_2__dealloc__(struct __pyx_memoryview_obj *__pyx_v_self) {
  int __pyx_v_i;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  PyThread_type_lock __pyx_t_5;
  PyThread_type_lock __pyx_t_6;

  /* "View.MemoryView":377
 * 
 *     def __dealloc__(memoryview self):
 *         if self.obj is not None:             # <<<<<<<<<<<<<<
 *             __Pyx_ReleaseBuffer(&self.view)
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:
 */
  __pyx_t_1 = (__pyx_v_self->obj != Py_None);
  if (__pyx_t_1) {

    /* "View.MemoryView":378
 *     def __dealloc__(memoryview self):
 *         if self.obj is not None:
 *             __Pyx_ReleaseBuffer(&self.view)             # <<<<<<<<<<<<<<
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:
 * 
 */
    __Pyx_ReleaseBuffer((&__pyx_v_self->view));

    /* "View.MemoryView":377
 * 
 *     def __dealloc__(memoryview self):
 *         if self.obj is not None:             # <<<<<<<<<<<<<<
 *             __Pyx_ReleaseBuffer(&self.view)
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":379
 *         if self.obj is not None:
 *             __Pyx_ReleaseBuffer(&self.view)
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:             # <<<<<<<<<<<<<<
 * 
 *             (<__pyx_buffer *> &self.view).obj = NULL
 */
  __pyx_t_1 = (((Py_buffer *)(&__pyx_v_self->view))->obj == Py_None);
  if (__pyx_t_1) {

    /* "View.MemoryView":381
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:
 * 
 *             (<__pyx_buffer *> &self.view).obj = NULL             # <<<<<<<<<<<<<<
 *             Py_DECREF(Py_None)
 * 
 */
    ((Py_buffer *)(&__pyx_v_self->view))->obj = NULL;

    /* "View.MemoryView":382
 * 
 *             (<__pyx_buffer *> &self.view).obj = NULL
 *             Py_DECREF(Py_None)             # <<<<<<<<<<<<<<
 * 
 *         cdef int i
 */
    Py_DECREF(Py_None);

    /* "View.MemoryView":379
 *         if self.obj is not None:
 *             __Pyx_ReleaseBuffer(&self.view)
 *         elif (<__pyx_buffer *> &self.view).obj == Py_None:             # <<<<<<<<<<<<<<
 * 
 *             (<__pyx_buffer *> &self.view).obj = NULL
 */
  }
  __pyx_L3:;

  /* "View.MemoryView":386
 *         cdef int i
 *         global __pyx_memoryview_thread_locks_used
 *         if self.lock != NULL:             # <<<<<<<<<<<<<<
 *             for i in range(__pyx_memoryview_thread_locks_used):
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 */
  __pyx_t_1 = (__pyx_v_self->lock != NULL);
  if (__pyx_t_1) {

    /* "View.MemoryView":387
 *         global __pyx_memoryview_thread_locks_used
 *         if self.lock != NULL:
 *             for i in range(__pyx_memoryview_thread_locks_used):             # <<<<<<<<<<<<<<
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 *                     __pyx_memoryview_thread_locks_used -= 1
 */
    __pyx_t_2 = __pyx_memoryview_thread_locks_used;
    __pyx_t_3 = __pyx_t_2;
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_i = __pyx_t_4;

      /* "View.MemoryView":388
 *         if self.lock != NULL:
 *             for i in range(__pyx_memoryview_thread_locks_used):
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:             # <<<<<<<<<<<<<<
 *                     __pyx_memoryview_thread_locks_used -= 1
 *                     if i != __pyx_memoryview_thread_locks_used:
 */
      __pyx_t_1 = ((__pyx_memoryview_thread_locks[__pyx_v_i]) == __pyx_v_self->lock);
      if (__pyx_t_1) {

        /* "View.MemoryView":389
 *             for i in range(__pyx_memoryview_thread_locks_used):
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 *                     __pyx_memoryview_thread_locks_used -= 1             # <<<<<<<<<<<<<<
 *                     if i != __pyx_memoryview_thread_locks_used:
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (
 */
        __pyx_memoryview_thread_locks_used = (__pyx_memoryview_thread_locks_used - 1);

        /* "View.MemoryView":390
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 *                     __pyx_memoryview_thread_locks_used -= 1
 *                     if i != __pyx_memoryview_thread_locks_used:             # <<<<<<<<<<<<<<
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (
 *                             __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used], __pyx_memoryview_thread_locks[i])
 */
        __pyx_t_1 = (__pyx_v_i != __pyx_memoryview_thread_locks_used);
        if (__pyx_t_1) {

          /* "View.MemoryView":392
 *                     if i != __pyx_memoryview_thread_locks_used:
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (
 *                             __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used], __pyx_memoryview_thread_locks[i])             # <<<<<<<<<<<<<<
 *                     break
 *             else:
 */
          __pyx_t_5 = (__pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]);
          __pyx_t_6 = (__pyx_memoryview_thread_locks[__pyx_v_i]);

          /* "View.MemoryView":391
 *                     __pyx_memoryview_thread_locks_used -= 1
 *                     if i != __pyx_memoryview_thread_locks_used:
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (             # <<<<<<<<<<<<<<
 *                             __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used], __pyx_memoryview_thread_locks[i])
 *                     break
 */
          (__pyx_memoryview_thread_locks[__pyx_v_i]) = __pyx_t_5;
          (__pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used]) = __pyx_t_6;

          /* "View.MemoryView":390
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 *                     __pyx_memoryview_thread_locks_used -= 1
 *                     if i != __pyx_memoryview_thread_locks_used:             # <<<<<<<<<<<<<<
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (
 *                             __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used], __pyx_memoryview_thread_locks[i])
 */
        }

        /* "View.MemoryView":393
 *                         __pyx_memoryview_thread_locks[i], __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used] = (
 *                             __pyx_memoryview_thread_locks[__pyx_memoryview_thread_locks_used], __pyx_memoryview_thread_locks[i])
 *                     break             # <<<<<<<<<<<<<<
 *             else:
 *                 PyThread_free_lock(self.lock)
 */
        goto __pyx_L6_break;

        /* "View.MemoryView":388
 *         if self.lock != NULL:
 *             for i in range(__pyx_memoryview_thread_locks_used):
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:             # <<<<<<<<<<<<<<
 *                     __pyx_memoryview_thread_locks_used -= 1
 *                     if i != __pyx_memoryview_thread_locks_used:
 */
      }
    }
    /*else*/ {

      /* "View.MemoryView":395
 *                     break
 *             else:
 *                 PyThread_free_lock(self.lock)             # <<<<<<<<<<<<<<
 * 
 *     cdef char *get_item_pointer(memoryview self, object index) except NULL:
 */
      PyThread_free_lock(__pyx_v_self->lock);
    }
    __pyx_L6_break:;

    /* "View.MemoryView":386
 *         cdef int i
 *         global __pyx_memoryview_thread_locks_used
 *         if self.lock != NULL:             # <<<<<<<<<<<<<<
 *             for i in range(__pyx_memoryview_thread_locks_used):
 *                 if __pyx_memoryview_thread_locks[i] is self.lock:
 */
  }

  /* "View.MemoryView":376
 *         self.typeinfo = NULL
 * 
 *     def __dealloc__(memoryview self):             # <<<<<<<<<<<<<<
 *         if self.obj is not None:
 *             __Pyx_ReleaseBuffer(&self.view)
 */

  /* function exit code */
}

/* "View.MemoryView":397
 *                 PyThread_free_lock(self.lock)
 * 
 *     cdef char *get_item_pointer(memoryview self, object index) except NULL:             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t dim
 *         cdef char *itemp = <char *> self.view.buf
 */

static char *__pyx_memoryview_get_item_pointer(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index) {
  Py_ssize_t __pyx_v_dim;
  char *__pyx_v_itemp;
  PyObject *__pyx_v_idx = NULL;
  char *__pyx_r;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  PyObject *(*__pyx_t_4)(PyObject *);
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  char *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item_pointer", 1);

  /* "View.MemoryView":399
 *     cdef char *get_item_pointer(memoryview self, object index) except NULL:
 *         cdef Py_ssize_t dim
 *         cdef char *itemp = <char *> self.view.buf             # <<<<<<<<<<<<<<
 * 
 *         for dim, idx in enumerate(index):
 */
  __pyx_v_itemp = ((char *)__pyx_v_self->view.buf);

  /* "View.MemoryView":401
 *         cdef char *itemp = <char *> self.view.buf
 * 
 *         for dim, idx in enumerate(index):             # <<<<<<<<<<<<<<
 *             itemp = pybuffer_index(&self.view, itemp, idx, dim)
 * 
 */
  __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_v_index)) || PyTuple_CheckExact(__pyx_v_index)) {
    __pyx_t_2 = __pyx_v_index; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_3 = 0;
    __pyx_t_4 = NULL;
  } else {
    __pyx_t_3 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_index); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 401, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 401, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_4)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(1, 401, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(1, 401, __pyx_L1_error)
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 401, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(1, 401, __pyx_L1_error)
          #endif
          if (__pyx_t_3 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_5 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_3); __Pyx_INCREF(__pyx_t_5); __pyx_t_3++; if (unlikely((0 < 0))) __PYX_ERR(1, 401, __pyx_L1_error)
        #else
        __pyx_t_5 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_3); __pyx_t_3++; if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 401, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_5);
        #endif
      }
    } else {
      __pyx_t_5 = __pyx_t_4(__pyx_t_2);
      if (unlikely(!__pyx_t_5)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(1, 401, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_5);
    }
    __Pyx_XDECREF_SET(__pyx_v_idx, __pyx_t_5);
    __pyx_t_5 = 0;
    __pyx_v_dim = __pyx_t_1;
    __pyx_t_1 = (__pyx_t_1 + 1);

    /* "View.MemoryView":402
 * 
 *         for dim, idx in enumerate(index):
 *             itemp = pybuffer_index(&self.view, itemp, idx, dim)             # <<<<<<<<<<<<<<
 * 
 *         return itemp
 */
    __pyx_t_6 = __Pyx_PyIndex_AsSsize_t(__pyx_v_idx); if (unlikely((__pyx_t_6 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(1, 402, __pyx_L1_error)
    __pyx_t_7 = __pyx_pybuffer_index((&__pyx_v_self->view), __pyx_v_itemp, __pyx_t_6, __pyx_v_dim); if (unlikely(__pyx_t_7 == ((char *)NULL))) __PYX_ERR(1, 402, __pyx_L1_error)
    __pyx_v_itemp = __pyx_t_7;

    /* "View.MemoryView":401
 *         cdef char *itemp = <char *> self.view.buf
 * 
 *         for dim, idx in enumerate(index):             # <<<<<<<<<<<<<<
 *             itemp = pybuffer_index(&self.view, itemp, idx, dim)
 * 
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "View.MemoryView":404
 *             itemp = pybuffer_index(&self.view, itemp, idx, dim)
 * 
 *         return itemp             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_itemp;
  goto __pyx_L0;

  /* "View.MemoryView":397
 *                 PyThread_free_lock(self.lock)
 * 
 *     cdef char *get_item_pointer(memoryview self, object index) except NULL:             # <<<<<<<<<<<<<<
 *         cdef Py_ssize_t dim
 *         cdef char *itemp = <char *> self.view.buf
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("View.MemoryView.memoryview.get_item_pointer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_idx);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":407
 * 
 * 
 *     def __getitem__(memoryview self, object index):             # <<<<<<<<<<<<<<
 *         if index is Ellipsis:
 *             return self
 */

/* Python wrapper */
static PyObject *__pyx_memoryview___getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index); /*proto*/
static PyObject *__pyx_memoryview___getitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getitem__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_4__getitem__(((struct __pyx_memoryview_obj *)__pyx_v_self), ((PyObject *)__pyx_v_index));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_4__getitem__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index) {
  PyObject *__pyx_v_have_slices = NULL;
  PyObject *__pyx_v_indices = NULL;
  char *__pyx_v_itemp;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  char *__pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getitem__", 1);

  /* "View.MemoryView":408
 * 
 *     def __getitem__(memoryview self, object index):
 *         if index is Ellipsis:             # <<<<<<<<<<<<<<
 *             return self
 * 
 */
  __pyx_t_1 = (__pyx_v_index == __pyx_builtin_Ellipsis);
  if (__pyx_t_1) {

    /* "View.MemoryView":409
 *     def __getitem__(memoryview self, object index):
 *         if index is Ellipsis:
 *             return self             # <<<<<<<<<<<<<<
 * 
 *         have_slices, indices = _unellipsify(index, self.view.ndim)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF((PyObject *)__pyx_v_self);
    __pyx_r = ((PyObject *)__pyx_v_self);
    goto __pyx_L0;

    /* "View.MemoryView":408
 * 
 *     def __getitem__(memoryview self, object index):
 *         if index is Ellipsis:             # <<<<<<<<<<<<<<
 *             return self
 * 
 */
  }

  /* "View.MemoryView":411
 *             return self
 * 
 *         have_slices, indices = _unellipsify(index, self.view.ndim)             # <<<<<<<<<<<<<<
 * 
 *         cdef char *itemp
 */
  __pyx_t_2 = _unellipsify(__pyx_v_index, __pyx_v_self->view.ndim); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 411, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (likely(__pyx_t_2 != Py_None)) {
    PyObject* sequence = __pyx_t_2;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(1, 411, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
    __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(1, 411, __pyx_L1_error)
  }
  __pyx_v_have_slices = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_indices = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "View.MemoryView":414
 * 
 *         cdef char *itemp
 *         if have_slices:             # <<<<<<<<<<<<<<
 *             return memview_slice(self, indices)
 *         else:
 */
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_v_have_slices); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(1, 414, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "View.MemoryView":415
 *         cdef char *itemp
 *         if have_slices:
 *             return memview_slice(self, indices)             # <<<<<<<<<<<<<<
 *         else:
 *             itemp = self.get_item_pointer(indices)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((PyObject *)__pyx_memview_slice(__pyx_v_self, __pyx_v_indices)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 415, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "View.MemoryView":414
 * 
 *         cdef char *itemp
 *         if have_slices:             # <<<<<<<<<<<<<<
 *             return memview_slice(self, indices)
 *         else:
 */
  }

  /* "View.MemoryView":417
 *             return memview_slice(self, indices)
 *         else:
 *             itemp = self.get_item_pointer(indices)             # <<<<<<<<<<<<<<
 *             return self.convert_item_to_object(itemp)
 * 
 */
  /*else*/ {
    __pyx_t_5 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->get_item_pointer(__pyx_v_self, __pyx_v_indices); if (unlikely(__pyx_t_5 == ((char *)NULL))) __PYX_ERR(1, 417, __pyx_L1_error)
    __pyx_v_itemp = __pyx_t_5;

    /* "View.MemoryView":418
 *         else:
 *             itemp = self.get_item_pointer(indices)
 *             return self.convert_item_to_object(itemp)             # <<<<<<<<<<<<<<
 * 
 *     def __setitem__(memoryview self, object index, object value):
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->convert_item_to_object(__pyx_v_self, __pyx_v_itemp); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 418, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "View.MemoryView":407
 * 
 * 
 *     def __getitem__(memoryview self, object index):             # <<<<<<<<<<<<<<
 *         if index is Ellipsis:
 *             return self
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("View.MemoryView.memoryview.__getitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_have_slices);
  __Pyx_XDECREF(__pyx_v_indices);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":420
 *             return self.convert_item_to_object(itemp)
 * 
 *     def __setitem__(memoryview self, object index, object value):             # <<<<<<<<<<<<<<
 *         if self.view.readonly:
 *             raise TypeError, "Cannot assign to read-only memoryview"
 */

/* Python wrapper */
static int __pyx_memoryview___setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value); /*proto*/
static int __pyx_memoryview___setitem__(PyObject *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setitem__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_6__setitem__(((struct __pyx_memoryview_obj *)__pyx_v_self), ((PyObject *)__pyx_v_index), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_6__setitem__(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value) {
  PyObject *__pyx_v_have_slices = NULL;
  PyObject *__pyx_v_obj = NULL;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setitem__", 0);
  __Pyx_INCREF(__pyx_v_index);

  /* "View.MemoryView":421
 * 
 *     def __setitem__(memoryview self, object index, object value):
 *         if self.view.readonly:             # <<<<<<<<<<<<<<
 *             raise TypeError, "Cannot assign to read-only memoryview"
 * 
 */
  if (unlikely(__pyx_v_self->view.readonly)) {

    /* "View.MemoryView":422
 *     def __setitem__(memoryview self, object index, object value):
 *         if self.view.readonly:
 *             raise TypeError, "Cannot assign to read-only memoryview"             # <<<<<<<<<<<<<<
 * 
 *         have_slices, index = _unellipsify(index, self.view.ndim)
 */
    __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_Cannot_assign_to_read_only_memor, 0, 0);
    __PYX_ERR(1, 422, __pyx_L1_error)

    /* "View.MemoryView":421
 * 
 *     def __setitem__(memoryview self, object index, object value):
 *         if self.view.readonly:             # <<<<<<<<<<<<<<
 *             raise TypeError, "Cannot assign to read-only memoryview"
 * 
 */
  }

  /* "View.MemoryView":424
 *             raise TypeError, "Cannot assign to read-only memoryview"
 * 
 *         have_slices, index = _unellipsify(index, self.view.ndim)             # <<<<<<<<<<<<<<
 * 
 *         if have_slices:
 */
  __pyx_t_1 = _unellipsify(__pyx_v_index, __pyx_v_self->view.ndim); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (likely(__pyx_t_1 != Py_None)) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(1, 424, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
    __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 424, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 424, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    __Pyx_RaiseNoneNotIterableError(); __PYX_ERR(1, 424, __pyx_L1_error)
  }
  __pyx_v_have_slices = __pyx_t_2;
  __pyx_t_2 = 0;
  __Pyx_DECREF_SET(__pyx_v_index, __pyx_t_3);
  __pyx_t_3 = 0;

  /* "View.MemoryView":426
 *         have_slices, index = _unellipsify(index, self.view.ndim)
 * 
 *         if have_slices:             # <<<<<<<<<<<<<<
 *             obj = self.is_slice(value)
 *             if obj:
 */
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_have_slices); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(1, 426, __pyx_L1_error)
  if (__pyx_t_4) {

    /* "View.MemoryView":427
 * 
 *         if have_slices:
 *             obj = self.is_slice(value)             # <<<<<<<<<<<<<<
 *             if obj:
 *                 self.setitem_slice_assignment(self[index], obj)
 */
    __pyx_t_1 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->is_slice(__pyx_v_self, __pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 427, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_obj = __pyx_t_1;
    __pyx_t_1 = 0;

    /* "View.MemoryView":428
 *         if have_slices:
 *             obj = self.is_slice(value)
 *             if obj:             # <<<<<<<<<<<<<<
 *                 self.setitem_slice_assignment(self[index], obj)
 *             else:
 */
    __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_v_obj); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(1, 428, __pyx_L1_error)
    if (__pyx_t_4) {

      /* "View.MemoryView":429
 *             obj = self.is_slice(value)
 *             if obj:
 *                 self.setitem_slice_assignment(self[index], obj)             # <<<<<<<<<<<<<<
 *             else:
 *                 self.setitem_slice_assign_scalar(self[index], value)
 */
      __pyx_t_1 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_self), __pyx_v_index); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 429, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_3 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->setitem_slice_assignment(__pyx_v_self, __pyx_t_1, __pyx_v_obj); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 429, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "View.MemoryView":428
 *         if have_slices:
 *             obj = self.is_slice(value)
 *             if obj:             # <<<<<<<<<<<<<<
 *                 self.setitem_slice_assignment(self[index], obj)
 *             else:
 */
      goto __pyx_L5;
    }

    /* "View.MemoryView":431
 *                 self.setitem_slice_assignment(self[index], obj)
 *             else:
 *                 self.setitem_slice_assign_scalar(self[index], value)             # <<<<<<<<<<<<<<
 *         else:
 *             self.setitem_indexed(index, value)
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_self), __pyx_v_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 431, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_memoryview_type))))) __PYX_ERR(1, 431, __pyx_L1_error)
      __pyx_t_1 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->setitem_slice_assign_scalar(__pyx_v_self, ((struct __pyx_memoryview_obj *)__pyx_t_3), __pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 431, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }
    __pyx_L5:;

    /* "View.MemoryView":426
 *         have_slices, index = _unellipsify(index, self.view.ndim)
 * 
 *         if have_slices:             # <<<<<<<<<<<<<<
 *             obj = self.is_slice(value)
 *             if obj:
 */
    goto __pyx_L4;
  }

  /* "View.MemoryView":433
 *                 self.setitem_slice_assign_scalar(self[index], value)
 *         else:
 *             self.setitem_indexed(index, value)             # <<<<<<<<<<<<<<
 * 
 *     cdef is_slice(self, obj):
 */
  /*else*/ {
    __pyx_t_1 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->setitem_indexed(__pyx_v_self, __pyx_v_index, __pyx_v_value); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 433, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  }
  __pyx_L4:;

  /* "View.MemoryView":420
 *             return self.convert_item_to_object(itemp)
 * 
 *     def __setitem__(memoryview self, object index, object value):             # <<<<<<<<<<<<<<
 *         if self.view.readonly:
 *             raise TypeError, "Cannot assign to read-only memoryview"
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview.__setitem__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_have_slices);
  __Pyx_XDECREF(__pyx_v_obj);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":435
 *             self.setitem_indexed(index, value)
 * 
 *     cdef is_slice(self, obj):             # <<<<<<<<<<<<<<
 *         if not isinstance(obj, memoryview):
 *             try:
 */

static PyObject *__pyx_memoryview_is_slice(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_obj) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_slice", 0);
  __Pyx_INCREF(__pyx_v_obj);

  /* "View.MemoryView":436
 * 
 *     cdef is_slice(self, obj):
 *         if not isinstance(obj, memoryview):             # <<<<<<<<<<<<<<
 *             try:
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_obj, __pyx_memoryview_type); 
  __pyx_t_2 = (!__pyx_t_1);
  if (__pyx_t_2) {

    /* "View.MemoryView":437
 *     cdef is_slice(self, obj):
 *         if not isinstance(obj, memoryview):
 *             try:             # <<<<<<<<<<<<<<
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 *                                  self.dtype_is_object)
 */
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_4, &__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_3);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_5);
      /*try:*/ {

        /* "View.MemoryView":438
 *         if not isinstance(obj, memoryview):
 *             try:
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,             # <<<<<<<<<<<<<<
 *                                  self.dtype_is_object)
 *             except TypeError:
 */
        __pyx_t_6 = __Pyx_PyInt_From_int(((__pyx_v_self->flags & (~PyBUF_WRITABLE)) | PyBUF_ANY_CONTIGUOUS)); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 438, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_6);

        /* "View.MemoryView":439
 *             try:
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 *                                  self.dtype_is_object)             # <<<<<<<<<<<<<<
 *             except TypeError:
 *                 return None
 */
        __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_v_self->dtype_is_object); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 439, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_7);

        /* "View.MemoryView":438
 *         if not isinstance(obj, memoryview):
 *             try:
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,             # <<<<<<<<<<<<<<
 *                                  self.dtype_is_object)
 *             except TypeError:
 */
        __pyx_t_8 = PyTuple_New(3); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 438, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_INCREF(__pyx_v_obj);
        __Pyx_GIVEREF(__pyx_v_obj);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_v_obj)) __PYX_ERR(1, 438, __pyx_L4_error);
        __Pyx_GIVEREF(__pyx_t_6);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 1, __pyx_t_6)) __PYX_ERR(1, 438, __pyx_L4_error);
        __Pyx_GIVEREF(__pyx_t_7);
        if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 2, __pyx_t_7)) __PYX_ERR(1, 438, __pyx_L4_error);
        __pyx_t_6 = 0;
        __pyx_t_7 = 0;
        __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_memoryview_type), __pyx_t_8, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 438, __pyx_L4_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        __Pyx_DECREF_SET(__pyx_v_obj, __pyx_t_7);
        __pyx_t_7 = 0;

        /* "View.MemoryView":437
 *     cdef is_slice(self, obj):
 *         if not isinstance(obj, memoryview):
 *             try:             # <<<<<<<<<<<<<<
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 *                                  self.dtype_is_object)
 */
      }
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L9_try_end;
      __pyx_L4_error:;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "View.MemoryView":440
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 *                                  self.dtype_is_object)
 *             except TypeError:             # <<<<<<<<<<<<<<
 *                 return None
 * 
 */
      __pyx_t_9 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_TypeError);
      if (__pyx_t_9) {
        __Pyx_AddTraceback("View.MemoryView.memoryview.is_slice", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_7, &__pyx_t_8, &__pyx_t_6) < 0) __PYX_ERR(1, 440, __pyx_L6_except_error)
        __Pyx_XGOTREF(__pyx_t_7);
        __Pyx_XGOTREF(__pyx_t_8);
        __Pyx_XGOTREF(__pyx_t_6);

        /* "View.MemoryView":441
 *                                  self.dtype_is_object)
 *             except TypeError:
 *                 return None             # <<<<<<<<<<<<<<
 * 
 *         return obj
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_r = Py_None; __Pyx_INCREF(Py_None);
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L7_except_return;
      }
      goto __pyx_L6_except_error;

      /* "View.MemoryView":437
 *     cdef is_slice(self, obj):
 *         if not isinstance(obj, memoryview):
 *             try:             # <<<<<<<<<<<<<<
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 *                                  self.dtype_is_object)
 */
      __pyx_L6_except_error:;
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      goto __pyx_L1_error;
      __pyx_L7_except_return:;
      __Pyx_XGIVEREF(__pyx_t_3);
      __Pyx_XGIVEREF(__pyx_t_4);
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_4, __pyx_t_5);
      goto __pyx_L0;
      __pyx_L9_try_end:;
    }

    /* "View.MemoryView":436
 * 
 *     cdef is_slice(self, obj):
 *         if not isinstance(obj, memoryview):             # <<<<<<<<<<<<<<
 *             try:
 *                 obj = memoryview(obj, self.flags & ~PyBUF_WRITABLE | PyBUF_ANY_CONTIGUOUS,
 */
  }

  /* "View.MemoryView":443
 *                 return None
 * 
 *         return obj             # <<<<<<<<<<<<<<
 * 
 *     cdef setitem_slice_assignment(self, dst, src):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_obj);
  __pyx_r = __pyx_v_obj;
  goto __pyx_L0;

  /* "View.MemoryView":435
 *             self.setitem_indexed(index, value)
 * 
 *     cdef is_slice(self, obj):             # <<<<<<<<<<<<<<
 *         if not isinstance(obj, memoryview):
 *             try:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("View.MemoryView.memoryview.is_slice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_obj);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":445
 *         return obj
 * 
 *     cdef setitem_slice_assignment(self, dst, src):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice dst_slice
 *         cdef __Pyx_memviewslice src_slice
 */

static PyObject *__pyx_memoryview_setitem_slice_assignment(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_dst, PyObject *__pyx_v_src) {
  __Pyx_memviewslice __pyx_v_dst_slice;
  __Pyx_memviewslice __pyx_v_src_slice;
  __Pyx_memviewslice __pyx_v_msrc;
  __Pyx_memviewslice __pyx_v_mdst;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setitem_slice_assignment", 1);

  /* "View.MemoryView":448
 *         cdef __Pyx_memviewslice dst_slice
 *         cdef __Pyx_memviewslice src_slice
 *         cdef __Pyx_memviewslice msrc = get_slice_from_memview(src, &src_slice)[0]             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice mdst = get_slice_from_memview(dst, &dst_slice)[0]
 * 
 */
  if (!(likely(((__pyx_v_src) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_src, __pyx_memoryview_type))))) __PYX_ERR(1, 448, __pyx_L1_error)
  __pyx_t_1 = __pyx_memoryview_get_slice_from_memoryview(((struct __pyx_memoryview_obj *)__pyx_v_src), (&__pyx_v_src_slice)); if (unlikely(__pyx_t_1 == ((__Pyx_memviewslice *)NULL))) __PYX_ERR(1, 448, __pyx_L1_error)
  __pyx_v_msrc = (__pyx_t_1[0]);

  /* "View.MemoryView":449
 *         cdef __Pyx_memviewslice src_slice
 *         cdef __Pyx_memviewslice msrc = get_slice_from_memview(src, &src_slice)[0]
 *         cdef __Pyx_memviewslice mdst = get_slice_from_memview(dst, &dst_slice)[0]             # <<<<<<<<<<<<<<
 * 
 *         memoryview_copy_contents(msrc, mdst, src.ndim, dst.ndim, self.dtype_is_object)
 */
  if (!(likely(((__pyx_v_dst) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_dst, __pyx_memoryview_type))))) __PYX_ERR(1, 449, __pyx_L1_error)
  __pyx_t_1 = __pyx_memoryview_get_slice_from_memoryview(((struct __pyx_memoryview_obj *)__pyx_v_dst), (&__pyx_v_dst_slice)); if (unlikely(__pyx_t_1 == ((__Pyx_memviewslice *)NULL))) __PYX_ERR(1, 449, __pyx_L1_error)
  __pyx_v_mdst = (__pyx_t_1[0]);

  /* "View.MemoryView":451
 *         cdef __Pyx_memviewslice mdst = get_slice_from_memview(dst, &dst_slice)[0]
 * 
 *         memoryview_copy_contents(msrc, mdst, src.ndim, dst.ndim, self.dtype_is_object)             # <<<<<<<<<<<<<<
 * 
 *     cdef setitem_slice_assign_scalar(self, memoryview dst, value):
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_src, __pyx_n_s_ndim); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_3 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 451, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_dst, __pyx_n_s_ndim); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 451, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_4 == (int)-1) && PyErr_Occurred())) __PYX_ERR(1, 451, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_5 = __pyx_memoryview_copy_contents(__pyx_v_msrc, __pyx_v_mdst, __pyx_t_3, __pyx_t_4, __pyx_v_self->dtype_is_object); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(1, 451, __pyx_L1_error)

  /* "View.MemoryView":445
 *         return obj
 * 
 *     cdef setitem_slice_assignment(self, dst, src):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice dst_slice
 *         cdef __Pyx_memviewslice src_slice
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.setitem_slice_assignment", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":453
 *         memoryview_copy_contents(msrc, mdst, src.ndim, dst.ndim, self.dtype_is_object)
 * 
 *     cdef setitem_slice_assign_scalar(self, memoryview dst, value):             # <<<<<<<<<<<<<<
 *         cdef int array[128]
 *         cdef void *tmp = NULL
 */

static PyObject *__pyx_memoryview_setitem_slice_assign_scalar(struct __pyx_memoryview_obj *__pyx_v_self, struct __pyx_memoryview_obj *__pyx_v_dst, PyObject *__pyx_v_value) {
  int __pyx_v_array[0x80];
  void *__pyx_v_tmp;
  void *__pyx_v_item;
  __Pyx_memviewslice *__pyx_v_dst_slice;
  __Pyx_memviewslice __pyx_v_tmp_slice;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice *__pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  char const *__pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setitem_slice_assign_scalar", 1);

  /* "View.MemoryView":455
 *     cdef setitem_slice_assign_scalar(self, memoryview dst, value):
 *         cdef int array[128]
 *         cdef void *tmp = NULL             # <<<<<<<<<<<<<<
 *         cdef void *item
 * 
 */
  __pyx_v_tmp = NULL;

  /* "View.MemoryView":460
 *         cdef __Pyx_memviewslice *dst_slice
 *         cdef __Pyx_memviewslice tmp_slice
 *         dst_slice = get_slice_from_memview(dst, &tmp_slice)             # <<<<<<<<<<<<<<
 * 
 *         if <size_t>self.view.itemsize > sizeof(array):
 */
  __pyx_t_1 = __pyx_memoryview_get_slice_from_memoryview(__pyx_v_dst, (&__pyx_v_tmp_slice)); if (unlikely(__pyx_t_1 == ((__Pyx_memviewslice *)NULL))) __PYX_ERR(1, 460, __pyx_L1_error)
  __pyx_v_dst_slice = __pyx_t_1;

  /* "View.MemoryView":462
 *         dst_slice = get_slice_from_memview(dst, &tmp_slice)
 * 
 *         if <size_t>self.view.itemsize > sizeof(array):             # <<<<<<<<<<<<<<
 *             tmp = PyMem_Malloc(self.view.itemsize)
 *             if tmp == NULL:
 */
  __pyx_t_2 = (((size_t)__pyx_v_self->view.itemsize) > (sizeof(__pyx_v_array)));
  if (__pyx_t_2) {

    /* "View.MemoryView":463
 * 
 *         if <size_t>self.view.itemsize > sizeof(array):
 *             tmp = PyMem_Malloc(self.view.itemsize)             # <<<<<<<<<<<<<<
 *             if tmp == NULL:
 *                 raise MemoryError
 */
    __pyx_v_tmp = PyMem_Malloc(__pyx_v_self->view.itemsize);

    /* "View.MemoryView":464
 *         if <size_t>self.view.itemsize > sizeof(array):
 *             tmp = PyMem_Malloc(self.view.itemsize)
 *             if tmp == NULL:             # <<<<<<<<<<<<<<
 *                 raise MemoryError
 *             item = tmp
 */
    __pyx_t_2 = (__pyx_v_tmp == NULL);
    if (unlikely(__pyx_t_2)) {

      /* "View.MemoryView":465
 *             tmp = PyMem_Malloc(self.view.itemsize)
 *             if tmp == NULL:
 *                 raise MemoryError             # <<<<<<<<<<<<<<
 *             item = tmp
 *         else:
 */
      PyErr_NoMemory(); __PYX_ERR(1, 465, __pyx_L1_error)

      /* "View.MemoryView":464
 *         if <size_t>self.view.itemsize > sizeof(array):
 *             tmp = PyMem_Malloc(self.view.itemsize)
 *             if tmp == NULL:             # <<<<<<<<<<<<<<
 *                 raise MemoryError
 *             item = tmp
 */
    }

    /* "View.MemoryView":466
 *             if tmp == NULL:
 *                 raise MemoryError
 *             item = tmp             # <<<<<<<<<<<<<<
 *         else:
 *             item = <void *> array
 */
    __pyx_v_item = __pyx_v_tmp;

    /* "View.MemoryView":462
 *         dst_slice = get_slice_from_memview(dst, &tmp_slice)
 * 
 *         if <size_t>self.view.itemsize > sizeof(array):             # <<<<<<<<<<<<<<
 *             tmp = PyMem_Malloc(self.view.itemsize)
 *             if tmp == NULL:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":468
 *             item = tmp
 *         else:
 *             item = <void *> array             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  /*else*/ {
    __pyx_v_item = ((void *)__pyx_v_array);
  }
  __pyx_L3:;

  /* "View.MemoryView":470
 *             item = <void *> array
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             if self.dtype_is_object:
 *                 (<PyObject **> item)[0] = <PyObject *> value
 */
  /*try:*/ {

    /* "View.MemoryView":471
 * 
 *         try:
 *             if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *                 (<PyObject **> item)[0] = <PyObject *> value
 *             else:
 */
    if (__pyx_v_self->dtype_is_object) {

      /* "View.MemoryView":472
 *         try:
 *             if self.dtype_is_object:
 *                 (<PyObject **> item)[0] = <PyObject *> value             # <<<<<<<<<<<<<<
 *             else:
 *                 self.assign_item_from_object(<char *> item, value)
 */
      (((PyObject **)__pyx_v_item)[0]) = ((PyObject *)__pyx_v_value);

      /* "View.MemoryView":471
 * 
 *         try:
 *             if self.dtype_is_object:             # <<<<<<<<<<<<<<
 *                 (<PyObject **> item)[0] = <PyObject *> value
 *             else:
 */
      goto __pyx_L8;
    }

    /* "View.MemoryView":474
 *                 (<PyObject **> item)[0] = <PyObject *> value
 *             else:
 *                 self.assign_item_from_object(<char *> item, value)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    /*else*/ {
      __pyx_t_3 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->assign_item_from_object(__pyx_v_self, ((char *)__pyx_v_item), __pyx_v_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 474, __pyx_L6_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }
    __pyx_L8:;

    /* "View.MemoryView":478
 * 
 * 
 *             if self.view.suboffsets != NULL:             # <<<<<<<<<<<<<<
 *                 assert_direct_dimensions(self.view.suboffsets, self.view.ndim)
 *             slice_assign_scalar(dst_slice, dst.view.ndim, self.view.itemsize,
 */
    __pyx_t_2 = (__pyx_v_self->view.suboffsets != NULL);
    if (__pyx_t_2) {

      /* "View.MemoryView":479
 * 
 *             if self.view.suboffsets != NULL:
 *                 assert_direct_dimensions(self.view.suboffsets, self.view.ndim)             # <<<<<<<<<<<<<<
 *             slice_assign_scalar(dst_slice, dst.view.ndim, self.view.itemsize,
 *                                 item, self.dtype_is_object)
 */
      __pyx_t_4 = assert_direct_dimensions(__pyx_v_self->view.suboffsets, __pyx_v_self->view.ndim); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 479, __pyx_L6_error)

      /* "View.MemoryView":478
 * 
 * 
 *             if self.view.suboffsets != NULL:             # <<<<<<<<<<<<<<
 *                 assert_direct_dimensions(self.view.suboffsets, self.view.ndim)
 *             slice_assign_scalar(dst_slice, dst.view.ndim, self.view.itemsize,
 */
    }

    /* "View.MemoryView":480
 *             if self.view.suboffsets != NULL:
 *                 assert_direct_dimensions(self.view.suboffsets, self.view.ndim)
 *             slice_assign_scalar(dst_slice, dst.view.ndim, self.view.itemsize,             # <<<<<<<<<<<<<<
 *                                 item, self.dtype_is_object)
 *         finally:
 */
    __pyx_memoryview_slice_assign_scalar(__pyx_v_dst_slice, __pyx_v_dst->view.ndim, __pyx_v_self->view.itemsize, __pyx_v_item, __pyx_v_self->dtype_is_object);
  }

  /* "View.MemoryView":483
 *                                 item, self.dtype_is_object)
 *         finally:
 *             PyMem_Free(tmp)             # <<<<<<<<<<<<<<
 * 
 *     cdef setitem_indexed(self, index, value):
 */
  /*finally:*/ {
    /*normal exit:*/{
      PyMem_Free(__pyx_v_tmp);
      goto __pyx_L7;
    }
    __pyx_L6_error:;
    /*exception exit:*/{
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0;
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (PY_MAJOR_VERSION >= 3) __Pyx_ExceptionSwap(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      if ((PY_MAJOR_VERSION < 3) || unlikely(__Pyx_GetException(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9) < 0)) __Pyx_ErrFetch(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_11);
      __Pyx_XGOTREF(__pyx_t_12);
      __pyx_t_4 = __pyx_lineno; __pyx_t_5 = __pyx_clineno; __pyx_t_6 = __pyx_filename;
      {
        PyMem_Free(__pyx_v_tmp);
      }
      if (PY_MAJOR_VERSION >= 3) {
        __Pyx_XGIVEREF(__pyx_t_10);
        __Pyx_XGIVEREF(__pyx_t_11);
        __Pyx_XGIVEREF(__pyx_t_12);
        __Pyx_ExceptionReset(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_ErrRestore(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      __pyx_t_7 = 0; __pyx_t_8 = 0; __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; __pyx_t_12 = 0;
      __pyx_lineno = __pyx_t_4; __pyx_clineno = __pyx_t_5; __pyx_filename = __pyx_t_6;
      goto __pyx_L1_error;
    }
    __pyx_L7:;
  }

  /* "View.MemoryView":453
 *         memoryview_copy_contents(msrc, mdst, src.ndim, dst.ndim, self.dtype_is_object)
 * 
 *     cdef setitem_slice_assign_scalar(self, memoryview dst, value):             # <<<<<<<<<<<<<<
 *         cdef int array[128]
 *         cdef void *tmp = NULL
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview.setitem_slice_assign_scalar", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":485
 *             PyMem_Free(tmp)
 * 
 *     cdef setitem_indexed(self, index, value):             # <<<<<<<<<<<<<<
 *         cdef char *itemp = self.get_item_pointer(index)
 *         self.assign_item_from_object(itemp, value)
 */

static PyObject *__pyx_memoryview_setitem_indexed(struct __pyx_memoryview_obj *__pyx_v_self, PyObject *__pyx_v_index, PyObject *__pyx_v_value) {
  char *__pyx_v_itemp;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  char *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("setitem_indexed", 1);

  /* "View.MemoryView":486
 * 
 *     cdef setitem_indexed(self, index, value):
 *         cdef char *itemp = self.get_item_pointer(index)             # <<<<<<<<<<<<<<
 *         self.assign_item_from_object(itemp, value)
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->get_item_pointer(__pyx_v_self, __pyx_v_index); if (unlikely(__pyx_t_1 == ((char *)NULL))) __PYX_ERR(1, 486, __pyx_L1_error)
  __pyx_v_itemp = __pyx_t_1;

  /* "View.MemoryView":487
 *     cdef setitem_indexed(self, index, value):
 *         cdef char *itemp = self.get_item_pointer(index)
 *         self.assign_item_from_object(itemp, value)             # <<<<<<<<<<<<<<
 * 
 *     cdef convert_item_to_object(self, char *itemp):
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->assign_item_from_object(__pyx_v_self, __pyx_v_itemp, __pyx_v_value); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 487, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "View.MemoryView":485
 *             PyMem_Free(tmp)
 * 
 *     cdef setitem_indexed(self, index, value):             # <<<<<<<<<<<<<<
 *         cdef char *itemp = self.get_item_pointer(index)
 *         self.assign_item_from_object(itemp, value)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.setitem_indexed", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":489
 *         self.assign_item_from_object(itemp, value)
 * 
 *     cdef convert_item_to_object(self, char *itemp):             # <<<<<<<<<<<<<<
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 */

static PyObject *__pyx_memoryview_convert_item_to_object(struct __pyx_memoryview_obj *__pyx_v_self, char *__pyx_v_itemp) {
  PyObject *__pyx_v_struct = NULL;
  PyObject *__pyx_v_bytesitem = 0;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("convert_item_to_object", 1);

  /* "View.MemoryView":492
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 *         import struct             # <<<<<<<<<<<<<<
 *         cdef bytes bytesitem
 * 
 */
  __pyx_t_1 = __Pyx_ImportDottedModule(__pyx_n_s_struct, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 492, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_struct = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "View.MemoryView":495
 *         cdef bytes bytesitem
 * 
 *         bytesitem = itemp[:self.view.itemsize]             # <<<<<<<<<<<<<<
 *         try:
 *             result = struct.unpack(self.view.format, bytesitem)
 */
  __pyx_t_1 = __Pyx_PyBytes_FromStringAndSize(__pyx_v_itemp + 0, __pyx_v_self->view.itemsize - 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 495, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_bytesitem = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "View.MemoryView":496
 * 
 *         bytesitem = itemp[:self.view.itemsize]
 *         try:             # <<<<<<<<<<<<<<
 *             result = struct.unpack(self.view.format, bytesitem)
 *         except struct.error:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_2, &__pyx_t_3, &__pyx_t_4);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_4);
    /*try:*/ {

      /* "View.MemoryView":497
 *         bytesitem = itemp[:self.view.itemsize]
 *         try:
 *             result = struct.unpack(self.view.format, bytesitem)             # <<<<<<<<<<<<<<
 *         except struct.error:
 *             raise ValueError, "Unable to convert item to object"
 */
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_struct, __pyx_n_s_unpack); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 497, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = __Pyx_PyBytes_FromString(__pyx_v_self->view.format); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 497, __pyx_L3_error)
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_7 = NULL;
      __pyx_t_8 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_5))) {
        __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
        if (likely(__pyx_t_7)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
          __Pyx_INCREF(__pyx_t_7);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_5, function);
          __pyx_t_8 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[3] = {__pyx_t_7, __pyx_t_6, __pyx_v_bytesitem};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_8, 2+__pyx_t_8);
        __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 497, __pyx_L3_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_v_result = __pyx_t_1;
      __pyx_t_1 = 0;

      /* "View.MemoryView":496
 * 
 *         bytesitem = itemp[:self.view.itemsize]
 *         try:             # <<<<<<<<<<<<<<
 *             result = struct.unpack(self.view.format, bytesitem)
 *         except struct.error:
 */
    }

    /* "View.MemoryView":501
 *             raise ValueError, "Unable to convert item to object"
 *         else:
 *             if len(self.view.format) == 1:             # <<<<<<<<<<<<<<
 *                 return result[0]
 *             return result
 */
    /*else:*/ {
      __pyx_t_9 = __Pyx_ssize_strlen(__pyx_v_self->view.format); if (unlikely(__pyx_t_9 == ((Py_ssize_t)-1))) __PYX_ERR(1, 501, __pyx_L5_except_error)
      __pyx_t_10 = (__pyx_t_9 == 1);
      if (__pyx_t_10) {

        /* "View.MemoryView":502
 *         else:
 *             if len(self.view.format) == 1:
 *                 return result[0]             # <<<<<<<<<<<<<<
 *             return result
 * 
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_1 = __Pyx_GetItemInt(__pyx_v_result, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 502, __pyx_L5_except_error)
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_r = __pyx_t_1;
        __pyx_t_1 = 0;
        goto __pyx_L6_except_return;

        /* "View.MemoryView":501
 *             raise ValueError, "Unable to convert item to object"
 *         else:
 *             if len(self.view.format) == 1:             # <<<<<<<<<<<<<<
 *                 return result[0]
 *             return result
 */
      }

      /* "View.MemoryView":503
 *             if len(self.view.format) == 1:
 *                 return result[0]
 *             return result             # <<<<<<<<<<<<<<
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):
 */
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_v_result);
      __pyx_r = __pyx_v_result;
      goto __pyx_L6_except_return;
    }
    __pyx_L3_error:;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "View.MemoryView":498
 *         try:
 *             result = struct.unpack(self.view.format, bytesitem)
 *         except struct.error:             # <<<<<<<<<<<<<<
 *             raise ValueError, "Unable to convert item to object"
 *         else:
 */
    __Pyx_ErrFetch(&__pyx_t_1, &__pyx_t_5, &__pyx_t_6);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_v_struct, __pyx_n_s_error); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 498, __pyx_L5_except_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyErr_GivenExceptionMatches(__pyx_t_1, __pyx_t_7);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_ErrRestore(__pyx_t_1, __pyx_t_5, __pyx_t_6);
    __pyx_t_1 = 0; __pyx_t_5 = 0; __pyx_t_6 = 0;
    if (__pyx_t_8) {
      __Pyx_AddTraceback("View.MemoryView.memoryview.convert_item_to_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_5, &__pyx_t_1) < 0) __PYX_ERR(1, 498, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_1);

      /* "View.MemoryView":499
 *             result = struct.unpack(self.view.format, bytesitem)
 *         except struct.error:
 *             raise ValueError, "Unable to convert item to object"             # <<<<<<<<<<<<<<
 *         else:
 *             if len(self.view.format) == 1:
 */
      __Pyx_Raise(__pyx_builtin_ValueError, __pyx_kp_s_Unable_to_convert_item_to_object, 0, 0);
      __PYX_ERR(1, 499, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;

    /* "View.MemoryView":496
 * 
 *         bytesitem = itemp[:self.view.itemsize]
 *         try:             # <<<<<<<<<<<<<<
 *             result = struct.unpack(self.view.format, bytesitem)
 *         except struct.error:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L1_error;
    __pyx_L6_except_return:;
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_4);
    __Pyx_ExceptionReset(__pyx_t_2, __pyx_t_3, __pyx_t_4);
    goto __pyx_L0;
  }

  /* "View.MemoryView":489
 *         self.assign_item_from_object(itemp, value)
 * 
 *     cdef convert_item_to_object(self, char *itemp):             # <<<<<<<<<<<<<<
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("View.MemoryView.memoryview.convert_item_to_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_struct);
  __Pyx_XDECREF(__pyx_v_bytesitem);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":505
 *             return result
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):             # <<<<<<<<<<<<<<
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 */

static PyObject *__pyx_memoryview_assign_item_from_object(struct __pyx_memoryview_obj *__pyx_v_self, char *__pyx_v_itemp, PyObject *__pyx_v_value) {
  PyObject *__pyx_v_struct = NULL;
  char __pyx_v_c;
  PyObject *__pyx_v_bytesvalue = 0;
  Py_ssize_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  char *__pyx_t_9;
  char *__pyx_t_10;
  char *__pyx_t_11;
  char *__pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("assign_item_from_object", 1);

  /* "View.MemoryView":508
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 *         import struct             # <<<<<<<<<<<<<<
 *         cdef char c
 *         cdef bytes bytesvalue
 */
  __pyx_t_1 = __Pyx_ImportDottedModule(__pyx_n_s_struct, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 508, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_struct = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "View.MemoryView":513
 *         cdef Py_ssize_t i
 * 
 *         if isinstance(value, tuple):             # <<<<<<<<<<<<<<
 *             bytesvalue = struct.pack(self.view.format, *value)
 *         else:
 */
  __pyx_t_2 = PyTuple_Check(__pyx_v_value); 
  if (__pyx_t_2) {

    /* "View.MemoryView":514
 * 
 *         if isinstance(value, tuple):
 *             bytesvalue = struct.pack(self.view.format, *value)             # <<<<<<<<<<<<<<
 *         else:
 *             bytesvalue = struct.pack(self.view.format, value)
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_v_struct, __pyx_n_s_pack); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyBytes_FromString(__pyx_v_self->view.format); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3)) __PYX_ERR(1, 514, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PySequence_Tuple(__pyx_v_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyNumber_Add(__pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, NULL); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 514, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (!(likely(PyBytes_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None) || __Pyx_RaiseUnexpectedTypeError("bytes", __pyx_t_3))) __PYX_ERR(1, 514, __pyx_L1_error)
    __pyx_v_bytesvalue = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "View.MemoryView":513
 *         cdef Py_ssize_t i
 * 
 *         if isinstance(value, tuple):             # <<<<<<<<<<<<<<
 *             bytesvalue = struct.pack(self.view.format, *value)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":516
 *             bytesvalue = struct.pack(self.view.format, *value)
 *         else:
 *             bytesvalue = struct.pack(self.view.format, value)             # <<<<<<<<<<<<<<
 * 
 *         for i, c in enumerate(bytesvalue):
 */
  /*else*/ {
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_v_struct, __pyx_n_s_pack); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 516, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = __Pyx_PyBytes_FromString(__pyx_v_self->view.format); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 516, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = NULL;
    __pyx_t_6 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_5))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_5);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_5, function);
        __pyx_t_6 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[3] = {__pyx_t_4, __pyx_t_1, __pyx_v_value};
      __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 516, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
    if (!(likely(PyBytes_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None) || __Pyx_RaiseUnexpectedTypeError("bytes", __pyx_t_3))) __PYX_ERR(1, 516, __pyx_L1_error)
    __pyx_v_bytesvalue = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "View.MemoryView":518
 *             bytesvalue = struct.pack(self.view.format, value)
 * 
 *         for i, c in enumerate(bytesvalue):             # <<<<<<<<<<<<<<
 *             itemp[i] = c
 * 
 */
  __pyx_t_7 = 0;
  if (unlikely(__pyx_v_bytesvalue == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' is not iterable");
    __PYX_ERR(1, 518, __pyx_L1_error)
  }
  __Pyx_INCREF(__pyx_v_bytesvalue);
  __pyx_t_8 = __pyx_v_bytesvalue;
  __pyx_t_10 = PyBytes_AS_STRING(__pyx_t_8);
  __pyx_t_11 = (__pyx_t_10 + PyBytes_GET_SIZE(__pyx_t_8));
  for (__pyx_t_12 = __pyx_t_10; __pyx_t_12 < __pyx_t_11; __pyx_t_12++) {
    __pyx_t_9 = __pyx_t_12;
    __pyx_v_c = (__pyx_t_9[0]);

    /* "View.MemoryView":519
 * 
 *         for i, c in enumerate(bytesvalue):
 *             itemp[i] = c             # <<<<<<<<<<<<<<
 * 
 *     @cname('getbuffer')
 */
    __pyx_v_i = __pyx_t_7;

    /* "View.MemoryView":518
 *             bytesvalue = struct.pack(self.view.format, value)
 * 
 *         for i, c in enumerate(bytesvalue):             # <<<<<<<<<<<<<<
 *             itemp[i] = c
 * 
 */
    __pyx_t_7 = (__pyx_t_7 + 1);

    /* "View.MemoryView":519
 * 
 *         for i, c in enumerate(bytesvalue):
 *             itemp[i] = c             # <<<<<<<<<<<<<<
 * 
 *     @cname('getbuffer')
 */
    (__pyx_v_itemp[__pyx_v_i]) = __pyx_v_c;
  }
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "View.MemoryView":505
 *             return result
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):             # <<<<<<<<<<<<<<
 *         """Only used if instantiated manually by the user, or if Cython doesn't
 *         know how to convert the type"""
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("View.MemoryView.memoryview.assign_item_from_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_struct);
  __Pyx_XDECREF(__pyx_v_bytesvalue);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":521
 *             itemp[i] = c
 * 
 *     @cname('getbuffer')             # <<<<<<<<<<<<<<
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         if flags & PyBUF_WRITABLE and self.view.readonly:
 */

/* Python wrapper */
CYTHON_UNUSED static int __pyx_memoryview_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
CYTHON_UNUSED static int __pyx_memoryview_getbuffer(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getbuffer__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_8__getbuffer__(((struct __pyx_memoryview_obj *)__pyx_v_self), ((Py_buffer *)__pyx_v_info), ((int)__pyx_v_flags));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_8__getbuffer__(struct __pyx_memoryview_obj *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  Py_ssize_t *__pyx_t_3;
  char *__pyx_t_4;
  void *__pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  if (unlikely(__pyx_v_info == NULL)) {
    PyErr_SetString(PyExc_BufferError, "PyObject_GetBuffer: view==NULL argument is obsolete");
    return -1;
  }
  __Pyx_RefNannySetupContext("__getbuffer__", 0);
  __pyx_v_info->obj = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(__pyx_v_info->obj);

  /* "View.MemoryView":523
 *     @cname('getbuffer')
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         if flags & PyBUF_WRITABLE and self.view.readonly:             # <<<<<<<<<<<<<<
 *             raise ValueError, "Cannot create writable memory view from read-only memoryview"
 * 
 */
  __pyx_t_2 = ((__pyx_v_flags & PyBUF_WRITABLE) != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_1 = __pyx_v_self->view.readonly;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_1)) {

    /* "View.MemoryView":524
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         if flags & PyBUF_WRITABLE and self.view.readonly:
 *             raise ValueError, "Cannot create writable memory view from read-only memoryview"             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_ND:
 */
    __Pyx_Raise(__pyx_builtin_ValueError, __pyx_kp_s_Cannot_create_writable_memory_vi, 0, 0);
    __PYX_ERR(1, 524, __pyx_L1_error)

    /* "View.MemoryView":523
 *     @cname('getbuffer')
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         if flags & PyBUF_WRITABLE and self.view.readonly:             # <<<<<<<<<<<<<<
 *             raise ValueError, "Cannot create writable memory view from read-only memoryview"
 * 
 */
  }

  /* "View.MemoryView":526
 *             raise ValueError, "Cannot create writable memory view from read-only memoryview"
 * 
 *         if flags & PyBUF_ND:             # <<<<<<<<<<<<<<
 *             info.shape = self.view.shape
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_ND) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":527
 * 
 *         if flags & PyBUF_ND:
 *             info.shape = self.view.shape             # <<<<<<<<<<<<<<
 *         else:
 *             info.shape = NULL
 */
    __pyx_t_3 = __pyx_v_self->view.shape;
    __pyx_v_info->shape = __pyx_t_3;

    /* "View.MemoryView":526
 *             raise ValueError, "Cannot create writable memory view from read-only memoryview"
 * 
 *         if flags & PyBUF_ND:             # <<<<<<<<<<<<<<
 *             info.shape = self.view.shape
 *         else:
 */
    goto __pyx_L6;
  }

  /* "View.MemoryView":529
 *             info.shape = self.view.shape
 *         else:
 *             info.shape = NULL             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_STRIDES:
 */
  /*else*/ {
    __pyx_v_info->shape = NULL;
  }
  __pyx_L6:;

  /* "View.MemoryView":531
 *             info.shape = NULL
 * 
 *         if flags & PyBUF_STRIDES:             # <<<<<<<<<<<<<<
 *             info.strides = self.view.strides
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_STRIDES) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":532
 * 
 *         if flags & PyBUF_STRIDES:
 *             info.strides = self.view.strides             # <<<<<<<<<<<<<<
 *         else:
 *             info.strides = NULL
 */
    __pyx_t_3 = __pyx_v_self->view.strides;
    __pyx_v_info->strides = __pyx_t_3;

    /* "View.MemoryView":531
 *             info.shape = NULL
 * 
 *         if flags & PyBUF_STRIDES:             # <<<<<<<<<<<<<<
 *             info.strides = self.view.strides
 *         else:
 */
    goto __pyx_L7;
  }

  /* "View.MemoryView":534
 *             info.strides = self.view.strides
 *         else:
 *             info.strides = NULL             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_INDIRECT:
 */
  /*else*/ {
    __pyx_v_info->strides = NULL;
  }
  __pyx_L7:;

  /* "View.MemoryView":536
 *             info.strides = NULL
 * 
 *         if flags & PyBUF_INDIRECT:             # <<<<<<<<<<<<<<
 *             info.suboffsets = self.view.suboffsets
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_INDIRECT) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":537
 * 
 *         if flags & PyBUF_INDIRECT:
 *             info.suboffsets = self.view.suboffsets             # <<<<<<<<<<<<<<
 *         else:
 *             info.suboffsets = NULL
 */
    __pyx_t_3 = __pyx_v_self->view.suboffsets;
    __pyx_v_info->suboffsets = __pyx_t_3;

    /* "View.MemoryView":536
 *             info.strides = NULL
 * 
 *         if flags & PyBUF_INDIRECT:             # <<<<<<<<<<<<<<
 *             info.suboffsets = self.view.suboffsets
 *         else:
 */
    goto __pyx_L8;
  }

  /* "View.MemoryView":539
 *             info.suboffsets = self.view.suboffsets
 *         else:
 *             info.suboffsets = NULL             # <<<<<<<<<<<<<<
 * 
 *         if flags & PyBUF_FORMAT:
 */
  /*else*/ {
    __pyx_v_info->suboffsets = NULL;
  }
  __pyx_L8:;

  /* "View.MemoryView":541
 *             info.suboffsets = NULL
 * 
 *         if flags & PyBUF_FORMAT:             # <<<<<<<<<<<<<<
 *             info.format = self.view.format
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_FORMAT) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":542
 * 
 *         if flags & PyBUF_FORMAT:
 *             info.format = self.view.format             # <<<<<<<<<<<<<<
 *         else:
 *             info.format = NULL
 */
    __pyx_t_4 = __pyx_v_self->view.format;
    __pyx_v_info->format = __pyx_t_4;

    /* "View.MemoryView":541
 *             info.suboffsets = NULL
 * 
 *         if flags & PyBUF_FORMAT:             # <<<<<<<<<<<<<<
 *             info.format = self.view.format
 *         else:
 */
    goto __pyx_L9;
  }

  /* "View.MemoryView":544
 *             info.format = self.view.format
 *         else:
 *             info.format = NULL             # <<<<<<<<<<<<<<
 * 
 *         info.buf = self.view.buf
 */
  /*else*/ {
    __pyx_v_info->format = NULL;
  }
  __pyx_L9:;

  /* "View.MemoryView":546
 *             info.format = NULL
 * 
 *         info.buf = self.view.buf             # <<<<<<<<<<<<<<
 *         info.ndim = self.view.ndim
 *         info.itemsize = self.view.itemsize
 */
  __pyx_t_5 = __pyx_v_self->view.buf;
  __pyx_v_info->buf = __pyx_t_5;

  /* "View.MemoryView":547
 * 
 *         info.buf = self.view.buf
 *         info.ndim = self.view.ndim             # <<<<<<<<<<<<<<
 *         info.itemsize = self.view.itemsize
 *         info.len = self.view.len
 */
  __pyx_t_6 = __pyx_v_self->view.ndim;
  __pyx_v_info->ndim = __pyx_t_6;

  /* "View.MemoryView":548
 *         info.buf = self.view.buf
 *         info.ndim = self.view.ndim
 *         info.itemsize = self.view.itemsize             # <<<<<<<<<<<<<<
 *         info.len = self.view.len
 *         info.readonly = self.view.readonly
 */
  __pyx_t_7 = __pyx_v_self->view.itemsize;
  __pyx_v_info->itemsize = __pyx_t_7;

  /* "View.MemoryView":549
 *         info.ndim = self.view.ndim
 *         info.itemsize = self.view.itemsize
 *         info.len = self.view.len             # <<<<<<<<<<<<<<
 *         info.readonly = self.view.readonly
 *         info.obj = self
 */
  __pyx_t_7 = __pyx_v_self->view.len;
  __pyx_v_info->len = __pyx_t_7;

  /* "View.MemoryView":550
 *         info.itemsize = self.view.itemsize
 *         info.len = self.view.len
 *         info.readonly = self.view.readonly             # <<<<<<<<<<<<<<
 *         info.obj = self
 * 
 */
  __pyx_t_1 = __pyx_v_self->view.readonly;
  __pyx_v_info->readonly = __pyx_t_1;

  /* "View.MemoryView":551
 *         info.len = self.view.len
 *         info.readonly = self.view.readonly
 *         info.obj = self             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_INCREF((PyObject *)__pyx_v_self);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self);
  __Pyx_GOTREF(__pyx_v_info->obj);
  __Pyx_DECREF(__pyx_v_info->obj);
  __pyx_v_info->obj = ((PyObject *)__pyx_v_self);

  /* "View.MemoryView":521
 *             itemp[i] = c
 * 
 *     @cname('getbuffer')             # <<<<<<<<<<<<<<
 *     def __getbuffer__(self, Py_buffer *info, int flags):
 *         if flags & PyBUF_WRITABLE and self.view.readonly:
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.memoryview.__getbuffer__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  if (__pyx_v_info->obj != NULL) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  goto __pyx_L2;
  __pyx_L0:;
  if (__pyx_v_info->obj == Py_None) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = 0;
  }
  __pyx_L2:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":554
 * 
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def T(self):
 *         cdef _memoryviewslice result = memoryview_copy(self)
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_1T_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_1T_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_1T___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_1T___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  struct __pyx_memoryviewslice_obj *__pyx_v_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "View.MemoryView":556
 *     @property
 *     def T(self):
 *         cdef _memoryviewslice result = memoryview_copy(self)             # <<<<<<<<<<<<<<
 *         transpose_memslice(&result.from_slice)
 *         return result
 */
  __pyx_t_1 = __pyx_memoryview_copy_object(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 556, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_memoryviewslice_type))))) __PYX_ERR(1, 556, __pyx_L1_error)
  __pyx_v_result = ((struct __pyx_memoryviewslice_obj *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "View.MemoryView":557
 *     def T(self):
 *         cdef _memoryviewslice result = memoryview_copy(self)
 *         transpose_memslice(&result.from_slice)             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  __pyx_t_2 = __pyx_memslice_transpose((&__pyx_v_result->from_slice)); if (unlikely(__pyx_t_2 == ((int)-1))) __PYX_ERR(1, 557, __pyx_L1_error)

  /* "View.MemoryView":558
 *         cdef _memoryviewslice result = memoryview_copy(self)
 *         transpose_memslice(&result.from_slice)
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_result);
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "View.MemoryView":554
 * 
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def T(self):
 *         cdef _memoryviewslice result = memoryview_copy(self)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.memoryview.T.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":560
 *         return result
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def base(self):
 *         return self._get_base()
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4base_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4base_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_4base___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4base___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "View.MemoryView":562
 *     @property
 *     def base(self):
 *         return self._get_base()             # <<<<<<<<<<<<<<
 * 
 *     cdef _get_base(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((struct __pyx_vtabstruct_memoryview *)__pyx_v_self->__pyx_vtab)->_get_base(__pyx_v_self); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":560
 *         return result
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def base(self):
 *         return self._get_base()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.memoryview.base.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":564
 *         return self._get_base()
 * 
 *     cdef _get_base(self):             # <<<<<<<<<<<<<<
 *         return self.obj
 * 
 */

static PyObject *__pyx_memoryview__get_base(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_base", 1);

  /* "View.MemoryView":565
 * 
 *     cdef _get_base(self):
 *         return self.obj             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->obj);
  __pyx_r = __pyx_v_self->obj;
  goto __pyx_L0;

  /* "View.MemoryView":564
 *         return self._get_base()
 * 
 *     cdef _get_base(self):             # <<<<<<<<<<<<<<
 *         return self.obj
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":567
 *         return self.obj
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def shape(self):
 *         return tuple([length for length in self.view.shape[:self.view.ndim]])
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_5shape_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_5shape_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_5shape___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_5shape___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  Py_ssize_t __pyx_7genexpr__pyx_v_length;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t *__pyx_t_2;
  Py_ssize_t *__pyx_t_3;
  Py_ssize_t *__pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "View.MemoryView":569
 *     @property
 *     def shape(self):
 *         return tuple([length for length in self.view.shape[:self.view.ndim]])             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  { /* enter inner scope */
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 569, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = (__pyx_v_self->view.shape + __pyx_v_self->view.ndim);
    for (__pyx_t_4 = __pyx_v_self->view.shape; __pyx_t_4 < __pyx_t_3; __pyx_t_4++) {
      __pyx_t_2 = __pyx_t_4;
      __pyx_7genexpr__pyx_v_length = (__pyx_t_2[0]);
      __pyx_t_5 = PyInt_FromSsize_t(__pyx_7genexpr__pyx_v_length); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 569, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_1, (PyObject*)__pyx_t_5))) __PYX_ERR(1, 569, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    }
  } /* exit inner scope */
  __pyx_t_5 = PyList_AsTuple(((PyObject*)__pyx_t_1)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 569, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":567
 *         return self.obj
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def shape(self):
 *         return tuple([length for length in self.view.shape[:self.view.ndim]])
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("View.MemoryView.memoryview.shape.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":571
 *         return tuple([length for length in self.view.shape[:self.view.ndim]])
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def strides(self):
 *         if self.view.strides == NULL:
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_7strides_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_7strides_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_7strides___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_7strides___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  Py_ssize_t __pyx_8genexpr1__pyx_v_stride;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t *__pyx_t_3;
  Py_ssize_t *__pyx_t_4;
  Py_ssize_t *__pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "View.MemoryView":573
 *     @property
 *     def strides(self):
 *         if self.view.strides == NULL:             # <<<<<<<<<<<<<<
 * 
 *             raise ValueError, "Buffer view does not expose strides"
 */
  __pyx_t_1 = (__pyx_v_self->view.strides == NULL);
  if (unlikely(__pyx_t_1)) {

    /* "View.MemoryView":575
 *         if self.view.strides == NULL:
 * 
 *             raise ValueError, "Buffer view does not expose strides"             # <<<<<<<<<<<<<<
 * 
 *         return tuple([stride for stride in self.view.strides[:self.view.ndim]])
 */
    __Pyx_Raise(__pyx_builtin_ValueError, __pyx_kp_s_Buffer_view_does_not_expose_stri, 0, 0);
    __PYX_ERR(1, 575, __pyx_L1_error)

    /* "View.MemoryView":573
 *     @property
 *     def strides(self):
 *         if self.view.strides == NULL:             # <<<<<<<<<<<<<<
 * 
 *             raise ValueError, "Buffer view does not expose strides"
 */
  }

  /* "View.MemoryView":577
 *             raise ValueError, "Buffer view does not expose strides"
 * 
 *         return tuple([stride for stride in self.view.strides[:self.view.ndim]])             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  { /* enter inner scope */
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 577, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = (__pyx_v_self->view.strides + __pyx_v_self->view.ndim);
    for (__pyx_t_5 = __pyx_v_self->view.strides; __pyx_t_5 < __pyx_t_4; __pyx_t_5++) {
      __pyx_t_3 = __pyx_t_5;
      __pyx_8genexpr1__pyx_v_stride = (__pyx_t_3[0]);
      __pyx_t_6 = PyInt_FromSsize_t(__pyx_8genexpr1__pyx_v_stride); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 577, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_6))) __PYX_ERR(1, 577, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  } /* exit inner scope */
  __pyx_t_6 = PyList_AsTuple(((PyObject*)__pyx_t_2)); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":571
 *         return tuple([length for length in self.view.shape[:self.view.ndim]])
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def strides(self):
 *         if self.view.strides == NULL:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("View.MemoryView.memoryview.strides.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":579
 *         return tuple([stride for stride in self.view.strides[:self.view.ndim]])
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def suboffsets(self):
 *         if self.view.suboffsets == NULL:
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_10suboffsets_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_10suboffsets_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_10suboffsets___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_10suboffsets___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  Py_ssize_t __pyx_8genexpr2__pyx_v_suboffset;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t *__pyx_t_3;
  Py_ssize_t *__pyx_t_4;
  Py_ssize_t *__pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "View.MemoryView":581
 *     @property
 *     def suboffsets(self):
 *         if self.view.suboffsets == NULL:             # <<<<<<<<<<<<<<
 *             return (-1,) * self.view.ndim
 * 
 */
  __pyx_t_1 = (__pyx_v_self->view.suboffsets == NULL);
  if (__pyx_t_1) {

    /* "View.MemoryView":582
 *     def suboffsets(self):
 *         if self.view.suboffsets == NULL:
 *             return (-1,) * self.view.ndim             # <<<<<<<<<<<<<<
 * 
 *         return tuple([suboffset for suboffset in self.view.suboffsets[:self.view.ndim]])
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_PySequence_Multiply(__pyx_tuple__4, __pyx_v_self->view.ndim); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 582, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "View.MemoryView":581
 *     @property
 *     def suboffsets(self):
 *         if self.view.suboffsets == NULL:             # <<<<<<<<<<<<<<
 *             return (-1,) * self.view.ndim
 * 
 */
  }

  /* "View.MemoryView":584
 *             return (-1,) * self.view.ndim
 * 
 *         return tuple([suboffset for suboffset in self.view.suboffsets[:self.view.ndim]])             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  { /* enter inner scope */
    __pyx_t_2 = PyList_New(0); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 584, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = (__pyx_v_self->view.suboffsets + __pyx_v_self->view.ndim);
    for (__pyx_t_5 = __pyx_v_self->view.suboffsets; __pyx_t_5 < __pyx_t_4; __pyx_t_5++) {
      __pyx_t_3 = __pyx_t_5;
      __pyx_8genexpr2__pyx_v_suboffset = (__pyx_t_3[0]);
      __pyx_t_6 = PyInt_FromSsize_t(__pyx_8genexpr2__pyx_v_suboffset); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 584, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (unlikely(__Pyx_ListComp_Append(__pyx_t_2, (PyObject*)__pyx_t_6))) __PYX_ERR(1, 584, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
  } /* exit inner scope */
  __pyx_t_6 = PyList_AsTuple(((PyObject*)__pyx_t_2)); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":579
 *         return tuple([stride for stride in self.view.strides[:self.view.ndim]])
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def suboffsets(self):
 *         if self.view.suboffsets == NULL:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("View.MemoryView.memoryview.suboffsets.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":586
 *         return tuple([suboffset for suboffset in self.view.suboffsets[:self.view.ndim]])
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def ndim(self):
 *         return self.view.ndim
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4ndim_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4ndim_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_4ndim___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4ndim___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "View.MemoryView":588
 *     @property
 *     def ndim(self):
 *         return self.view.ndim             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->view.ndim); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":586
 *         return tuple([suboffset for suboffset in self.view.suboffsets[:self.view.ndim]])
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def ndim(self):
 *         return self.view.ndim
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.memoryview.ndim.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":590
 *         return self.view.ndim
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def itemsize(self):
 *         return self.view.itemsize
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_8itemsize_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_8itemsize_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_8itemsize___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_8itemsize___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "View.MemoryView":592
 *     @property
 *     def itemsize(self):
 *         return self.view.itemsize             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_self->view.itemsize); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":590
 *         return self.view.ndim
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def itemsize(self):
 *         return self.view.itemsize
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.memoryview.itemsize.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":594
 *         return self.view.itemsize
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def nbytes(self):
 *         return self.size * self.view.itemsize
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_6nbytes_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_6nbytes_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_6nbytes___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_6nbytes___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "View.MemoryView":596
 *     @property
 *     def nbytes(self):
 *         return self.size * self.view.itemsize             # <<<<<<<<<<<<<<
 * 
 *     @property
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_size); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->view.itemsize); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Multiply(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":594
 *         return self.view.itemsize
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def nbytes(self):
 *         return self.size * self.view.itemsize
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview.nbytes.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":598
 *         return self.size * self.view.itemsize
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def size(self):
 *         if self._size is None:
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4size_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_15View_dot_MemoryView_10memoryview_4size_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_15View_dot_MemoryView_10memoryview_4size___get__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView_10memoryview_4size___get__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_length = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  Py_ssize_t *__pyx_t_2;
  Py_ssize_t *__pyx_t_3;
  Py_ssize_t *__pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);

  /* "View.MemoryView":600
 *     @property
 *     def size(self):
 *         if self._size is None:             # <<<<<<<<<<<<<<
 *             result = 1
 * 
 */
  __pyx_t_1 = (__pyx_v_self->_size == Py_None);
  if (__pyx_t_1) {

    /* "View.MemoryView":601
 *     def size(self):
 *         if self._size is None:
 *             result = 1             # <<<<<<<<<<<<<<
 * 
 *             for length in self.view.shape[:self.view.ndim]:
 */
    __Pyx_INCREF(__pyx_int_1);
    __pyx_v_result = __pyx_int_1;

    /* "View.MemoryView":603
 *             result = 1
 * 
 *             for length in self.view.shape[:self.view.ndim]:             # <<<<<<<<<<<<<<
 *                 result *= length
 * 
 */
    __pyx_t_3 = (__pyx_v_self->view.shape + __pyx_v_self->view.ndim);
    for (__pyx_t_4 = __pyx_v_self->view.shape; __pyx_t_4 < __pyx_t_3; __pyx_t_4++) {
      __pyx_t_2 = __pyx_t_4;
      __pyx_t_5 = PyInt_FromSsize_t((__pyx_t_2[0])); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 603, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_XDECREF_SET(__pyx_v_length, __pyx_t_5);
      __pyx_t_5 = 0;

      /* "View.MemoryView":604
 * 
 *             for length in self.view.shape[:self.view.ndim]:
 *                 result *= length             # <<<<<<<<<<<<<<
 * 
 *             self._size = result
 */
      __pyx_t_5 = PyNumber_InPlaceMultiply(__pyx_v_result, __pyx_v_length); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 604, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_5);
      __pyx_t_5 = 0;
    }

    /* "View.MemoryView":606
 *                 result *= length
 * 
 *             self._size = result             # <<<<<<<<<<<<<<
 * 
 *         return self._size
 */
    __Pyx_INCREF(__pyx_v_result);
    __Pyx_GIVEREF(__pyx_v_result);
    __Pyx_GOTREF(__pyx_v_self->_size);
    __Pyx_DECREF(__pyx_v_self->_size);
    __pyx_v_self->_size = __pyx_v_result;

    /* "View.MemoryView":600
 *     @property
 *     def size(self):
 *         if self._size is None:             # <<<<<<<<<<<<<<
 *             result = 1
 * 
 */
  }

  /* "View.MemoryView":608
 *             self._size = result
 * 
 *         return self._size             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->_size);
  __pyx_r = __pyx_v_self->_size;
  goto __pyx_L0;

  /* "View.MemoryView":598
 *         return self.size * self.view.itemsize
 * 
 *     @property             # <<<<<<<<<<<<<<
 *     def size(self):
 *         if self._size is None:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("View.MemoryView.memoryview.size.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_length);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":610
 *         return self._size
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         if self.view.ndim >= 1:
 *             return self.view.shape[0]
 */

/* Python wrapper */
static Py_ssize_t __pyx_memoryview___len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_memoryview___len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_10__len__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_10__len__(struct __pyx_memoryview_obj *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  int __pyx_t_1;

  /* "View.MemoryView":611
 * 
 *     def __len__(self):
 *         if self.view.ndim >= 1:             # <<<<<<<<<<<<<<
 *             return self.view.shape[0]
 * 
 */
  __pyx_t_1 = (__pyx_v_self->view.ndim >= 1);
  if (__pyx_t_1) {

    /* "View.MemoryView":612
 *     def __len__(self):
 *         if self.view.ndim >= 1:
 *             return self.view.shape[0]             # <<<<<<<<<<<<<<
 * 
 *         return 0
 */
    __pyx_r = (__pyx_v_self->view.shape[0]);
    goto __pyx_L0;

    /* "View.MemoryView":611
 * 
 *     def __len__(self):
 *         if self.view.ndim >= 1:             # <<<<<<<<<<<<<<
 *             return self.view.shape[0]
 * 
 */
  }

  /* "View.MemoryView":614
 *             return self.view.shape[0]
 * 
 *         return 0             # <<<<<<<<<<<<<<
 * 
 *     def __repr__(self):
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "View.MemoryView":610
 *         return self._size
 * 
 *     def __len__(self):             # <<<<<<<<<<<<<<
 *         if self.view.ndim >= 1:
 *             return self.view.shape[0]
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":616
 *         return 0
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<MemoryView of %r at 0x%x>" % (self.base.__class__.__name__,
 *                                                id(self))
 */

/* Python wrapper */
static PyObject *__pyx_memoryview___repr__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_memoryview___repr__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__repr__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_12__repr__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_12__repr__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__repr__", 1);

  /* "View.MemoryView":617
 * 
 *     def __repr__(self):
 *         return "<MemoryView of %r at 0x%x>" % (self.base.__class__.__name__,             # <<<<<<<<<<<<<<
 *                                                id(self))
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_base); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_class); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "View.MemoryView":618
 *     def __repr__(self):
 *         return "<MemoryView of %r at 0x%x>" % (self.base.__class__.__name__,
 *                                                id(self))             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self):
 */
  __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_id, ((PyObject *)__pyx_v_self)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "View.MemoryView":617
 * 
 *     def __repr__(self):
 *         return "<MemoryView of %r at 0x%x>" % (self.base.__class__.__name__,             # <<<<<<<<<<<<<<
 *                                                id(self))
 * 
 */
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(1, 617, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2)) __PYX_ERR(1, 617, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyString_Format(__pyx_kp_s_MemoryView_of_r_at_0x_x, __pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":616
 *         return 0
 * 
 *     def __repr__(self):             # <<<<<<<<<<<<<<
 *         return "<MemoryView of %r at 0x%x>" % (self.base.__class__.__name__,
 *                                                id(self))
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview.__repr__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":620
 *                                                id(self))
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "<MemoryView of %r object>" % (self.base.__class__.__name__,)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_memoryview___str__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_memoryview___str__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_14__str__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_14__str__(struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__str__", 1);

  /* "View.MemoryView":621
 * 
 *     def __str__(self):
 *         return "<MemoryView of %r object>" % (self.base.__class__.__name__,)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_base); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_class); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_name_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(1, 621, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_MemoryView_of_r_object, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":620
 *                                                id(self))
 * 
 *     def __str__(self):             # <<<<<<<<<<<<<<
 *         return "<MemoryView of %r object>" % (self.base.__class__.__name__,)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":624
 * 
 * 
 *     def is_c_contig(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 */

/* Python wrapper */
static PyObject *__pyx_memoryview_is_c_contig(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_memoryview_is_c_contig(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_c_contig (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("is_c_contig", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_c_contig", 0))) return NULL;
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_16is_c_contig(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_16is_c_contig(struct __pyx_memoryview_obj *__pyx_v_self) {
  __Pyx_memviewslice *__pyx_v_mslice;
  __Pyx_memviewslice __pyx_v_tmp;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_c_contig", 1);

  /* "View.MemoryView":627
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 *         mslice = get_slice_from_memview(self, &tmp)             # <<<<<<<<<<<<<<
 *         return slice_is_contig(mslice[0], 'C', self.view.ndim)
 * 
 */
  __pyx_t_1 = __pyx_memoryview_get_slice_from_memoryview(__pyx_v_self, (&__pyx_v_tmp)); if (unlikely(__pyx_t_1 == ((__Pyx_memviewslice *)NULL))) __PYX_ERR(1, 627, __pyx_L1_error)
  __pyx_v_mslice = __pyx_t_1;

  /* "View.MemoryView":628
 *         cdef __Pyx_memviewslice tmp
 *         mslice = get_slice_from_memview(self, &tmp)
 *         return slice_is_contig(mslice[0], 'C', self.view.ndim)             # <<<<<<<<<<<<<<
 * 
 *     def is_f_contig(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_memviewslice_is_contig((__pyx_v_mslice[0]), 'C', __pyx_v_self->view.ndim)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 628, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":624
 * 
 * 
 *     def is_c_contig(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.is_c_contig", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":630
 *         return slice_is_contig(mslice[0], 'C', self.view.ndim)
 * 
 *     def is_f_contig(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 */

/* Python wrapper */
static PyObject *__pyx_memoryview_is_f_contig(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_memoryview_is_f_contig(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_f_contig (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("is_f_contig", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "is_f_contig", 0))) return NULL;
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_18is_f_contig(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_18is_f_contig(struct __pyx_memoryview_obj *__pyx_v_self) {
  __Pyx_memviewslice *__pyx_v_mslice;
  __Pyx_memviewslice __pyx_v_tmp;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice *__pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_f_contig", 1);

  /* "View.MemoryView":633
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 *         mslice = get_slice_from_memview(self, &tmp)             # <<<<<<<<<<<<<<
 *         return slice_is_contig(mslice[0], 'F', self.view.ndim)
 * 
 */
  __pyx_t_1 = __pyx_memoryview_get_slice_from_memoryview(__pyx_v_self, (&__pyx_v_tmp)); if (unlikely(__pyx_t_1 == ((__Pyx_memviewslice *)NULL))) __PYX_ERR(1, 633, __pyx_L1_error)
  __pyx_v_mslice = __pyx_t_1;

  /* "View.MemoryView":634
 *         cdef __Pyx_memviewslice tmp
 *         mslice = get_slice_from_memview(self, &tmp)
 *         return slice_is_contig(mslice[0], 'F', self.view.ndim)             # <<<<<<<<<<<<<<
 * 
 *     def copy(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_memviewslice_is_contig((__pyx_v_mslice[0]), 'F', __pyx_v_self->view.ndim)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":630
 *         return slice_is_contig(mslice[0], 'C', self.view.ndim)
 * 
 *     def is_f_contig(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice *mslice
 *         cdef __Pyx_memviewslice tmp
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.is_f_contig", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":636
 *         return slice_is_contig(mslice[0], 'F', self.view.ndim)
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice mslice
 *         cdef int flags = self.flags & ~PyBUF_F_CONTIGUOUS
 */

/* Python wrapper */
static PyObject *__pyx_memoryview_copy(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_memoryview_copy(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("copy", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "copy", 0))) return NULL;
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_20copy(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_20copy(struct __pyx_memoryview_obj *__pyx_v_self) {
  __Pyx_memviewslice __pyx_v_mslice;
  int __pyx_v_flags;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy", 1);

  /* "View.MemoryView":638
 *     def copy(self):
 *         cdef __Pyx_memviewslice mslice
 *         cdef int flags = self.flags & ~PyBUF_F_CONTIGUOUS             # <<<<<<<<<<<<<<
 * 
 *         slice_copy(self, &mslice)
 */
  __pyx_v_flags = (__pyx_v_self->flags & (~PyBUF_F_CONTIGUOUS));

  /* "View.MemoryView":640
 *         cdef int flags = self.flags & ~PyBUF_F_CONTIGUOUS
 * 
 *         slice_copy(self, &mslice)             # <<<<<<<<<<<<<<
 *         mslice = slice_copy_contig(&mslice, "c", self.view.ndim,
 *                                    self.view.itemsize,
 */
  __pyx_memoryview_slice_copy(__pyx_v_self, (&__pyx_v_mslice));

  /* "View.MemoryView":641
 * 
 *         slice_copy(self, &mslice)
 *         mslice = slice_copy_contig(&mslice, "c", self.view.ndim,             # <<<<<<<<<<<<<<
 *                                    self.view.itemsize,
 *                                    flags|PyBUF_C_CONTIGUOUS,
 */
  __pyx_t_1 = __pyx_memoryview_copy_new_contig((&__pyx_v_mslice), ((char *)"c"), __pyx_v_self->view.ndim, __pyx_v_self->view.itemsize, (__pyx_v_flags | PyBUF_C_CONTIGUOUS), __pyx_v_self->dtype_is_object); if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 641, __pyx_L1_error)
  __pyx_v_mslice = __pyx_t_1;

  /* "View.MemoryView":646
 *                                    self.dtype_is_object)
 * 
 *         return memoryview_copy_from_slice(self, &mslice)             # <<<<<<<<<<<<<<
 * 
 *     def copy_fortran(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_memoryview_copy_object_from_slice(__pyx_v_self, (&__pyx_v_mslice)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":636
 *         return slice_is_contig(mslice[0], 'F', self.view.ndim)
 * 
 *     def copy(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice mslice
 *         cdef int flags = self.flags & ~PyBUF_F_CONTIGUOUS
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":648
 *         return memoryview_copy_from_slice(self, &mslice)
 * 
 *     def copy_fortran(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice src, dst
 *         cdef int flags = self.flags & ~PyBUF_C_CONTIGUOUS
 */

/* Python wrapper */
static PyObject *__pyx_memoryview_copy_fortran(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_memoryview_copy_fortran(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy_fortran (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("copy_fortran", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "copy_fortran", 0))) return NULL;
  __pyx_r = __pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_22copy_fortran(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_memoryview___pyx_pf_15View_dot_MemoryView_10memoryview_22copy_fortran(struct __pyx_memoryview_obj *__pyx_v_self) {
  __Pyx_memviewslice __pyx_v_src;
  __Pyx_memviewslice __pyx_v_dst;
  int __pyx_v_flags;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy_fortran", 1);

  /* "View.MemoryView":650
 *     def copy_fortran(self):
 *         cdef __Pyx_memviewslice src, dst
 *         cdef int flags = self.flags & ~PyBUF_C_CONTIGUOUS             # <<<<<<<<<<<<<<
 * 
 *         slice_copy(self, &src)
 */
  __pyx_v_flags = (__pyx_v_self->flags & (~PyBUF_C_CONTIGUOUS));

  /* "View.MemoryView":652
 *         cdef int flags = self.flags & ~PyBUF_C_CONTIGUOUS
 * 
 *         slice_copy(self, &src)             # <<<<<<<<<<<<<<
 *         dst = slice_copy_contig(&src, "fortran", self.view.ndim,
 *                                 self.view.itemsize,
 */
  __pyx_memoryview_slice_copy(__pyx_v_self, (&__pyx_v_src));

  /* "View.MemoryView":653
 * 
 *         slice_copy(self, &src)
 *         dst = slice_copy_contig(&src, "fortran", self.view.ndim,             # <<<<<<<<<<<<<<
 *                                 self.view.itemsize,
 *                                 flags|PyBUF_F_CONTIGUOUS,
 */
  __pyx_t_1 = __pyx_memoryview_copy_new_contig((&__pyx_v_src), ((char *)"fortran"), __pyx_v_self->view.ndim, __pyx_v_self->view.itemsize, (__pyx_v_flags | PyBUF_F_CONTIGUOUS), __pyx_v_self->dtype_is_object); if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 653, __pyx_L1_error)
  __pyx_v_dst = __pyx_t_1;

  /* "View.MemoryView":658
 *                                 self.dtype_is_object)
 * 
 *         return memoryview_copy_from_slice(self, &dst)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __pyx_memoryview_copy_object_from_slice(__pyx_v_self, (&__pyx_v_dst)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":648
 *         return memoryview_copy_from_slice(self, &mslice)
 * 
 *     def copy_fortran(self):             # <<<<<<<<<<<<<<
 *         cdef __Pyx_memviewslice src, dst
 *         cdef int flags = self.flags & ~PyBUF_C_CONTIGUOUS
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.memoryview.copy_fortran", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_memoryview_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_memoryview_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf___pyx_memoryview___reduce_cython__(((struct __pyx_memoryview_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_memoryview___reduce_cython__(CYTHON_UNUSED struct __pyx_memoryview_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.memoryview.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_memoryview_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_memoryview_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("View.MemoryView.memoryview.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf___pyx_memoryview_2__setstate_cython__(((struct __pyx_memoryview_obj *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_memoryview_2__setstate_cython__(CYTHON_UNUSED struct __pyx_memoryview_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.memoryview.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":662
 * 
 * @cname('__pyx_memoryview_new')
 * cdef memoryview_cwrapper(object o, int flags, bint dtype_is_object, __Pyx_TypeInfo *typeinfo):             # <<<<<<<<<<<<<<
 *     cdef memoryview result = memoryview(o, flags, dtype_is_object)
 *     result.typeinfo = typeinfo
 */

static PyObject *__pyx_memoryview_new(PyObject *__pyx_v_o, int __pyx_v_flags, int __pyx_v_dtype_is_object, __Pyx_TypeInfo *__pyx_v_typeinfo) {
  struct __pyx_memoryview_obj *__pyx_v_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("memoryview_cwrapper", 1);

  /* "View.MemoryView":663
 * @cname('__pyx_memoryview_new')
 * cdef memoryview_cwrapper(object o, int flags, bint dtype_is_object, __Pyx_TypeInfo *typeinfo):
 *     cdef memoryview result = memoryview(o, flags, dtype_is_object)             # <<<<<<<<<<<<<<
 *     result.typeinfo = typeinfo
 *     return result
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_dtype_is_object); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_o);
  __Pyx_GIVEREF(__pyx_v_o);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_o)) __PYX_ERR(1, 663, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1)) __PYX_ERR(1, 663, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_2)) __PYX_ERR(1, 663, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(((PyObject *)__pyx_memoryview_type), __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 663, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_result = ((struct __pyx_memoryview_obj *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "View.MemoryView":664
 * cdef memoryview_cwrapper(object o, int flags, bint dtype_is_object, __Pyx_TypeInfo *typeinfo):
 *     cdef memoryview result = memoryview(o, flags, dtype_is_object)
 *     result.typeinfo = typeinfo             # <<<<<<<<<<<<<<
 *     return result
 * 
 */
  __pyx_v_result->typeinfo = __pyx_v_typeinfo;

  /* "View.MemoryView":665
 *     cdef memoryview result = memoryview(o, flags, dtype_is_object)
 *     result.typeinfo = typeinfo
 *     return result             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_check')
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_result);
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "View.MemoryView":662
 * 
 * @cname('__pyx_memoryview_new')
 * cdef memoryview_cwrapper(object o, int flags, bint dtype_is_object, __Pyx_TypeInfo *typeinfo):             # <<<<<<<<<<<<<<
 *     cdef memoryview result = memoryview(o, flags, dtype_is_object)
 *     result.typeinfo = typeinfo
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview_cwrapper", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":668
 * 
 * @cname('__pyx_memoryview_check')
 * cdef inline bint memoryview_check(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return isinstance(o, memoryview)
 * 
 */

static CYTHON_INLINE int __pyx_memoryview_check(PyObject *__pyx_v_o) {
  int __pyx_r;
  int __pyx_t_1;

  /* "View.MemoryView":669
 * @cname('__pyx_memoryview_check')
 * cdef inline bint memoryview_check(object o) noexcept:
 *     return isinstance(o, memoryview)             # <<<<<<<<<<<<<<
 * 
 * cdef tuple _unellipsify(object index, int ndim):
 */
  __pyx_t_1 = __Pyx_TypeCheck(__pyx_v_o, __pyx_memoryview_type); 
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "View.MemoryView":668
 * 
 * @cname('__pyx_memoryview_check')
 * cdef inline bint memoryview_check(object o) noexcept:             # <<<<<<<<<<<<<<
 *     return isinstance(o, memoryview)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":671
 *     return isinstance(o, memoryview)
 * 
 * cdef tuple _unellipsify(object index, int ndim):             # <<<<<<<<<<<<<<
 *     """
 *     Replace all ellipses with full slices and fill incomplete indices with
 */

static PyObject *_unellipsify(PyObject *__pyx_v_index, int __pyx_v_ndim) {
  Py_ssize_t __pyx_v_idx;
  PyObject *__pyx_v_tup = NULL;
  PyObject *__pyx_v_result = NULL;
  int __pyx_v_have_slices;
  int __pyx_v_seen_ellipsis;
  PyObject *__pyx_v_item = NULL;
  Py_ssize_t __pyx_v_nslices;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_UCS4 __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_unellipsify", 1);

  /* "View.MemoryView":677
 *     """
 *     cdef Py_ssize_t idx
 *     tup = <tuple>index if isinstance(index, tuple) else (index,)             # <<<<<<<<<<<<<<
 * 
 *     result = [slice(None)] * ndim
 */
  __pyx_t_2 = PyTuple_Check(__pyx_v_index); 
  if (__pyx_t_2) {
    __Pyx_INCREF(((PyObject*)__pyx_v_index));
    __pyx_t_1 = __pyx_v_index;
  } else {
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 677, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_index);
    __Pyx_GIVEREF(__pyx_v_index);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_index)) __PYX_ERR(1, 677, __pyx_L1_error);
    __pyx_t_1 = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __pyx_v_tup = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "View.MemoryView":679
 *     tup = <tuple>index if isinstance(index, tuple) else (index,)
 * 
 *     result = [slice(None)] * ndim             # <<<<<<<<<<<<<<
 *     have_slices = False
 *     seen_ellipsis = False
 */
  __pyx_t_1 = PyList_New(1 * ((__pyx_v_ndim<0) ? 0:__pyx_v_ndim)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  { Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < __pyx_v_ndim; __pyx_temp++) {
      __Pyx_INCREF(__pyx_slice__5);
      __Pyx_GIVEREF(__pyx_slice__5);
      if (__Pyx_PyList_SET_ITEM(__pyx_t_1, __pyx_temp, __pyx_slice__5)) __PYX_ERR(1, 679, __pyx_L1_error);
    }
  }
  __pyx_v_result = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "View.MemoryView":680
 * 
 *     result = [slice(None)] * ndim
 *     have_slices = False             # <<<<<<<<<<<<<<
 *     seen_ellipsis = False
 *     idx = 0
 */
  __pyx_v_have_slices = 0;

  /* "View.MemoryView":681
 *     result = [slice(None)] * ndim
 *     have_slices = False
 *     seen_ellipsis = False             # <<<<<<<<<<<<<<
 *     idx = 0
 *     for item in tup:
 */
  __pyx_v_seen_ellipsis = 0;

  /* "View.MemoryView":682
 *     have_slices = False
 *     seen_ellipsis = False
 *     idx = 0             # <<<<<<<<<<<<<<
 *     for item in tup:
 *         if item is Ellipsis:
 */
  __pyx_v_idx = 0;

  /* "View.MemoryView":683
 *     seen_ellipsis = False
 *     idx = 0
 *     for item in tup:             # <<<<<<<<<<<<<<
 *         if item is Ellipsis:
 *             if not seen_ellipsis:
 */
  if (unlikely(__pyx_v_tup == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(1, 683, __pyx_L1_error)
  }
  __pyx_t_1 = __pyx_v_tup; __Pyx_INCREF(__pyx_t_1);
  __pyx_t_4 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_1);
      #if !CYTHON_ASSUME_SAFE_MACROS
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(1, 683, __pyx_L1_error)
      #endif
      if (__pyx_t_4 >= __pyx_temp) break;
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_4); __Pyx_INCREF(__pyx_t_3); __pyx_t_4++; if (unlikely((0 < 0))) __PYX_ERR(1, 683, __pyx_L1_error)
    #else
    __pyx_t_3 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 683, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_item, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "View.MemoryView":684
 *     idx = 0
 *     for item in tup:
 *         if item is Ellipsis:             # <<<<<<<<<<<<<<
 *             if not seen_ellipsis:
 *                 idx += ndim - len(tup)
 */
    __pyx_t_2 = (__pyx_v_item == __pyx_builtin_Ellipsis);
    if (__pyx_t_2) {

      /* "View.MemoryView":685
 *     for item in tup:
 *         if item is Ellipsis:
 *             if not seen_ellipsis:             # <<<<<<<<<<<<<<
 *                 idx += ndim - len(tup)
 *                 seen_ellipsis = True
 */
      __pyx_t_2 = (!__pyx_v_seen_ellipsis);
      if (__pyx_t_2) {

        /* "View.MemoryView":686
 *         if item is Ellipsis:
 *             if not seen_ellipsis:
 *                 idx += ndim - len(tup)             # <<<<<<<<<<<<<<
 *                 seen_ellipsis = True
 *             have_slices = True
 */
        if (unlikely(__pyx_v_tup == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
          __PYX_ERR(1, 686, __pyx_L1_error)
        }
        __pyx_t_5 = __Pyx_PyTuple_GET_SIZE(__pyx_v_tup); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(1, 686, __pyx_L1_error)
        __pyx_v_idx = (__pyx_v_idx + (__pyx_v_ndim - __pyx_t_5));

        /* "View.MemoryView":687
 *             if not seen_ellipsis:
 *                 idx += ndim - len(tup)
 *                 seen_ellipsis = True             # <<<<<<<<<<<<<<
 *             have_slices = True
 *         else:
 */
        __pyx_v_seen_ellipsis = 1;

        /* "View.MemoryView":685
 *     for item in tup:
 *         if item is Ellipsis:
 *             if not seen_ellipsis:             # <<<<<<<<<<<<<<
 *                 idx += ndim - len(tup)
 *                 seen_ellipsis = True
 */
      }

      /* "View.MemoryView":688
 *                 idx += ndim - len(tup)
 *                 seen_ellipsis = True
 *             have_slices = True             # <<<<<<<<<<<<<<
 *         else:
 *             if isinstance(item, slice):
 */
      __pyx_v_have_slices = 1;

      /* "View.MemoryView":684
 *     idx = 0
 *     for item in tup:
 *         if item is Ellipsis:             # <<<<<<<<<<<<<<
 *             if not seen_ellipsis:
 *                 idx += ndim - len(tup)
 */
      goto __pyx_L5;
    }

    /* "View.MemoryView":690
 *             have_slices = True
 *         else:
 *             if isinstance(item, slice):             # <<<<<<<<<<<<<<
 *                 have_slices = True
 *             elif not PyIndex_Check(item):
 */
    /*else*/ {
      __pyx_t_2 = PySlice_Check(__pyx_v_item); 
      if (__pyx_t_2) {

        /* "View.MemoryView":691
 *         else:
 *             if isinstance(item, slice):
 *                 have_slices = True             # <<<<<<<<<<<<<<
 *             elif not PyIndex_Check(item):
 *                 raise TypeError, f"Cannot index with type '{type(item)}'"
 */
        __pyx_v_have_slices = 1;

        /* "View.MemoryView":690
 *             have_slices = True
 *         else:
 *             if isinstance(item, slice):             # <<<<<<<<<<<<<<
 *                 have_slices = True
 *             elif not PyIndex_Check(item):
 */
        goto __pyx_L7;
      }

      /* "View.MemoryView":692
 *             if isinstance(item, slice):
 *                 have_slices = True
 *             elif not PyIndex_Check(item):             # <<<<<<<<<<<<<<
 *                 raise TypeError, f"Cannot index with type '{type(item)}'"
 *             result[idx] = item
 */
      __pyx_t_2 = (!(PyIndex_Check(__pyx_v_item) != 0));
      if (unlikely(__pyx_t_2)) {

        /* "View.MemoryView":693
 *                 have_slices = True
 *             elif not PyIndex_Check(item):
 *                 raise TypeError, f"Cannot index with type '{type(item)}'"             # <<<<<<<<<<<<<<
 *             result[idx] = item
 *         idx += 1
 */
        __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 693, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_5 = 0;
        __pyx_t_6 = 127;
        __Pyx_INCREF(__pyx_kp_u_Cannot_index_with_type);
        __pyx_t_5 += 24;
        __Pyx_GIVEREF(__pyx_kp_u_Cannot_index_with_type);
        PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_u_Cannot_index_with_type);
        __pyx_t_7 = __Pyx_PyObject_FormatSimple(((PyObject *)Py_TYPE(__pyx_v_item)), __pyx_empty_unicode); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 693, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_6 = (__Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) > __pyx_t_6) ? __Pyx_PyUnicode_MAX_CHAR_VALUE(__pyx_t_7) : __pyx_t_6;
        __pyx_t_5 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_7);
        __Pyx_GIVEREF(__pyx_t_7);
        PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_7);
        __pyx_t_7 = 0;
        __Pyx_INCREF(__pyx_kp_u__6);
        __pyx_t_5 += 1;
        __Pyx_GIVEREF(__pyx_kp_u__6);
        PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_kp_u__6);
        __pyx_t_7 = __Pyx_PyUnicode_Join(__pyx_t_3, 3, __pyx_t_5, __pyx_t_6); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 693, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_Raise(__pyx_builtin_TypeError, __pyx_t_7, 0, 0);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __PYX_ERR(1, 693, __pyx_L1_error)

        /* "View.MemoryView":692
 *             if isinstance(item, slice):
 *                 have_slices = True
 *             elif not PyIndex_Check(item):             # <<<<<<<<<<<<<<
 *                 raise TypeError, f"Cannot index with type '{type(item)}'"
 *             result[idx] = item
 */
      }
      __pyx_L7:;

      /* "View.MemoryView":694
 *             elif not PyIndex_Check(item):
 *                 raise TypeError, f"Cannot index with type '{type(item)}'"
 *             result[idx] = item             # <<<<<<<<<<<<<<
 *         idx += 1
 * 
 */
      if (unlikely((__Pyx_SetItemInt(__pyx_v_result, __pyx_v_idx, __pyx_v_item, Py_ssize_t, 1, PyInt_FromSsize_t, 1, 1, 1) < 0))) __PYX_ERR(1, 694, __pyx_L1_error)
    }
    __pyx_L5:;

    /* "View.MemoryView":695
 *                 raise TypeError, f"Cannot index with type '{type(item)}'"
 *             result[idx] = item
 *         idx += 1             # <<<<<<<<<<<<<<
 * 
 *     nslices = ndim - idx
 */
    __pyx_v_idx = (__pyx_v_idx + 1);

    /* "View.MemoryView":683
 *     seen_ellipsis = False
 *     idx = 0
 *     for item in tup:             # <<<<<<<<<<<<<<
 *         if item is Ellipsis:
 *             if not seen_ellipsis:
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "View.MemoryView":697
 *         idx += 1
 * 
 *     nslices = ndim - idx             # <<<<<<<<<<<<<<
 *     return have_slices or nslices, tuple(result)
 * 
 */
  __pyx_v_nslices = (__pyx_v_ndim - __pyx_v_idx);

  /* "View.MemoryView":698
 * 
 *     nslices = ndim - idx
 *     return have_slices or nslices, tuple(result)             # <<<<<<<<<<<<<<
 * 
 * cdef int assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim) except -1:
 */
  __Pyx_XDECREF(__pyx_r);
  if (!__pyx_v_have_slices) {
  } else {
    __pyx_t_7 = __Pyx_PyBool_FromLong(__pyx_v_have_slices); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 698, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_1 = __pyx_t_7;
    __pyx_t_7 = 0;
    goto __pyx_L9_bool_binop_done;
  }
  __pyx_t_7 = PyInt_FromSsize_t(__pyx_v_nslices); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = __pyx_t_7;
  __pyx_t_7 = 0;
  __pyx_L9_bool_binop_done:;
  __pyx_t_7 = PyList_AsTuple(__pyx_v_result); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(1, 698, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_7)) __PYX_ERR(1, 698, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_7 = 0;
  __pyx_r = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":671
 *     return isinstance(o, memoryview)
 * 
 * cdef tuple _unellipsify(object index, int ndim):             # <<<<<<<<<<<<<<
 *     """
 *     Replace all ellipses with full slices and fill incomplete indices with
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("View.MemoryView._unellipsify", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_tup);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_item);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":700
 *     return have_slices or nslices, tuple(result)
 * 
 * cdef int assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim) except -1:             # <<<<<<<<<<<<<<
 *     for suboffset in suboffsets[:ndim]:
 *         if suboffset >= 0:
 */

static int assert_direct_dimensions(Py_ssize_t *__pyx_v_suboffsets, int __pyx_v_ndim) {
  Py_ssize_t __pyx_v_suboffset;
  int __pyx_r;
  Py_ssize_t *__pyx_t_1;
  Py_ssize_t *__pyx_t_2;
  Py_ssize_t *__pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "View.MemoryView":701
 * 
 * cdef int assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim) except -1:
 *     for suboffset in suboffsets[:ndim]:             # <<<<<<<<<<<<<<
 *         if suboffset >= 0:
 *             raise ValueError, "Indirect dimensions not supported"
 */
  __pyx_t_2 = (__pyx_v_suboffsets + __pyx_v_ndim);
  for (__pyx_t_3 = __pyx_v_suboffsets; __pyx_t_3 < __pyx_t_2; __pyx_t_3++) {
    __pyx_t_1 = __pyx_t_3;
    __pyx_v_suboffset = (__pyx_t_1[0]);

    /* "View.MemoryView":702
 * cdef int assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim) except -1:
 *     for suboffset in suboffsets[:ndim]:
 *         if suboffset >= 0:             # <<<<<<<<<<<<<<
 *             raise ValueError, "Indirect dimensions not supported"
 *     return 0  # return type just used as an error flag
 */
    __pyx_t_4 = (__pyx_v_suboffset >= 0);
    if (unlikely(__pyx_t_4)) {

      /* "View.MemoryView":703
 *     for suboffset in suboffsets[:ndim]:
 *         if suboffset >= 0:
 *             raise ValueError, "Indirect dimensions not supported"             # <<<<<<<<<<<<<<
 *     return 0  # return type just used as an error flag
 * 
 */
      __Pyx_Raise(__pyx_builtin_ValueError, __pyx_kp_s_Indirect_dimensions_not_supporte, 0, 0);
      __PYX_ERR(1, 703, __pyx_L1_error)

      /* "View.MemoryView":702
 * cdef int assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim) except -1:
 *     for suboffset in suboffsets[:ndim]:
 *         if suboffset >= 0:             # <<<<<<<<<<<<<<
 *             raise ValueError, "Indirect dimensions not supported"
 *     return 0  # return type just used as an error flag
 */
    }
  }

  /* "View.MemoryView":704
 *         if suboffset >= 0:
 *             raise ValueError, "Indirect dimensions not supported"
 *     return 0  # return type just used as an error flag             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "View.MemoryView":700
 *     return have_slices or nslices, tuple(result)
 * 
 * cdef int assert_direct_dimensions(Py_ssize_t *suboffsets, int ndim) except -1:             # <<<<<<<<<<<<<<
 *     for suboffset in suboffsets[:ndim]:
 *         if suboffset >= 0:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView.assert_direct_dimensions", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":711
 * 
 * @cname('__pyx_memview_slice')
 * cdef memoryview memview_slice(memoryview memview, object indices):             # <<<<<<<<<<<<<<
 *     cdef int new_ndim = 0, suboffset_dim = -1, dim
 *     cdef bint negative_step
 */

static struct __pyx_memoryview_obj *__pyx_memview_slice(struct __pyx_memoryview_obj *__pyx_v_memview, PyObject *__pyx_v_indices) {
  int __pyx_v_new_ndim;
  int __pyx_v_suboffset_dim;
  int __pyx_v_dim;
  __Pyx_memviewslice __pyx_v_src;
  __Pyx_memviewslice __pyx_v_dst;
  __Pyx_memviewslice *__pyx_v_p_src;
  struct __pyx_memoryviewslice_obj *__pyx_v_memviewsliceobj = 0;
  __Pyx_memviewslice *__pyx_v_p_dst;
  int *__pyx_v_p_suboffset_dim;
  Py_ssize_t __pyx_v_start;
  Py_ssize_t __pyx_v_stop;
  Py_ssize_t __pyx_v_step;
  Py_ssize_t __pyx_v_cindex;
  int __pyx_v_have_start;
  int __pyx_v_have_stop;
  int __pyx_v_have_step;
  PyObject *__pyx_v_index = NULL;
  struct __pyx_memoryview_obj *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_memoryview_obj *__pyx_t_3;
  char *__pyx_t_4;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  PyObject *__pyx_t_8 = NULL;
  Py_ssize_t __pyx_t_9;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("memview_slice", 1);

  /* "View.MemoryView":712
 * @cname('__pyx_memview_slice')
 * cdef memoryview memview_slice(memoryview memview, object indices):
 *     cdef int new_ndim = 0, suboffset_dim = -1, dim             # <<<<<<<<<<<<<<
 *     cdef bint negative_step
 *     cdef __Pyx_memviewslice src, dst
 */
  __pyx_v_new_ndim = 0;
  __pyx_v_suboffset_dim = -1;

  /* "View.MemoryView":719
 * 
 * 
 *     memset(&dst, 0, sizeof(dst))             # <<<<<<<<<<<<<<
 * 
 *     cdef _memoryviewslice memviewsliceobj
 */
  (void)(memset((&__pyx_v_dst), 0, (sizeof(__pyx_v_dst))));

  /* "View.MemoryView":723
 *     cdef _memoryviewslice memviewsliceobj
 * 
 *     assert memview.view.ndim > 0             # <<<<<<<<<<<<<<
 * 
 *     if isinstance(memview, _memoryviewslice):
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(__pyx_assertions_enabled())) {
    __pyx_t_1 = (__pyx_v_memview->view.ndim > 0);
    if (unlikely(!__pyx_t_1)) {
      __Pyx_Raise(__pyx_builtin_AssertionError, 0, 0, 0);
      __PYX_ERR(1, 723, __pyx_L1_error)
    }
  }
  #else
  if ((1)); else __PYX_ERR(1, 723, __pyx_L1_error)
  #endif

  /* "View.MemoryView":725
 *     assert memview.view.ndim > 0
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         memviewsliceobj = memview
 *         p_src = &memviewsliceobj.from_slice
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type); 
  if (__pyx_t_1) {

    /* "View.MemoryView":726
 * 
 *     if isinstance(memview, _memoryviewslice):
 *         memviewsliceobj = memview             # <<<<<<<<<<<<<<
 *         p_src = &memviewsliceobj.from_slice
 *     else:
 */
    if (!(likely(((((PyObject *)__pyx_v_memview)) == Py_None) || likely(__Pyx_TypeTest(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type))))) __PYX_ERR(1, 726, __pyx_L1_error)
    __pyx_t_2 = ((PyObject *)__pyx_v_memview);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_memviewsliceobj = ((struct __pyx_memoryviewslice_obj *)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "View.MemoryView":727
 *     if isinstance(memview, _memoryviewslice):
 *         memviewsliceobj = memview
 *         p_src = &memviewsliceobj.from_slice             # <<<<<<<<<<<<<<
 *     else:
 *         slice_copy(memview, &src)
 */
    __pyx_v_p_src = (&__pyx_v_memviewsliceobj->from_slice);

    /* "View.MemoryView":725
 *     assert memview.view.ndim > 0
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         memviewsliceobj = memview
 *         p_src = &memviewsliceobj.from_slice
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":729
 *         p_src = &memviewsliceobj.from_slice
 *     else:
 *         slice_copy(memview, &src)             # <<<<<<<<<<<<<<
 *         p_src = &src
 * 
 */
  /*else*/ {
    __pyx_memoryview_slice_copy(__pyx_v_memview, (&__pyx_v_src));

    /* "View.MemoryView":730
 *     else:
 *         slice_copy(memview, &src)
 *         p_src = &src             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_v_p_src = (&__pyx_v_src);
  }
  __pyx_L3:;

  /* "View.MemoryView":736
 * 
 * 
 *     dst.memview = p_src.memview             # <<<<<<<<<<<<<<
 *     dst.data = p_src.data
 * 
 */
  __pyx_t_3 = __pyx_v_p_src->memview;
  __pyx_v_dst.memview = __pyx_t_3;

  /* "View.MemoryView":737
 * 
 *     dst.memview = p_src.memview
 *     dst.data = p_src.data             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_4 = __pyx_v_p_src->data;
  __pyx_v_dst.data = __pyx_t_4;

  /* "View.MemoryView":742
 * 
 * 
 *     cdef __Pyx_memviewslice *p_dst = &dst             # <<<<<<<<<<<<<<
 *     cdef int *p_suboffset_dim = &suboffset_dim
 *     cdef Py_ssize_t start, stop, step, cindex
 */
  __pyx_v_p_dst = (&__pyx_v_dst);

  /* "View.MemoryView":743
 * 
 *     cdef __Pyx_memviewslice *p_dst = &dst
 *     cdef int *p_suboffset_dim = &suboffset_dim             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t start, stop, step, cindex
 *     cdef bint have_start, have_stop, have_step
 */
  __pyx_v_p_suboffset_dim = (&__pyx_v_suboffset_dim);

  /* "View.MemoryView":747
 *     cdef bint have_start, have_stop, have_step
 * 
 *     for dim, index in enumerate(indices):             # <<<<<<<<<<<<<<
 *         if PyIndex_Check(index):
 *             cindex = index
 */
  __pyx_t_5 = 0;
  if (likely(PyList_CheckExact(__pyx_v_indices)) || PyTuple_CheckExact(__pyx_v_indices)) {
    __pyx_t_2 = __pyx_v_indices; __Pyx_INCREF(__pyx_t_2);
    __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_v_indices); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 747, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 747, __pyx_L1_error)
  }
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(1, 747, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_8 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_8); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(1, 747, __pyx_L1_error)
        #else
        __pyx_t_8 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 747, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        #endif
      } else {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyTuple_GET_SIZE(__pyx_t_2);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(1, 747, __pyx_L1_error)
          #endif
          if (__pyx_t_6 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_8 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_8); __pyx_t_6++; if (unlikely((0 < 0))) __PYX_ERR(1, 747, __pyx_L1_error)
        #else
        __pyx_t_8 = __Pyx_PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 747, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_8);
        #endif
      }
    } else {
      __pyx_t_8 = __pyx_t_7(__pyx_t_2);
      if (unlikely(!__pyx_t_8)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else __PYX_ERR(1, 747, __pyx_L1_error)
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_8);
    }
    __Pyx_XDECREF_SET(__pyx_v_index, __pyx_t_8);
    __pyx_t_8 = 0;
    __pyx_v_dim = __pyx_t_5;
    __pyx_t_5 = (__pyx_t_5 + 1);

    /* "View.MemoryView":748
 * 
 *     for dim, index in enumerate(indices):
 *         if PyIndex_Check(index):             # <<<<<<<<<<<<<<
 *             cindex = index
 *             slice_memviewslice(
 */
    __pyx_t_1 = (PyIndex_Check(__pyx_v_index) != 0);
    if (__pyx_t_1) {

      /* "View.MemoryView":749
 *     for dim, index in enumerate(indices):
 *         if PyIndex_Check(index):
 *             cindex = index             # <<<<<<<<<<<<<<
 *             slice_memviewslice(
 *                 p_dst, p_src.shape[dim], p_src.strides[dim], p_src.suboffsets[dim],
 */
      __pyx_t_9 = __Pyx_PyIndex_AsSsize_t(__pyx_v_index); if (unlikely((__pyx_t_9 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(1, 749, __pyx_L1_error)
      __pyx_v_cindex = __pyx_t_9;

      /* "View.MemoryView":750
 *         if PyIndex_Check(index):
 *             cindex = index
 *             slice_memviewslice(             # <<<<<<<<<<<<<<
 *                 p_dst, p_src.shape[dim], p_src.strides[dim], p_src.suboffsets[dim],
 *                 dim, new_ndim, p_suboffset_dim,
 */
      __pyx_t_10 = __pyx_memoryview_slice_memviewslice(__pyx_v_p_dst, (__pyx_v_p_src->shape[__pyx_v_dim]), (__pyx_v_p_src->strides[__pyx_v_dim]), (__pyx_v_p_src->suboffsets[__pyx_v_dim]), __pyx_v_dim, __pyx_v_new_ndim, __pyx_v_p_suboffset_dim, __pyx_v_cindex, 0, 0, 0, 0, 0, 0); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(1, 750, __pyx_L1_error)

      /* "View.MemoryView":748
 * 
 *     for dim, index in enumerate(indices):
 *         if PyIndex_Check(index):             # <<<<<<<<<<<<<<
 *             cindex = index
 *             slice_memviewslice(
 */
      goto __pyx_L6;
    }

    /* "View.MemoryView":756
 *                 0, 0, 0, # have_{start,stop,step}
 *                 False)
 *         elif index is None:             # <<<<<<<<<<<<<<
 *             p_dst.shape[new_ndim] = 1
 *             p_dst.strides[new_ndim] = 0
 */
    __pyx_t_1 = (__pyx_v_index == Py_None);
    if (__pyx_t_1) {

      /* "View.MemoryView":757
 *                 False)
 *         elif index is None:
 *             p_dst.shape[new_ndim] = 1             # <<<<<<<<<<<<<<
 *             p_dst.strides[new_ndim] = 0
 *             p_dst.suboffsets[new_ndim] = -1
 */
      (__pyx_v_p_dst->shape[__pyx_v_new_ndim]) = 1;

      /* "View.MemoryView":758
 *         elif index is None:
 *             p_dst.shape[new_ndim] = 1
 *             p_dst.strides[new_ndim] = 0             # <<<<<<<<<<<<<<
 *             p_dst.suboffsets[new_ndim] = -1
 *             new_ndim += 1
 */
      (__pyx_v_p_dst->strides[__pyx_v_new_ndim]) = 0;

      /* "View.MemoryView":759
 *             p_dst.shape[new_ndim] = 1
 *             p_dst.strides[new_ndim] = 0
 *             p_dst.suboffsets[new_ndim] = -1             # <<<<<<<<<<<<<<
 *             new_ndim += 1
 *         else:
 */
      (__pyx_v_p_dst->suboffsets[__pyx_v_new_ndim]) = -1L;

      /* "View.MemoryView":760
 *             p_dst.strides[new_ndim] = 0
 *             p_dst.suboffsets[new_ndim] = -1
 *             new_ndim += 1             # <<<<<<<<<<<<<<
 *         else:
 *             start = index.start or 0
 */
      __pyx_v_new_ndim = (__pyx_v_new_ndim + 1);

      /* "View.MemoryView":756
 *                 0, 0, 0, # have_{start,stop,step}
 *                 False)
 *         elif index is None:             # <<<<<<<<<<<<<<
 *             p_dst.shape[new_ndim] = 1
 *             p_dst.strides[new_ndim] = 0
 */
      goto __pyx_L6;
    }

    /* "View.MemoryView":762
 *             new_ndim += 1
 *         else:
 *             start = index.start or 0             # <<<<<<<<<<<<<<
 *             stop = index.stop or 0
 *             step = index.step or 0
 */
    /*else*/ {
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_start); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 762, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(1, 762, __pyx_L1_error)
      if (!__pyx_t_1) {
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else {
        __pyx_t_11 = __Pyx_PyIndex_AsSsize_t(__pyx_t_8); if (unlikely((__pyx_t_11 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(1, 762, __pyx_L1_error)
        __pyx_t_9 = __pyx_t_11;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L7_bool_binop_done;
      }
      __pyx_t_9 = 0;
      __pyx_L7_bool_binop_done:;
      __pyx_v_start = __pyx_t_9;

      /* "View.MemoryView":763
 *         else:
 *             start = index.start or 0
 *             stop = index.stop or 0             # <<<<<<<<<<<<<<
 *             step = index.step or 0
 * 
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_stop); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 763, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(1, 763, __pyx_L1_error)
      if (!__pyx_t_1) {
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else {
        __pyx_t_11 = __Pyx_PyIndex_AsSsize_t(__pyx_t_8); if (unlikely((__pyx_t_11 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(1, 763, __pyx_L1_error)
        __pyx_t_9 = __pyx_t_11;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L9_bool_binop_done;
      }
      __pyx_t_9 = 0;
      __pyx_L9_bool_binop_done:;
      __pyx_v_stop = __pyx_t_9;

      /* "View.MemoryView":764
 *             start = index.start or 0
 *             stop = index.stop or 0
 *             step = index.step or 0             # <<<<<<<<<<<<<<
 * 
 *             have_start = index.start is not None
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_step); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 764, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely((__pyx_t_1 < 0))) __PYX_ERR(1, 764, __pyx_L1_error)
      if (!__pyx_t_1) {
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      } else {
        __pyx_t_11 = __Pyx_PyIndex_AsSsize_t(__pyx_t_8); if (unlikely((__pyx_t_11 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(1, 764, __pyx_L1_error)
        __pyx_t_9 = __pyx_t_11;
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        goto __pyx_L11_bool_binop_done;
      }
      __pyx_t_9 = 0;
      __pyx_L11_bool_binop_done:;
      __pyx_v_step = __pyx_t_9;

      /* "View.MemoryView":766
 *             step = index.step or 0
 * 
 *             have_start = index.start is not None             # <<<<<<<<<<<<<<
 *             have_stop = index.stop is not None
 *             have_step = index.step is not None
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_start); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 766, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = (__pyx_t_8 != Py_None);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_have_start = __pyx_t_1;

      /* "View.MemoryView":767
 * 
 *             have_start = index.start is not None
 *             have_stop = index.stop is not None             # <<<<<<<<<<<<<<
 *             have_step = index.step is not None
 * 
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_stop); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 767, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = (__pyx_t_8 != Py_None);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_have_stop = __pyx_t_1;

      /* "View.MemoryView":768
 *             have_start = index.start is not None
 *             have_stop = index.stop is not None
 *             have_step = index.step is not None             # <<<<<<<<<<<<<<
 * 
 *             slice_memviewslice(
 */
      __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_v_index, __pyx_n_s_step); if (unlikely(!__pyx_t_8)) __PYX_ERR(1, 768, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __pyx_t_1 = (__pyx_t_8 != Py_None);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __pyx_v_have_step = __pyx_t_1;

      /* "View.MemoryView":770
 *             have_step = index.step is not None
 * 
 *             slice_memviewslice(             # <<<<<<<<<<<<<<
 *                 p_dst, p_src.shape[dim], p_src.strides[dim], p_src.suboffsets[dim],
 *                 dim, new_ndim, p_suboffset_dim,
 */
      __pyx_t_10 = __pyx_memoryview_slice_memviewslice(__pyx_v_p_dst, (__pyx_v_p_src->shape[__pyx_v_dim]), (__pyx_v_p_src->strides[__pyx_v_dim]), (__pyx_v_p_src->suboffsets[__pyx_v_dim]), __pyx_v_dim, __pyx_v_new_ndim, __pyx_v_p_suboffset_dim, __pyx_v_start, __pyx_v_stop, __pyx_v_step, __pyx_v_have_start, __pyx_v_have_stop, __pyx_v_have_step, 1); if (unlikely(__pyx_t_10 == ((int)-1))) __PYX_ERR(1, 770, __pyx_L1_error)

      /* "View.MemoryView":776
 *                 have_start, have_stop, have_step,
 *                 True)
 *             new_ndim += 1             # <<<<<<<<<<<<<<
 * 
 *     if isinstance(memview, _memoryviewslice):
 */
      __pyx_v_new_ndim = (__pyx_v_new_ndim + 1);
    }
    __pyx_L6:;

    /* "View.MemoryView":747
 *     cdef bint have_start, have_stop, have_step
 * 
 *     for dim, index in enumerate(indices):             # <<<<<<<<<<<<<<
 *         if PyIndex_Check(index):
 *             cindex = index
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "View.MemoryView":778
 *             new_ndim += 1
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         return memoryview_fromslice(dst, new_ndim,
 *                                     memviewsliceobj.to_object_func,
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type); 
  if (__pyx_t_1) {

    /* "View.MemoryView":779
 * 
 *     if isinstance(memview, _memoryviewslice):
 *         return memoryview_fromslice(dst, new_ndim,             # <<<<<<<<<<<<<<
 *                                     memviewsliceobj.to_object_func,
 *                                     memviewsliceobj.to_dtype_func,
 */
    __Pyx_XDECREF((PyObject *)__pyx_r);

    /* "View.MemoryView":780
 *     if isinstance(memview, _memoryviewslice):
 *         return memoryview_fromslice(dst, new_ndim,
 *                                     memviewsliceobj.to_object_func,             # <<<<<<<<<<<<<<
 *                                     memviewsliceobj.to_dtype_func,
 *                                     memview.dtype_is_object)
 */
    if (unlikely(!__pyx_v_memviewsliceobj)) { __Pyx_RaiseUnboundLocalError("memviewsliceobj"); __PYX_ERR(1, 780, __pyx_L1_error) }

    /* "View.MemoryView":781
 *         return memoryview_fromslice(dst, new_ndim,
 *                                     memviewsliceobj.to_object_func,
 *                                     memviewsliceobj.to_dtype_func,             # <<<<<<<<<<<<<<
 *                                     memview.dtype_is_object)
 *     else:
 */
    if (unlikely(!__pyx_v_memviewsliceobj)) { __Pyx_RaiseUnboundLocalError("memviewsliceobj"); __PYX_ERR(1, 781, __pyx_L1_error) }

    /* "View.MemoryView":779
 * 
 *     if isinstance(memview, _memoryviewslice):
 *         return memoryview_fromslice(dst, new_ndim,             # <<<<<<<<<<<<<<
 *                                     memviewsliceobj.to_object_func,
 *                                     memviewsliceobj.to_dtype_func,
 */
    __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_dst, __pyx_v_new_ndim, __pyx_v_memviewsliceobj->to_object_func, __pyx_v_memviewsliceobj->to_dtype_func, __pyx_v_memview->dtype_is_object); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 779, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_memoryview_type))))) __PYX_ERR(1, 779, __pyx_L1_error)
    __pyx_r = ((struct __pyx_memoryview_obj *)__pyx_t_2);
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "View.MemoryView":778
 *             new_ndim += 1
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         return memoryview_fromslice(dst, new_ndim,
 *                                     memviewsliceobj.to_object_func,
 */
  }

  /* "View.MemoryView":784
 *                                     memview.dtype_is_object)
 *     else:
 *         return memoryview_fromslice(dst, new_ndim, NULL, NULL,             # <<<<<<<<<<<<<<
 *                                     memview.dtype_is_object)
 * 
 */
  /*else*/ {
    __Pyx_XDECREF((PyObject *)__pyx_r);

    /* "View.MemoryView":785
 *     else:
 *         return memoryview_fromslice(dst, new_ndim, NULL, NULL,
 *                                     memview.dtype_is_object)             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_dst, __pyx_v_new_ndim, NULL, NULL, __pyx_v_memview->dtype_is_object); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 784, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);

    /* "View.MemoryView":784
 *                                     memview.dtype_is_object)
 *     else:
 *         return memoryview_fromslice(dst, new_ndim, NULL, NULL,             # <<<<<<<<<<<<<<
 *                                     memview.dtype_is_object)
 * 
 */
    if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_memoryview_type))))) __PYX_ERR(1, 784, __pyx_L1_error)
    __pyx_r = ((struct __pyx_memoryview_obj *)__pyx_t_2);
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "View.MemoryView":711
 * 
 * @cname('__pyx_memview_slice')
 * cdef memoryview memview_slice(memoryview memview, object indices):             # <<<<<<<<<<<<<<
 *     cdef int new_ndim = 0, suboffset_dim = -1, dim
 *     cdef bint negative_step
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("View.MemoryView.memview_slice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_memviewsliceobj);
  __Pyx_XDECREF(__pyx_v_index);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":793
 * 
 * @cname('__pyx_memoryview_slice_memviewslice')
 * cdef int slice_memviewslice(             # <<<<<<<<<<<<<<
 *         __Pyx_memviewslice *dst,
 *         Py_ssize_t shape, Py_ssize_t stride, Py_ssize_t suboffset,
 */

static int __pyx_memoryview_slice_memviewslice(__Pyx_memviewslice *__pyx_v_dst, Py_ssize_t __pyx_v_shape, Py_ssize_t __pyx_v_stride, Py_ssize_t __pyx_v_suboffset, int __pyx_v_dim, int __pyx_v_new_ndim, int *__pyx_v_suboffset_dim, Py_ssize_t __pyx_v_start, Py_ssize_t __pyx_v_stop, Py_ssize_t __pyx_v_step, int __pyx_v_have_start, int __pyx_v_have_stop, int __pyx_v_have_step, int __pyx_v_is_slice) {
  Py_ssize_t __pyx_v_new_shape;
  int __pyx_v_negative_step;
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save;
  #endif

  /* "View.MemoryView":813
 *     cdef bint negative_step
 * 
 *     if not is_slice:             # <<<<<<<<<<<<<<
 * 
 *         if start < 0:
 */
  __pyx_t_1 = (!__pyx_v_is_slice);
  if (__pyx_t_1) {

    /* "View.MemoryView":815
 *     if not is_slice:
 * 
 *         if start < 0:             # <<<<<<<<<<<<<<
 *             start += shape
 *         if not 0 <= start < shape:
 */
    __pyx_t_1 = (__pyx_v_start < 0);
    if (__pyx_t_1) {

      /* "View.MemoryView":816
 * 
 *         if start < 0:
 *             start += shape             # <<<<<<<<<<<<<<
 *         if not 0 <= start < shape:
 *             _err_dim(PyExc_IndexError, "Index out of bounds (axis %d)", dim)
 */
      __pyx_v_start = (__pyx_v_start + __pyx_v_shape);

      /* "View.MemoryView":815
 *     if not is_slice:
 * 
 *         if start < 0:             # <<<<<<<<<<<<<<
 *             start += shape
 *         if not 0 <= start < shape:
 */
    }

    /* "View.MemoryView":817
 *         if start < 0:
 *             start += shape
 *         if not 0 <= start < shape:             # <<<<<<<<<<<<<<
 *             _err_dim(PyExc_IndexError, "Index out of bounds (axis %d)", dim)
 *     else:
 */
    __pyx_t_1 = (0 <= __pyx_v_start);
    if (__pyx_t_1) {
      __pyx_t_1 = (__pyx_v_start < __pyx_v_shape);
    }
    __pyx_t_2 = (!__pyx_t_1);
    if (__pyx_t_2) {

      /* "View.MemoryView":818
 *             start += shape
 *         if not 0 <= start < shape:
 *             _err_dim(PyExc_IndexError, "Index out of bounds (axis %d)", dim)             # <<<<<<<<<<<<<<
 *     else:
 * 
 */
      __pyx_t_3 = __pyx_memoryview_err_dim(PyExc_IndexError, __pyx_kp_s_Index_out_of_bounds_axis_d, __pyx_v_dim); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(1, 818, __pyx_L1_error)

      /* "View.MemoryView":817
 *         if start < 0:
 *             start += shape
 *         if not 0 <= start < shape:             # <<<<<<<<<<<<<<
 *             _err_dim(PyExc_IndexError, "Index out of bounds (axis %d)", dim)
 *     else:
 */
    }

    /* "View.MemoryView":813
 *     cdef bint negative_step
 * 
 *     if not is_slice:             # <<<<<<<<<<<<<<
 * 
 *         if start < 0:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":821
 *     else:
 * 
 *         if have_step:             # <<<<<<<<<<<<<<
 *             negative_step = step < 0
 *             if step == 0:
 */
  /*else*/ {
    __pyx_t_2 = (__pyx_v_have_step != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":822
 * 
 *         if have_step:
 *             negative_step = step < 0             # <<<<<<<<<<<<<<
 *             if step == 0:
 *                 _err_dim(PyExc_ValueError, "Step may not be zero (axis %d)", dim)
 */
      __pyx_v_negative_step = (__pyx_v_step < 0);

      /* "View.MemoryView":823
 *         if have_step:
 *             negative_step = step < 0
 *             if step == 0:             # <<<<<<<<<<<<<<
 *                 _err_dim(PyExc_ValueError, "Step may not be zero (axis %d)", dim)
 *         else:
 */
      __pyx_t_2 = (__pyx_v_step == 0);
      if (__pyx_t_2) {

        /* "View.MemoryView":824
 *             negative_step = step < 0
 *             if step == 0:
 *                 _err_dim(PyExc_ValueError, "Step may not be zero (axis %d)", dim)             # <<<<<<<<<<<<<<
 *         else:
 *             negative_step = False
 */
        __pyx_t_3 = __pyx_memoryview_err_dim(PyExc_ValueError, __pyx_kp_s_Step_may_not_be_zero_axis_d, __pyx_v_dim); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(1, 824, __pyx_L1_error)

        /* "View.MemoryView":823
 *         if have_step:
 *             negative_step = step < 0
 *             if step == 0:             # <<<<<<<<<<<<<<
 *                 _err_dim(PyExc_ValueError, "Step may not be zero (axis %d)", dim)
 *         else:
 */
      }

      /* "View.MemoryView":821
 *     else:
 * 
 *         if have_step:             # <<<<<<<<<<<<<<
 *             negative_step = step < 0
 *             if step == 0:
 */
      goto __pyx_L6;
    }

    /* "View.MemoryView":826
 *                 _err_dim(PyExc_ValueError, "Step may not be zero (axis %d)", dim)
 *         else:
 *             negative_step = False             # <<<<<<<<<<<<<<
 *             step = 1
 * 
 */
    /*else*/ {
      __pyx_v_negative_step = 0;

      /* "View.MemoryView":827
 *         else:
 *             negative_step = False
 *             step = 1             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_v_step = 1;
    }
    __pyx_L6:;

    /* "View.MemoryView":830
 * 
 * 
 *         if have_start:             # <<<<<<<<<<<<<<
 *             if start < 0:
 *                 start += shape
 */
    __pyx_t_2 = (__pyx_v_have_start != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":831
 * 
 *         if have_start:
 *             if start < 0:             # <<<<<<<<<<<<<<
 *                 start += shape
 *                 if start < 0:
 */
      __pyx_t_2 = (__pyx_v_start < 0);
      if (__pyx_t_2) {

        /* "View.MemoryView":832
 *         if have_start:
 *             if start < 0:
 *                 start += shape             # <<<<<<<<<<<<<<
 *                 if start < 0:
 *                     start = 0
 */
        __pyx_v_start = (__pyx_v_start + __pyx_v_shape);

        /* "View.MemoryView":833
 *             if start < 0:
 *                 start += shape
 *                 if start < 0:             # <<<<<<<<<<<<<<
 *                     start = 0
 *             elif start >= shape:
 */
        __pyx_t_2 = (__pyx_v_start < 0);
        if (__pyx_t_2) {

          /* "View.MemoryView":834
 *                 start += shape
 *                 if start < 0:
 *                     start = 0             # <<<<<<<<<<<<<<
 *             elif start >= shape:
 *                 if negative_step:
 */
          __pyx_v_start = 0;

          /* "View.MemoryView":833
 *             if start < 0:
 *                 start += shape
 *                 if start < 0:             # <<<<<<<<<<<<<<
 *                     start = 0
 *             elif start >= shape:
 */
        }

        /* "View.MemoryView":831
 * 
 *         if have_start:
 *             if start < 0:             # <<<<<<<<<<<<<<
 *                 start += shape
 *                 if start < 0:
 */
        goto __pyx_L9;
      }

      /* "View.MemoryView":835
 *                 if start < 0:
 *                     start = 0
 *             elif start >= shape:             # <<<<<<<<<<<<<<
 *                 if negative_step:
 *                     start = shape - 1
 */
      __pyx_t_2 = (__pyx_v_start >= __pyx_v_shape);
      if (__pyx_t_2) {

        /* "View.MemoryView":836
 *                     start = 0
 *             elif start >= shape:
 *                 if negative_step:             # <<<<<<<<<<<<<<
 *                     start = shape - 1
 *                 else:
 */
        if (__pyx_v_negative_step) {

          /* "View.MemoryView":837
 *             elif start >= shape:
 *                 if negative_step:
 *                     start = shape - 1             # <<<<<<<<<<<<<<
 *                 else:
 *                     start = shape
 */
          __pyx_v_start = (__pyx_v_shape - 1);

          /* "View.MemoryView":836
 *                     start = 0
 *             elif start >= shape:
 *                 if negative_step:             # <<<<<<<<<<<<<<
 *                     start = shape - 1
 *                 else:
 */
          goto __pyx_L11;
        }

        /* "View.MemoryView":839
 *                     start = shape - 1
 *                 else:
 *                     start = shape             # <<<<<<<<<<<<<<
 *         else:
 *             if negative_step:
 */
        /*else*/ {
          __pyx_v_start = __pyx_v_shape;
        }
        __pyx_L11:;

        /* "View.MemoryView":835
 *                 if start < 0:
 *                     start = 0
 *             elif start >= shape:             # <<<<<<<<<<<<<<
 *                 if negative_step:
 *                     start = shape - 1
 */
      }
      __pyx_L9:;

      /* "View.MemoryView":830
 * 
 * 
 *         if have_start:             # <<<<<<<<<<<<<<
 *             if start < 0:
 *                 start += shape
 */
      goto __pyx_L8;
    }

    /* "View.MemoryView":841
 *                     start = shape
 *         else:
 *             if negative_step:             # <<<<<<<<<<<<<<
 *                 start = shape - 1
 *             else:
 */
    /*else*/ {
      if (__pyx_v_negative_step) {

        /* "View.MemoryView":842
 *         else:
 *             if negative_step:
 *                 start = shape - 1             # <<<<<<<<<<<<<<
 *             else:
 *                 start = 0
 */
        __pyx_v_start = (__pyx_v_shape - 1);

        /* "View.MemoryView":841
 *                     start = shape
 *         else:
 *             if negative_step:             # <<<<<<<<<<<<<<
 *                 start = shape - 1
 *             else:
 */
        goto __pyx_L12;
      }

      /* "View.MemoryView":844
 *                 start = shape - 1
 *             else:
 *                 start = 0             # <<<<<<<<<<<<<<
 * 
 *         if have_stop:
 */
      /*else*/ {
        __pyx_v_start = 0;
      }
      __pyx_L12:;
    }
    __pyx_L8:;

    /* "View.MemoryView":846
 *                 start = 0
 * 
 *         if have_stop:             # <<<<<<<<<<<<<<
 *             if stop < 0:
 *                 stop += shape
 */
    __pyx_t_2 = (__pyx_v_have_stop != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":847
 * 
 *         if have_stop:
 *             if stop < 0:             # <<<<<<<<<<<<<<
 *                 stop += shape
 *                 if stop < 0:
 */
      __pyx_t_2 = (__pyx_v_stop < 0);
      if (__pyx_t_2) {

        /* "View.MemoryView":848
 *         if have_stop:
 *             if stop < 0:
 *                 stop += shape             # <<<<<<<<<<<<<<
 *                 if stop < 0:
 *                     stop = 0
 */
        __pyx_v_stop = (__pyx_v_stop + __pyx_v_shape);

        /* "View.MemoryView":849
 *             if stop < 0:
 *                 stop += shape
 *                 if stop < 0:             # <<<<<<<<<<<<<<
 *                     stop = 0
 *             elif stop > shape:
 */
        __pyx_t_2 = (__pyx_v_stop < 0);
        if (__pyx_t_2) {

          /* "View.MemoryView":850
 *                 stop += shape
 *                 if stop < 0:
 *                     stop = 0             # <<<<<<<<<<<<<<
 *             elif stop > shape:
 *                 stop = shape
 */
          __pyx_v_stop = 0;

          /* "View.MemoryView":849
 *             if stop < 0:
 *                 stop += shape
 *                 if stop < 0:             # <<<<<<<<<<<<<<
 *                     stop = 0
 *             elif stop > shape:
 */
        }

        /* "View.MemoryView":847
 * 
 *         if have_stop:
 *             if stop < 0:             # <<<<<<<<<<<<<<
 *                 stop += shape
 *                 if stop < 0:
 */
        goto __pyx_L14;
      }

      /* "View.MemoryView":851
 *                 if stop < 0:
 *                     stop = 0
 *             elif stop > shape:             # <<<<<<<<<<<<<<
 *                 stop = shape
 *         else:
 */
      __pyx_t_2 = (__pyx_v_stop > __pyx_v_shape);
      if (__pyx_t_2) {

        /* "View.MemoryView":852
 *                     stop = 0
 *             elif stop > shape:
 *                 stop = shape             # <<<<<<<<<<<<<<
 *         else:
 *             if negative_step:
 */
        __pyx_v_stop = __pyx_v_shape;

        /* "View.MemoryView":851
 *                 if stop < 0:
 *                     stop = 0
 *             elif stop > shape:             # <<<<<<<<<<<<<<
 *                 stop = shape
 *         else:
 */
      }
      __pyx_L14:;

      /* "View.MemoryView":846
 *                 start = 0
 * 
 *         if have_stop:             # <<<<<<<<<<<<<<
 *             if stop < 0:
 *                 stop += shape
 */
      goto __pyx_L13;
    }

    /* "View.MemoryView":854
 *                 stop = shape
 *         else:
 *             if negative_step:             # <<<<<<<<<<<<<<
 *                 stop = -1
 *             else:
 */
    /*else*/ {
      if (__pyx_v_negative_step) {

        /* "View.MemoryView":855
 *         else:
 *             if negative_step:
 *                 stop = -1             # <<<<<<<<<<<<<<
 *             else:
 *                 stop = shape
 */
        __pyx_v_stop = -1L;

        /* "View.MemoryView":854
 *                 stop = shape
 *         else:
 *             if negative_step:             # <<<<<<<<<<<<<<
 *                 stop = -1
 *             else:
 */
        goto __pyx_L16;
      }

      /* "View.MemoryView":857
 *                 stop = -1
 *             else:
 *                 stop = shape             # <<<<<<<<<<<<<<
 * 
 * 
 */
      /*else*/ {
        __pyx_v_stop = __pyx_v_shape;
      }
      __pyx_L16:;
    }
    __pyx_L13:;

    /* "View.MemoryView":861
 * 
 *         with cython.cdivision(True):
 *             new_shape = (stop - start) // step             # <<<<<<<<<<<<<<
 * 
 *             if (stop - start) - step * new_shape:
 */
    __pyx_v_new_shape = ((__pyx_v_stop - __pyx_v_start) / __pyx_v_step);

    /* "View.MemoryView":863
 *             new_shape = (stop - start) // step
 * 
 *             if (stop - start) - step * new_shape:             # <<<<<<<<<<<<<<
 *                 new_shape += 1
 * 
 */
    __pyx_t_2 = (((__pyx_v_stop - __pyx_v_start) - (__pyx_v_step * __pyx_v_new_shape)) != 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":864
 * 
 *             if (stop - start) - step * new_shape:
 *                 new_shape += 1             # <<<<<<<<<<<<<<
 * 
 *         if new_shape < 0:
 */
      __pyx_v_new_shape = (__pyx_v_new_shape + 1);

      /* "View.MemoryView":863
 *             new_shape = (stop - start) // step
 * 
 *             if (stop - start) - step * new_shape:             # <<<<<<<<<<<<<<
 *                 new_shape += 1
 * 
 */
    }

    /* "View.MemoryView":866
 *                 new_shape += 1
 * 
 *         if new_shape < 0:             # <<<<<<<<<<<<<<
 *             new_shape = 0
 * 
 */
    __pyx_t_2 = (__pyx_v_new_shape < 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":867
 * 
 *         if new_shape < 0:
 *             new_shape = 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_v_new_shape = 0;

      /* "View.MemoryView":866
 *                 new_shape += 1
 * 
 *         if new_shape < 0:             # <<<<<<<<<<<<<<
 *             new_shape = 0
 * 
 */
    }

    /* "View.MemoryView":870
 * 
 * 
 *         dst.strides[new_ndim] = stride * step             # <<<<<<<<<<<<<<
 *         dst.shape[new_ndim] = new_shape
 *         dst.suboffsets[new_ndim] = suboffset
 */
    (__pyx_v_dst->strides[__pyx_v_new_ndim]) = (__pyx_v_stride * __pyx_v_step);

    /* "View.MemoryView":871
 * 
 *         dst.strides[new_ndim] = stride * step
 *         dst.shape[new_ndim] = new_shape             # <<<<<<<<<<<<<<
 *         dst.suboffsets[new_ndim] = suboffset
 * 
 */
    (__pyx_v_dst->shape[__pyx_v_new_ndim]) = __pyx_v_new_shape;

    /* "View.MemoryView":872
 *         dst.strides[new_ndim] = stride * step
 *         dst.shape[new_ndim] = new_shape
 *         dst.suboffsets[new_ndim] = suboffset             # <<<<<<<<<<<<<<
 * 
 * 
 */
    (__pyx_v_dst->suboffsets[__pyx_v_new_ndim]) = __pyx_v_suboffset;
  }
  __pyx_L3:;

  /* "View.MemoryView":875
 * 
 * 
 *     if suboffset_dim[0] < 0:             # <<<<<<<<<<<<<<
 *         dst.data += start * stride
 *     else:
 */
  __pyx_t_2 = ((__pyx_v_suboffset_dim[0]) < 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":876
 * 
 *     if suboffset_dim[0] < 0:
 *         dst.data += start * stride             # <<<<<<<<<<<<<<
 *     else:
 *         dst.suboffsets[suboffset_dim[0]] += start * stride
 */
    __pyx_v_dst->data = (__pyx_v_dst->data + (__pyx_v_start * __pyx_v_stride));

    /* "View.MemoryView":875
 * 
 * 
 *     if suboffset_dim[0] < 0:             # <<<<<<<<<<<<<<
 *         dst.data += start * stride
 *     else:
 */
    goto __pyx_L19;
  }

  /* "View.MemoryView":878
 *         dst.data += start * stride
 *     else:
 *         dst.suboffsets[suboffset_dim[0]] += start * stride             # <<<<<<<<<<<<<<
 * 
 *     if suboffset >= 0:
 */
  /*else*/ {
    __pyx_t_3 = (__pyx_v_suboffset_dim[0]);
    (__pyx_v_dst->suboffsets[__pyx_t_3]) = ((__pyx_v_dst->suboffsets[__pyx_t_3]) + (__pyx_v_start * __pyx_v_stride));
  }
  __pyx_L19:;

  /* "View.MemoryView":880
 *         dst.suboffsets[suboffset_dim[0]] += start * stride
 * 
 *     if suboffset >= 0:             # <<<<<<<<<<<<<<
 *         if not is_slice:
 *             if new_ndim == 0:
 */
  __pyx_t_2 = (__pyx_v_suboffset >= 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":881
 * 
 *     if suboffset >= 0:
 *         if not is_slice:             # <<<<<<<<<<<<<<
 *             if new_ndim == 0:
 *                 dst.data = (<char **> dst.data)[0] + suboffset
 */
    __pyx_t_2 = (!__pyx_v_is_slice);
    if (__pyx_t_2) {

      /* "View.MemoryView":882
 *     if suboffset >= 0:
 *         if not is_slice:
 *             if new_ndim == 0:             # <<<<<<<<<<<<<<
 *                 dst.data = (<char **> dst.data)[0] + suboffset
 *             else:
 */
      __pyx_t_2 = (__pyx_v_new_ndim == 0);
      if (__pyx_t_2) {

        /* "View.MemoryView":883
 *         if not is_slice:
 *             if new_ndim == 0:
 *                 dst.data = (<char **> dst.data)[0] + suboffset             # <<<<<<<<<<<<<<
 *             else:
 *                 _err_dim(PyExc_IndexError, "All dimensions preceding dimension %d "
 */
        __pyx_v_dst->data = ((((char **)__pyx_v_dst->data)[0]) + __pyx_v_suboffset);

        /* "View.MemoryView":882
 *     if suboffset >= 0:
 *         if not is_slice:
 *             if new_ndim == 0:             # <<<<<<<<<<<<<<
 *                 dst.data = (<char **> dst.data)[0] + suboffset
 *             else:
 */
        goto __pyx_L22;
      }

      /* "View.MemoryView":885
 *                 dst.data = (<char **> dst.data)[0] + suboffset
 *             else:
 *                 _err_dim(PyExc_IndexError, "All dimensions preceding dimension %d "             # <<<<<<<<<<<<<<
 *                                      "must be indexed and not sliced", dim)
 *         else:
 */
      /*else*/ {

        /* "View.MemoryView":886
 *             else:
 *                 _err_dim(PyExc_IndexError, "All dimensions preceding dimension %d "
 *                                      "must be indexed and not sliced", dim)             # <<<<<<<<<<<<<<
 *         else:
 *             suboffset_dim[0] = new_ndim
 */
        __pyx_t_3 = __pyx_memoryview_err_dim(PyExc_IndexError, __pyx_kp_s_All_dimensions_preceding_dimensi, __pyx_v_dim); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(1, 885, __pyx_L1_error)
      }
      __pyx_L22:;

      /* "View.MemoryView":881
 * 
 *     if suboffset >= 0:
 *         if not is_slice:             # <<<<<<<<<<<<<<
 *             if new_ndim == 0:
 *                 dst.data = (<char **> dst.data)[0] + suboffset
 */
      goto __pyx_L21;
    }

    /* "View.MemoryView":888
 *                                      "must be indexed and not sliced", dim)
 *         else:
 *             suboffset_dim[0] = new_ndim             # <<<<<<<<<<<<<<
 * 
 *     return 0
 */
    /*else*/ {
      (__pyx_v_suboffset_dim[0]) = __pyx_v_new_ndim;
    }
    __pyx_L21:;

    /* "View.MemoryView":880
 *         dst.suboffsets[suboffset_dim[0]] += start * stride
 * 
 *     if suboffset >= 0:             # <<<<<<<<<<<<<<
 *         if not is_slice:
 *             if new_ndim == 0:
 */
  }

  /* "View.MemoryView":890
 *             suboffset_dim[0] = new_ndim
 * 
 *     return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "View.MemoryView":793
 * 
 * @cname('__pyx_memoryview_slice_memviewslice')
 * cdef int slice_memviewslice(             # <<<<<<<<<<<<<<
 *         __Pyx_memviewslice *dst,
 *         Py_ssize_t shape, Py_ssize_t stride, Py_ssize_t suboffset,
 */

  /* function exit code */
  __pyx_L1_error:;
  #ifdef WITH_THREAD
  __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_AddTraceback("View.MemoryView.slice_memviewslice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":896
 * 
 * @cname('__pyx_pybuffer_index')
 * cdef char *pybuffer_index(Py_buffer *view, char *bufp, Py_ssize_t index,             # <<<<<<<<<<<<<<
 *                           Py_ssize_t dim) except NULL:
 *     cdef Py_ssize_t shape, stride, suboffset = -1
 */

static char *__pyx_pybuffer_index(Py_buffer *__pyx_v_view, char *__pyx_v_bufp, Py_ssize_t __pyx_v_index, Py_ssize_t __pyx_v_dim) {
  Py_ssize_t __pyx_v_shape;
  Py_ssize_t __pyx_v_stride;
  Py_ssize_t __pyx_v_suboffset;
  Py_ssize_t __pyx_v_itemsize;
  char *__pyx_v_resultp;
  char *__pyx_r;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  Py_UCS4 __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pybuffer_index", 1);

  /* "View.MemoryView":898
 * cdef char *pybuffer_index(Py_buffer *view, char *bufp, Py_ssize_t index,
 *                           Py_ssize_t dim) except NULL:
 *     cdef Py_ssize_t shape, stride, suboffset = -1             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t itemsize = view.itemsize
 *     cdef char *resultp
 */
  __pyx_v_suboffset = -1L;

  /* "View.MemoryView":899
 *                           Py_ssize_t dim) except NULL:
 *     cdef Py_ssize_t shape, stride, suboffset = -1
 *     cdef Py_ssize_t itemsize = view.itemsize             # <<<<<<<<<<<<<<
 *     cdef char *resultp
 * 
 */
  __pyx_t_1 = __pyx_v_view->itemsize;
  __pyx_v_itemsize = __pyx_t_1;

  /* "View.MemoryView":902
 *     cdef char *resultp
 * 
 *     if view.ndim == 0:             # <<<<<<<<<<<<<<
 *         shape = view.len // itemsize
 *         stride = itemsize
 */
  __pyx_t_2 = (__pyx_v_view->ndim == 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":903
 * 
 *     if view.ndim == 0:
 *         shape = view.len // itemsize             # <<<<<<<<<<<<<<
 *         stride = itemsize
 *     else:
 */
    if (unlikely(__pyx_v_itemsize == 0)) {
      PyErr_SetString(PyExc_ZeroDivisionError, "integer division or modulo by zero");
      __PYX_ERR(1, 903, __pyx_L1_error)
    }
    else if (sizeof(Py_ssize_t) == sizeof(long) && (!(((Py_ssize_t)-1) > 0)) && unlikely(__pyx_v_itemsize == (Py_ssize_t)-1)  && unlikely(__Pyx_UNARY_NEG_WOULD_OVERFLOW(__pyx_v_view->len))) {
      PyErr_SetString(PyExc_OverflowError, "value too large to perform division");
      __PYX_ERR(1, 903, __pyx_L1_error)
    }
    __pyx_v_shape = __Pyx_div_Py_ssize_t(__pyx_v_view->len, __pyx_v_itemsize);

    /* "View.MemoryView":904
 *     if view.ndim == 0:
 *         shape = view.len // itemsize
 *         stride = itemsize             # <<<<<<<<<<<<<<
 *     else:
 *         shape = view.shape[dim]
 */
    __pyx_v_stride = __pyx_v_itemsize;

    /* "View.MemoryView":902
 *     cdef char *resultp
 * 
 *     if view.ndim == 0:             # <<<<<<<<<<<<<<
 *         shape = view.len // itemsize
 *         stride = itemsize
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":906
 *         stride = itemsize
 *     else:
 *         shape = view.shape[dim]             # <<<<<<<<<<<<<<
 *         stride = view.strides[dim]
 *         if view.suboffsets != NULL:
 */
  /*else*/ {
    __pyx_v_shape = (__pyx_v_view->shape[__pyx_v_dim]);

    /* "View.MemoryView":907
 *     else:
 *         shape = view.shape[dim]
 *         stride = view.strides[dim]             # <<<<<<<<<<<<<<
 *         if view.suboffsets != NULL:
 *             suboffset = view.suboffsets[dim]
 */
    __pyx_v_stride = (__pyx_v_view->strides[__pyx_v_dim]);

    /* "View.MemoryView":908
 *         shape = view.shape[dim]
 *         stride = view.strides[dim]
 *         if view.suboffsets != NULL:             # <<<<<<<<<<<<<<
 *             suboffset = view.suboffsets[dim]
 * 
 */
    __pyx_t_2 = (__pyx_v_view->suboffsets != NULL);
    if (__pyx_t_2) {

      /* "View.MemoryView":909
 *         stride = view.strides[dim]
 *         if view.suboffsets != NULL:
 *             suboffset = view.suboffsets[dim]             # <<<<<<<<<<<<<<
 * 
 *     if index < 0:
 */
      __pyx_v_suboffset = (__pyx_v_view->suboffsets[__pyx_v_dim]);

      /* "View.MemoryView":908
 *         shape = view.shape[dim]
 *         stride = view.strides[dim]
 *         if view.suboffsets != NULL:             # <<<<<<<<<<<<<<
 *             suboffset = view.suboffsets[dim]
 * 
 */
    }
  }
  __pyx_L3:;

  /* "View.MemoryView":911
 *             suboffset = view.suboffsets[dim]
 * 
 *     if index < 0:             # <<<<<<<<<<<<<<
 *         index += view.shape[dim]
 *         if index < 0:
 */
  __pyx_t_2 = (__pyx_v_index < 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":912
 * 
 *     if index < 0:
 *         index += view.shape[dim]             # <<<<<<<<<<<<<<
 *         if index < 0:
 *             raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 */
    __pyx_v_index = (__pyx_v_index + (__pyx_v_view->shape[__pyx_v_dim]));

    /* "View.MemoryView":913
 *     if index < 0:
 *         index += view.shape[dim]
 *         if index < 0:             # <<<<<<<<<<<<<<
 *             raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 * 
 */
    __pyx_t_2 = (__pyx_v_index < 0);
    if (unlikely(__pyx_t_2)) {

      /* "View.MemoryView":914
 *         index += view.shape[dim]
 *         if index < 0:
 *             raise IndexError, f"Out of bounds on buffer access (axis {dim})"             # <<<<<<<<<<<<<<
 * 
 *     if index >= shape:
 */
      __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 914, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = 0;
      __pyx_t_4 = 127;
      __Pyx_INCREF(__pyx_kp_u_Out_of_bounds_on_buffer_access_a);
      __pyx_t_1 += 37;
      __Pyx_GIVEREF(__pyx_kp_u_Out_of_bounds_on_buffer_access_a);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_u_Out_of_bounds_on_buffer_access_a);
      __pyx_t_5 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_v_dim, 0, ' ', 'd'); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 914, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_1 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_5);
      __pyx_t_5 = 0;
      __Pyx_INCREF(__pyx_kp_u__7);
      __pyx_t_1 += 1;
      __Pyx_GIVEREF(__pyx_kp_u__7);
      PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_kp_u__7);
      __pyx_t_5 = __Pyx_PyUnicode_Join(__pyx_t_3, 3, __pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 914, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_builtin_IndexError, __pyx_t_5, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __PYX_ERR(1, 914, __pyx_L1_error)

      /* "View.MemoryView":913
 *     if index < 0:
 *         index += view.shape[dim]
 *         if index < 0:             # <<<<<<<<<<<<<<
 *             raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 * 
 */
    }

    /* "View.MemoryView":911
 *             suboffset = view.suboffsets[dim]
 * 
 *     if index < 0:             # <<<<<<<<<<<<<<
 *         index += view.shape[dim]
 *         if index < 0:
 */
  }

  /* "View.MemoryView":916
 *             raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 * 
 *     if index >= shape:             # <<<<<<<<<<<<<<
 *         raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 * 
 */
  __pyx_t_2 = (__pyx_v_index >= __pyx_v_shape);
  if (unlikely(__pyx_t_2)) {

    /* "View.MemoryView":917
 * 
 *     if index >= shape:
 *         raise IndexError, f"Out of bounds on buffer access (axis {dim})"             # <<<<<<<<<<<<<<
 * 
 *     resultp = bufp + index * stride
 */
    __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = 0;
    __pyx_t_4 = 127;
    __Pyx_INCREF(__pyx_kp_u_Out_of_bounds_on_buffer_access_a);
    __pyx_t_1 += 37;
    __Pyx_GIVEREF(__pyx_kp_u_Out_of_bounds_on_buffer_access_a);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_kp_u_Out_of_bounds_on_buffer_access_a);
    __pyx_t_3 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_v_dim, 0, ' ', 'd'); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_INCREF(__pyx_kp_u__7);
    __pyx_t_1 += 1;
    __Pyx_GIVEREF(__pyx_kp_u__7);
    PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_kp_u__7);
    __pyx_t_3 = __Pyx_PyUnicode_Join(__pyx_t_5, 3, __pyx_t_1, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 917, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_Raise(__pyx_builtin_IndexError, __pyx_t_3, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __PYX_ERR(1, 917, __pyx_L1_error)

    /* "View.MemoryView":916
 *             raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 * 
 *     if index >= shape:             # <<<<<<<<<<<<<<
 *         raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 * 
 */
  }

  /* "View.MemoryView":919
 *         raise IndexError, f"Out of bounds on buffer access (axis {dim})"
 * 
 *     resultp = bufp + index * stride             # <<<<<<<<<<<<<<
 *     if suboffset >= 0:
 *         resultp = (<char **> resultp)[0] + suboffset
 */
  __pyx_v_resultp = (__pyx_v_bufp + (__pyx_v_index * __pyx_v_stride));

  /* "View.MemoryView":920
 * 
 *     resultp = bufp + index * stride
 *     if suboffset >= 0:             # <<<<<<<<<<<<<<
 *         resultp = (<char **> resultp)[0] + suboffset
 * 
 */
  __pyx_t_2 = (__pyx_v_suboffset >= 0);
  if (__pyx_t_2) {

    /* "View.MemoryView":921
 *     resultp = bufp + index * stride
 *     if suboffset >= 0:
 *         resultp = (<char **> resultp)[0] + suboffset             # <<<<<<<<<<<<<<
 * 
 *     return resultp
 */
    __pyx_v_resultp = ((((char **)__pyx_v_resultp)[0]) + __pyx_v_suboffset);

    /* "View.MemoryView":920
 * 
 *     resultp = bufp + index * stride
 *     if suboffset >= 0:             # <<<<<<<<<<<<<<
 *         resultp = (<char **> resultp)[0] + suboffset
 * 
 */
  }

  /* "View.MemoryView":923
 *         resultp = (<char **> resultp)[0] + suboffset
 * 
 *     return resultp             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_resultp;
  goto __pyx_L0;

  /* "View.MemoryView":896
 * 
 * @cname('__pyx_pybuffer_index')
 * cdef char *pybuffer_index(Py_buffer *view, char *bufp, Py_ssize_t index,             # <<<<<<<<<<<<<<
 *                           Py_ssize_t dim) except NULL:
 *     cdef Py_ssize_t shape, stride, suboffset = -1
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("View.MemoryView.pybuffer_index", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":929
 * 
 * @cname('__pyx_memslice_transpose')
 * cdef int transpose_memslice(__Pyx_memviewslice *memslice) except -1 nogil:             # <<<<<<<<<<<<<<
 *     cdef int ndim = memslice.memview.view.ndim
 * 
 */

static int __pyx_memslice_transpose(__Pyx_memviewslice *__pyx_v_memslice) {
  int __pyx_v_ndim;
  Py_ssize_t *__pyx_v_shape;
  Py_ssize_t *__pyx_v_strides;
  int __pyx_v_i;
  int __pyx_v_j;
  int __pyx_r;
  int __pyx_t_1;
  Py_ssize_t *__pyx_t_2;
  long __pyx_t_3;
  long __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save;
  #endif

  /* "View.MemoryView":930
 * @cname('__pyx_memslice_transpose')
 * cdef int transpose_memslice(__Pyx_memviewslice *memslice) except -1 nogil:
 *     cdef int ndim = memslice.memview.view.ndim             # <<<<<<<<<<<<<<
 * 
 *     cdef Py_ssize_t *shape = memslice.shape
 */
  __pyx_t_1 = __pyx_v_memslice->memview->view.ndim;
  __pyx_v_ndim = __pyx_t_1;

  /* "View.MemoryView":932
 *     cdef int ndim = memslice.memview.view.ndim
 * 
 *     cdef Py_ssize_t *shape = memslice.shape             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t *strides = memslice.strides
 * 
 */
  __pyx_t_2 = __pyx_v_memslice->shape;
  __pyx_v_shape = __pyx_t_2;

  /* "View.MemoryView":933
 * 
 *     cdef Py_ssize_t *shape = memslice.shape
 *     cdef Py_ssize_t *strides = memslice.strides             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __pyx_v_memslice->strides;
  __pyx_v_strides = __pyx_t_2;

  /* "View.MemoryView":937
 * 
 *     cdef int i, j
 *     for i in range(ndim // 2):             # <<<<<<<<<<<<<<
 *         j = ndim - 1 - i
 *         strides[i], strides[j] = strides[j], strides[i]
 */
  __pyx_t_3 = __Pyx_div_long(__pyx_v_ndim, 2);
  __pyx_t_4 = __pyx_t_3;
  for (__pyx_t_1 = 0; __pyx_t_1 < __pyx_t_4; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "View.MemoryView":938
 *     cdef int i, j
 *     for i in range(ndim // 2):
 *         j = ndim - 1 - i             # <<<<<<<<<<<<<<
 *         strides[i], strides[j] = strides[j], strides[i]
 *         shape[i], shape[j] = shape[j], shape[i]
 */
    __pyx_v_j = ((__pyx_v_ndim - 1) - __pyx_v_i);

    /* "View.MemoryView":939
 *     for i in range(ndim // 2):
 *         j = ndim - 1 - i
 *         strides[i], strides[j] = strides[j], strides[i]             # <<<<<<<<<<<<<<
 *         shape[i], shape[j] = shape[j], shape[i]
 * 
 */
    __pyx_t_5 = (__pyx_v_strides[__pyx_v_j]);
    __pyx_t_6 = (__pyx_v_strides[__pyx_v_i]);
    (__pyx_v_strides[__pyx_v_i]) = __pyx_t_5;
    (__pyx_v_strides[__pyx_v_j]) = __pyx_t_6;

    /* "View.MemoryView":940
 *         j = ndim - 1 - i
 *         strides[i], strides[j] = strides[j], strides[i]
 *         shape[i], shape[j] = shape[j], shape[i]             # <<<<<<<<<<<<<<
 * 
 *         if memslice.suboffsets[i] >= 0 or memslice.suboffsets[j] >= 0:
 */
    __pyx_t_6 = (__pyx_v_shape[__pyx_v_j]);
    __pyx_t_5 = (__pyx_v_shape[__pyx_v_i]);
    (__pyx_v_shape[__pyx_v_i]) = __pyx_t_6;
    (__pyx_v_shape[__pyx_v_j]) = __pyx_t_5;

    /* "View.MemoryView":942
 *         shape[i], shape[j] = shape[j], shape[i]
 * 
 *         if memslice.suboffsets[i] >= 0 or memslice.suboffsets[j] >= 0:             # <<<<<<<<<<<<<<
 *             _err(PyExc_ValueError, "Cannot transpose memoryview with indirect dimensions")
 * 
 */
    __pyx_t_8 = ((__pyx_v_memslice->suboffsets[__pyx_v_i]) >= 0);
    if (!__pyx_t_8) {
    } else {
      __pyx_t_7 = __pyx_t_8;
      goto __pyx_L6_bool_binop_done;
    }
    __pyx_t_8 = ((__pyx_v_memslice->suboffsets[__pyx_v_j]) >= 0);
    __pyx_t_7 = __pyx_t_8;
    __pyx_L6_bool_binop_done:;
    if (__pyx_t_7) {

      /* "View.MemoryView":943
 * 
 *         if memslice.suboffsets[i] >= 0 or memslice.suboffsets[j] >= 0:
 *             _err(PyExc_ValueError, "Cannot transpose memoryview with indirect dimensions")             # <<<<<<<<<<<<<<
 * 
 *     return 0
 */
      __pyx_t_9 = __pyx_memoryview_err(PyExc_ValueError, __pyx_kp_s_Cannot_transpose_memoryview_with); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(1, 943, __pyx_L1_error)

      /* "View.MemoryView":942
 *         shape[i], shape[j] = shape[j], shape[i]
 * 
 *         if memslice.suboffsets[i] >= 0 or memslice.suboffsets[j] >= 0:             # <<<<<<<<<<<<<<
 *             _err(PyExc_ValueError, "Cannot transpose memoryview with indirect dimensions")
 * 
 */
    }
  }

  /* "View.MemoryView":945
 *             _err(PyExc_ValueError, "Cannot transpose memoryview with indirect dimensions")
 * 
 *     return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "View.MemoryView":929
 * 
 * @cname('__pyx_memslice_transpose')
 * cdef int transpose_memslice(__Pyx_memviewslice *memslice) except -1 nogil:             # <<<<<<<<<<<<<<
 *     cdef int ndim = memslice.memview.view.ndim
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  #ifdef WITH_THREAD
  __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_AddTraceback("View.MemoryView.transpose_memslice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":963
 *     cdef int (*to_dtype_func)(char *, object) except 0
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         __PYX_XCLEAR_MEMVIEW(&self.from_slice, 1)
 * 
 */

/* Python wrapper */
static void __pyx_memoryviewslice___dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_memoryviewslice___dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_memoryviewslice___pyx_pf_15View_dot_MemoryView_16_memoryviewslice___dealloc__(((struct __pyx_memoryviewslice_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_memoryviewslice___pyx_pf_15View_dot_MemoryView_16_memoryviewslice___dealloc__(struct __pyx_memoryviewslice_obj *__pyx_v_self) {

  /* "View.MemoryView":964
 * 
 *     def __dealloc__(self):
 *         __PYX_XCLEAR_MEMVIEW(&self.from_slice, 1)             # <<<<<<<<<<<<<<
 * 
 *     cdef convert_item_to_object(self, char *itemp):
 */
  __PYX_XCLEAR_MEMVIEW((&__pyx_v_self->from_slice), 1);

  /* "View.MemoryView":963
 *     cdef int (*to_dtype_func)(char *, object) except 0
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         __PYX_XCLEAR_MEMVIEW(&self.from_slice, 1)
 * 
 */

  /* function exit code */
}

/* "View.MemoryView":966
 *         __PYX_XCLEAR_MEMVIEW(&self.from_slice, 1)
 * 
 *     cdef convert_item_to_object(self, char *itemp):             # <<<<<<<<<<<<<<
 *         if self.to_object_func != NULL:
 *             return self.to_object_func(itemp)
 */

static PyObject *__pyx_memoryviewslice_convert_item_to_object(struct __pyx_memoryviewslice_obj *__pyx_v_self, char *__pyx_v_itemp) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("convert_item_to_object", 1);

  /* "View.MemoryView":967
 * 
 *     cdef convert_item_to_object(self, char *itemp):
 *         if self.to_object_func != NULL:             # <<<<<<<<<<<<<<
 *             return self.to_object_func(itemp)
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->to_object_func != NULL);
  if (__pyx_t_1) {

    /* "View.MemoryView":968
 *     cdef convert_item_to_object(self, char *itemp):
 *         if self.to_object_func != NULL:
 *             return self.to_object_func(itemp)             # <<<<<<<<<<<<<<
 *         else:
 *             return memoryview.convert_item_to_object(self, itemp)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_v_self->to_object_func(__pyx_v_itemp); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 968, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "View.MemoryView":967
 * 
 *     cdef convert_item_to_object(self, char *itemp):
 *         if self.to_object_func != NULL:             # <<<<<<<<<<<<<<
 *             return self.to_object_func(itemp)
 *         else:
 */
  }

  /* "View.MemoryView":970
 *             return self.to_object_func(itemp)
 *         else:
 *             return memoryview.convert_item_to_object(self, itemp)             # <<<<<<<<<<<<<<
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __pyx_memoryview_convert_item_to_object(((struct __pyx_memoryview_obj *)__pyx_v_self), __pyx_v_itemp); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 970, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;
  }

  /* "View.MemoryView":966
 *         __PYX_XCLEAR_MEMVIEW(&self.from_slice, 1)
 * 
 *     cdef convert_item_to_object(self, char *itemp):             # <<<<<<<<<<<<<<
 *         if self.to_object_func != NULL:
 *             return self.to_object_func(itemp)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView._memoryviewslice.convert_item_to_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":972
 *             return memoryview.convert_item_to_object(self, itemp)
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):             # <<<<<<<<<<<<<<
 *         if self.to_dtype_func != NULL:
 *             self.to_dtype_func(itemp, value)
 */

static PyObject *__pyx_memoryviewslice_assign_item_from_object(struct __pyx_memoryviewslice_obj *__pyx_v_self, char *__pyx_v_itemp, PyObject *__pyx_v_value) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("assign_item_from_object", 1);

  /* "View.MemoryView":973
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):
 *         if self.to_dtype_func != NULL:             # <<<<<<<<<<<<<<
 *             self.to_dtype_func(itemp, value)
 *         else:
 */
  __pyx_t_1 = (__pyx_v_self->to_dtype_func != NULL);
  if (__pyx_t_1) {

    /* "View.MemoryView":974
 *     cdef assign_item_from_object(self, char *itemp, object value):
 *         if self.to_dtype_func != NULL:
 *             self.to_dtype_func(itemp, value)             # <<<<<<<<<<<<<<
 *         else:
 *             memoryview.assign_item_from_object(self, itemp, value)
 */
    __pyx_t_2 = __pyx_v_self->to_dtype_func(__pyx_v_itemp, __pyx_v_value); if (unlikely(__pyx_t_2 == ((int)0))) __PYX_ERR(1, 974, __pyx_L1_error)

    /* "View.MemoryView":973
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):
 *         if self.to_dtype_func != NULL:             # <<<<<<<<<<<<<<
 *             self.to_dtype_func(itemp, value)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":976
 *             self.to_dtype_func(itemp, value)
 *         else:
 *             memoryview.assign_item_from_object(self, itemp, value)             # <<<<<<<<<<<<<<
 * 
 *     cdef _get_base(self):
 */
  /*else*/ {
    __pyx_t_3 = __pyx_memoryview_assign_item_from_object(((struct __pyx_memoryview_obj *)__pyx_v_self), __pyx_v_itemp, __pyx_v_value); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 976, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_L3:;

  /* "View.MemoryView":972
 *             return memoryview.convert_item_to_object(self, itemp)
 * 
 *     cdef assign_item_from_object(self, char *itemp, object value):             # <<<<<<<<<<<<<<
 *         if self.to_dtype_func != NULL:
 *             self.to_dtype_func(itemp, value)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView._memoryviewslice.assign_item_from_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":978
 *             memoryview.assign_item_from_object(self, itemp, value)
 * 
 *     cdef _get_base(self):             # <<<<<<<<<<<<<<
 *         return self.from_object
 * 
 */

static PyObject *__pyx_memoryviewslice__get_base(struct __pyx_memoryviewslice_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_get_base", 1);

  /* "View.MemoryView":979
 * 
 *     cdef _get_base(self):
 *         return self.from_object             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_self->from_object);
  __pyx_r = __pyx_v_self->from_object;
  goto __pyx_L0;

  /* "View.MemoryView":978
 *             memoryview.assign_item_from_object(self, itemp, value)
 * 
 *     cdef _get_base(self):             # <<<<<<<<<<<<<<
 *         return self.from_object
 * 
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_memoryviewslice_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_memoryviewslice_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf___pyx_memoryviewslice___reduce_cython__(((struct __pyx_memoryviewslice_obj *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_memoryviewslice___reduce_cython__(CYTHON_UNUSED struct __pyx_memoryviewslice_obj *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView._memoryviewslice.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw___pyx_memoryviewslice_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_pw___pyx_memoryviewslice_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("View.MemoryView._memoryviewslice.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf___pyx_memoryviewslice_2__setstate_cython__(((struct __pyx_memoryviewslice_obj *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf___pyx_memoryviewslice_2__setstate_cython__(CYTHON_UNUSED struct __pyx_memoryviewslice_obj *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView._memoryviewslice.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":999
 * 
 * @cname('__pyx_memoryview_fromslice')
 * cdef memoryview_fromslice(__Pyx_memviewslice memviewslice,             # <<<<<<<<<<<<<<
 *                           int ndim,
 *                           object (*to_object_func)(char *),
 */

static PyObject *__pyx_memoryview_fromslice(__Pyx_memviewslice __pyx_v_memviewslice, int __pyx_v_ndim, PyObject *(*__pyx_v_to_object_func)(char *), int (*__pyx_v_to_dtype_func)(char *, PyObject *), int __pyx_v_dtype_is_object) {
  struct __pyx_memoryviewslice_obj *__pyx_v_result = 0;
  Py_ssize_t __pyx_v_suboffset;
  PyObject *__pyx_v_length = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __Pyx_TypeInfo *__pyx_t_4;
  Py_buffer __pyx_t_5;
  Py_ssize_t *__pyx_t_6;
  Py_ssize_t *__pyx_t_7;
  Py_ssize_t *__pyx_t_8;
  Py_ssize_t __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("memoryview_fromslice", 1);

  /* "View.MemoryView":1007
 *     cdef _memoryviewslice result
 * 
 *     if <PyObject *> memviewslice.memview == Py_None:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  __pyx_t_1 = (((PyObject *)__pyx_v_memviewslice.memview) == Py_None);
  if (__pyx_t_1) {

    /* "View.MemoryView":1008
 * 
 *     if <PyObject *> memviewslice.memview == Py_None:
 *         return None             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "View.MemoryView":1007
 *     cdef _memoryviewslice result
 * 
 *     if <PyObject *> memviewslice.memview == Py_None:             # <<<<<<<<<<<<<<
 *         return None
 * 
 */
  }

  /* "View.MemoryView":1013
 * 
 * 
 *     result = _memoryviewslice.__new__(_memoryviewslice, None, 0, dtype_is_object)             # <<<<<<<<<<<<<<
 * 
 *     result.from_slice = memviewslice
 */
  __pyx_t_2 = __Pyx_PyBool_FromLong(__pyx_v_dtype_is_object); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(3); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, Py_None)) __PYX_ERR(1, 1013, __pyx_L1_error);
  __Pyx_INCREF(__pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_int_0)) __PYX_ERR(1, 1013, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 2, __pyx_t_2)) __PYX_ERR(1, 1013, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = ((PyObject *)__pyx_tp_new__memoryviewslice(((PyTypeObject *)__pyx_memoryviewslice_type), __pyx_t_3, NULL)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1013, __pyx_L1_error)
  __Pyx_GOTREF((PyObject *)__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_result = ((struct __pyx_memoryviewslice_obj *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "View.MemoryView":1015
 *     result = _memoryviewslice.__new__(_memoryviewslice, None, 0, dtype_is_object)
 * 
 *     result.from_slice = memviewslice             # <<<<<<<<<<<<<<
 *     __PYX_INC_MEMVIEW(&memviewslice, 1)
 * 
 */
  __pyx_v_result->from_slice = __pyx_v_memviewslice;

  /* "View.MemoryView":1016
 * 
 *     result.from_slice = memviewslice
 *     __PYX_INC_MEMVIEW(&memviewslice, 1)             # <<<<<<<<<<<<<<
 * 
 *     result.from_object = (<memoryview> memviewslice.memview)._get_base()
 */
  __PYX_INC_MEMVIEW((&__pyx_v_memviewslice), 1);

  /* "View.MemoryView":1018
 *     __PYX_INC_MEMVIEW(&memviewslice, 1)
 * 
 *     result.from_object = (<memoryview> memviewslice.memview)._get_base()             # <<<<<<<<<<<<<<
 *     result.typeinfo = memviewslice.memview.typeinfo
 * 
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_memoryview *)((struct __pyx_memoryview_obj *)__pyx_v_memviewslice.memview)->__pyx_vtab)->_get_base(((struct __pyx_memoryview_obj *)__pyx_v_memviewslice.memview)); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_result->from_object);
  __Pyx_DECREF(__pyx_v_result->from_object);
  __pyx_v_result->from_object = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "View.MemoryView":1019
 * 
 *     result.from_object = (<memoryview> memviewslice.memview)._get_base()
 *     result.typeinfo = memviewslice.memview.typeinfo             # <<<<<<<<<<<<<<
 * 
 *     result.view = memviewslice.memview.view
 */
  __pyx_t_4 = __pyx_v_memviewslice.memview->typeinfo;
  __pyx_v_result->__pyx_base.typeinfo = __pyx_t_4;

  /* "View.MemoryView":1021
 *     result.typeinfo = memviewslice.memview.typeinfo
 * 
 *     result.view = memviewslice.memview.view             # <<<<<<<<<<<<<<
 *     result.view.buf = <void *> memviewslice.data
 *     result.view.ndim = ndim
 */
  __pyx_t_5 = __pyx_v_memviewslice.memview->view;
  __pyx_v_result->__pyx_base.view = __pyx_t_5;

  /* "View.MemoryView":1022
 * 
 *     result.view = memviewslice.memview.view
 *     result.view.buf = <void *> memviewslice.data             # <<<<<<<<<<<<<<
 *     result.view.ndim = ndim
 *     (<__pyx_buffer *> &result.view).obj = Py_None
 */
  __pyx_v_result->__pyx_base.view.buf = ((void *)__pyx_v_memviewslice.data);

  /* "View.MemoryView":1023
 *     result.view = memviewslice.memview.view
 *     result.view.buf = <void *> memviewslice.data
 *     result.view.ndim = ndim             # <<<<<<<<<<<<<<
 *     (<__pyx_buffer *> &result.view).obj = Py_None
 *     Py_INCREF(Py_None)
 */
  __pyx_v_result->__pyx_base.view.ndim = __pyx_v_ndim;

  /* "View.MemoryView":1024
 *     result.view.buf = <void *> memviewslice.data
 *     result.view.ndim = ndim
 *     (<__pyx_buffer *> &result.view).obj = Py_None             # <<<<<<<<<<<<<<
 *     Py_INCREF(Py_None)
 * 
 */
  ((Py_buffer *)(&__pyx_v_result->__pyx_base.view))->obj = Py_None;

  /* "View.MemoryView":1025
 *     result.view.ndim = ndim
 *     (<__pyx_buffer *> &result.view).obj = Py_None
 *     Py_INCREF(Py_None)             # <<<<<<<<<<<<<<
 * 
 *     if (<memoryview>memviewslice.memview).flags & PyBUF_WRITABLE:
 */
  Py_INCREF(Py_None);

  /* "View.MemoryView":1027
 *     Py_INCREF(Py_None)
 * 
 *     if (<memoryview>memviewslice.memview).flags & PyBUF_WRITABLE:             # <<<<<<<<<<<<<<
 *         result.flags = PyBUF_RECORDS
 *     else:
 */
  __pyx_t_1 = ((((struct __pyx_memoryview_obj *)__pyx_v_memviewslice.memview)->flags & PyBUF_WRITABLE) != 0);
  if (__pyx_t_1) {

    /* "View.MemoryView":1028
 * 
 *     if (<memoryview>memviewslice.memview).flags & PyBUF_WRITABLE:
 *         result.flags = PyBUF_RECORDS             # <<<<<<<<<<<<<<
 *     else:
 *         result.flags = PyBUF_RECORDS_RO
 */
    __pyx_v_result->__pyx_base.flags = PyBUF_RECORDS;

    /* "View.MemoryView":1027
 *     Py_INCREF(Py_None)
 * 
 *     if (<memoryview>memviewslice.memview).flags & PyBUF_WRITABLE:             # <<<<<<<<<<<<<<
 *         result.flags = PyBUF_RECORDS
 *     else:
 */
    goto __pyx_L4;
  }

  /* "View.MemoryView":1030
 *         result.flags = PyBUF_RECORDS
 *     else:
 *         result.flags = PyBUF_RECORDS_RO             # <<<<<<<<<<<<<<
 * 
 *     result.view.shape = <Py_ssize_t *> result.from_slice.shape
 */
  /*else*/ {
    __pyx_v_result->__pyx_base.flags = PyBUF_RECORDS_RO;
  }
  __pyx_L4:;

  /* "View.MemoryView":1032
 *         result.flags = PyBUF_RECORDS_RO
 * 
 *     result.view.shape = <Py_ssize_t *> result.from_slice.shape             # <<<<<<<<<<<<<<
 *     result.view.strides = <Py_ssize_t *> result.from_slice.strides
 * 
 */
  __pyx_v_result->__pyx_base.view.shape = ((Py_ssize_t *)__pyx_v_result->from_slice.shape);

  /* "View.MemoryView":1033
 * 
 *     result.view.shape = <Py_ssize_t *> result.from_slice.shape
 *     result.view.strides = <Py_ssize_t *> result.from_slice.strides             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_result->__pyx_base.view.strides = ((Py_ssize_t *)__pyx_v_result->from_slice.strides);

  /* "View.MemoryView":1036
 * 
 * 
 *     result.view.suboffsets = NULL             # <<<<<<<<<<<<<<
 *     for suboffset in result.from_slice.suboffsets[:ndim]:
 *         if suboffset >= 0:
 */
  __pyx_v_result->__pyx_base.view.suboffsets = NULL;

  /* "View.MemoryView":1037
 * 
 *     result.view.suboffsets = NULL
 *     for suboffset in result.from_slice.suboffsets[:ndim]:             # <<<<<<<<<<<<<<
 *         if suboffset >= 0:
 *             result.view.suboffsets = <Py_ssize_t *> result.from_slice.suboffsets
 */
  __pyx_t_7 = (__pyx_v_result->from_slice.suboffsets + __pyx_v_ndim);
  for (__pyx_t_8 = __pyx_v_result->from_slice.suboffsets; __pyx_t_8 < __pyx_t_7; __pyx_t_8++) {
    __pyx_t_6 = __pyx_t_8;
    __pyx_v_suboffset = (__pyx_t_6[0]);

    /* "View.MemoryView":1038
 *     result.view.suboffsets = NULL
 *     for suboffset in result.from_slice.suboffsets[:ndim]:
 *         if suboffset >= 0:             # <<<<<<<<<<<<<<
 *             result.view.suboffsets = <Py_ssize_t *> result.from_slice.suboffsets
 *             break
 */
    __pyx_t_1 = (__pyx_v_suboffset >= 0);
    if (__pyx_t_1) {

      /* "View.MemoryView":1039
 *     for suboffset in result.from_slice.suboffsets[:ndim]:
 *         if suboffset >= 0:
 *             result.view.suboffsets = <Py_ssize_t *> result.from_slice.suboffsets             # <<<<<<<<<<<<<<
 *             break
 * 
 */
      __pyx_v_result->__pyx_base.view.suboffsets = ((Py_ssize_t *)__pyx_v_result->from_slice.suboffsets);

      /* "View.MemoryView":1040
 *         if suboffset >= 0:
 *             result.view.suboffsets = <Py_ssize_t *> result.from_slice.suboffsets
 *             break             # <<<<<<<<<<<<<<
 * 
 *     result.view.len = result.view.itemsize
 */
      goto __pyx_L6_break;

      /* "View.MemoryView":1038
 *     result.view.suboffsets = NULL
 *     for suboffset in result.from_slice.suboffsets[:ndim]:
 *         if suboffset >= 0:             # <<<<<<<<<<<<<<
 *             result.view.suboffsets = <Py_ssize_t *> result.from_slice.suboffsets
 *             break
 */
    }
  }
  __pyx_L6_break:;

  /* "View.MemoryView":1042
 *             break
 * 
 *     result.view.len = result.view.itemsize             # <<<<<<<<<<<<<<
 *     for length in result.view.shape[:ndim]:
 *         result.view.len *= length
 */
  __pyx_t_9 = __pyx_v_result->__pyx_base.view.itemsize;
  __pyx_v_result->__pyx_base.view.len = __pyx_t_9;

  /* "View.MemoryView":1043
 * 
 *     result.view.len = result.view.itemsize
 *     for length in result.view.shape[:ndim]:             # <<<<<<<<<<<<<<
 *         result.view.len *= length
 * 
 */
  __pyx_t_7 = (__pyx_v_result->__pyx_base.view.shape + __pyx_v_ndim);
  for (__pyx_t_8 = __pyx_v_result->__pyx_base.view.shape; __pyx_t_8 < __pyx_t_7; __pyx_t_8++) {
    __pyx_t_6 = __pyx_t_8;
    __pyx_t_2 = PyInt_FromSsize_t((__pyx_t_6[0])); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1043, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_XDECREF_SET(__pyx_v_length, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "View.MemoryView":1044
 *     result.view.len = result.view.itemsize
 *     for length in result.view.shape[:ndim]:
 *         result.view.len *= length             # <<<<<<<<<<<<<<
 * 
 *     result.to_object_func = to_object_func
 */
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_result->__pyx_base.view.len); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1044, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyNumber_InPlaceMultiply(__pyx_t_2, __pyx_v_length); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 1044, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_9 = __Pyx_PyIndex_AsSsize_t(__pyx_t_3); if (unlikely((__pyx_t_9 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(1, 1044, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_result->__pyx_base.view.len = __pyx_t_9;
  }

  /* "View.MemoryView":1046
 *         result.view.len *= length
 * 
 *     result.to_object_func = to_object_func             # <<<<<<<<<<<<<<
 *     result.to_dtype_func = to_dtype_func
 * 
 */
  __pyx_v_result->to_object_func = __pyx_v_to_object_func;

  /* "View.MemoryView":1047
 * 
 *     result.to_object_func = to_object_func
 *     result.to_dtype_func = to_dtype_func             # <<<<<<<<<<<<<<
 * 
 *     return result
 */
  __pyx_v_result->to_dtype_func = __pyx_v_to_dtype_func;

  /* "View.MemoryView":1049
 *     result.to_dtype_func = to_dtype_func
 * 
 *     return result             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_get_slice_from_memoryview')
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_result);
  __pyx_r = ((PyObject *)__pyx_v_result);
  goto __pyx_L0;

  /* "View.MemoryView":999
 * 
 * @cname('__pyx_memoryview_fromslice')
 * cdef memoryview_fromslice(__Pyx_memviewslice memviewslice,             # <<<<<<<<<<<<<<
 *                           int ndim,
 *                           object (*to_object_func)(char *),
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("View.MemoryView.memoryview_fromslice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_length);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":1052
 * 
 * @cname('__pyx_memoryview_get_slice_from_memoryview')
 * cdef __Pyx_memviewslice *get_slice_from_memview(memoryview memview,             # <<<<<<<<<<<<<<
 *                                                    __Pyx_memviewslice *mslice) except NULL:
 *     cdef _memoryviewslice obj
 */

static __Pyx_memviewslice *__pyx_memoryview_get_slice_from_memoryview(struct __pyx_memoryview_obj *__pyx_v_memview, __Pyx_memviewslice *__pyx_v_mslice) {
  struct __pyx_memoryviewslice_obj *__pyx_v_obj = 0;
  __Pyx_memviewslice *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_slice_from_memview", 1);

  /* "View.MemoryView":1055
 *                                                    __Pyx_memviewslice *mslice) except NULL:
 *     cdef _memoryviewslice obj
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         obj = memview
 *         return &obj.from_slice
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type); 
  if (__pyx_t_1) {

    /* "View.MemoryView":1056
 *     cdef _memoryviewslice obj
 *     if isinstance(memview, _memoryviewslice):
 *         obj = memview             # <<<<<<<<<<<<<<
 *         return &obj.from_slice
 *     else:
 */
    if (!(likely(((((PyObject *)__pyx_v_memview)) == Py_None) || likely(__Pyx_TypeTest(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type))))) __PYX_ERR(1, 1056, __pyx_L1_error)
    __pyx_t_2 = ((PyObject *)__pyx_v_memview);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_obj = ((struct __pyx_memoryviewslice_obj *)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "View.MemoryView":1057
 *     if isinstance(memview, _memoryviewslice):
 *         obj = memview
 *         return &obj.from_slice             # <<<<<<<<<<<<<<
 *     else:
 *         slice_copy(memview, mslice)
 */
    __pyx_r = (&__pyx_v_obj->from_slice);
    goto __pyx_L0;

    /* "View.MemoryView":1055
 *                                                    __Pyx_memviewslice *mslice) except NULL:
 *     cdef _memoryviewslice obj
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         obj = memview
 *         return &obj.from_slice
 */
  }

  /* "View.MemoryView":1059
 *         return &obj.from_slice
 *     else:
 *         slice_copy(memview, mslice)             # <<<<<<<<<<<<<<
 *         return mslice
 * 
 */
  /*else*/ {
    __pyx_memoryview_slice_copy(__pyx_v_memview, __pyx_v_mslice);

    /* "View.MemoryView":1060
 *     else:
 *         slice_copy(memview, mslice)
 *         return mslice             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_slice_copy')
 */
    __pyx_r = __pyx_v_mslice;
    goto __pyx_L0;
  }

  /* "View.MemoryView":1052
 * 
 * @cname('__pyx_memoryview_get_slice_from_memoryview')
 * cdef __Pyx_memviewslice *get_slice_from_memview(memoryview memview,             # <<<<<<<<<<<<<<
 *                                                    __Pyx_memviewslice *mslice) except NULL:
 *     cdef _memoryviewslice obj
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView.get_slice_from_memview", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_obj);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":1063
 * 
 * @cname('__pyx_memoryview_slice_copy')
 * cdef void slice_copy(memoryview memview, __Pyx_memviewslice *dst) noexcept:             # <<<<<<<<<<<<<<
 *     cdef int dim
 *     cdef (Py_ssize_t*) shape, strides, suboffsets
 */

static void __pyx_memoryview_slice_copy(struct __pyx_memoryview_obj *__pyx_v_memview, __Pyx_memviewslice *__pyx_v_dst) {
  int __pyx_v_dim;
  Py_ssize_t *__pyx_v_shape;
  Py_ssize_t *__pyx_v_strides;
  Py_ssize_t *__pyx_v_suboffsets;
  Py_ssize_t *__pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;

  /* "View.MemoryView":1067
 *     cdef (Py_ssize_t*) shape, strides, suboffsets
 * 
 *     shape = memview.view.shape             # <<<<<<<<<<<<<<
 *     strides = memview.view.strides
 *     suboffsets = memview.view.suboffsets
 */
  __pyx_t_1 = __pyx_v_memview->view.shape;
  __pyx_v_shape = __pyx_t_1;

  /* "View.MemoryView":1068
 * 
 *     shape = memview.view.shape
 *     strides = memview.view.strides             # <<<<<<<<<<<<<<
 *     suboffsets = memview.view.suboffsets
 * 
 */
  __pyx_t_1 = __pyx_v_memview->view.strides;
  __pyx_v_strides = __pyx_t_1;

  /* "View.MemoryView":1069
 *     shape = memview.view.shape
 *     strides = memview.view.strides
 *     suboffsets = memview.view.suboffsets             # <<<<<<<<<<<<<<
 * 
 *     dst.memview = <__pyx_memoryview *> memview
 */
  __pyx_t_1 = __pyx_v_memview->view.suboffsets;
  __pyx_v_suboffsets = __pyx_t_1;

  /* "View.MemoryView":1071
 *     suboffsets = memview.view.suboffsets
 * 
 *     dst.memview = <__pyx_memoryview *> memview             # <<<<<<<<<<<<<<
 *     dst.data = <char *> memview.view.buf
 * 
 */
  __pyx_v_dst->memview = ((struct __pyx_memoryview_obj *)__pyx_v_memview);

  /* "View.MemoryView":1072
 * 
 *     dst.memview = <__pyx_memoryview *> memview
 *     dst.data = <char *> memview.view.buf             # <<<<<<<<<<<<<<
 * 
 *     for dim in range(memview.view.ndim):
 */
  __pyx_v_dst->data = ((char *)__pyx_v_memview->view.buf);

  /* "View.MemoryView":1074
 *     dst.data = <char *> memview.view.buf
 * 
 *     for dim in range(memview.view.ndim):             # <<<<<<<<<<<<<<
 *         dst.shape[dim] = shape[dim]
 *         dst.strides[dim] = strides[dim]
 */
  __pyx_t_2 = __pyx_v_memview->view.ndim;
  __pyx_t_3 = __pyx_t_2;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_dim = __pyx_t_4;

    /* "View.MemoryView":1075
 * 
 *     for dim in range(memview.view.ndim):
 *         dst.shape[dim] = shape[dim]             # <<<<<<<<<<<<<<
 *         dst.strides[dim] = strides[dim]
 *         dst.suboffsets[dim] = suboffsets[dim] if suboffsets else -1
 */
    (__pyx_v_dst->shape[__pyx_v_dim]) = (__pyx_v_shape[__pyx_v_dim]);

    /* "View.MemoryView":1076
 *     for dim in range(memview.view.ndim):
 *         dst.shape[dim] = shape[dim]
 *         dst.strides[dim] = strides[dim]             # <<<<<<<<<<<<<<
 *         dst.suboffsets[dim] = suboffsets[dim] if suboffsets else -1
 * 
 */
    (__pyx_v_dst->strides[__pyx_v_dim]) = (__pyx_v_strides[__pyx_v_dim]);

    /* "View.MemoryView":1077
 *         dst.shape[dim] = shape[dim]
 *         dst.strides[dim] = strides[dim]
 *         dst.suboffsets[dim] = suboffsets[dim] if suboffsets else -1             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_copy_object')
 */
    __pyx_t_6 = (__pyx_v_suboffsets != 0);
    if (__pyx_t_6) {
      __pyx_t_5 = (__pyx_v_suboffsets[__pyx_v_dim]);
    } else {
      __pyx_t_5 = -1L;
    }
    (__pyx_v_dst->suboffsets[__pyx_v_dim]) = __pyx_t_5;
  }

  /* "View.MemoryView":1063
 * 
 * @cname('__pyx_memoryview_slice_copy')
 * cdef void slice_copy(memoryview memview, __Pyx_memviewslice *dst) noexcept:             # <<<<<<<<<<<<<<
 *     cdef int dim
 *     cdef (Py_ssize_t*) shape, strides, suboffsets
 */

  /* function exit code */
}

/* "View.MemoryView":1080
 * 
 * @cname('__pyx_memoryview_copy_object')
 * cdef memoryview_copy(memoryview memview):             # <<<<<<<<<<<<<<
 *     "Create a new memoryview object"
 *     cdef __Pyx_memviewslice memviewslice
 */

static PyObject *__pyx_memoryview_copy_object(struct __pyx_memoryview_obj *__pyx_v_memview) {
  __Pyx_memviewslice __pyx_v_memviewslice;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("memoryview_copy", 1);

  /* "View.MemoryView":1083
 *     "Create a new memoryview object"
 *     cdef __Pyx_memviewslice memviewslice
 *     slice_copy(memview, &memviewslice)             # <<<<<<<<<<<<<<
 *     return memoryview_copy_from_slice(memview, &memviewslice)
 * 
 */
  __pyx_memoryview_slice_copy(__pyx_v_memview, (&__pyx_v_memviewslice));

  /* "View.MemoryView":1084
 *     cdef __Pyx_memviewslice memviewslice
 *     slice_copy(memview, &memviewslice)
 *     return memoryview_copy_from_slice(memview, &memviewslice)             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_copy_object_from_slice')
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_memoryview_copy_object_from_slice(__pyx_v_memview, (&__pyx_v_memviewslice)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1084, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":1080
 * 
 * @cname('__pyx_memoryview_copy_object')
 * cdef memoryview_copy(memoryview memview):             # <<<<<<<<<<<<<<
 *     "Create a new memoryview object"
 *     cdef __Pyx_memviewslice memviewslice
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("View.MemoryView.memoryview_copy", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":1087
 * 
 * @cname('__pyx_memoryview_copy_object_from_slice')
 * cdef memoryview_copy_from_slice(memoryview memview, __Pyx_memviewslice *memviewslice):             # <<<<<<<<<<<<<<
 *     """
 *     Create a new memoryview object from a given memoryview object and slice.
 */

static PyObject *__pyx_memoryview_copy_object_from_slice(struct __pyx_memoryview_obj *__pyx_v_memview, __Pyx_memviewslice *__pyx_v_memviewslice) {
  PyObject *(*__pyx_v_to_object_func)(char *);
  int (*__pyx_v_to_dtype_func)(char *, PyObject *);
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *(*__pyx_t_2)(char *);
  int (*__pyx_t_3)(char *, PyObject *);
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("memoryview_copy_from_slice", 1);

  /* "View.MemoryView":1094
 *     cdef int (*to_dtype_func)(char *, object) except 0
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         to_object_func = (<_memoryviewslice> memview).to_object_func
 *         to_dtype_func = (<_memoryviewslice> memview).to_dtype_func
 */
  __pyx_t_1 = __Pyx_TypeCheck(((PyObject *)__pyx_v_memview), __pyx_memoryviewslice_type); 
  if (__pyx_t_1) {

    /* "View.MemoryView":1095
 * 
 *     if isinstance(memview, _memoryviewslice):
 *         to_object_func = (<_memoryviewslice> memview).to_object_func             # <<<<<<<<<<<<<<
 *         to_dtype_func = (<_memoryviewslice> memview).to_dtype_func
 *     else:
 */
    __pyx_t_2 = ((struct __pyx_memoryviewslice_obj *)__pyx_v_memview)->to_object_func;
    __pyx_v_to_object_func = __pyx_t_2;

    /* "View.MemoryView":1096
 *     if isinstance(memview, _memoryviewslice):
 *         to_object_func = (<_memoryviewslice> memview).to_object_func
 *         to_dtype_func = (<_memoryviewslice> memview).to_dtype_func             # <<<<<<<<<<<<<<
 *     else:
 *         to_object_func = NULL
 */
    __pyx_t_3 = ((struct __pyx_memoryviewslice_obj *)__pyx_v_memview)->to_dtype_func;
    __pyx_v_to_dtype_func = __pyx_t_3;

    /* "View.MemoryView":1094
 *     cdef int (*to_dtype_func)(char *, object) except 0
 * 
 *     if isinstance(memview, _memoryviewslice):             # <<<<<<<<<<<<<<
 *         to_object_func = (<_memoryviewslice> memview).to_object_func
 *         to_dtype_func = (<_memoryviewslice> memview).to_dtype_func
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":1098
 *         to_dtype_func = (<_memoryviewslice> memview).to_dtype_func
 *     else:
 *         to_object_func = NULL             # <<<<<<<<<<<<<<
 *         to_dtype_func = NULL
 * 
 */
  /*else*/ {
    __pyx_v_to_object_func = NULL;

    /* "View.MemoryView":1099
 *     else:
 *         to_object_func = NULL
 *         to_dtype_func = NULL             # <<<<<<<<<<<<<<
 * 
 *     return memoryview_fromslice(memviewslice[0], memview.view.ndim,
 */
    __pyx_v_to_dtype_func = NULL;
  }
  __pyx_L3:;

  /* "View.MemoryView":1101
 *         to_dtype_func = NULL
 * 
 *     return memoryview_fromslice(memviewslice[0], memview.view.ndim,             # <<<<<<<<<<<<<<
 *                                 to_object_func, to_dtype_func,
 *                                 memview.dtype_is_object)
 */
  __Pyx_XDECREF(__pyx_r);

  /* "View.MemoryView":1103
 *     return memoryview_fromslice(memviewslice[0], memview.view.ndim,
 *                                 to_object_func, to_dtype_func,
 *                                 memview.dtype_is_object)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_4 = __pyx_memoryview_fromslice((__pyx_v_memviewslice[0]), __pyx_v_memview->view.ndim, __pyx_v_to_object_func, __pyx_v_to_dtype_func, __pyx_v_memview->dtype_is_object); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "View.MemoryView":1087
 * 
 * @cname('__pyx_memoryview_copy_object_from_slice')
 * cdef memoryview_copy_from_slice(memoryview memview, __Pyx_memviewslice *memviewslice):             # <<<<<<<<<<<<<<
 *     """
 *     Create a new memoryview object from a given memoryview object and slice.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("View.MemoryView.memoryview_copy_from_slice", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "View.MemoryView":1109
 * 
 * 
 * cdef Py_ssize_t abs_py_ssize_t(Py_ssize_t arg) noexcept nogil:             # <<<<<<<<<<<<<<
 *     return -arg if arg < 0 else arg
 * 
 */

static Py_ssize_t abs_py_ssize_t(Py_ssize_t __pyx_v_arg) {
  Py_ssize_t __pyx_r;
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;

  /* "View.MemoryView":1110
 * 
 * cdef Py_ssize_t abs_py_ssize_t(Py_ssize_t arg) noexcept nogil:
 *     return -arg if arg < 0 else arg             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_get_best_slice_order')
 */
  __pyx_t_2 = (__pyx_v_arg < 0);
  if (__pyx_t_2) {
    __pyx_t_1 = (-__pyx_v_arg);
  } else {
    __pyx_t_1 = __pyx_v_arg;
  }
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "View.MemoryView":1109
 * 
 * 
 * cdef Py_ssize_t abs_py_ssize_t(Py_ssize_t arg) noexcept nogil:             # <<<<<<<<<<<<<<
 *     return -arg if arg < 0 else arg
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1113
 * 
 * @cname('__pyx_get_best_slice_order')
 * cdef char get_best_order(__Pyx_memviewslice *mslice, int ndim) noexcept nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Figure out the best memory access order for a given slice.
 */

static char __pyx_get_best_slice_order(__Pyx_memviewslice *__pyx_v_mslice, int __pyx_v_ndim) {
  int __pyx_v_i;
  Py_ssize_t __pyx_v_c_stride;
  Py_ssize_t __pyx_v_f_stride;
  char __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;

  /* "View.MemoryView":1118
 *     """
 *     cdef int i
 *     cdef Py_ssize_t c_stride = 0             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t f_stride = 0
 * 
 */
  __pyx_v_c_stride = 0;

  /* "View.MemoryView":1119
 *     cdef int i
 *     cdef Py_ssize_t c_stride = 0
 *     cdef Py_ssize_t f_stride = 0             # <<<<<<<<<<<<<<
 * 
 *     for i in range(ndim - 1, -1, -1):
 */
  __pyx_v_f_stride = 0;

  /* "View.MemoryView":1121
 *     cdef Py_ssize_t f_stride = 0
 * 
 *     for i in range(ndim - 1, -1, -1):             # <<<<<<<<<<<<<<
 *         if mslice.shape[i] > 1:
 *             c_stride = mslice.strides[i]
 */
  for (__pyx_t_1 = (__pyx_v_ndim - 1); __pyx_t_1 > -1; __pyx_t_1-=1) {
    __pyx_v_i = __pyx_t_1;

    /* "View.MemoryView":1122
 * 
 *     for i in range(ndim - 1, -1, -1):
 *         if mslice.shape[i] > 1:             # <<<<<<<<<<<<<<
 *             c_stride = mslice.strides[i]
 *             break
 */
    __pyx_t_2 = ((__pyx_v_mslice->shape[__pyx_v_i]) > 1);
    if (__pyx_t_2) {

      /* "View.MemoryView":1123
 *     for i in range(ndim - 1, -1, -1):
 *         if mslice.shape[i] > 1:
 *             c_stride = mslice.strides[i]             # <<<<<<<<<<<<<<
 *             break
 * 
 */
      __pyx_v_c_stride = (__pyx_v_mslice->strides[__pyx_v_i]);

      /* "View.MemoryView":1124
 *         if mslice.shape[i] > 1:
 *             c_stride = mslice.strides[i]
 *             break             # <<<<<<<<<<<<<<
 * 
 *     for i in range(ndim):
 */
      goto __pyx_L4_break;

      /* "View.MemoryView":1122
 * 
 *     for i in range(ndim - 1, -1, -1):
 *         if mslice.shape[i] > 1:             # <<<<<<<<<<<<<<
 *             c_stride = mslice.strides[i]
 *             break
 */
    }
  }
  __pyx_L4_break:;

  /* "View.MemoryView":1126
 *             break
 * 
 *     for i in range(ndim):             # <<<<<<<<<<<<<<
 *         if mslice.shape[i] > 1:
 *             f_stride = mslice.strides[i]
 */
  __pyx_t_1 = __pyx_v_ndim;
  __pyx_t_3 = __pyx_t_1;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "View.MemoryView":1127
 * 
 *     for i in range(ndim):
 *         if mslice.shape[i] > 1:             # <<<<<<<<<<<<<<
 *             f_stride = mslice.strides[i]
 *             break
 */
    __pyx_t_2 = ((__pyx_v_mslice->shape[__pyx_v_i]) > 1);
    if (__pyx_t_2) {

      /* "View.MemoryView":1128
 *     for i in range(ndim):
 *         if mslice.shape[i] > 1:
 *             f_stride = mslice.strides[i]             # <<<<<<<<<<<<<<
 *             break
 * 
 */
      __pyx_v_f_stride = (__pyx_v_mslice->strides[__pyx_v_i]);

      /* "View.MemoryView":1129
 *         if mslice.shape[i] > 1:
 *             f_stride = mslice.strides[i]
 *             break             # <<<<<<<<<<<<<<
 * 
 *     if abs_py_ssize_t(c_stride) <= abs_py_ssize_t(f_stride):
 */
      goto __pyx_L7_break;

      /* "View.MemoryView":1127
 * 
 *     for i in range(ndim):
 *         if mslice.shape[i] > 1:             # <<<<<<<<<<<<<<
 *             f_stride = mslice.strides[i]
 *             break
 */
    }
  }
  __pyx_L7_break:;

  /* "View.MemoryView":1131
 *             break
 * 
 *     if abs_py_ssize_t(c_stride) <= abs_py_ssize_t(f_stride):             # <<<<<<<<<<<<<<
 *         return 'C'
 *     else:
 */
  __pyx_t_2 = (abs_py_ssize_t(__pyx_v_c_stride) <= abs_py_ssize_t(__pyx_v_f_stride));
  if (__pyx_t_2) {

    /* "View.MemoryView":1132
 * 
 *     if abs_py_ssize_t(c_stride) <= abs_py_ssize_t(f_stride):
 *         return 'C'             # <<<<<<<<<<<<<<
 *     else:
 *         return 'F'
 */
    __pyx_r = 'C';
    goto __pyx_L0;

    /* "View.MemoryView":1131
 *             break
 * 
 *     if abs_py_ssize_t(c_stride) <= abs_py_ssize_t(f_stride):             # <<<<<<<<<<<<<<
 *         return 'C'
 *     else:
 */
  }

  /* "View.MemoryView":1134
 *         return 'C'
 *     else:
 *         return 'F'             # <<<<<<<<<<<<<<
 * 
 * @cython.cdivision(True)
 */
  /*else*/ {
    __pyx_r = 'F';
    goto __pyx_L0;
  }

  /* "View.MemoryView":1113
 * 
 * @cname('__pyx_get_best_slice_order')
 * cdef char get_best_order(__Pyx_memviewslice *mslice, int ndim) noexcept nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Figure out the best memory access order for a given slice.
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1137
 * 
 * @cython.cdivision(True)
 * cdef void _copy_strided_to_strided(char *src_data, Py_ssize_t *src_strides,             # <<<<<<<<<<<<<<
 *                                    char *dst_data, Py_ssize_t *dst_strides,
 *                                    Py_ssize_t *src_shape, Py_ssize_t *dst_shape,
 */

static void _copy_strided_to_strided(char *__pyx_v_src_data, Py_ssize_t *__pyx_v_src_strides, char *__pyx_v_dst_data, Py_ssize_t *__pyx_v_dst_strides, Py_ssize_t *__pyx_v_src_shape, Py_ssize_t *__pyx_v_dst_shape, int __pyx_v_ndim, size_t __pyx_v_itemsize) {
  CYTHON_UNUSED Py_ssize_t __pyx_v_i;
  CYTHON_UNUSED Py_ssize_t __pyx_v_src_extent;
  Py_ssize_t __pyx_v_dst_extent;
  Py_ssize_t __pyx_v_src_stride;
  Py_ssize_t __pyx_v_dst_stride;
  int __pyx_t_1;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;

  /* "View.MemoryView":1144
 * 
 *     cdef Py_ssize_t i
 *     cdef Py_ssize_t src_extent = src_shape[0]             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t dst_extent = dst_shape[0]
 *     cdef Py_ssize_t src_stride = src_strides[0]
 */
  __pyx_v_src_extent = (__pyx_v_src_shape[0]);

  /* "View.MemoryView":1145
 *     cdef Py_ssize_t i
 *     cdef Py_ssize_t src_extent = src_shape[0]
 *     cdef Py_ssize_t dst_extent = dst_shape[0]             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t src_stride = src_strides[0]
 *     cdef Py_ssize_t dst_stride = dst_strides[0]
 */
  __pyx_v_dst_extent = (__pyx_v_dst_shape[0]);

  /* "View.MemoryView":1146
 *     cdef Py_ssize_t src_extent = src_shape[0]
 *     cdef Py_ssize_t dst_extent = dst_shape[0]
 *     cdef Py_ssize_t src_stride = src_strides[0]             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t dst_stride = dst_strides[0]
 * 
 */
  __pyx_v_src_stride = (__pyx_v_src_strides[0]);

  /* "View.MemoryView":1147
 *     cdef Py_ssize_t dst_extent = dst_shape[0]
 *     cdef Py_ssize_t src_stride = src_strides[0]
 *     cdef Py_ssize_t dst_stride = dst_strides[0]             # <<<<<<<<<<<<<<
 * 
 *     if ndim == 1:
 */
  __pyx_v_dst_stride = (__pyx_v_dst_strides[0]);

  /* "View.MemoryView":1149
 *     cdef Py_ssize_t dst_stride = dst_strides[0]
 * 
 *     if ndim == 1:             # <<<<<<<<<<<<<<
 *         if (src_stride > 0 and dst_stride > 0 and
 *             <size_t> src_stride == itemsize == <size_t> dst_stride):
 */
  __pyx_t_1 = (__pyx_v_ndim == 1);
  if (__pyx_t_1) {

    /* "View.MemoryView":1150
 * 
 *     if ndim == 1:
 *         if (src_stride > 0 and dst_stride > 0 and             # <<<<<<<<<<<<<<
 *             <size_t> src_stride == itemsize == <size_t> dst_stride):
 *             memcpy(dst_data, src_data, itemsize * dst_extent)
 */
    __pyx_t_2 = (__pyx_v_src_stride > 0);
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L5_bool_binop_done;
    }
    __pyx_t_2 = (__pyx_v_dst_stride > 0);
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L5_bool_binop_done;
    }

    /* "View.MemoryView":1151
 *     if ndim == 1:
 *         if (src_stride > 0 and dst_stride > 0 and
 *             <size_t> src_stride == itemsize == <size_t> dst_stride):             # <<<<<<<<<<<<<<
 *             memcpy(dst_data, src_data, itemsize * dst_extent)
 *         else:
 */
    __pyx_t_2 = (((size_t)__pyx_v_src_stride) == __pyx_v_itemsize);
    if (__pyx_t_2) {
      __pyx_t_2 = (__pyx_v_itemsize == ((size_t)__pyx_v_dst_stride));
    }
    __pyx_t_1 = __pyx_t_2;
    __pyx_L5_bool_binop_done:;

    /* "View.MemoryView":1150
 * 
 *     if ndim == 1:
 *         if (src_stride > 0 and dst_stride > 0 and             # <<<<<<<<<<<<<<
 *             <size_t> src_stride == itemsize == <size_t> dst_stride):
 *             memcpy(dst_data, src_data, itemsize * dst_extent)
 */
    if (__pyx_t_1) {

      /* "View.MemoryView":1152
 *         if (src_stride > 0 and dst_stride > 0 and
 *             <size_t> src_stride == itemsize == <size_t> dst_stride):
 *             memcpy(dst_data, src_data, itemsize * dst_extent)             # <<<<<<<<<<<<<<
 *         else:
 *             for i in range(dst_extent):
 */
      (void)(memcpy(__pyx_v_dst_data, __pyx_v_src_data, (__pyx_v_itemsize * __pyx_v_dst_extent)));

      /* "View.MemoryView":1150
 * 
 *     if ndim == 1:
 *         if (src_stride > 0 and dst_stride > 0 and             # <<<<<<<<<<<<<<
 *             <size_t> src_stride == itemsize == <size_t> dst_stride):
 *             memcpy(dst_data, src_data, itemsize * dst_extent)
 */
      goto __pyx_L4;
    }

    /* "View.MemoryView":1154
 *             memcpy(dst_data, src_data, itemsize * dst_extent)
 *         else:
 *             for i in range(dst_extent):             # <<<<<<<<<<<<<<
 *                 memcpy(dst_data, src_data, itemsize)
 *                 src_data += src_stride
 */
    /*else*/ {
      __pyx_t_3 = __pyx_v_dst_extent;
      __pyx_t_4 = __pyx_t_3;
      for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
        __pyx_v_i = __pyx_t_5;

        /* "View.MemoryView":1155
 *         else:
 *             for i in range(dst_extent):
 *                 memcpy(dst_data, src_data, itemsize)             # <<<<<<<<<<<<<<
 *                 src_data += src_stride
 *                 dst_data += dst_stride
 */
        (void)(memcpy(__pyx_v_dst_data, __pyx_v_src_data, __pyx_v_itemsize));

        /* "View.MemoryView":1156
 *             for i in range(dst_extent):
 *                 memcpy(dst_data, src_data, itemsize)
 *                 src_data += src_stride             # <<<<<<<<<<<<<<
 *                 dst_data += dst_stride
 *     else:
 */
        __pyx_v_src_data = (__pyx_v_src_data + __pyx_v_src_stride);

        /* "View.MemoryView":1157
 *                 memcpy(dst_data, src_data, itemsize)
 *                 src_data += src_stride
 *                 dst_data += dst_stride             # <<<<<<<<<<<<<<
 *     else:
 *         for i in range(dst_extent):
 */
        __pyx_v_dst_data = (__pyx_v_dst_data + __pyx_v_dst_stride);
      }
    }
    __pyx_L4:;

    /* "View.MemoryView":1149
 *     cdef Py_ssize_t dst_stride = dst_strides[0]
 * 
 *     if ndim == 1:             # <<<<<<<<<<<<<<
 *         if (src_stride > 0 and dst_stride > 0 and
 *             <size_t> src_stride == itemsize == <size_t> dst_stride):
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":1159
 *                 dst_data += dst_stride
 *     else:
 *         for i in range(dst_extent):             # <<<<<<<<<<<<<<
 *             _copy_strided_to_strided(src_data, src_strides + 1,
 *                                      dst_data, dst_strides + 1,
 */
  /*else*/ {
    __pyx_t_3 = __pyx_v_dst_extent;
    __pyx_t_4 = __pyx_t_3;
    for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
      __pyx_v_i = __pyx_t_5;

      /* "View.MemoryView":1160
 *     else:
 *         for i in range(dst_extent):
 *             _copy_strided_to_strided(src_data, src_strides + 1,             # <<<<<<<<<<<<<<
 *                                      dst_data, dst_strides + 1,
 *                                      src_shape + 1, dst_shape + 1,
 */
      _copy_strided_to_strided(__pyx_v_src_data, (__pyx_v_src_strides + 1), __pyx_v_dst_data, (__pyx_v_dst_strides + 1), (__pyx_v_src_shape + 1), (__pyx_v_dst_shape + 1), (__pyx_v_ndim - 1), __pyx_v_itemsize);

      /* "View.MemoryView":1164
 *                                      src_shape + 1, dst_shape + 1,
 *                                      ndim - 1, itemsize)
 *             src_data += src_stride             # <<<<<<<<<<<<<<
 *             dst_data += dst_stride
 * 
 */
      __pyx_v_src_data = (__pyx_v_src_data + __pyx_v_src_stride);

      /* "View.MemoryView":1165
 *                                      ndim - 1, itemsize)
 *             src_data += src_stride
 *             dst_data += dst_stride             # <<<<<<<<<<<<<<
 * 
 * cdef void copy_strided_to_strided(__Pyx_memviewslice *src,
 */
      __pyx_v_dst_data = (__pyx_v_dst_data + __pyx_v_dst_stride);
    }
  }
  __pyx_L3:;

  /* "View.MemoryView":1137
 * 
 * @cython.cdivision(True)
 * cdef void _copy_strided_to_strided(char *src_data, Py_ssize_t *src_strides,             # <<<<<<<<<<<<<<
 *                                    char *dst_data, Py_ssize_t *dst_strides,
 *                                    Py_ssize_t *src_shape, Py_ssize_t *dst_shape,
 */

  /* function exit code */
}

/* "View.MemoryView":1167
 *             dst_data += dst_stride
 * 
 * cdef void copy_strided_to_strided(__Pyx_memviewslice *src,             # <<<<<<<<<<<<<<
 *                                   __Pyx_memviewslice *dst,
 *                                   int ndim, size_t itemsize) noexcept nogil:
 */

static void copy_strided_to_strided(__Pyx_memviewslice *__pyx_v_src, __Pyx_memviewslice *__pyx_v_dst, int __pyx_v_ndim, size_t __pyx_v_itemsize) {

  /* "View.MemoryView":1170
 *                                   __Pyx_memviewslice *dst,
 *                                   int ndim, size_t itemsize) noexcept nogil:
 *     _copy_strided_to_strided(src.data, src.strides, dst.data, dst.strides,             # <<<<<<<<<<<<<<
 *                              src.shape, dst.shape, ndim, itemsize)
 * 
 */
  _copy_strided_to_strided(__pyx_v_src->data, __pyx_v_src->strides, __pyx_v_dst->data, __pyx_v_dst->strides, __pyx_v_src->shape, __pyx_v_dst->shape, __pyx_v_ndim, __pyx_v_itemsize);

  /* "View.MemoryView":1167
 *             dst_data += dst_stride
 * 
 * cdef void copy_strided_to_strided(__Pyx_memviewslice *src,             # <<<<<<<<<<<<<<
 *                                   __Pyx_memviewslice *dst,
 *                                   int ndim, size_t itemsize) noexcept nogil:
 */

  /* function exit code */
}

/* "View.MemoryView":1174
 * 
 * @cname('__pyx_memoryview_slice_get_size')
 * cdef Py_ssize_t slice_get_size(__Pyx_memviewslice *src, int ndim) noexcept nogil:             # <<<<<<<<<<<<<<
 *     "Return the size of the memory occupied by the slice in number of bytes"
 *     cdef Py_ssize_t shape, size = src.memview.view.itemsize
 */

static Py_ssize_t __pyx_memoryview_slice_get_size(__Pyx_memviewslice *__pyx_v_src, int __pyx_v_ndim) {
  Py_ssize_t __pyx_v_shape;
  Py_ssize_t __pyx_v_size;
  Py_ssize_t __pyx_r;
  Py_ssize_t __pyx_t_1;
  Py_ssize_t *__pyx_t_2;
  Py_ssize_t *__pyx_t_3;
  Py_ssize_t *__pyx_t_4;

  /* "View.MemoryView":1176
 * cdef Py_ssize_t slice_get_size(__Pyx_memviewslice *src, int ndim) noexcept nogil:
 *     "Return the size of the memory occupied by the slice in number of bytes"
 *     cdef Py_ssize_t shape, size = src.memview.view.itemsize             # <<<<<<<<<<<<<<
 * 
 *     for shape in src.shape[:ndim]:
 */
  __pyx_t_1 = __pyx_v_src->memview->view.itemsize;
  __pyx_v_size = __pyx_t_1;

  /* "View.MemoryView":1178
 *     cdef Py_ssize_t shape, size = src.memview.view.itemsize
 * 
 *     for shape in src.shape[:ndim]:             # <<<<<<<<<<<<<<
 *         size *= shape
 * 
 */
  __pyx_t_3 = (__pyx_v_src->shape + __pyx_v_ndim);
  for (__pyx_t_4 = __pyx_v_src->shape; __pyx_t_4 < __pyx_t_3; __pyx_t_4++) {
    __pyx_t_2 = __pyx_t_4;
    __pyx_v_shape = (__pyx_t_2[0]);

    /* "View.MemoryView":1179
 * 
 *     for shape in src.shape[:ndim]:
 *         size *= shape             # <<<<<<<<<<<<<<
 * 
 *     return size
 */
    __pyx_v_size = (__pyx_v_size * __pyx_v_shape);
  }

  /* "View.MemoryView":1181
 *         size *= shape
 * 
 *     return size             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_fill_contig_strides_array')
 */
  __pyx_r = __pyx_v_size;
  goto __pyx_L0;

  /* "View.MemoryView":1174
 * 
 * @cname('__pyx_memoryview_slice_get_size')
 * cdef Py_ssize_t slice_get_size(__Pyx_memviewslice *src, int ndim) noexcept nogil:             # <<<<<<<<<<<<<<
 *     "Return the size of the memory occupied by the slice in number of bytes"
 *     cdef Py_ssize_t shape, size = src.memview.view.itemsize
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1184
 * 
 * @cname('__pyx_fill_contig_strides_array')
 * cdef Py_ssize_t fill_contig_strides_array(             # <<<<<<<<<<<<<<
 *                 Py_ssize_t *shape, Py_ssize_t *strides, Py_ssize_t stride,
 *                 int ndim, char order) noexcept nogil:
 */

static Py_ssize_t __pyx_fill_contig_strides_array(Py_ssize_t *__pyx_v_shape, Py_ssize_t *__pyx_v_strides, Py_ssize_t __pyx_v_stride, int __pyx_v_ndim, char __pyx_v_order) {
  int __pyx_v_idx;
  Py_ssize_t __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;

  /* "View.MemoryView":1193
 *     cdef int idx
 * 
 *     if order == 'F':             # <<<<<<<<<<<<<<
 *         for idx in range(ndim):
 *             strides[idx] = stride
 */
  __pyx_t_1 = (__pyx_v_order == 'F');
  if (__pyx_t_1) {

    /* "View.MemoryView":1194
 * 
 *     if order == 'F':
 *         for idx in range(ndim):             # <<<<<<<<<<<<<<
 *             strides[idx] = stride
 *             stride *= shape[idx]
 */
    __pyx_t_2 = __pyx_v_ndim;
    __pyx_t_3 = __pyx_t_2;
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_idx = __pyx_t_4;

      /* "View.MemoryView":1195
 *     if order == 'F':
 *         for idx in range(ndim):
 *             strides[idx] = stride             # <<<<<<<<<<<<<<
 *             stride *= shape[idx]
 *     else:
 */
      (__pyx_v_strides[__pyx_v_idx]) = __pyx_v_stride;

      /* "View.MemoryView":1196
 *         for idx in range(ndim):
 *             strides[idx] = stride
 *             stride *= shape[idx]             # <<<<<<<<<<<<<<
 *     else:
 *         for idx in range(ndim - 1, -1, -1):
 */
      __pyx_v_stride = (__pyx_v_stride * (__pyx_v_shape[__pyx_v_idx]));
    }

    /* "View.MemoryView":1193
 *     cdef int idx
 * 
 *     if order == 'F':             # <<<<<<<<<<<<<<
 *         for idx in range(ndim):
 *             strides[idx] = stride
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":1198
 *             stride *= shape[idx]
 *     else:
 *         for idx in range(ndim - 1, -1, -1):             # <<<<<<<<<<<<<<
 *             strides[idx] = stride
 *             stride *= shape[idx]
 */
  /*else*/ {
    for (__pyx_t_2 = (__pyx_v_ndim - 1); __pyx_t_2 > -1; __pyx_t_2-=1) {
      __pyx_v_idx = __pyx_t_2;

      /* "View.MemoryView":1199
 *     else:
 *         for idx in range(ndim - 1, -1, -1):
 *             strides[idx] = stride             # <<<<<<<<<<<<<<
 *             stride *= shape[idx]
 * 
 */
      (__pyx_v_strides[__pyx_v_idx]) = __pyx_v_stride;

      /* "View.MemoryView":1200
 *         for idx in range(ndim - 1, -1, -1):
 *             strides[idx] = stride
 *             stride *= shape[idx]             # <<<<<<<<<<<<<<
 * 
 *     return stride
 */
      __pyx_v_stride = (__pyx_v_stride * (__pyx_v_shape[__pyx_v_idx]));
    }
  }
  __pyx_L3:;

  /* "View.MemoryView":1202
 *             stride *= shape[idx]
 * 
 *     return stride             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_copy_data_to_temp')
 */
  __pyx_r = __pyx_v_stride;
  goto __pyx_L0;

  /* "View.MemoryView":1184
 * 
 * @cname('__pyx_fill_contig_strides_array')
 * cdef Py_ssize_t fill_contig_strides_array(             # <<<<<<<<<<<<<<
 *                 Py_ssize_t *shape, Py_ssize_t *strides, Py_ssize_t stride,
 *                 int ndim, char order) noexcept nogil:
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1205
 * 
 * @cname('__pyx_memoryview_copy_data_to_temp')
 * cdef void *copy_data_to_temp(__Pyx_memviewslice *src,             # <<<<<<<<<<<<<<
 *                              __Pyx_memviewslice *tmpslice,
 *                              char order,
 */

static void *__pyx_memoryview_copy_data_to_temp(__Pyx_memviewslice *__pyx_v_src, __Pyx_memviewslice *__pyx_v_tmpslice, char __pyx_v_order, int __pyx_v_ndim) {
  int __pyx_v_i;
  void *__pyx_v_result;
  size_t __pyx_v_itemsize;
  size_t __pyx_v_size;
  void *__pyx_r;
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  struct __pyx_memoryview_obj *__pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save;
  #endif

  /* "View.MemoryView":1216
 *     cdef void *result
 * 
 *     cdef size_t itemsize = src.memview.view.itemsize             # <<<<<<<<<<<<<<
 *     cdef size_t size = slice_get_size(src, ndim)
 * 
 */
  __pyx_t_1 = __pyx_v_src->memview->view.itemsize;
  __pyx_v_itemsize = __pyx_t_1;

  /* "View.MemoryView":1217
 * 
 *     cdef size_t itemsize = src.memview.view.itemsize
 *     cdef size_t size = slice_get_size(src, ndim)             # <<<<<<<<<<<<<<
 * 
 *     result = malloc(size)
 */
  __pyx_v_size = __pyx_memoryview_slice_get_size(__pyx_v_src, __pyx_v_ndim);

  /* "View.MemoryView":1219
 *     cdef size_t size = slice_get_size(src, ndim)
 * 
 *     result = malloc(size)             # <<<<<<<<<<<<<<
 *     if not result:
 *         _err_no_memory()
 */
  __pyx_v_result = malloc(__pyx_v_size);

  /* "View.MemoryView":1220
 * 
 *     result = malloc(size)
 *     if not result:             # <<<<<<<<<<<<<<
 *         _err_no_memory()
 * 
 */
  __pyx_t_2 = (!(__pyx_v_result != 0));
  if (__pyx_t_2) {

    /* "View.MemoryView":1221
 *     result = malloc(size)
 *     if not result:
 *         _err_no_memory()             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_3 = __pyx_memoryview_err_no_memory(); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(1, 1221, __pyx_L1_error)

    /* "View.MemoryView":1220
 * 
 *     result = malloc(size)
 *     if not result:             # <<<<<<<<<<<<<<
 *         _err_no_memory()
 * 
 */
  }

  /* "View.MemoryView":1224
 * 
 * 
 *     tmpslice.data = <char *> result             # <<<<<<<<<<<<<<
 *     tmpslice.memview = src.memview
 *     for i in range(ndim):
 */
  __pyx_v_tmpslice->data = ((char *)__pyx_v_result);

  /* "View.MemoryView":1225
 * 
 *     tmpslice.data = <char *> result
 *     tmpslice.memview = src.memview             # <<<<<<<<<<<<<<
 *     for i in range(ndim):
 *         tmpslice.shape[i] = src.shape[i]
 */
  __pyx_t_4 = __pyx_v_src->memview;
  __pyx_v_tmpslice->memview = __pyx_t_4;

  /* "View.MemoryView":1226
 *     tmpslice.data = <char *> result
 *     tmpslice.memview = src.memview
 *     for i in range(ndim):             # <<<<<<<<<<<<<<
 *         tmpslice.shape[i] = src.shape[i]
 *         tmpslice.suboffsets[i] = -1
 */
  __pyx_t_3 = __pyx_v_ndim;
  __pyx_t_5 = __pyx_t_3;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "View.MemoryView":1227
 *     tmpslice.memview = src.memview
 *     for i in range(ndim):
 *         tmpslice.shape[i] = src.shape[i]             # <<<<<<<<<<<<<<
 *         tmpslice.suboffsets[i] = -1
 * 
 */
    (__pyx_v_tmpslice->shape[__pyx_v_i]) = (__pyx_v_src->shape[__pyx_v_i]);

    /* "View.MemoryView":1228
 *     for i in range(ndim):
 *         tmpslice.shape[i] = src.shape[i]
 *         tmpslice.suboffsets[i] = -1             # <<<<<<<<<<<<<<
 * 
 *     fill_contig_strides_array(&tmpslice.shape[0], &tmpslice.strides[0], itemsize, ndim, order)
 */
    (__pyx_v_tmpslice->suboffsets[__pyx_v_i]) = -1L;
  }

  /* "View.MemoryView":1230
 *         tmpslice.suboffsets[i] = -1
 * 
 *     fill_contig_strides_array(&tmpslice.shape[0], &tmpslice.strides[0], itemsize, ndim, order)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  (void)(__pyx_fill_contig_strides_array((&(__pyx_v_tmpslice->shape[0])), (&(__pyx_v_tmpslice->strides[0])), __pyx_v_itemsize, __pyx_v_ndim, __pyx_v_order));

  /* "View.MemoryView":1233
 * 
 * 
 *     for i in range(ndim):             # <<<<<<<<<<<<<<
 *         if tmpslice.shape[i] == 1:
 *             tmpslice.strides[i] = 0
 */
  __pyx_t_3 = __pyx_v_ndim;
  __pyx_t_5 = __pyx_t_3;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "View.MemoryView":1234
 * 
 *     for i in range(ndim):
 *         if tmpslice.shape[i] == 1:             # <<<<<<<<<<<<<<
 *             tmpslice.strides[i] = 0
 * 
 */
    __pyx_t_2 = ((__pyx_v_tmpslice->shape[__pyx_v_i]) == 1);
    if (__pyx_t_2) {

      /* "View.MemoryView":1235
 *     for i in range(ndim):
 *         if tmpslice.shape[i] == 1:
 *             tmpslice.strides[i] = 0             # <<<<<<<<<<<<<<
 * 
 *     if slice_is_contig(src[0], order, ndim):
 */
      (__pyx_v_tmpslice->strides[__pyx_v_i]) = 0;

      /* "View.MemoryView":1234
 * 
 *     for i in range(ndim):
 *         if tmpslice.shape[i] == 1:             # <<<<<<<<<<<<<<
 *             tmpslice.strides[i] = 0
 * 
 */
    }
  }

  /* "View.MemoryView":1237
 *             tmpslice.strides[i] = 0
 * 
 *     if slice_is_contig(src[0], order, ndim):             # <<<<<<<<<<<<<<
 *         memcpy(result, src.data, size)
 *     else:
 */
  __pyx_t_2 = __pyx_memviewslice_is_contig((__pyx_v_src[0]), __pyx_v_order, __pyx_v_ndim);
  if (__pyx_t_2) {

    /* "View.MemoryView":1238
 * 
 *     if slice_is_contig(src[0], order, ndim):
 *         memcpy(result, src.data, size)             # <<<<<<<<<<<<<<
 *     else:
 *         copy_strided_to_strided(src, tmpslice, ndim, itemsize)
 */
    (void)(memcpy(__pyx_v_result, __pyx_v_src->data, __pyx_v_size));

    /* "View.MemoryView":1237
 *             tmpslice.strides[i] = 0
 * 
 *     if slice_is_contig(src[0], order, ndim):             # <<<<<<<<<<<<<<
 *         memcpy(result, src.data, size)
 *     else:
 */
    goto __pyx_L9;
  }

  /* "View.MemoryView":1240
 *         memcpy(result, src.data, size)
 *     else:
 *         copy_strided_to_strided(src, tmpslice, ndim, itemsize)             # <<<<<<<<<<<<<<
 * 
 *     return result
 */
  /*else*/ {
    copy_strided_to_strided(__pyx_v_src, __pyx_v_tmpslice, __pyx_v_ndim, __pyx_v_itemsize);
  }
  __pyx_L9:;

  /* "View.MemoryView":1242
 *         copy_strided_to_strided(src, tmpslice, ndim, itemsize)
 * 
 *     return result             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "View.MemoryView":1205
 * 
 * @cname('__pyx_memoryview_copy_data_to_temp')
 * cdef void *copy_data_to_temp(__Pyx_memviewslice *src,             # <<<<<<<<<<<<<<
 *                              __Pyx_memviewslice *tmpslice,
 *                              char order,
 */

  /* function exit code */
  __pyx_L1_error:;
  #ifdef WITH_THREAD
  __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_AddTraceback("View.MemoryView.copy_data_to_temp", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1247
 * 
 * @cname('__pyx_memoryview_err_extents')
 * cdef int _err_extents(int i, Py_ssize_t extent1,             # <<<<<<<<<<<<<<
 *                              Py_ssize_t extent2) except -1 with gil:
 *     raise ValueError, f"got differing extents in dimension {i} (got {extent1} and {extent2})"
 */

static int __pyx_memoryview_err_extents(int __pyx_v_i, Py_ssize_t __pyx_v_extent1, Py_ssize_t __pyx_v_extent2) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  Py_UCS4 __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("_err_extents", 0);

  /* "View.MemoryView":1249
 * cdef int _err_extents(int i, Py_ssize_t extent1,
 *                              Py_ssize_t extent2) except -1 with gil:
 *     raise ValueError, f"got differing extents in dimension {i} (got {extent1} and {extent2})"             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_err_dim')
 */
  __pyx_t_1 = PyTuple_New(7); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = 0;
  __pyx_t_3 = 127;
  __Pyx_INCREF(__pyx_kp_u_got_differing_extents_in_dimensi);
  __pyx_t_2 += 35;
  __Pyx_GIVEREF(__pyx_kp_u_got_differing_extents_in_dimensi);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u_got_differing_extents_in_dimensi);
  __pyx_t_4 = __Pyx_PyUnicode_From_int(__pyx_v_i, 0, ' ', 'd'); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_INCREF(__pyx_kp_u_got);
  __pyx_t_2 += 6;
  __Pyx_GIVEREF(__pyx_kp_u_got);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u_got);
  __pyx_t_4 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_v_extent1, 0, ' ', 'd'); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 3, __pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_INCREF(__pyx_kp_u_and);
  __pyx_t_2 += 5;
  __Pyx_GIVEREF(__pyx_kp_u_and);
  PyTuple_SET_ITEM(__pyx_t_1, 4, __pyx_kp_u_and);
  __pyx_t_4 = __Pyx_PyUnicode_From_Py_ssize_t(__pyx_v_extent2, 0, ' ', 'd'); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 += __Pyx_PyUnicode_GET_LENGTH(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 5, __pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_INCREF(__pyx_kp_u__7);
  __pyx_t_2 += 1;
  __Pyx_GIVEREF(__pyx_kp_u__7);
  PyTuple_SET_ITEM(__pyx_t_1, 6, __pyx_kp_u__7);
  __pyx_t_4 = __Pyx_PyUnicode_Join(__pyx_t_1, 7, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_Raise(__pyx_builtin_ValueError, __pyx_t_4, 0, 0);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __PYX_ERR(1, 1249, __pyx_L1_error)

  /* "View.MemoryView":1247
 * 
 * @cname('__pyx_memoryview_err_extents')
 * cdef int _err_extents(int i, Py_ssize_t extent1,             # <<<<<<<<<<<<<<
 *                              Py_ssize_t extent2) except -1 with gil:
 *     raise ValueError, f"got differing extents in dimension {i} (got {extent1} and {extent2})"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("View.MemoryView._err_extents", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "View.MemoryView":1252
 * 
 * @cname('__pyx_memoryview_err_dim')
 * cdef int _err_dim(PyObject *error, str msg, int dim) except -1 with gil:             # <<<<<<<<<<<<<<
 *     raise <object>error, msg % dim
 * 
 */

static int __pyx_memoryview_err_dim(PyObject *__pyx_v_error, PyObject *__pyx_v_msg, int __pyx_v_dim) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("_err_dim", 0);
  __Pyx_INCREF(__pyx_v_msg);

  /* "View.MemoryView":1253
 * @cname('__pyx_memoryview_err_dim')
 * cdef int _err_dim(PyObject *error, str msg, int dim) except -1 with gil:
 *     raise <object>error, msg % dim             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_err')
 */
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_dim); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyString_FormatSafe(__pyx_v_msg, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 1253, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_Raise(((PyObject *)__pyx_v_error), __pyx_t_2, 0, 0);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __PYX_ERR(1, 1253, __pyx_L1_error)

  /* "View.MemoryView":1252
 * 
 * @cname('__pyx_memoryview_err_dim')
 * cdef int _err_dim(PyObject *error, str msg, int dim) except -1 with gil:             # <<<<<<<<<<<<<<
 *     raise <object>error, msg % dim
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("View.MemoryView._err_dim", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_XDECREF(__pyx_v_msg);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "View.MemoryView":1256
 * 
 * @cname('__pyx_memoryview_err')
 * cdef int _err(PyObject *error, str msg) except -1 with gil:             # <<<<<<<<<<<<<<
 *     raise <object>error, msg
 * 
 */

static int __pyx_memoryview_err(PyObject *__pyx_v_error, PyObject *__pyx_v_msg) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_RefNannySetupContext("_err", 0);
  __Pyx_INCREF(__pyx_v_msg);

  /* "View.MemoryView":1257
 * @cname('__pyx_memoryview_err')
 * cdef int _err(PyObject *error, str msg) except -1 with gil:
 *     raise <object>error, msg             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_err_no_memory')
 */
  __Pyx_Raise(((PyObject *)__pyx_v_error), __pyx_v_msg, 0, 0);
  __PYX_ERR(1, 1257, __pyx_L1_error)

  /* "View.MemoryView":1256
 * 
 * @cname('__pyx_memoryview_err')
 * cdef int _err(PyObject *error, str msg) except -1 with gil:             # <<<<<<<<<<<<<<
 *     raise <object>error, msg
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView._err", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __Pyx_XDECREF(__pyx_v_msg);
  __Pyx_RefNannyFinishContext();
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "View.MemoryView":1260
 * 
 * @cname('__pyx_memoryview_err_no_memory')
 * cdef int _err_no_memory() except -1 with gil:             # <<<<<<<<<<<<<<
 *     raise MemoryError
 * 
 */

static int __pyx_memoryview_err_no_memory(void) {
  int __pyx_r;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif

  /* "View.MemoryView":1261
 * @cname('__pyx_memoryview_err_no_memory')
 * cdef int _err_no_memory() except -1 with gil:
 *     raise MemoryError             # <<<<<<<<<<<<<<
 * 
 * 
 */
  PyErr_NoMemory(); __PYX_ERR(1, 1261, __pyx_L1_error)

  /* "View.MemoryView":1260
 * 
 * @cname('__pyx_memoryview_err_no_memory')
 * cdef int _err_no_memory() except -1 with gil:             # <<<<<<<<<<<<<<
 *     raise MemoryError
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("View.MemoryView._err_no_memory", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  return __pyx_r;
}

/* "View.MemoryView":1265
 * 
 * @cname('__pyx_memoryview_copy_contents')
 * cdef int memoryview_copy_contents(__Pyx_memviewslice src,             # <<<<<<<<<<<<<<
 *                                   __Pyx_memviewslice dst,
 *                                   int src_ndim, int dst_ndim,
 */

static int __pyx_memoryview_copy_contents(__Pyx_memviewslice __pyx_v_src, __Pyx_memviewslice __pyx_v_dst, int __pyx_v_src_ndim, int __pyx_v_dst_ndim, int __pyx_v_dtype_is_object) {
  void *__pyx_v_tmpdata;
  size_t __pyx_v_itemsize;
  int __pyx_v_i;
  char __pyx_v_order;
  int __pyx_v_broadcasting;
  int __pyx_v_direct_copy;
  __Pyx_memviewslice __pyx_v_tmp;
  int __pyx_v_ndim;
  int __pyx_r;
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_t_6;
  void *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save;
  #endif

  /* "View.MemoryView":1273
 *     Check for overlapping memory and verify the shapes.
 *     """
 *     cdef void *tmpdata = NULL             # <<<<<<<<<<<<<<
 *     cdef size_t itemsize = src.memview.view.itemsize
 *     cdef int i
 */
  __pyx_v_tmpdata = NULL;

  /* "View.MemoryView":1274
 *     """
 *     cdef void *tmpdata = NULL
 *     cdef size_t itemsize = src.memview.view.itemsize             # <<<<<<<<<<<<<<
 *     cdef int i
 *     cdef char order = get_best_order(&src, src_ndim)
 */
  __pyx_t_1 = __pyx_v_src.memview->view.itemsize;
  __pyx_v_itemsize = __pyx_t_1;

  /* "View.MemoryView":1276
 *     cdef size_t itemsize = src.memview.view.itemsize
 *     cdef int i
 *     cdef char order = get_best_order(&src, src_ndim)             # <<<<<<<<<<<<<<
 *     cdef bint broadcasting = False
 *     cdef bint direct_copy = False
 */
  __pyx_v_order = __pyx_get_best_slice_order((&__pyx_v_src), __pyx_v_src_ndim);

  /* "View.MemoryView":1277
 *     cdef int i
 *     cdef char order = get_best_order(&src, src_ndim)
 *     cdef bint broadcasting = False             # <<<<<<<<<<<<<<
 *     cdef bint direct_copy = False
 *     cdef __Pyx_memviewslice tmp
 */
  __pyx_v_broadcasting = 0;

  /* "View.MemoryView":1278
 *     cdef char order = get_best_order(&src, src_ndim)
 *     cdef bint broadcasting = False
 *     cdef bint direct_copy = False             # <<<<<<<<<<<<<<
 *     cdef __Pyx_memviewslice tmp
 * 
 */
  __pyx_v_direct_copy = 0;

  /* "View.MemoryView":1281
 *     cdef __Pyx_memviewslice tmp
 * 
 *     if src_ndim < dst_ndim:             # <<<<<<<<<<<<<<
 *         broadcast_leading(&src, src_ndim, dst_ndim)
 *     elif dst_ndim < src_ndim:
 */
  __pyx_t_2 = (__pyx_v_src_ndim < __pyx_v_dst_ndim);
  if (__pyx_t_2) {

    /* "View.MemoryView":1282
 * 
 *     if src_ndim < dst_ndim:
 *         broadcast_leading(&src, src_ndim, dst_ndim)             # <<<<<<<<<<<<<<
 *     elif dst_ndim < src_ndim:
 *         broadcast_leading(&dst, dst_ndim, src_ndim)
 */
    __pyx_memoryview_broadcast_leading((&__pyx_v_src), __pyx_v_src_ndim, __pyx_v_dst_ndim);

    /* "View.MemoryView":1281
 *     cdef __Pyx_memviewslice tmp
 * 
 *     if src_ndim < dst_ndim:             # <<<<<<<<<<<<<<
 *         broadcast_leading(&src, src_ndim, dst_ndim)
 *     elif dst_ndim < src_ndim:
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":1283
 *     if src_ndim < dst_ndim:
 *         broadcast_leading(&src, src_ndim, dst_ndim)
 *     elif dst_ndim < src_ndim:             # <<<<<<<<<<<<<<
 *         broadcast_leading(&dst, dst_ndim, src_ndim)
 * 
 */
  __pyx_t_2 = (__pyx_v_dst_ndim < __pyx_v_src_ndim);
  if (__pyx_t_2) {

    /* "View.MemoryView":1284
 *         broadcast_leading(&src, src_ndim, dst_ndim)
 *     elif dst_ndim < src_ndim:
 *         broadcast_leading(&dst, dst_ndim, src_ndim)             # <<<<<<<<<<<<<<
 * 
 *     cdef int ndim = max(src_ndim, dst_ndim)
 */
    __pyx_memoryview_broadcast_leading((&__pyx_v_dst), __pyx_v_dst_ndim, __pyx_v_src_ndim);

    /* "View.MemoryView":1283
 *     if src_ndim < dst_ndim:
 *         broadcast_leading(&src, src_ndim, dst_ndim)
 *     elif dst_ndim < src_ndim:             # <<<<<<<<<<<<<<
 *         broadcast_leading(&dst, dst_ndim, src_ndim)
 * 
 */
  }
  __pyx_L3:;

  /* "View.MemoryView":1286
 *         broadcast_leading(&dst, dst_ndim, src_ndim)
 * 
 *     cdef int ndim = max(src_ndim, dst_ndim)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(ndim):
 */
  __pyx_t_3 = __pyx_v_dst_ndim;
  __pyx_t_4 = __pyx_v_src_ndim;
  __pyx_t_2 = (__pyx_t_3 > __pyx_t_4);
  if (__pyx_t_2) {
    __pyx_t_5 = __pyx_t_3;
  } else {
    __pyx_t_5 = __pyx_t_4;
  }
  __pyx_v_ndim = __pyx_t_5;

  /* "View.MemoryView":1288
 *     cdef int ndim = max(src_ndim, dst_ndim)
 * 
 *     for i in range(ndim):             # <<<<<<<<<<<<<<
 *         if src.shape[i] != dst.shape[i]:
 *             if src.shape[i] == 1:
 */
  __pyx_t_5 = __pyx_v_ndim;
  __pyx_t_3 = __pyx_t_5;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_i = __pyx_t_4;

    /* "View.MemoryView":1289
 * 
 *     for i in range(ndim):
 *         if src.shape[i] != dst.shape[i]:             # <<<<<<<<<<<<<<
 *             if src.shape[i] == 1:
 *                 broadcasting = True
 */
    __pyx_t_2 = ((__pyx_v_src.shape[__pyx_v_i]) != (__pyx_v_dst.shape[__pyx_v_i]));
    if (__pyx_t_2) {

      /* "View.MemoryView":1290
 *     for i in range(ndim):
 *         if src.shape[i] != dst.shape[i]:
 *             if src.shape[i] == 1:             # <<<<<<<<<<<<<<
 *                 broadcasting = True
 *                 src.strides[i] = 0
 */
      __pyx_t_2 = ((__pyx_v_src.shape[__pyx_v_i]) == 1);
      if (__pyx_t_2) {

        /* "View.MemoryView":1291
 *         if src.shape[i] != dst.shape[i]:
 *             if src.shape[i] == 1:
 *                 broadcasting = True             # <<<<<<<<<<<<<<
 *                 src.strides[i] = 0
 *             else:
 */
        __pyx_v_broadcasting = 1;

        /* "View.MemoryView":1292
 *             if src.shape[i] == 1:
 *                 broadcasting = True
 *                 src.strides[i] = 0             # <<<<<<<<<<<<<<
 *             else:
 *                 _err_extents(i, dst.shape[i], src.shape[i])
 */
        (__pyx_v_src.strides[__pyx_v_i]) = 0;

        /* "View.MemoryView":1290
 *     for i in range(ndim):
 *         if src.shape[i] != dst.shape[i]:
 *             if src.shape[i] == 1:             # <<<<<<<<<<<<<<
 *                 broadcasting = True
 *                 src.strides[i] = 0
 */
        goto __pyx_L7;
      }

      /* "View.MemoryView":1294
 *                 src.strides[i] = 0
 *             else:
 *                 _err_extents(i, dst.shape[i], src.shape[i])             # <<<<<<<<<<<<<<
 * 
 *         if src.suboffsets[i] >= 0:
 */
      /*else*/ {
        __pyx_t_6 = __pyx_memoryview_err_extents(__pyx_v_i, (__pyx_v_dst.shape[__pyx_v_i]), (__pyx_v_src.shape[__pyx_v_i])); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(1, 1294, __pyx_L1_error)
      }
      __pyx_L7:;

      /* "View.MemoryView":1289
 * 
 *     for i in range(ndim):
 *         if src.shape[i] != dst.shape[i]:             # <<<<<<<<<<<<<<
 *             if src.shape[i] == 1:
 *                 broadcasting = True
 */
    }

    /* "View.MemoryView":1296
 *                 _err_extents(i, dst.shape[i], src.shape[i])
 * 
 *         if src.suboffsets[i] >= 0:             # <<<<<<<<<<<<<<
 *             _err_dim(PyExc_ValueError, "Dimension %d is not direct", i)
 * 
 */
    __pyx_t_2 = ((__pyx_v_src.suboffsets[__pyx_v_i]) >= 0);
    if (__pyx_t_2) {

      /* "View.MemoryView":1297
 * 
 *         if src.suboffsets[i] >= 0:
 *             _err_dim(PyExc_ValueError, "Dimension %d is not direct", i)             # <<<<<<<<<<<<<<
 * 
 *     if slices_overlap(&src, &dst, ndim, itemsize):
 */
      __pyx_t_6 = __pyx_memoryview_err_dim(PyExc_ValueError, __pyx_kp_s_Dimension_d_is_not_direct, __pyx_v_i); if (unlikely(__pyx_t_6 == ((int)-1))) __PYX_ERR(1, 1297, __pyx_L1_error)

      /* "View.MemoryView":1296
 *                 _err_extents(i, dst.shape[i], src.shape[i])
 * 
 *         if src.suboffsets[i] >= 0:             # <<<<<<<<<<<<<<
 *             _err_dim(PyExc_ValueError, "Dimension %d is not direct", i)
 * 
 */
    }
  }

  /* "View.MemoryView":1299
 *             _err_dim(PyExc_ValueError, "Dimension %d is not direct", i)
 * 
 *     if slices_overlap(&src, &dst, ndim, itemsize):             # <<<<<<<<<<<<<<
 * 
 *         if not slice_is_contig(src, order, ndim):
 */
  __pyx_t_2 = __pyx_slices_overlap((&__pyx_v_src), (&__pyx_v_dst), __pyx_v_ndim, __pyx_v_itemsize);
  if (__pyx_t_2) {

    /* "View.MemoryView":1301
 *     if slices_overlap(&src, &dst, ndim, itemsize):
 * 
 *         if not slice_is_contig(src, order, ndim):             # <<<<<<<<<<<<<<
 *             order = get_best_order(&dst, ndim)
 * 
 */
    __pyx_t_2 = (!__pyx_memviewslice_is_contig(__pyx_v_src, __pyx_v_order, __pyx_v_ndim));
    if (__pyx_t_2) {

      /* "View.MemoryView":1302
 * 
 *         if not slice_is_contig(src, order, ndim):
 *             order = get_best_order(&dst, ndim)             # <<<<<<<<<<<<<<
 * 
 *         tmpdata = copy_data_to_temp(&src, &tmp, order, ndim)
 */
      __pyx_v_order = __pyx_get_best_slice_order((&__pyx_v_dst), __pyx_v_ndim);

      /* "View.MemoryView":1301
 *     if slices_overlap(&src, &dst, ndim, itemsize):
 * 
 *         if not slice_is_contig(src, order, ndim):             # <<<<<<<<<<<<<<
 *             order = get_best_order(&dst, ndim)
 * 
 */
    }

    /* "View.MemoryView":1304
 *             order = get_best_order(&dst, ndim)
 * 
 *         tmpdata = copy_data_to_temp(&src, &tmp, order, ndim)             # <<<<<<<<<<<<<<
 *         src = tmp
 * 
 */
    __pyx_t_7 = __pyx_memoryview_copy_data_to_temp((&__pyx_v_src), (&__pyx_v_tmp), __pyx_v_order, __pyx_v_ndim); if (unlikely(__pyx_t_7 == ((void *)NULL))) __PYX_ERR(1, 1304, __pyx_L1_error)
    __pyx_v_tmpdata = __pyx_t_7;

    /* "View.MemoryView":1305
 * 
 *         tmpdata = copy_data_to_temp(&src, &tmp, order, ndim)
 *         src = tmp             # <<<<<<<<<<<<<<
 * 
 *     if not broadcasting:
 */
    __pyx_v_src = __pyx_v_tmp;

    /* "View.MemoryView":1299
 *             _err_dim(PyExc_ValueError, "Dimension %d is not direct", i)
 * 
 *     if slices_overlap(&src, &dst, ndim, itemsize):             # <<<<<<<<<<<<<<
 * 
 *         if not slice_is_contig(src, order, ndim):
 */
  }

  /* "View.MemoryView":1307
 *         src = tmp
 * 
 *     if not broadcasting:             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = (!__pyx_v_broadcasting);
  if (__pyx_t_2) {

    /* "View.MemoryView":1310
 * 
 * 
 *         if slice_is_contig(src, 'C', ndim):             # <<<<<<<<<<<<<<
 *             direct_copy = slice_is_contig(dst, 'C', ndim)
 *         elif slice_is_contig(src, 'F', ndim):
 */
    __pyx_t_2 = __pyx_memviewslice_is_contig(__pyx_v_src, 'C', __pyx_v_ndim);
    if (__pyx_t_2) {

      /* "View.MemoryView":1311
 * 
 *         if slice_is_contig(src, 'C', ndim):
 *             direct_copy = slice_is_contig(dst, 'C', ndim)             # <<<<<<<<<<<<<<
 *         elif slice_is_contig(src, 'F', ndim):
 *             direct_copy = slice_is_contig(dst, 'F', ndim)
 */
      __pyx_v_direct_copy = __pyx_memviewslice_is_contig(__pyx_v_dst, 'C', __pyx_v_ndim);

      /* "View.MemoryView":1310
 * 
 * 
 *         if slice_is_contig(src, 'C', ndim):             # <<<<<<<<<<<<<<
 *             direct_copy = slice_is_contig(dst, 'C', ndim)
 *         elif slice_is_contig(src, 'F', ndim):
 */
      goto __pyx_L12;
    }

    /* "View.MemoryView":1312
 *         if slice_is_contig(src, 'C', ndim):
 *             direct_copy = slice_is_contig(dst, 'C', ndim)
 *         elif slice_is_contig(src, 'F', ndim):             # <<<<<<<<<<<<<<
 *             direct_copy = slice_is_contig(dst, 'F', ndim)
 * 
 */
    __pyx_t_2 = __pyx_memviewslice_is_contig(__pyx_v_src, 'F', __pyx_v_ndim);
    if (__pyx_t_2) {

      /* "View.MemoryView":1313
 *             direct_copy = slice_is_contig(dst, 'C', ndim)
 *         elif slice_is_contig(src, 'F', ndim):
 *             direct_copy = slice_is_contig(dst, 'F', ndim)             # <<<<<<<<<<<<<<
 * 
 *         if direct_copy:
 */
      __pyx_v_direct_copy = __pyx_memviewslice_is_contig(__pyx_v_dst, 'F', __pyx_v_ndim);

      /* "View.MemoryView":1312
 *         if slice_is_contig(src, 'C', ndim):
 *             direct_copy = slice_is_contig(dst, 'C', ndim)
 *         elif slice_is_contig(src, 'F', ndim):             # <<<<<<<<<<<<<<
 *             direct_copy = slice_is_contig(dst, 'F', ndim)
 * 
 */
    }
    __pyx_L12:;

    /* "View.MemoryView":1315
 *             direct_copy = slice_is_contig(dst, 'F', ndim)
 * 
 *         if direct_copy:             # <<<<<<<<<<<<<<
 * 
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=False)
 */
    if (__pyx_v_direct_copy) {

      /* "View.MemoryView":1317
 *         if direct_copy:
 * 
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=False)             # <<<<<<<<<<<<<<
 *             memcpy(dst.data, src.data, slice_get_size(&src, ndim))
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=True)
 */
      __pyx_memoryview_refcount_copying((&__pyx_v_dst), __pyx_v_dtype_is_object, __pyx_v_ndim, 0);

      /* "View.MemoryView":1318
 * 
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=False)
 *             memcpy(dst.data, src.data, slice_get_size(&src, ndim))             # <<<<<<<<<<<<<<
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=True)
 *             free(tmpdata)
 */
      (void)(memcpy(__pyx_v_dst.data, __pyx_v_src.data, __pyx_memoryview_slice_get_size((&__pyx_v_src), __pyx_v_ndim)));

      /* "View.MemoryView":1319
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=False)
 *             memcpy(dst.data, src.data, slice_get_size(&src, ndim))
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=True)             # <<<<<<<<<<<<<<
 *             free(tmpdata)
 *             return 0
 */
      __pyx_memoryview_refcount_copying((&__pyx_v_dst), __pyx_v_dtype_is_object, __pyx_v_ndim, 1);

      /* "View.MemoryView":1320
 *             memcpy(dst.data, src.data, slice_get_size(&src, ndim))
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=True)
 *             free(tmpdata)             # <<<<<<<<<<<<<<
 *             return 0
 * 
 */
      free(__pyx_v_tmpdata);

      /* "View.MemoryView":1321
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=True)
 *             free(tmpdata)
 *             return 0             # <<<<<<<<<<<<<<
 * 
 *     if order == 'F' == get_best_order(&dst, ndim):
 */
      __pyx_r = 0;
      goto __pyx_L0;

      /* "View.MemoryView":1315
 *             direct_copy = slice_is_contig(dst, 'F', ndim)
 * 
 *         if direct_copy:             # <<<<<<<<<<<<<<
 * 
 *             refcount_copying(&dst, dtype_is_object, ndim, inc=False)
 */
    }

    /* "View.MemoryView":1307
 *         src = tmp
 * 
 *     if not broadcasting:             # <<<<<<<<<<<<<<
 * 
 * 
 */
  }

  /* "View.MemoryView":1323
 *             return 0
 * 
 *     if order == 'F' == get_best_order(&dst, ndim):             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = (__pyx_v_order == 'F');
  if (__pyx_t_2) {
    __pyx_t_2 = ('F' == __pyx_get_best_slice_order((&__pyx_v_dst), __pyx_v_ndim));
  }
  if (__pyx_t_2) {

    /* "View.MemoryView":1326
 * 
 * 
 *         transpose_memslice(&src)             # <<<<<<<<<<<<<<
 *         transpose_memslice(&dst)
 * 
 */
    __pyx_t_5 = __pyx_memslice_transpose((&__pyx_v_src)); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(1, 1326, __pyx_L1_error)

    /* "View.MemoryView":1327
 * 
 *         transpose_memslice(&src)
 *         transpose_memslice(&dst)             # <<<<<<<<<<<<<<
 * 
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=False)
 */
    __pyx_t_5 = __pyx_memslice_transpose((&__pyx_v_dst)); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(1, 1327, __pyx_L1_error)

    /* "View.MemoryView":1323
 *             return 0
 * 
 *     if order == 'F' == get_best_order(&dst, ndim):             # <<<<<<<<<<<<<<
 * 
 * 
 */
  }

  /* "View.MemoryView":1329
 *         transpose_memslice(&dst)
 * 
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=False)             # <<<<<<<<<<<<<<
 *     copy_strided_to_strided(&src, &dst, ndim, itemsize)
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=True)
 */
  __pyx_memoryview_refcount_copying((&__pyx_v_dst), __pyx_v_dtype_is_object, __pyx_v_ndim, 0);

  /* "View.MemoryView":1330
 * 
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=False)
 *     copy_strided_to_strided(&src, &dst, ndim, itemsize)             # <<<<<<<<<<<<<<
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=True)
 * 
 */
  copy_strided_to_strided((&__pyx_v_src), (&__pyx_v_dst), __pyx_v_ndim, __pyx_v_itemsize);

  /* "View.MemoryView":1331
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=False)
 *     copy_strided_to_strided(&src, &dst, ndim, itemsize)
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=True)             # <<<<<<<<<<<<<<
 * 
 *     free(tmpdata)
 */
  __pyx_memoryview_refcount_copying((&__pyx_v_dst), __pyx_v_dtype_is_object, __pyx_v_ndim, 1);

  /* "View.MemoryView":1333
 *     refcount_copying(&dst, dtype_is_object, ndim, inc=True)
 * 
 *     free(tmpdata)             # <<<<<<<<<<<<<<
 *     return 0
 * 
 */
  free(__pyx_v_tmpdata);

  /* "View.MemoryView":1334
 * 
 *     free(tmpdata)
 *     return 0             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_broadcast_leading')
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "View.MemoryView":1265
 * 
 * @cname('__pyx_memoryview_copy_contents')
 * cdef int memoryview_copy_contents(__Pyx_memviewslice src,             # <<<<<<<<<<<<<<
 *                                   __Pyx_memviewslice dst,
 *                                   int src_ndim, int dst_ndim,
 */

  /* function exit code */
  __pyx_L1_error:;
  #ifdef WITH_THREAD
  __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_AddTraceback("View.MemoryView.memoryview_copy_contents", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  __pyx_L0:;
  return __pyx_r;
}

/* "View.MemoryView":1337
 * 
 * @cname('__pyx_memoryview_broadcast_leading')
 * cdef void broadcast_leading(__Pyx_memviewslice *mslice,             # <<<<<<<<<<<<<<
 *                             int ndim,
 *                             int ndim_other) noexcept nogil:
 */

static void __pyx_memoryview_broadcast_leading(__Pyx_memviewslice *__pyx_v_mslice, int __pyx_v_ndim, int __pyx_v_ndim_other) {
  int __pyx_v_i;
  int __pyx_v_offset;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;

  /* "View.MemoryView":1341
 *                             int ndim_other) noexcept nogil:
 *     cdef int i
 *     cdef int offset = ndim_other - ndim             # <<<<<<<<<<<<<<
 * 
 *     for i in range(ndim - 1, -1, -1):
 */
  __pyx_v_offset = (__pyx_v_ndim_other - __pyx_v_ndim);

  /* "View.MemoryView":1343
 *     cdef int offset = ndim_other - ndim
 * 
 *     for i in range(ndim - 1, -1, -1):             # <<<<<<<<<<<<<<
 *         mslice.shape[i + offset] = mslice.shape[i]
 *         mslice.strides[i + offset] = mslice.strides[i]
 */
  for (__pyx_t_1 = (__pyx_v_ndim - 1); __pyx_t_1 > -1; __pyx_t_1-=1) {
    __pyx_v_i = __pyx_t_1;

    /* "View.MemoryView":1344
 * 
 *     for i in range(ndim - 1, -1, -1):
 *         mslice.shape[i + offset] = mslice.shape[i]             # <<<<<<<<<<<<<<
 *         mslice.strides[i + offset] = mslice.strides[i]
 *         mslice.suboffsets[i + offset] = mslice.suboffsets[i]
 */
    (__pyx_v_mslice->shape[(__pyx_v_i + __pyx_v_offset)]) = (__pyx_v_mslice->shape[__pyx_v_i]);

    /* "View.MemoryView":1345
 *     for i in range(ndim - 1, -1, -1):
 *         mslice.shape[i + offset] = mslice.shape[i]
 *         mslice.strides[i + offset] = mslice.strides[i]             # <<<<<<<<<<<<<<
 *         mslice.suboffsets[i + offset] = mslice.suboffsets[i]
 * 
 */
    (__pyx_v_mslice->strides[(__pyx_v_i + __pyx_v_offset)]) = (__pyx_v_mslice->strides[__pyx_v_i]);

    /* "View.MemoryView":1346
 *         mslice.shape[i + offset] = mslice.shape[i]
 *         mslice.strides[i + offset] = mslice.strides[i]
 *         mslice.suboffsets[i + offset] = mslice.suboffsets[i]             # <<<<<<<<<<<<<<
 * 
 *     for i in range(offset):
 */
    (__pyx_v_mslice->suboffsets[(__pyx_v_i + __pyx_v_offset)]) = (__pyx_v_mslice->suboffsets[__pyx_v_i]);
  }

  /* "View.MemoryView":1348
 *         mslice.suboffsets[i + offset] = mslice.suboffsets[i]
 * 
 *     for i in range(offset):             # <<<<<<<<<<<<<<
 *         mslice.shape[i] = 1
 *         mslice.strides[i] = mslice.strides[0]
 */
  __pyx_t_1 = __pyx_v_offset;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "View.MemoryView":1349
 * 
 *     for i in range(offset):
 *         mslice.shape[i] = 1             # <<<<<<<<<<<<<<
 *         mslice.strides[i] = mslice.strides[0]
 *         mslice.suboffsets[i] = -1
 */
    (__pyx_v_mslice->shape[__pyx_v_i]) = 1;

    /* "View.MemoryView":1350
 *     for i in range(offset):
 *         mslice.shape[i] = 1
 *         mslice.strides[i] = mslice.strides[0]             # <<<<<<<<<<<<<<
 *         mslice.suboffsets[i] = -1
 * 
 */
    (__pyx_v_mslice->strides[__pyx_v_i]) = (__pyx_v_mslice->strides[0]);

    /* "View.MemoryView":1351
 *         mslice.shape[i] = 1
 *         mslice.strides[i] = mslice.strides[0]
 *         mslice.suboffsets[i] = -1             # <<<<<<<<<<<<<<
 * 
 * 
 */
    (__pyx_v_mslice->suboffsets[__pyx_v_i]) = -1L;
  }

  /* "View.MemoryView":1337
 * 
 * @cname('__pyx_memoryview_broadcast_leading')
 * cdef void broadcast_leading(__Pyx_memviewslice *mslice,             # <<<<<<<<<<<<<<
 *                             int ndim,
 *                             int ndim_other) noexcept nogil:
 */

  /* function exit code */
}

/* "View.MemoryView":1359
 * 
 * @cname('__pyx_memoryview_refcount_copying')
 * cdef void refcount_copying(__Pyx_memviewslice *dst, bint dtype_is_object, int ndim, bint inc) noexcept nogil:             # <<<<<<<<<<<<<<
 * 
 *     if dtype_is_object:
 */

static void __pyx_memoryview_refcount_copying(__Pyx_memviewslice *__pyx_v_dst, int __pyx_v_dtype_is_object, int __pyx_v_ndim, int __pyx_v_inc) {

  /* "View.MemoryView":1361
 * cdef void refcount_copying(__Pyx_memviewslice *dst, bint dtype_is_object, int ndim, bint inc) noexcept nogil:
 * 
 *     if dtype_is_object:             # <<<<<<<<<<<<<<
 *         refcount_objects_in_slice_with_gil(dst.data, dst.shape, dst.strides, ndim, inc)
 * 
 */
  if (__pyx_v_dtype_is_object) {

    /* "View.MemoryView":1362
 * 
 *     if dtype_is_object:
 *         refcount_objects_in_slice_with_gil(dst.data, dst.shape, dst.strides, ndim, inc)             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_refcount_objects_in_slice_with_gil')
 */
    __pyx_memoryview_refcount_objects_in_slice_with_gil(__pyx_v_dst->data, __pyx_v_dst->shape, __pyx_v_dst->strides, __pyx_v_ndim, __pyx_v_inc);

    /* "View.MemoryView":1361
 * cdef void refcount_copying(__Pyx_memviewslice *dst, bint dtype_is_object, int ndim, bint inc) noexcept nogil:
 * 
 *     if dtype_is_object:             # <<<<<<<<<<<<<<
 *         refcount_objects_in_slice_with_gil(dst.data, dst.shape, dst.strides, ndim, inc)
 * 
 */
  }

  /* "View.MemoryView":1359
 * 
 * @cname('__pyx_memoryview_refcount_copying')
 * cdef void refcount_copying(__Pyx_memviewslice *dst, bint dtype_is_object, int ndim, bint inc) noexcept nogil:             # <<<<<<<<<<<<<<
 * 
 *     if dtype_is_object:
 */

  /* function exit code */
}

/* "View.MemoryView":1365
 * 
 * @cname('__pyx_memoryview_refcount_objects_in_slice_with_gil')
 * cdef void refcount_objects_in_slice_with_gil(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                                              Py_ssize_t *strides, int ndim,
 *                                              bint inc) noexcept with gil:
 */

static void __pyx_memoryview_refcount_objects_in_slice_with_gil(char *__pyx_v_data, Py_ssize_t *__pyx_v_shape, Py_ssize_t *__pyx_v_strides, int __pyx_v_ndim, int __pyx_v_inc) {
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif

  /* "View.MemoryView":1368
 *                                              Py_ssize_t *strides, int ndim,
 *                                              bint inc) noexcept with gil:
 *     refcount_objects_in_slice(data, shape, strides, ndim, inc)             # <<<<<<<<<<<<<<
 * 
 * @cname('__pyx_memoryview_refcount_objects_in_slice')
 */
  __pyx_memoryview_refcount_objects_in_slice(__pyx_v_data, __pyx_v_shape, __pyx_v_strides, __pyx_v_ndim, __pyx_v_inc);

  /* "View.MemoryView":1365
 * 
 * @cname('__pyx_memoryview_refcount_objects_in_slice_with_gil')
 * cdef void refcount_objects_in_slice_with_gil(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                                              Py_ssize_t *strides, int ndim,
 *                                              bint inc) noexcept with gil:
 */

  /* function exit code */
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
}

/* "View.MemoryView":1371
 * 
 * @cname('__pyx_memoryview_refcount_objects_in_slice')
 * cdef void refcount_objects_in_slice(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                                     Py_ssize_t *strides, int ndim, bint inc) noexcept:
 *     cdef Py_ssize_t i
 */

static void __pyx_memoryview_refcount_objects_in_slice(char *__pyx_v_data, Py_ssize_t *__pyx_v_shape, Py_ssize_t *__pyx_v_strides, int __pyx_v_ndim, int __pyx_v_inc) {
  CYTHON_UNUSED Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_stride;
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;

  /* "View.MemoryView":1374
 *                                     Py_ssize_t *strides, int ndim, bint inc) noexcept:
 *     cdef Py_ssize_t i
 *     cdef Py_ssize_t stride = strides[0]             # <<<<<<<<<<<<<<
 * 
 *     for i in range(shape[0]):
 */
  __pyx_v_stride = (__pyx_v_strides[0]);

  /* "View.MemoryView":1376
 *     cdef Py_ssize_t stride = strides[0]
 * 
 *     for i in range(shape[0]):             # <<<<<<<<<<<<<<
 *         if ndim == 1:
 *             if inc:
 */
  __pyx_t_1 = (__pyx_v_shape[0]);
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "View.MemoryView":1377
 * 
 *     for i in range(shape[0]):
 *         if ndim == 1:             # <<<<<<<<<<<<<<
 *             if inc:
 *                 Py_INCREF((<PyObject **> data)[0])
 */
    __pyx_t_4 = (__pyx_v_ndim == 1);
    if (__pyx_t_4) {

      /* "View.MemoryView":1378
 *     for i in range(shape[0]):
 *         if ndim == 1:
 *             if inc:             # <<<<<<<<<<<<<<
 *                 Py_INCREF((<PyObject **> data)[0])
 *             else:
 */
      if (__pyx_v_inc) {

        /* "View.MemoryView":1379
 *         if ndim == 1:
 *             if inc:
 *                 Py_INCREF((<PyObject **> data)[0])             # <<<<<<<<<<<<<<
 *             else:
 *                 Py_DECREF((<PyObject **> data)[0])
 */
        Py_INCREF((((PyObject **)__pyx_v_data)[0]));

        /* "View.MemoryView":1378
 *     for i in range(shape[0]):
 *         if ndim == 1:
 *             if inc:             # <<<<<<<<<<<<<<
 *                 Py_INCREF((<PyObject **> data)[0])
 *             else:
 */
        goto __pyx_L6;
      }

      /* "View.MemoryView":1381
 *                 Py_INCREF((<PyObject **> data)[0])
 *             else:
 *                 Py_DECREF((<PyObject **> data)[0])             # <<<<<<<<<<<<<<
 *         else:
 *             refcount_objects_in_slice(data, shape + 1, strides + 1, ndim - 1, inc)
 */
      /*else*/ {
        Py_DECREF((((PyObject **)__pyx_v_data)[0]));
      }
      __pyx_L6:;

      /* "View.MemoryView":1377
 * 
 *     for i in range(shape[0]):
 *         if ndim == 1:             # <<<<<<<<<<<<<<
 *             if inc:
 *                 Py_INCREF((<PyObject **> data)[0])
 */
      goto __pyx_L5;
    }

    /* "View.MemoryView":1383
 *                 Py_DECREF((<PyObject **> data)[0])
 *         else:
 *             refcount_objects_in_slice(data, shape + 1, strides + 1, ndim - 1, inc)             # <<<<<<<<<<<<<<
 * 
 *         data += stride
 */
    /*else*/ {
      __pyx_memoryview_refcount_objects_in_slice(__pyx_v_data, (__pyx_v_shape + 1), (__pyx_v_strides + 1), (__pyx_v_ndim - 1), __pyx_v_inc);
    }
    __pyx_L5:;

    /* "View.MemoryView":1385
 *             refcount_objects_in_slice(data, shape + 1, strides + 1, ndim - 1, inc)
 * 
 *         data += stride             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_v_data = (__pyx_v_data + __pyx_v_stride);
  }

  /* "View.MemoryView":1371
 * 
 * @cname('__pyx_memoryview_refcount_objects_in_slice')
 * cdef void refcount_objects_in_slice(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                                     Py_ssize_t *strides, int ndim, bint inc) noexcept:
 *     cdef Py_ssize_t i
 */

  /* function exit code */
}

/* "View.MemoryView":1391
 * 
 * @cname('__pyx_memoryview_slice_assign_scalar')
 * cdef void slice_assign_scalar(__Pyx_memviewslice *dst, int ndim,             # <<<<<<<<<<<<<<
 *                               size_t itemsize, void *item,
 *                               bint dtype_is_object) noexcept nogil:
 */

static void __pyx_memoryview_slice_assign_scalar(__Pyx_memviewslice *__pyx_v_dst, int __pyx_v_ndim, size_t __pyx_v_itemsize, void *__pyx_v_item, int __pyx_v_dtype_is_object) {

  /* "View.MemoryView":1394
 *                               size_t itemsize, void *item,
 *                               bint dtype_is_object) noexcept nogil:
 *     refcount_copying(dst, dtype_is_object, ndim, inc=False)             # <<<<<<<<<<<<<<
 *     _slice_assign_scalar(dst.data, dst.shape, dst.strides, ndim, itemsize, item)
 *     refcount_copying(dst, dtype_is_object, ndim, inc=True)
 */
  __pyx_memoryview_refcount_copying(__pyx_v_dst, __pyx_v_dtype_is_object, __pyx_v_ndim, 0);

  /* "View.MemoryView":1395
 *                               bint dtype_is_object) noexcept nogil:
 *     refcount_copying(dst, dtype_is_object, ndim, inc=False)
 *     _slice_assign_scalar(dst.data, dst.shape, dst.strides, ndim, itemsize, item)             # <<<<<<<<<<<<<<
 *     refcount_copying(dst, dtype_is_object, ndim, inc=True)
 * 
 */
  __pyx_memoryview__slice_assign_scalar(__pyx_v_dst->data, __pyx_v_dst->shape, __pyx_v_dst->strides, __pyx_v_ndim, __pyx_v_itemsize, __pyx_v_item);

  /* "View.MemoryView":1396
 *     refcount_copying(dst, dtype_is_object, ndim, inc=False)
 *     _slice_assign_scalar(dst.data, dst.shape, dst.strides, ndim, itemsize, item)
 *     refcount_copying(dst, dtype_is_object, ndim, inc=True)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_memoryview_refcount_copying(__pyx_v_dst, __pyx_v_dtype_is_object, __pyx_v_ndim, 1);

  /* "View.MemoryView":1391
 * 
 * @cname('__pyx_memoryview_slice_assign_scalar')
 * cdef void slice_assign_scalar(__Pyx_memviewslice *dst, int ndim,             # <<<<<<<<<<<<<<
 *                               size_t itemsize, void *item,
 *                               bint dtype_is_object) noexcept nogil:
 */

  /* function exit code */
}

/* "View.MemoryView":1400
 * 
 * @cname('__pyx_memoryview__slice_assign_scalar')
 * cdef void _slice_assign_scalar(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                               Py_ssize_t *strides, int ndim,
 *                               size_t itemsize, void *item) noexcept nogil:
 */

static void __pyx_memoryview__slice_assign_scalar(char *__pyx_v_data, Py_ssize_t *__pyx_v_shape, Py_ssize_t *__pyx_v_strides, int __pyx_v_ndim, size_t __pyx_v_itemsize, void *__pyx_v_item) {
  CYTHON_UNUSED Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_stride;
  Py_ssize_t __pyx_v_extent;
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;

  /* "View.MemoryView":1404
 *                               size_t itemsize, void *item) noexcept nogil:
 *     cdef Py_ssize_t i
 *     cdef Py_ssize_t stride = strides[0]             # <<<<<<<<<<<<<<
 *     cdef Py_ssize_t extent = shape[0]
 * 
 */
  __pyx_v_stride = (__pyx_v_strides[0]);

  /* "View.MemoryView":1405
 *     cdef Py_ssize_t i
 *     cdef Py_ssize_t stride = strides[0]
 *     cdef Py_ssize_t extent = shape[0]             # <<<<<<<<<<<<<<
 * 
 *     if ndim == 1:
 */
  __pyx_v_extent = (__pyx_v_shape[0]);

  /* "View.MemoryView":1407
 *     cdef Py_ssize_t extent = shape[0]
 * 
 *     if ndim == 1:             # <<<<<<<<<<<<<<
 *         for i in range(extent):
 *             memcpy(data, item, itemsize)
 */
  __pyx_t_1 = (__pyx_v_ndim == 1);
  if (__pyx_t_1) {

    /* "View.MemoryView":1408
 * 
 *     if ndim == 1:
 *         for i in range(extent):             # <<<<<<<<<<<<<<
 *             memcpy(data, item, itemsize)
 *             data += stride
 */
    __pyx_t_2 = __pyx_v_extent;
    __pyx_t_3 = __pyx_t_2;
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_i = __pyx_t_4;

      /* "View.MemoryView":1409
 *     if ndim == 1:
 *         for i in range(extent):
 *             memcpy(data, item, itemsize)             # <<<<<<<<<<<<<<
 *             data += stride
 *     else:
 */
      (void)(memcpy(__pyx_v_data, __pyx_v_item, __pyx_v_itemsize));

      /* "View.MemoryView":1410
 *         for i in range(extent):
 *             memcpy(data, item, itemsize)
 *             data += stride             # <<<<<<<<<<<<<<
 *     else:
 *         for i in range(extent):
 */
      __pyx_v_data = (__pyx_v_data + __pyx_v_stride);
    }

    /* "View.MemoryView":1407
 *     cdef Py_ssize_t extent = shape[0]
 * 
 *     if ndim == 1:             # <<<<<<<<<<<<<<
 *         for i in range(extent):
 *             memcpy(data, item, itemsize)
 */
    goto __pyx_L3;
  }

  /* "View.MemoryView":1412
 *             data += stride
 *     else:
 *         for i in range(extent):             # <<<<<<<<<<<<<<
 *             _slice_assign_scalar(data, shape + 1, strides + 1, ndim - 1, itemsize, item)
 *             data += stride
 */
  /*else*/ {
    __pyx_t_2 = __pyx_v_extent;
    __pyx_t_3 = __pyx_t_2;
    for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_i = __pyx_t_4;

      /* "View.MemoryView":1413
 *     else:
 *         for i in range(extent):
 *             _slice_assign_scalar(data, shape + 1, strides + 1, ndim - 1, itemsize, item)             # <<<<<<<<<<<<<<
 *             data += stride
 * 
 */
      __pyx_memoryview__slice_assign_scalar(__pyx_v_data, (__pyx_v_shape + 1), (__pyx_v_strides + 1), (__pyx_v_ndim - 1), __pyx_v_itemsize, __pyx_v_item);

      /* "View.MemoryView":1414
 *         for i in range(extent):
 *             _slice_assign_scalar(data, shape + 1, strides + 1, ndim - 1, itemsize, item)
 *             data += stride             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_v_data = (__pyx_v_data + __pyx_v_stride);
    }
  }
  __pyx_L3:;

  /* "View.MemoryView":1400
 * 
 * @cname('__pyx_memoryview__slice_assign_scalar')
 * cdef void _slice_assign_scalar(char *data, Py_ssize_t *shape,             # <<<<<<<<<<<<<<
 *                               Py_ssize_t *strides, int ndim,
 *                               size_t itemsize, void *item) noexcept nogil:
 */

  /* function exit code */
}

/* "(tree fragment)":1
 * def __pyx_unpickle_Enum(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_15View_dot_MemoryView_1__pyx_unpickle_Enum(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_15View_dot_MemoryView_1__pyx_unpickle_Enum = {"__pyx_unpickle_Enum", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_15View_dot_MemoryView_1__pyx_unpickle_Enum, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_15View_dot_MemoryView_1__pyx_unpickle_Enum(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_Enum (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_type)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_checksum)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Enum", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Enum", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_unpickle_Enum") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_Enum", 1, 3, 3, __pyx_nargs); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("View.MemoryView.__pyx_unpickle_Enum", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_15View_dot_MemoryView___pyx_unpickle_Enum(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_15View_dot_MemoryView___pyx_unpickle_Enum(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_Enum", 1);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x82a3537, 0x6ae9995, 0xb068931):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum
 */
  __pyx_t_1 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_tuple__8, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x82a3537, 0x6ae9995, 0xb068931):
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum
 *     __pyx_result = Enum.__new__(__pyx_type)
 */
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_PickleError)) __PYX_ERR(1, 5, __pyx_L1_error);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v___pyx_PickleError = __pyx_t_1;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum not in (0x82a3537, 0x6ae9995, 0xb068931):
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum             # <<<<<<<<<<<<<<
 *     __pyx_result = Enum.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_3 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_0x_x_vs_0, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_v___pyx_PickleError, __pyx_t_1, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x82a3537, 0x6ae9995, 0xb068931):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum
 *     __pyx_result = Enum.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_MemviewEnum_type), __pyx_n_s_new); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v___pyx_type};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v___pyx_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum
 *     __pyx_result = Enum.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_2 = (__pyx_v___pyx_state != Py_None);
  if (__pyx_t_2) {

    /* "(tree fragment)":9
 *     __pyx_result = Enum.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_1 = __pyx_unpickle_Enum__set_state(((struct __pyx_MemviewEnum_obj *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum
 *     __pyx_result = Enum.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):
 *     __pyx_result.name = __pyx_state[0]
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_Enum(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("View.MemoryView.__pyx_unpickle_Enum", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.name = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_unpickle_Enum__set_state(struct __pyx_MemviewEnum_obj *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_Enum__set_state", 1);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):
 *     __pyx_result.name = __pyx_state[0]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF(__pyx_v___pyx_result->name);
  __Pyx_DECREF(__pyx_v___pyx_result->name);
  __pyx_v___pyx_result->name = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):
 *     __pyx_result.name = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 13, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_4 = (__pyx_t_3 > 1);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {

    /* "(tree fragment)":14
 *     __pyx_result.name = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[1])             # <<<<<<<<<<<<<<
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_update); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 14, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 14, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
      __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):
 *     __pyx_result.name = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_Enum__set_state(<Enum> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_Enum__set_state(Enum __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.name = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("View.MemoryView.__pyx_unpickle_Enum__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":245
 * 
 *         @property
 *         cdef inline PyObject* base(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns a borrowed reference to the object owning the data/memory.
 *             """
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_7ndarray_4base_base(PyArrayObject *__pyx_v_self) {
  PyObject *__pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":248
 *             """Returns a borrowed reference to the object owning the data/memory.
 *             """
 *             return PyArray_BASE(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_BASE(__pyx_v_self);
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":245
 * 
 *         @property
 *         cdef inline PyObject* base(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns a borrowed reference to the object owning the data/memory.
 *             """
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":251
 * 
 *         @property
 *         cdef inline dtype descr(self):             # <<<<<<<<<<<<<<
 *             """Returns an owned reference to the dtype of the array.
 *             """
 */

static CYTHON_INLINE PyArray_Descr *__pyx_f_5numpy_7ndarray_5descr_descr(PyArrayObject *__pyx_v_self) {
  PyArray_Descr *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyArray_Descr *__pyx_t_1;
  __Pyx_RefNannySetupContext("descr", 1);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":254
 *             """Returns an owned reference to the dtype of the array.
 *             """
 *             return <dtype>PyArray_DESCR(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_1 = PyArray_DESCR(__pyx_v_self);
  __Pyx_INCREF((PyObject *)((PyArray_Descr *)__pyx_t_1));
  __pyx_r = ((PyArray_Descr *)__pyx_t_1);
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":251
 * 
 *         @property
 *         cdef inline dtype descr(self):             # <<<<<<<<<<<<<<
 *             """Returns an owned reference to the dtype of the array.
 *             """
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":257
 * 
 *         @property
 *         cdef inline int ndim(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns the number of dimensions in the array.
 *             """
 */

static CYTHON_INLINE int __pyx_f_5numpy_7ndarray_4ndim_ndim(PyArrayObject *__pyx_v_self) {
  int __pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":260
 *             """Returns the number of dimensions in the array.
 *             """
 *             return PyArray_NDIM(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_NDIM(__pyx_v_self);
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":257
 * 
 *         @property
 *         cdef inline int ndim(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns the number of dimensions in the array.
 *             """
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":263
 * 
 *         @property
 *         cdef inline npy_intp *shape(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns a pointer to the dimensions/shape of the array.
 *             The number of elements matches the number of dimensions of the array (ndim).
 */

static CYTHON_INLINE npy_intp *__pyx_f_5numpy_7ndarray_5shape_shape(PyArrayObject *__pyx_v_self) {
  npy_intp *__pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":268
 *             Can return NULL for 0-dimensional arrays.
 *             """
 *             return PyArray_DIMS(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_DIMS(__pyx_v_self);
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":263
 * 
 *         @property
 *         cdef inline npy_intp *shape(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns a pointer to the dimensions/shape of the array.
 *             The number of elements matches the number of dimensions of the array (ndim).
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":271
 * 
 *         @property
 *         cdef inline npy_intp *strides(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns a pointer to the strides of the array.
 *             The number of elements matches the number of dimensions of the array (ndim).
 */

static CYTHON_INLINE npy_intp *__pyx_f_5numpy_7ndarray_7strides_strides(PyArrayObject *__pyx_v_self) {
  npy_intp *__pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":275
 *             The number of elements matches the number of dimensions of the array (ndim).
 *             """
 *             return PyArray_STRIDES(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_STRIDES(__pyx_v_self);
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":271
 * 
 *         @property
 *         cdef inline npy_intp *strides(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns a pointer to the strides of the array.
 *             The number of elements matches the number of dimensions of the array (ndim).
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":278
 * 
 *         @property
 *         cdef inline npy_intp size(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns the total size (in number of elements) of the array.
 *             """
 */

static CYTHON_INLINE npy_intp __pyx_f_5numpy_7ndarray_4size_size(PyArrayObject *__pyx_v_self) {
  npy_intp __pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":281
 *             """Returns the total size (in number of elements) of the array.
 *             """
 *             return PyArray_SIZE(self)             # <<<<<<<<<<<<<<
 * 
 *         @property
 */
  __pyx_r = PyArray_SIZE(__pyx_v_self);
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":278
 * 
 *         @property
 *         cdef inline npy_intp size(self) nogil:             # <<<<<<<<<<<<<<
 *             """Returns the total size (in number of elements) of the array.
 *             """
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":284
 * 
 *         @property
 *         cdef inline char* data(self) nogil:             # <<<<<<<<<<<<<<
 *             """The pointer to the data buffer as a char*.
 *             This is provided for legacy reasons to avoid direct struct field access.
 */

static CYTHON_INLINE char *__pyx_f_5numpy_7ndarray_4data_data(PyArrayObject *__pyx_v_self) {
  char *__pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":290
 *             of `PyArray_DATA()` instead, which returns a 'void*'.
 *             """
 *             return PyArray_BYTES(self)             # <<<<<<<<<<<<<<
 * 
 *     ctypedef unsigned char      npy_bool
 */
  __pyx_r = PyArray_BYTES(__pyx_v_self);
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":284
 * 
 *         @property
 *         cdef inline char* data(self) nogil:             # <<<<<<<<<<<<<<
 *             """The pointer to the data buffer as a char*.
 *             This is provided for legacy reasons to avoid direct struct field access.
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":773
 * ctypedef npy_cdouble     complex_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew1(PyObject *__pyx_v_a) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew1", 1);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":774
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 *     return PyArray_MultiIterNew(1, <void*>a)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(1, ((void *)__pyx_v_a)); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":773
 * ctypedef npy_cdouble     complex_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":776
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew2(PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew2", 1);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":777
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(2, ((void *)__pyx_v_a), ((void *)__pyx_v_b)); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":776
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":779
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew3(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew3", 1);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":780
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(3, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c)); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 780, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":779
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew3", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":782
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew4(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew4", 1);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":783
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(4, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d)); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 783, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":782
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew4", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":785
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew5(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d, PyObject *__pyx_v_e) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew5", 1);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":786
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)             # <<<<<<<<<<<<<<
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(5, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d), ((void *)__pyx_v_e)); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 786, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":785
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew5", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":788
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):             # <<<<<<<<<<<<<<
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyDataType_SHAPE(PyArray_Descr *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("PyDataType_SHAPE", 1);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":789
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):             # <<<<<<<<<<<<<<
 *         return <tuple>d.subarray.shape
 *     else:
 */
  __pyx_t_1 = PyDataType_HASSUBARRAY(__pyx_v_d);
  if (__pyx_t_1) {

    /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":790
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape             # <<<<<<<<<<<<<<
 *     else:
 *         return ()
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject*)__pyx_v_d->subarray->shape));
    __pyx_r = ((PyObject*)__pyx_v_d->subarray->shape);
    goto __pyx_L0;

    /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":789
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):
 *     if PyDataType_HASSUBARRAY(d):             # <<<<<<<<<<<<<<
 *         return <tuple>d.subarray.shape
 *     else:
 */
  }

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":792
 *         return <tuple>d.subarray.shape
 *     else:
 *         return ()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_empty_tuple);
    __pyx_r = __pyx_empty_tuple;
    goto __pyx_L0;
  }

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":788
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline tuple PyDataType_SHAPE(dtype d):             # <<<<<<<<<<<<<<
 *     if PyDataType_HASSUBARRAY(d):
 *         return <tuple>d.subarray.shape
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":968
 *     int _import_umath() except -1
 * 
 * cdef inline void set_array_base(ndarray arr, object base):             # <<<<<<<<<<<<<<
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)
 */

static CYTHON_INLINE void __pyx_f_5numpy_set_array_base(PyArrayObject *__pyx_v_arr, PyObject *__pyx_v_base) {
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":969
 * 
 * cdef inline void set_array_base(ndarray arr, object base):
 *     Py_INCREF(base) # important to do this before stealing the reference below!             # <<<<<<<<<<<<<<
 *     PyArray_SetBaseObject(arr, base)
 * 
 */
  Py_INCREF(__pyx_v_base);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":970
 * cdef inline void set_array_base(ndarray arr, object base):
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object get_array_base(ndarray arr):
 */
  __pyx_t_1 = PyArray_SetBaseObject(__pyx_v_arr, __pyx_v_base); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(3, 970, __pyx_L1_error)

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":968
 *     int _import_umath() except -1
 * 
 * cdef inline void set_array_base(ndarray arr, object base):             # <<<<<<<<<<<<<<
 *     Py_INCREF(base) # important to do this before stealing the reference below!
 *     PyArray_SetBaseObject(arr, base)
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("numpy.set_array_base", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":972
 *     PyArray_SetBaseObject(arr, base)
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_get_array_base(PyArrayObject *__pyx_v_arr) {
  PyObject *__pyx_v_base;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("get_array_base", 1);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":973
 * 
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)             # <<<<<<<<<<<<<<
 *     if base is NULL:
 *         return None
 */
  __pyx_v_base = PyArray_BASE(__pyx_v_arr);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":974
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)
 *     if base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     return <object>base
 */
  __pyx_t_1 = (__pyx_v_base == NULL);
  if (__pyx_t_1) {

    /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":975
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 *         return None             # <<<<<<<<<<<<<<
 *     return <object>base
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_r = Py_None; __Pyx_INCREF(Py_None);
    goto __pyx_L0;

    /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":974
 * cdef inline object get_array_base(ndarray arr):
 *     base = PyArray_BASE(arr)
 *     if base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     return <object>base
 */
  }

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":976
 *     if base is NULL:
 *         return None
 *     return <object>base             # <<<<<<<<<<<<<<
 * 
 * # Versions of the import_* functions which are more suitable for
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_base));
  __pyx_r = ((PyObject *)__pyx_v_base);
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":972
 *     PyArray_SetBaseObject(arr, base)
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     base = PyArray_BASE(arr)
 *     if base is NULL:
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":980
 * # Versions of the import_* functions which are more suitable for
 * # Cython code.
 * cdef inline int import_array() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         __pyx_import_array()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_array(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("import_array", 1);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":981
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         __pyx_import_array()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":982
 * cdef inline int import_array() except -1:
 *     try:
 *         __pyx_import_array()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")
 */
      __pyx_t_4 = _import_array(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(3, 982, __pyx_L3_error)

      /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":981
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         __pyx_import_array()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":983
 *     try:
 *         __pyx_import_array()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(3, 983, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":984
 *         __pyx_import_array()
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_umath() except -1:
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__9, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(3, 984, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(3, 984, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;

    /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":981
 * # Cython code.
 * cdef inline int import_array() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         __pyx_import_array()
 *     except Exception:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":980
 * # Versions of the import_* functions which are more suitable for
 * # Cython code.
 * cdef inline int import_array() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         __pyx_import_array()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":986
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 * cdef inline int import_umath() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_umath(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("import_umath", 1);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":987
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":988
 * cdef inline int import_umath() except -1:
 *     try:
 *         _import_umath()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")
 */
      __pyx_t_4 = _import_umath(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(3, 988, __pyx_L3_error)

      /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":987
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":989
 *     try:
 *         _import_umath()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_umath", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(3, 989, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":990
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_ufunc() except -1:
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__10, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(3, 990, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(3, 990, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;

    /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":987
 * 
 * cdef inline int import_umath() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":986
 *         raise ImportError("numpy.core.multiarray failed to import")
 * 
 * cdef inline int import_umath() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_umath", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":992
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 * cdef inline int import_ufunc() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

static CYTHON_INLINE int __pyx_f_5numpy_import_ufunc(void) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("import_ufunc", 1);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":993
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":994
 * cdef inline int import_ufunc() except -1:
 *     try:
 *         _import_umath()             # <<<<<<<<<<<<<<
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")
 */
      __pyx_t_4 = _import_umath(); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(3, 994, __pyx_L3_error)

      /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":993
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L8_try_end;
    __pyx_L3_error:;

    /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":995
 *     try:
 *         _import_umath()
 *     except Exception:             # <<<<<<<<<<<<<<
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 */
    __pyx_t_4 = __Pyx_PyErr_ExceptionMatches(((PyObject *)(&((PyTypeObject*)PyExc_Exception)[0])));
    if (__pyx_t_4) {
      __Pyx_AddTraceback("numpy.import_ufunc", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7) < 0) __PYX_ERR(3, 995, __pyx_L5_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":996
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_ImportError, __pyx_tuple__10, NULL); if (unlikely(!__pyx_t_8)) __PYX_ERR(3, 996, __pyx_L5_except_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      __PYX_ERR(3, 996, __pyx_L5_except_error)
    }
    goto __pyx_L5_except_error;

    /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":993
 * 
 * cdef inline int import_ufunc() except -1:
 *     try:             # <<<<<<<<<<<<<<
 *         _import_umath()
 *     except Exception:
 */
    __pyx_L5_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L8_try_end:;
  }

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":992
 *         raise ImportError("numpy.core.umath failed to import")
 * 
 * cdef inline int import_ufunc() except -1:             # <<<<<<<<<<<<<<
 *     try:
 *         _import_umath()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.import_ufunc", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":999
 * 
 * 
 * cdef inline bint is_timedelta64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.timedelta64)`
 */

static CYTHON_INLINE int __pyx_f_5numpy_is_timedelta64_object(PyObject *__pyx_v_obj) {
  int __pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1011
 *     bool
 *     """
 *     return PyObject_TypeCheck(obj, &PyTimedeltaArrType_Type)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = PyObject_TypeCheck(__pyx_v_obj, (&PyTimedeltaArrType_Type));
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":999
 * 
 * 
 * cdef inline bint is_timedelta64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.timedelta64)`
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1014
 * 
 * 
 * cdef inline bint is_datetime64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.datetime64)`
 */

static CYTHON_INLINE int __pyx_f_5numpy_is_datetime64_object(PyObject *__pyx_v_obj) {
  int __pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1026
 *     bool
 *     """
 *     return PyObject_TypeCheck(obj, &PyDatetimeArrType_Type)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = PyObject_TypeCheck(__pyx_v_obj, (&PyDatetimeArrType_Type));
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1014
 * 
 * 
 * cdef inline bint is_datetime64_object(object obj):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(obj, np.datetime64)`
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1029
 * 
 * 
 * cdef inline npy_datetime get_datetime64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy datetime64 object
 */

static CYTHON_INLINE npy_datetime __pyx_f_5numpy_get_datetime64_value(PyObject *__pyx_v_obj) {
  npy_datetime __pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1036
 *     also needed.  That can be found using `get_datetime64_unit`.
 *     """
 *     return (<PyDatetimeScalarObject*>obj).obval             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = ((PyDatetimeScalarObject *)__pyx_v_obj)->obval;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1029
 * 
 * 
 * cdef inline npy_datetime get_datetime64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy datetime64 object
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1039
 * 
 * 
 * cdef inline npy_timedelta get_timedelta64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy timedelta64 object
 */

static CYTHON_INLINE npy_timedelta __pyx_f_5numpy_get_timedelta64_value(PyObject *__pyx_v_obj) {
  npy_timedelta __pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1043
 *     returns the int64 value underlying scalar numpy timedelta64 object
 *     """
 *     return (<PyTimedeltaScalarObject*>obj).obval             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = ((PyTimedeltaScalarObject *)__pyx_v_obj)->obval;
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1039
 * 
 * 
 * cdef inline npy_timedelta get_timedelta64_value(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the int64 value underlying scalar numpy timedelta64 object
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1046
 * 
 * 
 * cdef inline NPY_DATETIMEUNIT get_datetime64_unit(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the unit part of the dtype for a numpy datetime64 object.
 */

static CYTHON_INLINE NPY_DATETIMEUNIT __pyx_f_5numpy_get_datetime64_unit(PyObject *__pyx_v_obj) {
  NPY_DATETIMEUNIT __pyx_r;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1050
 *     returns the unit part of the dtype for a numpy datetime64 object.
 *     """
 *     return <NPY_DATETIMEUNIT>(<PyDatetimeScalarObject*>obj).obmeta.base             # <<<<<<<<<<<<<<
 */
  __pyx_r = ((NPY_DATETIMEUNIT)((PyDatetimeScalarObject *)__pyx_v_obj)->obmeta.base);
  goto __pyx_L0;

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":1046
 * 
 * 
 * cdef inline NPY_DATETIMEUNIT get_datetime64_unit(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     returns the unit part of the dtype for a numpy datetime64 object.
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/tslibs/util.pxd":46
 * 
 * 
 * cdef inline int64_t get_nat():             # <<<<<<<<<<<<<<
 *     return NPY_MIN_INT64
 * 
 */

static CYTHON_INLINE __pyx_t_5numpy_int64_t __pyx_f_6pandas_5_libs_6tslibs_4util_get_nat(void) {
  __pyx_t_5numpy_int64_t __pyx_r;

  /* "pandas/_libs/tslibs/util.pxd":47
 * 
 * cdef inline int64_t get_nat():
 *     return NPY_MIN_INT64             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = NPY_MIN_INT64;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/util.pxd":46
 * 
 * 
 * cdef inline int64_t get_nat():             # <<<<<<<<<<<<<<
 *     return NPY_MIN_INT64
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/tslibs/util.pxd":53
 * # Type Checking
 * 
 * cdef inline bint is_integer_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of
 */

static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_integer_object(PyObject *__pyx_v_obj) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save;
  #endif

  /* "pandas/_libs/tslibs/util.pxd":71
 *     This counts np.timedelta64 objects as integers.
 *     """
 *     return (not PyBool_Check(obj) and PyArray_IsIntegerScalar(obj)             # <<<<<<<<<<<<<<
 *             and not is_timedelta64_object(obj))
 * 
 */
  __pyx_t_2 = (!PyBool_Check(__pyx_v_obj));
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }

  /* "pandas/_libs/tslibs/util.pxd":72
 *     """
 *     return (not PyBool_Check(obj) and PyArray_IsIntegerScalar(obj)
 *             and not is_timedelta64_object(obj))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = PyArray_IsIntegerScalar(__pyx_v_obj);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_4util_is_timedelta64_object(__pyx_v_obj); if (unlikely(__pyx_t_2 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(4, 72, __pyx_L1_error)
  __pyx_t_3 = (!__pyx_t_2);
  __pyx_t_1 = __pyx_t_3;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/util.pxd":53
 * # Type Checking
 * 
 * cdef inline bint is_integer_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of
 */

  /* function exit code */
  __pyx_L1_error:;
  #ifdef WITH_THREAD
  __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_AddTraceback("pandas._libs.tslibs.util.is_integer_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/tslibs/util.pxd":75
 * 
 * 
 * cdef inline bint is_float_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, (float, np.float_))`
 */

static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_float_object(PyObject *__pyx_v_obj) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;

  /* "pandas/_libs/tslibs/util.pxd":87
 *     is_float : bool
 *     """
 *     return (PyFloat_Check(obj) or             # <<<<<<<<<<<<<<
 *             (PyObject_TypeCheck(obj, &PyFloatingArrType_Type)))
 * 
 */
  __pyx_t_2 = PyFloat_Check(__pyx_v_obj);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }

  /* "pandas/_libs/tslibs/util.pxd":88
 *     """
 *     return (PyFloat_Check(obj) or
 *             (PyObject_TypeCheck(obj, &PyFloatingArrType_Type)))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = PyObject_TypeCheck(__pyx_v_obj, (&PyFloatingArrType_Type));
  __pyx_t_1 = __pyx_t_2;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/util.pxd":75
 * 
 * 
 * cdef inline bint is_float_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, (float, np.float_))`
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/tslibs/util.pxd":91
 * 
 * 
 * cdef inline bint is_complex_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, (complex, np.complex_))`
 */

static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_complex_object(PyObject *__pyx_v_obj) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;

  /* "pandas/_libs/tslibs/util.pxd":103
 *     is_complex : bool
 *     """
 *     return (PyComplex_Check(obj) or             # <<<<<<<<<<<<<<
 *             PyObject_TypeCheck(obj, &PyComplexFloatingArrType_Type))
 * 
 */
  __pyx_t_2 = PyComplex_Check(__pyx_v_obj);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }

  /* "pandas/_libs/tslibs/util.pxd":104
 *     """
 *     return (PyComplex_Check(obj) or
 *             PyObject_TypeCheck(obj, &PyComplexFloatingArrType_Type))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = PyObject_TypeCheck(__pyx_v_obj, (&PyComplexFloatingArrType_Type));
  __pyx_t_1 = __pyx_t_2;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/util.pxd":91
 * 
 * 
 * cdef inline bint is_complex_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, (complex, np.complex_))`
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/tslibs/util.pxd":107
 * 
 * 
 * cdef inline bint is_bool_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, (bool, np.bool_))`
 */

static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_bool_object(PyObject *__pyx_v_obj) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;

  /* "pandas/_libs/tslibs/util.pxd":119
 *     is_bool : bool
 *     """
 *     return (PyBool_Check(obj) or             # <<<<<<<<<<<<<<
 *             PyObject_TypeCheck(obj, &PyBoolArrType_Type))
 * 
 */
  __pyx_t_2 = PyBool_Check(__pyx_v_obj);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }

  /* "pandas/_libs/tslibs/util.pxd":120
 *     """
 *     return (PyBool_Check(obj) or
 *             PyObject_TypeCheck(obj, &PyBoolArrType_Type))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = PyObject_TypeCheck(__pyx_v_obj, (&PyBoolArrType_Type));
  __pyx_t_1 = __pyx_t_2;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/util.pxd":107
 * 
 * 
 * cdef inline bint is_bool_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, (bool, np.bool_))`
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/tslibs/util.pxd":123
 * 
 * 
 * cdef inline bint is_real_number_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     return is_bool_object(obj) or is_integer_object(obj) or is_float_object(obj)
 * 
 */

static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_real_number_object(PyObject *__pyx_v_obj) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  #ifdef WITH_THREAD
  PyGILState_STATE __pyx_gilstate_save;
  #endif

  /* "pandas/_libs/tslibs/util.pxd":124
 * 
 * cdef inline bint is_real_number_object(object obj) nogil:
 *     return is_bool_object(obj) or is_integer_object(obj) or is_float_object(obj)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_4util_is_bool_object(__pyx_v_obj); if (unlikely(__pyx_t_2 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(4, 124, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_4util_is_integer_object(__pyx_v_obj); if (unlikely(__pyx_t_2 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(4, 124, __pyx_L1_error)
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_6tslibs_4util_is_float_object(__pyx_v_obj); if (unlikely(__pyx_t_2 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(4, 124, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/util.pxd":123
 * 
 * 
 * cdef inline bint is_real_number_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     return is_bool_object(obj) or is_integer_object(obj) or is_float_object(obj)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  #ifdef WITH_THREAD
  __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
  #endif
  __Pyx_AddTraceback("pandas._libs.tslibs.util.is_real_number_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  #ifdef WITH_THREAD
  __Pyx_PyGILState_Release(__pyx_gilstate_save);
  #endif
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/tslibs/util.pxd":127
 * 
 * 
 * cdef inline bint is_timedelta64_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, np.timedelta64)`
 */

static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_timedelta64_object(PyObject *__pyx_v_obj) {
  int __pyx_r;

  /* "pandas/_libs/tslibs/util.pxd":139
 *     is_timedelta64 : bool
 *     """
 *     return PyObject_TypeCheck(obj, &PyTimedeltaArrType_Type)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = PyObject_TypeCheck(__pyx_v_obj, (&PyTimedeltaArrType_Type));
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/util.pxd":127
 * 
 * 
 * cdef inline bint is_timedelta64_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, np.timedelta64)`
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/tslibs/util.pxd":142
 * 
 * 
 * cdef inline bint is_datetime64_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, np.datetime64)`
 */

static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_datetime64_object(PyObject *__pyx_v_obj) {
  int __pyx_r;

  /* "pandas/_libs/tslibs/util.pxd":154
 *     is_datetime64 : bool
 *     """
 *     return PyObject_TypeCheck(obj, &PyDatetimeArrType_Type)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = PyObject_TypeCheck(__pyx_v_obj, (&PyDatetimeArrType_Type));
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/util.pxd":142
 * 
 * 
 * cdef inline bint is_datetime64_object(object obj) nogil:             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, np.datetime64)`
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/tslibs/util.pxd":157
 * 
 * 
 * cdef inline bint is_array(object val):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, np.ndarray)`
 */

static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_array(PyObject *__pyx_v_val) {
  int __pyx_r;

  /* "pandas/_libs/tslibs/util.pxd":169
 *     is_ndarray : bool
 *     """
 *     return PyArray_Check(val)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = PyArray_Check(__pyx_v_val);
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/util.pxd":157
 * 
 * 
 * cdef inline bint is_array(object val):             # <<<<<<<<<<<<<<
 *     """
 *     Cython equivalent of `isinstance(val, np.ndarray)`
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/tslibs/util.pxd":172
 * 
 * 
 * cdef inline bint is_nan(object val):             # <<<<<<<<<<<<<<
 *     """
 *     Check if val is a Not-A-Number float or complex, including
 */

static CYTHON_INLINE int __pyx_f_6pandas_5_libs_6tslibs_4util_is_nan(PyObject *__pyx_v_val) {
  __pyx_t_5numpy_float64_t __pyx_v_fval;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __pyx_t_5numpy_float64_t __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_nan", 1);

  /* "pandas/_libs/tslibs/util.pxd":186
 *     """
 *     cdef float64_t fval
 *     if is_float_object(val):             # <<<<<<<<<<<<<<
 *         fval = val
 *         return fval != fval
 */
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_4util_is_float_object(__pyx_v_val); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(4, 186, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "pandas/_libs/tslibs/util.pxd":187
 *     cdef float64_t fval
 *     if is_float_object(val):
 *         fval = val             # <<<<<<<<<<<<<<
 *         return fval != fval
 *     return is_complex_object(val) and val != val
 */
    __pyx_t_2 = __pyx_PyFloat_AsDouble(__pyx_v_val); if (unlikely((__pyx_t_2 == ((npy_float64)-1)) && PyErr_Occurred())) __PYX_ERR(4, 187, __pyx_L1_error)
    __pyx_v_fval = __pyx_t_2;

    /* "pandas/_libs/tslibs/util.pxd":188
 *     if is_float_object(val):
 *         fval = val
 *         return fval != fval             # <<<<<<<<<<<<<<
 *     return is_complex_object(val) and val != val
 * 
 */
    __pyx_r = (__pyx_v_fval != __pyx_v_fval);
    goto __pyx_L0;

    /* "pandas/_libs/tslibs/util.pxd":186
 *     """
 *     cdef float64_t fval
 *     if is_float_object(val):             # <<<<<<<<<<<<<<
 *         fval = val
 *         return fval != fval
 */
  }

  /* "pandas/_libs/tslibs/util.pxd":189
 *         fval = val
 *         return fval != fval
 *     return is_complex_object(val) and val != val             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_3 = __pyx_f_6pandas_5_libs_6tslibs_4util_is_complex_object(__pyx_v_val); if (unlikely(__pyx_t_3 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(4, 189, __pyx_L1_error)
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = PyObject_RichCompare(__pyx_v_val, __pyx_v_val, Py_NE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(4, 189, __pyx_L1_error)
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(4, 189, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/util.pxd":172
 * 
 * 
 * cdef inline bint is_nan(object val):             # <<<<<<<<<<<<<<
 *     """
 *     Check if val is a Not-A-Number float or complex, including
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.tslibs.util.is_nan", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/util.pxd":192
 * 
 * 
 * cdef inline const char* get_c_string_buf_and_size(str py_string,             # <<<<<<<<<<<<<<
 *                                                   Py_ssize_t *length) except NULL:
 *     """
 */

static CYTHON_INLINE char const *__pyx_f_6pandas_5_libs_6tslibs_4util_get_c_string_buf_and_size(PyObject *__pyx_v_py_string, Py_ssize_t *__pyx_v_length) {
  char const *__pyx_r;
  char const *__pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "pandas/_libs/tslibs/util.pxd":212
 *     buf : const char*
 *     """
 *     return PyUnicode_AsUTF8AndSize(py_string, length)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = PyUnicode_AsUTF8AndSize(__pyx_v_py_string, __pyx_v_length); if (unlikely(__pyx_t_1 == ((char const *)NULL))) __PYX_ERR(4, 212, __pyx_L1_error)
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/util.pxd":192
 * 
 * 
 * cdef inline const char* get_c_string_buf_and_size(str py_string,             # <<<<<<<<<<<<<<
 *                                                   Py_ssize_t *length) except NULL:
 *     """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.tslibs.util.get_c_string_buf_and_size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/tslibs/util.pxd":215
 * 
 * 
 * cdef inline const char* get_c_string(str py_string) except NULL:             # <<<<<<<<<<<<<<
 *     return get_c_string_buf_and_size(py_string, NULL)
 * 
 */

static CYTHON_INLINE char const *__pyx_f_6pandas_5_libs_6tslibs_4util_get_c_string(PyObject *__pyx_v_py_string) {
  char const *__pyx_r;
  char const *__pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "pandas/_libs/tslibs/util.pxd":216
 * 
 * cdef inline const char* get_c_string(str py_string) except NULL:
 *     return get_c_string_buf_and_size(py_string, NULL)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = __pyx_f_6pandas_5_libs_6tslibs_4util_get_c_string_buf_and_size(__pyx_v_py_string, NULL); if (unlikely(__pyx_t_1 == ((char const *)NULL))) __PYX_ERR(4, 216, __pyx_L1_error)
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/util.pxd":215
 * 
 * 
 * cdef inline const char* get_c_string(str py_string) except NULL:             # <<<<<<<<<<<<<<
 *     return get_c_string_buf_and_size(py_string, NULL)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.tslibs.util.get_c_string", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/tslibs/util.pxd":219
 * 
 * 
 * cdef inline bytes string_encode_locale(str py_string):             # <<<<<<<<<<<<<<
 *     """As opposed to PyUnicode_Encode, use current system locale to encode."""
 *     return PyUnicode_EncodeLocale(py_string, NULL)
 */

static CYTHON_INLINE PyObject *__pyx_f_6pandas_5_libs_6tslibs_4util_string_encode_locale(PyObject *__pyx_v_py_string) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("string_encode_locale", 1);

  /* "pandas/_libs/tslibs/util.pxd":221
 * cdef inline bytes string_encode_locale(str py_string):
 *     """As opposed to PyUnicode_Encode, use current system locale to encode."""
 *     return PyUnicode_EncodeLocale(py_string, NULL)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyUnicode_EncodeLocale(__pyx_v_py_string, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(PyBytes_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None) || __Pyx_RaiseUnexpectedTypeError("bytes", __pyx_t_1))) __PYX_ERR(4, 221, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/util.pxd":219
 * 
 * 
 * cdef inline bytes string_encode_locale(str py_string):             # <<<<<<<<<<<<<<
 *     """As opposed to PyUnicode_Encode, use current system locale to encode."""
 *     return PyUnicode_EncodeLocale(py_string, NULL)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.util.string_encode_locale", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/tslibs/util.pxd":224
 * 
 * 
 * cdef inline object char_to_string_locale(const char* data):             # <<<<<<<<<<<<<<
 *     """As opposed to PyUnicode_FromString, use current system locale to decode."""
 *     return PyUnicode_DecodeLocale(data, NULL)
 */

static CYTHON_INLINE PyObject *__pyx_f_6pandas_5_libs_6tslibs_4util_char_to_string_locale(char const *__pyx_v_data) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("char_to_string_locale", 1);

  /* "pandas/_libs/tslibs/util.pxd":226
 * cdef inline object char_to_string_locale(const char* data):
 *     """As opposed to PyUnicode_FromString, use current system locale to decode."""
 *     return PyUnicode_DecodeLocale(data, NULL)             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyUnicode_DecodeLocale(__pyx_v_data, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 226, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/tslibs/util.pxd":224
 * 
 * 
 * cdef inline object char_to_string_locale(const char* data):             # <<<<<<<<<<<<<<
 *     """As opposed to PyUnicode_FromString, use current system locale to decode."""
 *     return PyUnicode_DecodeLocale(data, NULL)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.tslibs.util.char_to_string_locale", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable.pyx":39
 * 
 * 
 * def get_hashtable_trace_domain():             # <<<<<<<<<<<<<<
 *     return KHASH_TRACE_DOMAIN
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_1get_hashtable_trace_domain(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_1get_hashtable_trace_domain = {"get_hashtable_trace_domain", (PyCFunction)__pyx_pw_6pandas_5_libs_9hashtable_1get_hashtable_trace_domain, METH_NOARGS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_1get_hashtable_trace_domain(PyObject *__pyx_self, CYTHON_UNUSED PyObject *unused) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_hashtable_trace_domain (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_get_hashtable_trace_domain(__pyx_self);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_get_hashtable_trace_domain(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_hashtable_trace_domain", 1);

  /* "pandas/_libs/hashtable.pyx":40
 * 
 * def get_hashtable_trace_domain():
 *     return KHASH_TRACE_DOMAIN             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(KHASH_TRACE_DOMAIN); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 40, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable.pyx":39
 * 
 * 
 * def get_hashtable_trace_domain():             # <<<<<<<<<<<<<<
 *     return KHASH_TRACE_DOMAIN
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.get_hashtable_trace_domain", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable.pyx":43
 * 
 * 
 * def object_hash(obj):             # <<<<<<<<<<<<<<
 *     return kh_python_hash_func(obj)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_3object_hash(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_3object_hash = {"object_hash", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_3object_hash, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_3object_hash(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_obj = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("object_hash (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_obj,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_obj)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 43, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "object_hash") < 0)) __PYX_ERR(0, 43, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_obj = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("object_hash", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 43, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.object_hash", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_2object_hash(__pyx_self, __pyx_v_obj);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_2object_hash(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_obj) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("object_hash", 1);

  /* "pandas/_libs/hashtable.pyx":44
 * 
 * def object_hash(obj):
 *     return kh_python_hash_func(obj)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_npy_uint32(kh_python_hash_func(__pyx_v_obj)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 44, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable.pyx":43
 * 
 * 
 * def object_hash(obj):             # <<<<<<<<<<<<<<
 *     return kh_python_hash_func(obj)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.object_hash", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable.pyx":47
 * 
 * 
 * def objects_are_equal(a, b):             # <<<<<<<<<<<<<<
 *     return kh_python_hash_equal(a, b)
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_5objects_are_equal(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_5objects_are_equal = {"objects_are_equal", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_5objects_are_equal, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_5objects_are_equal(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_a = 0;
  PyObject *__pyx_v_b = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("objects_are_equal (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_a,&__pyx_n_s_b,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_a)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 47, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_b)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 47, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("objects_are_equal", 1, 2, 2, 1); __PYX_ERR(0, 47, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "objects_are_equal") < 0)) __PYX_ERR(0, 47, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_a = values[0];
    __pyx_v_b = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("objects_are_equal", 1, 2, 2, __pyx_nargs); __PYX_ERR(0, 47, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.objects_are_equal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_4objects_are_equal(__pyx_self, __pyx_v_a, __pyx_v_b);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_4objects_are_equal(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("objects_are_equal", 1);

  /* "pandas/_libs/hashtable.pyx":48
 * 
 * def objects_are_equal(a, b):
 *     return kh_python_hash_equal(a, b)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyBool_FromLong(kh_python_hash_equal(__pyx_v_a, __pyx_v_b)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 48, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable.pyx":47
 * 
 * 
 * def objects_are_equal(a, b):             # <<<<<<<<<<<<<<
 *     return kh_python_hash_equal(a, b)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.objects_are_equal", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":7
 * """
 * 
 * cdef khcomplex64_t to_khcomplex64_t(complex64_t val) nogil:             # <<<<<<<<<<<<<<
 *     cdef khcomplex64_t res
 *     res.real = val.real
 */

static khcomplex64_t __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex64_t(__pyx_t_float_complex __pyx_v_val) {
  khcomplex64_t __pyx_v_res;
  khcomplex64_t __pyx_r;
  float __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":9
 * cdef khcomplex64_t to_khcomplex64_t(complex64_t val) nogil:
 *     cdef khcomplex64_t res
 *     res.real = val.real             # <<<<<<<<<<<<<<
 *     res.imag = val.imag
 *     return res
 */
  __pyx_t_1 = __Pyx_CREAL(__pyx_v_val);
  __pyx_v_res.real = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":10
 *     cdef khcomplex64_t res
 *     res.real = val.real
 *     res.imag = val.imag             # <<<<<<<<<<<<<<
 *     return res
 * cdef khcomplex128_t to_khcomplex128_t(complex128_t val) nogil:
 */
  __pyx_t_1 = __Pyx_CIMAG(__pyx_v_val);
  __pyx_v_res.imag = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":11
 *     res.real = val.real
 *     res.imag = val.imag
 *     return res             # <<<<<<<<<<<<<<
 * cdef khcomplex128_t to_khcomplex128_t(complex128_t val) nogil:
 *     cdef khcomplex128_t res
 */
  __pyx_r = __pyx_v_res;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7
 * """
 * 
 * cdef khcomplex64_t to_khcomplex64_t(complex64_t val) nogil:             # <<<<<<<<<<<<<<
 *     cdef khcomplex64_t res
 *     res.real = val.real
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":12
 *     res.imag = val.imag
 *     return res
 * cdef khcomplex128_t to_khcomplex128_t(complex128_t val) nogil:             # <<<<<<<<<<<<<<
 *     cdef khcomplex128_t res
 *     res.real = val.real
 */

static khcomplex128_t __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex128_t(__pyx_t_double_complex __pyx_v_val) {
  khcomplex128_t __pyx_v_res;
  khcomplex128_t __pyx_r;
  double __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":14
 * cdef khcomplex128_t to_khcomplex128_t(complex128_t val) nogil:
 *     cdef khcomplex128_t res
 *     res.real = val.real             # <<<<<<<<<<<<<<
 *     res.imag = val.imag
 *     return res
 */
  __pyx_t_1 = __Pyx_CREAL(__pyx_v_val);
  __pyx_v_res.real = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":15
 *     cdef khcomplex128_t res
 *     res.real = val.real
 *     res.imag = val.imag             # <<<<<<<<<<<<<<
 *     return res
 * 
 */
  __pyx_t_1 = __Pyx_CIMAG(__pyx_v_val);
  __pyx_v_res.imag = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":16
 *     res.real = val.real
 *     res.imag = val.imag
 *     return res             # <<<<<<<<<<<<<<
 * 
 * cdef bint is_nan_khcomplex128_t(khcomplex128_t val) nogil:
 */
  __pyx_r = __pyx_v_res;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":12
 *     res.imag = val.imag
 *     return res
 * cdef khcomplex128_t to_khcomplex128_t(complex128_t val) nogil:             # <<<<<<<<<<<<<<
 *     cdef khcomplex128_t res
 *     res.real = val.real
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":18
 *     return res
 * 
 * cdef bint is_nan_khcomplex128_t(khcomplex128_t val) nogil:             # <<<<<<<<<<<<<<
 *     return val.real != val.real or val.imag != val.imag
 * # are_equivalent_khcomplex128_t is cimported via khash.pxd
 */

static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_khcomplex128_t(khcomplex128_t __pyx_v_val) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":19
 * 
 * cdef bint is_nan_khcomplex128_t(khcomplex128_t val) nogil:
 *     return val.real != val.real or val.imag != val.imag             # <<<<<<<<<<<<<<
 * # are_equivalent_khcomplex128_t is cimported via khash.pxd
 * 
 */
  __pyx_t_2 = (__pyx_v_val.real != __pyx_v_val.real);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_val.imag != __pyx_v_val.imag);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":18
 *     return res
 * 
 * cdef bint is_nan_khcomplex128_t(khcomplex128_t val) nogil:             # <<<<<<<<<<<<<<
 *     return val.real != val.real or val.imag != val.imag
 * # are_equivalent_khcomplex128_t is cimported via khash.pxd
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":22
 * # are_equivalent_khcomplex128_t is cimported via khash.pxd
 * 
 * cdef bint is_nan_khcomplex64_t(khcomplex64_t val) nogil:             # <<<<<<<<<<<<<<
 *     return val.real != val.real or val.imag != val.imag
 * # are_equivalent_khcomplex64_t is cimported via khash.pxd
 */

static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_khcomplex64_t(khcomplex64_t __pyx_v_val) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":23
 * 
 * cdef bint is_nan_khcomplex64_t(khcomplex64_t val) nogil:
 *     return val.real != val.real or val.imag != val.imag             # <<<<<<<<<<<<<<
 * # are_equivalent_khcomplex64_t is cimported via khash.pxd
 * 
 */
  __pyx_t_2 = (__pyx_v_val.real != __pyx_v_val.real);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L3_bool_binop_done;
  }
  __pyx_t_2 = (__pyx_v_val.imag != __pyx_v_val.imag);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L3_bool_binop_done:;
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":22
 * # are_equivalent_khcomplex128_t is cimported via khash.pxd
 * 
 * cdef bint is_nan_khcomplex64_t(khcomplex64_t val) nogil:             # <<<<<<<<<<<<<<
 *     return val.real != val.real or val.imag != val.imag
 * # are_equivalent_khcomplex64_t is cimported via khash.pxd
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":26
 * # are_equivalent_khcomplex64_t is cimported via khash.pxd
 * 
 * cdef bint is_nan_float64_t(float64_t val) nogil:             # <<<<<<<<<<<<<<
 *     return val != val
 * # are_equivalent_float64_t is cimported via khash.pxd
 */

static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_float64_t(__pyx_t_5numpy_float64_t __pyx_v_val) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":27
 * 
 * cdef bint is_nan_float64_t(float64_t val) nogil:
 *     return val != val             # <<<<<<<<<<<<<<
 * # are_equivalent_float64_t is cimported via khash.pxd
 * 
 */
  __pyx_r = (__pyx_v_val != __pyx_v_val);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":26
 * # are_equivalent_khcomplex64_t is cimported via khash.pxd
 * 
 * cdef bint is_nan_float64_t(float64_t val) nogil:             # <<<<<<<<<<<<<<
 *     return val != val
 * # are_equivalent_float64_t is cimported via khash.pxd
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":30
 * # are_equivalent_float64_t is cimported via khash.pxd
 * 
 * cdef bint is_nan_float32_t(float32_t val) nogil:             # <<<<<<<<<<<<<<
 *     return val != val
 * # are_equivalent_float32_t is cimported via khash.pxd
 */

static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_float32_t(__pyx_t_5numpy_float32_t __pyx_v_val) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":31
 * 
 * cdef bint is_nan_float32_t(float32_t val) nogil:
 *     return val != val             # <<<<<<<<<<<<<<
 * # are_equivalent_float32_t is cimported via khash.pxd
 * 
 */
  __pyx_r = (__pyx_v_val != __pyx_v_val);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":30
 * # are_equivalent_float64_t is cimported via khash.pxd
 * 
 * cdef bint is_nan_float32_t(float32_t val) nogil:             # <<<<<<<<<<<<<<
 *     return val != val
 * # are_equivalent_float32_t is cimported via khash.pxd
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":34
 * # are_equivalent_float32_t is cimported via khash.pxd
 * 
 * cdef bint is_nan_int64_t(int64_t val) nogil:             # <<<<<<<<<<<<<<
 *     return False
 * cdef bint are_equivalent_int64_t(int64_t val1, int64_t val2) nogil:
 */

static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_int64_t(CYTHON_UNUSED __pyx_t_5numpy_int64_t __pyx_v_val) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":35
 * 
 * cdef bint is_nan_int64_t(int64_t val) nogil:
 *     return False             # <<<<<<<<<<<<<<
 * cdef bint are_equivalent_int64_t(int64_t val1, int64_t val2) nogil:
 *     return val1 == val2
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":34
 * # are_equivalent_float32_t is cimported via khash.pxd
 * 
 * cdef bint is_nan_int64_t(int64_t val) nogil:             # <<<<<<<<<<<<<<
 *     return False
 * cdef bint are_equivalent_int64_t(int64_t val1, int64_t val2) nogil:
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":36
 * cdef bint is_nan_int64_t(int64_t val) nogil:
 *     return False
 * cdef bint are_equivalent_int64_t(int64_t val1, int64_t val2) nogil:             # <<<<<<<<<<<<<<
 *     return val1 == val2
 * 
 */

static int __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_int64_t(__pyx_t_5numpy_int64_t __pyx_v_val1, __pyx_t_5numpy_int64_t __pyx_v_val2) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":37
 *     return False
 * cdef bint are_equivalent_int64_t(int64_t val1, int64_t val2) nogil:
 *     return val1 == val2             # <<<<<<<<<<<<<<
 * 
 * cdef bint is_nan_int32_t(int32_t val) nogil:
 */
  __pyx_r = (__pyx_v_val1 == __pyx_v_val2);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":36
 * cdef bint is_nan_int64_t(int64_t val) nogil:
 *     return False
 * cdef bint are_equivalent_int64_t(int64_t val1, int64_t val2) nogil:             # <<<<<<<<<<<<<<
 *     return val1 == val2
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":39
 *     return val1 == val2
 * 
 * cdef bint is_nan_int32_t(int32_t val) nogil:             # <<<<<<<<<<<<<<
 *     return False
 * cdef bint are_equivalent_int32_t(int32_t val1, int32_t val2) nogil:
 */

static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_int32_t(CYTHON_UNUSED __pyx_t_5numpy_int32_t __pyx_v_val) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":40
 * 
 * cdef bint is_nan_int32_t(int32_t val) nogil:
 *     return False             # <<<<<<<<<<<<<<
 * cdef bint are_equivalent_int32_t(int32_t val1, int32_t val2) nogil:
 *     return val1 == val2
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":39
 *     return val1 == val2
 * 
 * cdef bint is_nan_int32_t(int32_t val) nogil:             # <<<<<<<<<<<<<<
 *     return False
 * cdef bint are_equivalent_int32_t(int32_t val1, int32_t val2) nogil:
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":41
 * cdef bint is_nan_int32_t(int32_t val) nogil:
 *     return False
 * cdef bint are_equivalent_int32_t(int32_t val1, int32_t val2) nogil:             # <<<<<<<<<<<<<<
 *     return val1 == val2
 * 
 */

static int __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_int32_t(__pyx_t_5numpy_int32_t __pyx_v_val1, __pyx_t_5numpy_int32_t __pyx_v_val2) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":42
 *     return False
 * cdef bint are_equivalent_int32_t(int32_t val1, int32_t val2) nogil:
 *     return val1 == val2             # <<<<<<<<<<<<<<
 * 
 * cdef bint is_nan_int16_t(int16_t val) nogil:
 */
  __pyx_r = (__pyx_v_val1 == __pyx_v_val2);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":41
 * cdef bint is_nan_int32_t(int32_t val) nogil:
 *     return False
 * cdef bint are_equivalent_int32_t(int32_t val1, int32_t val2) nogil:             # <<<<<<<<<<<<<<
 *     return val1 == val2
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":44
 *     return val1 == val2
 * 
 * cdef bint is_nan_int16_t(int16_t val) nogil:             # <<<<<<<<<<<<<<
 *     return False
 * cdef bint are_equivalent_int16_t(int16_t val1, int16_t val2) nogil:
 */

static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_int16_t(CYTHON_UNUSED __pyx_t_5numpy_int16_t __pyx_v_val) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":45
 * 
 * cdef bint is_nan_int16_t(int16_t val) nogil:
 *     return False             # <<<<<<<<<<<<<<
 * cdef bint are_equivalent_int16_t(int16_t val1, int16_t val2) nogil:
 *     return val1 == val2
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":44
 *     return val1 == val2
 * 
 * cdef bint is_nan_int16_t(int16_t val) nogil:             # <<<<<<<<<<<<<<
 *     return False
 * cdef bint are_equivalent_int16_t(int16_t val1, int16_t val2) nogil:
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":46
 * cdef bint is_nan_int16_t(int16_t val) nogil:
 *     return False
 * cdef bint are_equivalent_int16_t(int16_t val1, int16_t val2) nogil:             # <<<<<<<<<<<<<<
 *     return val1 == val2
 * 
 */

static int __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_int16_t(__pyx_t_5numpy_int16_t __pyx_v_val1, __pyx_t_5numpy_int16_t __pyx_v_val2) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":47
 *     return False
 * cdef bint are_equivalent_int16_t(int16_t val1, int16_t val2) nogil:
 *     return val1 == val2             # <<<<<<<<<<<<<<
 * 
 * cdef bint is_nan_int8_t(int8_t val) nogil:
 */
  __pyx_r = (__pyx_v_val1 == __pyx_v_val2);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":46
 * cdef bint is_nan_int16_t(int16_t val) nogil:
 *     return False
 * cdef bint are_equivalent_int16_t(int16_t val1, int16_t val2) nogil:             # <<<<<<<<<<<<<<
 *     return val1 == val2
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":49
 *     return val1 == val2
 * 
 * cdef bint is_nan_int8_t(int8_t val) nogil:             # <<<<<<<<<<<<<<
 *     return False
 * cdef bint are_equivalent_int8_t(int8_t val1, int8_t val2) nogil:
 */

static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_int8_t(CYTHON_UNUSED __pyx_t_5numpy_int8_t __pyx_v_val) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":50
 * 
 * cdef bint is_nan_int8_t(int8_t val) nogil:
 *     return False             # <<<<<<<<<<<<<<
 * cdef bint are_equivalent_int8_t(int8_t val1, int8_t val2) nogil:
 *     return val1 == val2
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":49
 *     return val1 == val2
 * 
 * cdef bint is_nan_int8_t(int8_t val) nogil:             # <<<<<<<<<<<<<<
 *     return False
 * cdef bint are_equivalent_int8_t(int8_t val1, int8_t val2) nogil:
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":51
 * cdef bint is_nan_int8_t(int8_t val) nogil:
 *     return False
 * cdef bint are_equivalent_int8_t(int8_t val1, int8_t val2) nogil:             # <<<<<<<<<<<<<<
 *     return val1 == val2
 * 
 */

static int __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_int8_t(__pyx_t_5numpy_int8_t __pyx_v_val1, __pyx_t_5numpy_int8_t __pyx_v_val2) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":52
 *     return False
 * cdef bint are_equivalent_int8_t(int8_t val1, int8_t val2) nogil:
 *     return val1 == val2             # <<<<<<<<<<<<<<
 * 
 * cdef bint is_nan_uint64_t(uint64_t val) nogil:
 */
  __pyx_r = (__pyx_v_val1 == __pyx_v_val2);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":51
 * cdef bint is_nan_int8_t(int8_t val) nogil:
 *     return False
 * cdef bint are_equivalent_int8_t(int8_t val1, int8_t val2) nogil:             # <<<<<<<<<<<<<<
 *     return val1 == val2
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":54
 *     return val1 == val2
 * 
 * cdef bint is_nan_uint64_t(uint64_t val) nogil:             # <<<<<<<<<<<<<<
 *     return False
 * cdef bint are_equivalent_uint64_t(uint64_t val1, uint64_t val2) nogil:
 */

static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_uint64_t(CYTHON_UNUSED __pyx_t_5numpy_uint64_t __pyx_v_val) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":55
 * 
 * cdef bint is_nan_uint64_t(uint64_t val) nogil:
 *     return False             # <<<<<<<<<<<<<<
 * cdef bint are_equivalent_uint64_t(uint64_t val1, uint64_t val2) nogil:
 *     return val1 == val2
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":54
 *     return val1 == val2
 * 
 * cdef bint is_nan_uint64_t(uint64_t val) nogil:             # <<<<<<<<<<<<<<
 *     return False
 * cdef bint are_equivalent_uint64_t(uint64_t val1, uint64_t val2) nogil:
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":56
 * cdef bint is_nan_uint64_t(uint64_t val) nogil:
 *     return False
 * cdef bint are_equivalent_uint64_t(uint64_t val1, uint64_t val2) nogil:             # <<<<<<<<<<<<<<
 *     return val1 == val2
 * 
 */

static int __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_uint64_t(__pyx_t_5numpy_uint64_t __pyx_v_val1, __pyx_t_5numpy_uint64_t __pyx_v_val2) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":57
 *     return False
 * cdef bint are_equivalent_uint64_t(uint64_t val1, uint64_t val2) nogil:
 *     return val1 == val2             # <<<<<<<<<<<<<<
 * 
 * cdef bint is_nan_uint32_t(uint32_t val) nogil:
 */
  __pyx_r = (__pyx_v_val1 == __pyx_v_val2);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":56
 * cdef bint is_nan_uint64_t(uint64_t val) nogil:
 *     return False
 * cdef bint are_equivalent_uint64_t(uint64_t val1, uint64_t val2) nogil:             # <<<<<<<<<<<<<<
 *     return val1 == val2
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":59
 *     return val1 == val2
 * 
 * cdef bint is_nan_uint32_t(uint32_t val) nogil:             # <<<<<<<<<<<<<<
 *     return False
 * cdef bint are_equivalent_uint32_t(uint32_t val1, uint32_t val2) nogil:
 */

static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_uint32_t(CYTHON_UNUSED __pyx_t_5numpy_uint32_t __pyx_v_val) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":60
 * 
 * cdef bint is_nan_uint32_t(uint32_t val) nogil:
 *     return False             # <<<<<<<<<<<<<<
 * cdef bint are_equivalent_uint32_t(uint32_t val1, uint32_t val2) nogil:
 *     return val1 == val2
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":59
 *     return val1 == val2
 * 
 * cdef bint is_nan_uint32_t(uint32_t val) nogil:             # <<<<<<<<<<<<<<
 *     return False
 * cdef bint are_equivalent_uint32_t(uint32_t val1, uint32_t val2) nogil:
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":61
 * cdef bint is_nan_uint32_t(uint32_t val) nogil:
 *     return False
 * cdef bint are_equivalent_uint32_t(uint32_t val1, uint32_t val2) nogil:             # <<<<<<<<<<<<<<
 *     return val1 == val2
 * 
 */

static int __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_uint32_t(__pyx_t_5numpy_uint32_t __pyx_v_val1, __pyx_t_5numpy_uint32_t __pyx_v_val2) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":62
 *     return False
 * cdef bint are_equivalent_uint32_t(uint32_t val1, uint32_t val2) nogil:
 *     return val1 == val2             # <<<<<<<<<<<<<<
 * 
 * cdef bint is_nan_uint16_t(uint16_t val) nogil:
 */
  __pyx_r = (__pyx_v_val1 == __pyx_v_val2);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":61
 * cdef bint is_nan_uint32_t(uint32_t val) nogil:
 *     return False
 * cdef bint are_equivalent_uint32_t(uint32_t val1, uint32_t val2) nogil:             # <<<<<<<<<<<<<<
 *     return val1 == val2
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":64
 *     return val1 == val2
 * 
 * cdef bint is_nan_uint16_t(uint16_t val) nogil:             # <<<<<<<<<<<<<<
 *     return False
 * cdef bint are_equivalent_uint16_t(uint16_t val1, uint16_t val2) nogil:
 */

static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_uint16_t(CYTHON_UNUSED __pyx_t_5numpy_uint16_t __pyx_v_val) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":65
 * 
 * cdef bint is_nan_uint16_t(uint16_t val) nogil:
 *     return False             # <<<<<<<<<<<<<<
 * cdef bint are_equivalent_uint16_t(uint16_t val1, uint16_t val2) nogil:
 *     return val1 == val2
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":64
 *     return val1 == val2
 * 
 * cdef bint is_nan_uint16_t(uint16_t val) nogil:             # <<<<<<<<<<<<<<
 *     return False
 * cdef bint are_equivalent_uint16_t(uint16_t val1, uint16_t val2) nogil:
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":66
 * cdef bint is_nan_uint16_t(uint16_t val) nogil:
 *     return False
 * cdef bint are_equivalent_uint16_t(uint16_t val1, uint16_t val2) nogil:             # <<<<<<<<<<<<<<
 *     return val1 == val2
 * 
 */

static int __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_uint16_t(__pyx_t_5numpy_uint16_t __pyx_v_val1, __pyx_t_5numpy_uint16_t __pyx_v_val2) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":67
 *     return False
 * cdef bint are_equivalent_uint16_t(uint16_t val1, uint16_t val2) nogil:
 *     return val1 == val2             # <<<<<<<<<<<<<<
 * 
 * cdef bint is_nan_uint8_t(uint8_t val) nogil:
 */
  __pyx_r = (__pyx_v_val1 == __pyx_v_val2);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":66
 * cdef bint is_nan_uint16_t(uint16_t val) nogil:
 *     return False
 * cdef bint are_equivalent_uint16_t(uint16_t val1, uint16_t val2) nogil:             # <<<<<<<<<<<<<<
 *     return val1 == val2
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":69
 *     return val1 == val2
 * 
 * cdef bint is_nan_uint8_t(uint8_t val) nogil:             # <<<<<<<<<<<<<<
 *     return False
 * cdef bint are_equivalent_uint8_t(uint8_t val1, uint8_t val2) nogil:
 */

static int __pyx_f_6pandas_5_libs_9hashtable_is_nan_uint8_t(CYTHON_UNUSED __pyx_t_5numpy_uint8_t __pyx_v_val) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":70
 * 
 * cdef bint is_nan_uint8_t(uint8_t val) nogil:
 *     return False             # <<<<<<<<<<<<<<
 * cdef bint are_equivalent_uint8_t(uint8_t val1, uint8_t val2) nogil:
 *     return val1 == val2
 */
  __pyx_r = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":69
 *     return val1 == val2
 * 
 * cdef bint is_nan_uint8_t(uint8_t val) nogil:             # <<<<<<<<<<<<<<
 *     return False
 * cdef bint are_equivalent_uint8_t(uint8_t val1, uint8_t val2) nogil:
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":71
 * cdef bint is_nan_uint8_t(uint8_t val) nogil:
 *     return False
 * cdef bint are_equivalent_uint8_t(uint8_t val1, uint8_t val2) nogil:             # <<<<<<<<<<<<<<
 *     return val1 == val2
 * from pandas._libs.khash cimport (
 */

static int __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_uint8_t(__pyx_t_5numpy_uint8_t __pyx_v_val1, __pyx_t_5numpy_uint8_t __pyx_v_val2) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":72
 *     return False
 * cdef bint are_equivalent_uint8_t(uint8_t val1, uint8_t val2) nogil:
 *     return val1 == val2             # <<<<<<<<<<<<<<
 * from pandas._libs.khash cimport (
 *     kh_destroy_complex64,
 */
  __pyx_r = (__pyx_v_val1 == __pyx_v_val2);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":71
 * cdef bint is_nan_uint8_t(uint8_t val) nogil:
 *     return False
 * cdef bint are_equivalent_uint8_t(uint8_t val1, uint8_t val2) nogil:             # <<<<<<<<<<<<<<
 *     return val1 == val2
 * from pandas._libs.khash cimport (
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":211
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_complex128(Complex128VectorData *data,             # <<<<<<<<<<<<<<
 *                                        khcomplex128_t x) nogil:
 * 
 */

static void __pyx_f_6pandas_5_libs_9hashtable_append_data_complex128(__pyx_t_6pandas_5_libs_9hashtable_Complex128VectorData *__pyx_v_data, khcomplex128_t __pyx_v_x) {

  /* "pandas/_libs/hashtable_class_helper.pxi":214
 *                                        khcomplex128_t x) nogil:
 * 
 *     data.data[data.n] = x             # <<<<<<<<<<<<<<
 *     data.n += 1
 * # Int64VectorData is defined in the .pxd file because it is needed (indirectly)
 */
  (__pyx_v_data->data[__pyx_v_data->n]) = __pyx_v_x;

  /* "pandas/_libs/hashtable_class_helper.pxi":215
 * 
 *     data.data[data.n] = x
 *     data.n += 1             # <<<<<<<<<<<<<<
 * # Int64VectorData is defined in the .pxd file because it is needed (indirectly)
 * #  by IntervalTree
 */
  __pyx_v_data->n = (__pyx_v_data->n + 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":211
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_complex128(Complex128VectorData *data,             # <<<<<<<<<<<<<<
 *                                        khcomplex128_t x) nogil:
 * 
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":226
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_complex64(Complex64VectorData *data,             # <<<<<<<<<<<<<<
 *                                        khcomplex64_t x) nogil:
 * 
 */

static void __pyx_f_6pandas_5_libs_9hashtable_append_data_complex64(__pyx_t_6pandas_5_libs_9hashtable_Complex64VectorData *__pyx_v_data, khcomplex64_t __pyx_v_x) {

  /* "pandas/_libs/hashtable_class_helper.pxi":229
 *                                        khcomplex64_t x) nogil:
 * 
 *     data.data[data.n] = x             # <<<<<<<<<<<<<<
 *     data.n += 1
 * # Int64VectorData is defined in the .pxd file because it is needed (indirectly)
 */
  (__pyx_v_data->data[__pyx_v_data->n]) = __pyx_v_x;

  /* "pandas/_libs/hashtable_class_helper.pxi":230
 * 
 *     data.data[data.n] = x
 *     data.n += 1             # <<<<<<<<<<<<<<
 * # Int64VectorData is defined in the .pxd file because it is needed (indirectly)
 * #  by IntervalTree
 */
  __pyx_v_data->n = (__pyx_v_data->n + 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":226
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_complex64(Complex64VectorData *data,             # <<<<<<<<<<<<<<
 *                                        khcomplex64_t x) nogil:
 * 
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":241
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_float64(Float64VectorData *data,             # <<<<<<<<<<<<<<
 *                                        float64_t x) nogil:
 * 
 */

static void __pyx_f_6pandas_5_libs_9hashtable_append_data_float64(__pyx_t_6pandas_5_libs_9hashtable_Float64VectorData *__pyx_v_data, __pyx_t_5numpy_float64_t __pyx_v_x) {

  /* "pandas/_libs/hashtable_class_helper.pxi":244
 *                                        float64_t x) nogil:
 * 
 *     data.data[data.n] = x             # <<<<<<<<<<<<<<
 *     data.n += 1
 * # Int64VectorData is defined in the .pxd file because it is needed (indirectly)
 */
  (__pyx_v_data->data[__pyx_v_data->n]) = __pyx_v_x;

  /* "pandas/_libs/hashtable_class_helper.pxi":245
 * 
 *     data.data[data.n] = x
 *     data.n += 1             # <<<<<<<<<<<<<<
 * # Int64VectorData is defined in the .pxd file because it is needed (indirectly)
 * #  by IntervalTree
 */
  __pyx_v_data->n = (__pyx_v_data->n + 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":241
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_float64(Float64VectorData *data,             # <<<<<<<<<<<<<<
 *                                        float64_t x) nogil:
 * 
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":256
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_float32(Float32VectorData *data,             # <<<<<<<<<<<<<<
 *                                        float32_t x) nogil:
 * 
 */

static void __pyx_f_6pandas_5_libs_9hashtable_append_data_float32(__pyx_t_6pandas_5_libs_9hashtable_Float32VectorData *__pyx_v_data, __pyx_t_5numpy_float32_t __pyx_v_x) {

  /* "pandas/_libs/hashtable_class_helper.pxi":259
 *                                        float32_t x) nogil:
 * 
 *     data.data[data.n] = x             # <<<<<<<<<<<<<<
 *     data.n += 1
 * 
 */
  (__pyx_v_data->data[__pyx_v_data->n]) = __pyx_v_x;

  /* "pandas/_libs/hashtable_class_helper.pxi":260
 * 
 *     data.data[data.n] = x
 *     data.n += 1             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_data->n = (__pyx_v_data->n + 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":256
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_float32(Float32VectorData *data,             # <<<<<<<<<<<<<<
 *                                        float32_t x) nogil:
 * 
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":265
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_int64(Int64VectorData *data,             # <<<<<<<<<<<<<<
 *                                        int64_t x) nogil:
 * 
 */

static void __pyx_f_6pandas_5_libs_9hashtable_append_data_int64(struct __pyx_t_6pandas_5_libs_9hashtable_Int64VectorData *__pyx_v_data, __pyx_t_5numpy_int64_t __pyx_v_x) {

  /* "pandas/_libs/hashtable_class_helper.pxi":268
 *                                        int64_t x) nogil:
 * 
 *     data.data[data.n] = x             # <<<<<<<<<<<<<<
 *     data.n += 1
 * # Int64VectorData is defined in the .pxd file because it is needed (indirectly)
 */
  (__pyx_v_data->data[__pyx_v_data->n]) = __pyx_v_x;

  /* "pandas/_libs/hashtable_class_helper.pxi":269
 * 
 *     data.data[data.n] = x
 *     data.n += 1             # <<<<<<<<<<<<<<
 * # Int64VectorData is defined in the .pxd file because it is needed (indirectly)
 * #  by IntervalTree
 */
  __pyx_v_data->n = (__pyx_v_data->n + 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":265
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_int64(Int64VectorData *data,             # <<<<<<<<<<<<<<
 *                                        int64_t x) nogil:
 * 
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":280
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_int32(Int32VectorData *data,             # <<<<<<<<<<<<<<
 *                                        int32_t x) nogil:
 * 
 */

static void __pyx_f_6pandas_5_libs_9hashtable_append_data_int32(__pyx_t_6pandas_5_libs_9hashtable_Int32VectorData *__pyx_v_data, __pyx_t_5numpy_int32_t __pyx_v_x) {

  /* "pandas/_libs/hashtable_class_helper.pxi":283
 *                                        int32_t x) nogil:
 * 
 *     data.data[data.n] = x             # <<<<<<<<<<<<<<
 *     data.n += 1
 * # Int64VectorData is defined in the .pxd file because it is needed (indirectly)
 */
  (__pyx_v_data->data[__pyx_v_data->n]) = __pyx_v_x;

  /* "pandas/_libs/hashtable_class_helper.pxi":284
 * 
 *     data.data[data.n] = x
 *     data.n += 1             # <<<<<<<<<<<<<<
 * # Int64VectorData is defined in the .pxd file because it is needed (indirectly)
 * #  by IntervalTree
 */
  __pyx_v_data->n = (__pyx_v_data->n + 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":280
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_int32(Int32VectorData *data,             # <<<<<<<<<<<<<<
 *                                        int32_t x) nogil:
 * 
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":295
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_int16(Int16VectorData *data,             # <<<<<<<<<<<<<<
 *                                        int16_t x) nogil:
 * 
 */

static void __pyx_f_6pandas_5_libs_9hashtable_append_data_int16(__pyx_t_6pandas_5_libs_9hashtable_Int16VectorData *__pyx_v_data, __pyx_t_5numpy_int16_t __pyx_v_x) {

  /* "pandas/_libs/hashtable_class_helper.pxi":298
 *                                        int16_t x) nogil:
 * 
 *     data.data[data.n] = x             # <<<<<<<<<<<<<<
 *     data.n += 1
 * # Int64VectorData is defined in the .pxd file because it is needed (indirectly)
 */
  (__pyx_v_data->data[__pyx_v_data->n]) = __pyx_v_x;

  /* "pandas/_libs/hashtable_class_helper.pxi":299
 * 
 *     data.data[data.n] = x
 *     data.n += 1             # <<<<<<<<<<<<<<
 * # Int64VectorData is defined in the .pxd file because it is needed (indirectly)
 * #  by IntervalTree
 */
  __pyx_v_data->n = (__pyx_v_data->n + 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":295
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_int16(Int16VectorData *data,             # <<<<<<<<<<<<<<
 *                                        int16_t x) nogil:
 * 
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":310
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_int8(Int8VectorData *data,             # <<<<<<<<<<<<<<
 *                                        int8_t x) nogil:
 * 
 */

static void __pyx_f_6pandas_5_libs_9hashtable_append_data_int8(__pyx_t_6pandas_5_libs_9hashtable_Int8VectorData *__pyx_v_data, __pyx_t_5numpy_int8_t __pyx_v_x) {

  /* "pandas/_libs/hashtable_class_helper.pxi":313
 *                                        int8_t x) nogil:
 * 
 *     data.data[data.n] = x             # <<<<<<<<<<<<<<
 *     data.n += 1
 * # Int64VectorData is defined in the .pxd file because it is needed (indirectly)
 */
  (__pyx_v_data->data[__pyx_v_data->n]) = __pyx_v_x;

  /* "pandas/_libs/hashtable_class_helper.pxi":314
 * 
 *     data.data[data.n] = x
 *     data.n += 1             # <<<<<<<<<<<<<<
 * # Int64VectorData is defined in the .pxd file because it is needed (indirectly)
 * #  by IntervalTree
 */
  __pyx_v_data->n = (__pyx_v_data->n + 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":310
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_int8(Int8VectorData *data,             # <<<<<<<<<<<<<<
 *                                        int8_t x) nogil:
 * 
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":325
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_string(StringVectorData *data,             # <<<<<<<<<<<<<<
 *                                        char * x) nogil:
 * 
 */

static void __pyx_f_6pandas_5_libs_9hashtable_append_data_string(__pyx_t_6pandas_5_libs_9hashtable_StringVectorData *__pyx_v_data, char *__pyx_v_x) {

  /* "pandas/_libs/hashtable_class_helper.pxi":328
 *                                        char * x) nogil:
 * 
 *     data.data[data.n] = x             # <<<<<<<<<<<<<<
 *     data.n += 1
 * # Int64VectorData is defined in the .pxd file because it is needed (indirectly)
 */
  (__pyx_v_data->data[__pyx_v_data->n]) = __pyx_v_x;

  /* "pandas/_libs/hashtable_class_helper.pxi":329
 * 
 *     data.data[data.n] = x
 *     data.n += 1             # <<<<<<<<<<<<<<
 * # Int64VectorData is defined in the .pxd file because it is needed (indirectly)
 * #  by IntervalTree
 */
  __pyx_v_data->n = (__pyx_v_data->n + 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":325
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_string(StringVectorData *data,             # <<<<<<<<<<<<<<
 *                                        char * x) nogil:
 * 
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":340
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_uint64(UInt64VectorData *data,             # <<<<<<<<<<<<<<
 *                                        uint64_t x) nogil:
 * 
 */

static void __pyx_f_6pandas_5_libs_9hashtable_append_data_uint64(__pyx_t_6pandas_5_libs_9hashtable_UInt64VectorData *__pyx_v_data, __pyx_t_5numpy_uint64_t __pyx_v_x) {

  /* "pandas/_libs/hashtable_class_helper.pxi":343
 *                                        uint64_t x) nogil:
 * 
 *     data.data[data.n] = x             # <<<<<<<<<<<<<<
 *     data.n += 1
 * # Int64VectorData is defined in the .pxd file because it is needed (indirectly)
 */
  (__pyx_v_data->data[__pyx_v_data->n]) = __pyx_v_x;

  /* "pandas/_libs/hashtable_class_helper.pxi":344
 * 
 *     data.data[data.n] = x
 *     data.n += 1             # <<<<<<<<<<<<<<
 * # Int64VectorData is defined in the .pxd file because it is needed (indirectly)
 * #  by IntervalTree
 */
  __pyx_v_data->n = (__pyx_v_data->n + 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":340
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_uint64(UInt64VectorData *data,             # <<<<<<<<<<<<<<
 *                                        uint64_t x) nogil:
 * 
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":355
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_uint32(UInt32VectorData *data,             # <<<<<<<<<<<<<<
 *                                        uint32_t x) nogil:
 * 
 */

static void __pyx_f_6pandas_5_libs_9hashtable_append_data_uint32(__pyx_t_6pandas_5_libs_9hashtable_UInt32VectorData *__pyx_v_data, __pyx_t_5numpy_uint32_t __pyx_v_x) {

  /* "pandas/_libs/hashtable_class_helper.pxi":358
 *                                        uint32_t x) nogil:
 * 
 *     data.data[data.n] = x             # <<<<<<<<<<<<<<
 *     data.n += 1
 * # Int64VectorData is defined in the .pxd file because it is needed (indirectly)
 */
  (__pyx_v_data->data[__pyx_v_data->n]) = __pyx_v_x;

  /* "pandas/_libs/hashtable_class_helper.pxi":359
 * 
 *     data.data[data.n] = x
 *     data.n += 1             # <<<<<<<<<<<<<<
 * # Int64VectorData is defined in the .pxd file because it is needed (indirectly)
 * #  by IntervalTree
 */
  __pyx_v_data->n = (__pyx_v_data->n + 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":355
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_uint32(UInt32VectorData *data,             # <<<<<<<<<<<<<<
 *                                        uint32_t x) nogil:
 * 
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":370
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_uint16(UInt16VectorData *data,             # <<<<<<<<<<<<<<
 *                                        uint16_t x) nogil:
 * 
 */

static void __pyx_f_6pandas_5_libs_9hashtable_append_data_uint16(__pyx_t_6pandas_5_libs_9hashtable_UInt16VectorData *__pyx_v_data, __pyx_t_5numpy_uint16_t __pyx_v_x) {

  /* "pandas/_libs/hashtable_class_helper.pxi":373
 *                                        uint16_t x) nogil:
 * 
 *     data.data[data.n] = x             # <<<<<<<<<<<<<<
 *     data.n += 1
 * # Int64VectorData is defined in the .pxd file because it is needed (indirectly)
 */
  (__pyx_v_data->data[__pyx_v_data->n]) = __pyx_v_x;

  /* "pandas/_libs/hashtable_class_helper.pxi":374
 * 
 *     data.data[data.n] = x
 *     data.n += 1             # <<<<<<<<<<<<<<
 * # Int64VectorData is defined in the .pxd file because it is needed (indirectly)
 * #  by IntervalTree
 */
  __pyx_v_data->n = (__pyx_v_data->n + 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":370
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_uint16(UInt16VectorData *data,             # <<<<<<<<<<<<<<
 *                                        uint16_t x) nogil:
 * 
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":385
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_uint8(UInt8VectorData *data,             # <<<<<<<<<<<<<<
 *                                        uint8_t x) nogil:
 * 
 */

static void __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_v_data, __pyx_t_5numpy_uint8_t __pyx_v_x) {

  /* "pandas/_libs/hashtable_class_helper.pxi":388
 *                                        uint8_t x) nogil:
 * 
 *     data.data[data.n] = x             # <<<<<<<<<<<<<<
 *     data.n += 1
 * 
 */
  (__pyx_v_data->data[__pyx_v_data->n]) = __pyx_v_x;

  /* "pandas/_libs/hashtable_class_helper.pxi":389
 * 
 *     data.data[data.n] = x
 *     data.n += 1             # <<<<<<<<<<<<<<
 * 
 * ctypedef fused vector_data:
 */
  __pyx_v_data->n = (__pyx_v_data->n + 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":385
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef void append_data_uint8(UInt8VectorData *data,             # <<<<<<<<<<<<<<
 *                                        uint8_t x) nogil:
 * 
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":406
 *     StringVectorData
 * 
 * cdef bint needs_resize(vector_data *data) nogil:             # <<<<<<<<<<<<<<
 *     return data.n == data.m
 * 
 */

static int __pyx_fuse_0__pyx_f_6pandas_5_libs_9hashtable_needs_resize(struct __pyx_t_6pandas_5_libs_9hashtable_Int64VectorData *__pyx_v_data) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":407
 * 
 * cdef bint needs_resize(vector_data *data) nogil:
 *     return data.n == data.m             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __pyx_r = (__pyx_v_data->n == __pyx_v_data->m);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":406
 *     StringVectorData
 * 
 * cdef bint needs_resize(vector_data *data) nogil:             # <<<<<<<<<<<<<<
 *     return data.n == data.m
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

static int __pyx_fuse_1__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_Int32VectorData *__pyx_v_data) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":407
 * 
 * cdef bint needs_resize(vector_data *data) nogil:
 *     return data.n == data.m             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __pyx_r = (__pyx_v_data->n == __pyx_v_data->m);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":406
 *     StringVectorData
 * 
 * cdef bint needs_resize(vector_data *data) nogil:             # <<<<<<<<<<<<<<
 *     return data.n == data.m
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

static int __pyx_fuse_2__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_Int16VectorData *__pyx_v_data) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":407
 * 
 * cdef bint needs_resize(vector_data *data) nogil:
 *     return data.n == data.m             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __pyx_r = (__pyx_v_data->n == __pyx_v_data->m);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":406
 *     StringVectorData
 * 
 * cdef bint needs_resize(vector_data *data) nogil:             # <<<<<<<<<<<<<<
 *     return data.n == data.m
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

static int __pyx_fuse_3__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_Int8VectorData *__pyx_v_data) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":407
 * 
 * cdef bint needs_resize(vector_data *data) nogil:
 *     return data.n == data.m             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __pyx_r = (__pyx_v_data->n == __pyx_v_data->m);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":406
 *     StringVectorData
 * 
 * cdef bint needs_resize(vector_data *data) nogil:             # <<<<<<<<<<<<<<
 *     return data.n == data.m
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

static int __pyx_fuse_4__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_UInt64VectorData *__pyx_v_data) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":407
 * 
 * cdef bint needs_resize(vector_data *data) nogil:
 *     return data.n == data.m             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __pyx_r = (__pyx_v_data->n == __pyx_v_data->m);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":406
 *     StringVectorData
 * 
 * cdef bint needs_resize(vector_data *data) nogil:             # <<<<<<<<<<<<<<
 *     return data.n == data.m
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

static int __pyx_fuse_5__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_UInt32VectorData *__pyx_v_data) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":407
 * 
 * cdef bint needs_resize(vector_data *data) nogil:
 *     return data.n == data.m             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __pyx_r = (__pyx_v_data->n == __pyx_v_data->m);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":406
 *     StringVectorData
 * 
 * cdef bint needs_resize(vector_data *data) nogil:             # <<<<<<<<<<<<<<
 *     return data.n == data.m
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

static int __pyx_fuse_6__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_UInt16VectorData *__pyx_v_data) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":407
 * 
 * cdef bint needs_resize(vector_data *data) nogil:
 *     return data.n == data.m             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __pyx_r = (__pyx_v_data->n == __pyx_v_data->m);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":406
 *     StringVectorData
 * 
 * cdef bint needs_resize(vector_data *data) nogil:             # <<<<<<<<<<<<<<
 *     return data.n == data.m
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

static int __pyx_fuse_7__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_v_data) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":407
 * 
 * cdef bint needs_resize(vector_data *data) nogil:
 *     return data.n == data.m             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __pyx_r = (__pyx_v_data->n == __pyx_v_data->m);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":406
 *     StringVectorData
 * 
 * cdef bint needs_resize(vector_data *data) nogil:             # <<<<<<<<<<<<<<
 *     return data.n == data.m
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

static int __pyx_fuse_8__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_Float64VectorData *__pyx_v_data) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":407
 * 
 * cdef bint needs_resize(vector_data *data) nogil:
 *     return data.n == data.m             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __pyx_r = (__pyx_v_data->n == __pyx_v_data->m);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":406
 *     StringVectorData
 * 
 * cdef bint needs_resize(vector_data *data) nogil:             # <<<<<<<<<<<<<<
 *     return data.n == data.m
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

static int __pyx_fuse_9__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_Float32VectorData *__pyx_v_data) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":407
 * 
 * cdef bint needs_resize(vector_data *data) nogil:
 *     return data.n == data.m             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __pyx_r = (__pyx_v_data->n == __pyx_v_data->m);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":406
 *     StringVectorData
 * 
 * cdef bint needs_resize(vector_data *data) nogil:             # <<<<<<<<<<<<<<
 *     return data.n == data.m
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

static int __pyx_fuse_10__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_Complex128VectorData *__pyx_v_data) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":407
 * 
 * cdef bint needs_resize(vector_data *data) nogil:
 *     return data.n == data.m             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __pyx_r = (__pyx_v_data->n == __pyx_v_data->m);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":406
 *     StringVectorData
 * 
 * cdef bint needs_resize(vector_data *data) nogil:             # <<<<<<<<<<<<<<
 *     return data.n == data.m
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

static int __pyx_fuse_11__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_Complex64VectorData *__pyx_v_data) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":407
 * 
 * cdef bint needs_resize(vector_data *data) nogil:
 *     return data.n == data.m             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __pyx_r = (__pyx_v_data->n == __pyx_v_data->m);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":406
 *     StringVectorData
 * 
 * cdef bint needs_resize(vector_data *data) nogil:             # <<<<<<<<<<<<<<
 *     return data.n == data.m
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

static int __pyx_fuse_12__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_t_6pandas_5_libs_9hashtable_StringVectorData *__pyx_v_data) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":407
 * 
 * cdef bint needs_resize(vector_data *data) nogil:
 *     return data.n == data.m             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __pyx_r = (__pyx_v_data->n == __pyx_v_data->m);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":406
 *     StringVectorData
 * 
 * cdef bint needs_resize(vector_data *data) nogil:             # <<<<<<<<<<<<<<
 *     return data.n == data.m
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":417
 *     #    bint external_view_exists
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.external_view_exists = False
 * 
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_6Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_6Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_6Vector___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_6Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Vector *__pyx_v_self) {
  int __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":418
 * 
 *     def __cinit__(self):
 *         self.external_view_exists = False             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->external_view_exists = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":417
 *     #    bint external_view_exists
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.external_view_exists = False
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_6Vector_3__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_6Vector_3__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_6Vector_3__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_6Vector_3__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_6Vector_2__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_6Vector_2__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Vector.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_6Vector_5__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_6Vector_5__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_6Vector_5__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_6Vector_5__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_6Vector_4__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Vector *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_6Vector_4__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":429
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <Complex128VectorData *>PyMem_Malloc(
 *             sizeof(Complex128VectorData))
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Complex128Vector___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16Complex128Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  char *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":430
 * 
 *     def __cinit__(self):
 *         self.data = <Complex128VectorData *>PyMem_Malloc(             # <<<<<<<<<<<<<<
 *             sizeof(Complex128VectorData))
 *         if not self.data:
 */
  __pyx_v_self->data = ((__pyx_t_6pandas_5_libs_9hashtable_Complex128VectorData *)PyMem_Malloc((sizeof(__pyx_t_6pandas_5_libs_9hashtable_Complex128VectorData))));

  /* "pandas/_libs/hashtable_class_helper.pxi":432
 *         self.data = <Complex128VectorData *>PyMem_Malloc(
 *             sizeof(Complex128VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  __pyx_t_1 = (!(__pyx_v_self->data != 0));
  if (unlikely(__pyx_t_1)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":433
 *             sizeof(Complex128VectorData))
 *         if not self.data:
 *             raise MemoryError()             # <<<<<<<<<<<<<<
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 */
    PyErr_NoMemory(); __PYX_ERR(2, 433, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":432
 *         self.data = <Complex128VectorData *>PyMem_Malloc(
 *             sizeof(Complex128VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":434
 *         if not self.data:
 *             raise MemoryError()
 *         self.data.n = 0             # <<<<<<<<<<<<<<
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.complex128)
 */
  __pyx_v_self->data->n = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":435
 *             raise MemoryError()
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP             # <<<<<<<<<<<<<<
 *         self.ao = np.empty(self.data.m, dtype=np.complex128)
 *         self.data.data = <khcomplex128_t*>self.ao.data
 */
  __pyx_v_self->data->m = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;

  /* "pandas/_libs/hashtable_class_helper.pxi":436
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.complex128)             # <<<<<<<<<<<<<<
 *         self.data.data = <khcomplex128_t*>self.ao.data
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 436, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_complex128); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 436, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 436, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_6);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->ao);
  __Pyx_DECREF((PyObject *)__pyx_v_self->ao);
  __pyx_v_self->ao = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":437
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.complex128)
 *         self.data.data = <khcomplex128_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     cdef resize(self):
 */
  __pyx_t_6 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_6);
  __pyx_t_7 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_6)); if (unlikely(__pyx_t_7 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 437, __pyx_L1_error)
  __pyx_v_self->data->data = ((khcomplex128_t *)__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":429
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <Complex128VectorData *>PyMem_Malloc(
 *             sizeof(Complex128VectorData))
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128Vector.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":439
 *         self.data.data = <khcomplex128_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_16Complex128Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  char *__pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("resize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":440
 * 
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)             # <<<<<<<<<<<<<<
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <khcomplex128_t*>self.ao.data
 */
  __pyx_t_1 = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;
  __pyx_t_2 = (__pyx_v_self->data->m * 4);
  __pyx_t_4 = (__pyx_t_1 > __pyx_t_2);
  if (__pyx_t_4) {
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_3 = __pyx_t_2;
  }
  __pyx_v_self->data->m = __pyx_t_3;

  /* "pandas/_libs/hashtable_class_helper.pxi":441
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)             # <<<<<<<<<<<<<<
 *         self.data.data = <khcomplex128_t*>self.ao.data
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 441, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 441, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 441, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6)) __PYX_ERR(2, 441, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 441, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 441, __pyx_L1_error)
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 441, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":442
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <khcomplex128_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_8 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_8);
  __pyx_t_9 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_8)); if (unlikely(__pyx_t_9 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 442, __pyx_L1_error)
  __pyx_v_self->data->data = ((khcomplex128_t *)__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":439
 *         self.data.data = <khcomplex128_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128Vector.resize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":444
 *         self.data.data = <khcomplex128_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_3__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_16Complex128Vector_2__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_16Complex128Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":445
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  __pyx_t_1 = (__pyx_v_self->data != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":446
 *     def __dealloc__(self):
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)             # <<<<<<<<<<<<<<
 *             self.data = NULL
 * 
 */
    PyMem_Free(__pyx_v_self->data);

    /* "pandas/_libs/hashtable_class_helper.pxi":447
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 *             self.data = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
    __pyx_v_self->data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":445
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":444
 *         self.data.data = <khcomplex128_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":449
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_5__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_5__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Complex128Vector_4__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_16Complex128Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_self) {
  Py_ssize_t __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":450
 * 
 *     def __len__(self) -> int:
 *         return self.data.n             # <<<<<<<<<<<<<<
 * 
 *     cpdef ndarray to_array(self):
 */
  __pyx_r = __pyx_v_self->data->n;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":449
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":452
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_16Complex128Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_self, int __pyx_skip_dispatch) {
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_to_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 452, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_7to_array)) {
        __Pyx_XDECREF((PyObject *)__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 452, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 452, __pyx_L1_error)
        __pyx_r = ((PyArrayObject *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":453
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  __pyx_t_6 = (__pyx_v_self->data->m != __pyx_v_self->data->n);
  if (__pyx_t_6) {

    /* "pandas/_libs/hashtable_class_helper.pxi":454
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":456
 *             if self.external_view_exists:
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")             # <<<<<<<<<<<<<<
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 456, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(2, 456, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":454
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":457
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)             # <<<<<<<<<<<<<<
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 457, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 457, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 457, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 457, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 457, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 457, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 457, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":458
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n             # <<<<<<<<<<<<<<
 *         self.external_view_exists = True
 *         return self.ao
 */
    __pyx_t_7 = __pyx_v_self->data->n;
    __pyx_v_self->data->m = __pyx_t_7;

    /* "pandas/_libs/hashtable_class_helper.pxi":453
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":459
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 *         self.external_view_exists = True             # <<<<<<<<<<<<<<
 *         return self.ao
 * 
 */
  __pyx_v_self->__pyx_base.external_view_exists = 1;

  /* "pandas/_libs/hashtable_class_helper.pxi":460
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 *         return self.ao             # <<<<<<<<<<<<<<
 * 
 *     cdef void append(self, khcomplex128_t x):
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->ao);
  __pyx_r = __pyx_v_self->ao;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":452
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Complex128Vector_7to_array = {"to_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_7to_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("to_array", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "to_array", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Complex128Vector_6to_array(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Complex128Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_6pandas_5_libs_9hashtable_16Complex128Vector_to_array(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":462
 *         return self.ao
 * 
 *     cdef void append(self, khcomplex128_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

static void __pyx_f_6pandas_5_libs_9hashtable_16Complex128Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_self, khcomplex128_t __pyx_v_x) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("append", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":464
 *     cdef void append(self, khcomplex128_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  __pyx_t_1 = __pyx_fuse_10__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_self->data); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(2, 464, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":465
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":466
 *         if needs_resize(self.data):
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "             # <<<<<<<<<<<<<<
 *                                  "Vector.resize() needed")
 *             self.resize()
 */
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 466, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(2, 466, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":465
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":468
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 *             self.resize()             # <<<<<<<<<<<<<<
 * 
 *         append_data_complex128(self.data, x)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex128Vector *)__pyx_v_self->__pyx_vtab)->resize(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 468, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":464
 *     cdef void append(self, khcomplex128_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":470
 *             self.resize()
 * 
 *         append_data_complex128(self.data, x)             # <<<<<<<<<<<<<<
 * 
 *     cdef extend(self, const khcomplex128_t[:] x):
 */
  __pyx_f_6pandas_5_libs_9hashtable_append_data_complex128(__pyx_v_self->data, __pyx_v_x); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 470, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":462
 *         return self.ao
 * 
 *     cdef void append(self, khcomplex128_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128Vector.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "pandas/_libs/hashtable_class_helper.pxi":472
 *         append_data_complex128(self.data, x)
 * 
 *     cdef extend(self, const khcomplex128_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_16Complex128Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x) {
  Py_ssize_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extend", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":473
 * 
 *     cdef extend(self, const khcomplex128_t[:] x):
 *         for i in range(len(x)):             # <<<<<<<<<<<<<<
 *             self.append(x[i])
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_x); 
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "pandas/_libs/hashtable_class_helper.pxi":474
 *     cdef extend(self, const khcomplex128_t[:] x):
 *         for i in range(len(x)):
 *             self.append(x[i])             # <<<<<<<<<<<<<<
 * 
 * cdef class Complex64Vector(Vector):
 */
    __pyx_t_4 = __pyx_v_i;
    __pyx_t_5 = -1;
    if (__pyx_t_4 < 0) {
      __pyx_t_4 += __pyx_v_x.shape[0];
      if (unlikely(__pyx_t_4 < 0)) __pyx_t_5 = 0;
    } else if (unlikely(__pyx_t_4 >= __pyx_v_x.shape[0])) __pyx_t_5 = 0;
    if (unlikely(__pyx_t_5 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_5);
      __PYX_ERR(2, 474, __pyx_L1_error)
    }
    ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex128Vector *)__pyx_v_self->__pyx_vtab)->append(__pyx_v_self, (*((khcomplex128_t const  *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_4 * __pyx_v_x.strides[0]) )))); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 474, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":472
 *         append_data_complex128(self.data, x)
 * 
 *     cdef extend(self, const khcomplex128_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128Vector.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Complex128Vector_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Complex128Vector_8__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Complex128Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128Vector.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Complex128Vector_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Complex128Vector_10__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Complex128Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":484
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <Complex64VectorData *>PyMem_Malloc(
 *             sizeof(Complex64VectorData))
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Complex64Vector___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15Complex64Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  char *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":485
 * 
 *     def __cinit__(self):
 *         self.data = <Complex64VectorData *>PyMem_Malloc(             # <<<<<<<<<<<<<<
 *             sizeof(Complex64VectorData))
 *         if not self.data:
 */
  __pyx_v_self->data = ((__pyx_t_6pandas_5_libs_9hashtable_Complex64VectorData *)PyMem_Malloc((sizeof(__pyx_t_6pandas_5_libs_9hashtable_Complex64VectorData))));

  /* "pandas/_libs/hashtable_class_helper.pxi":487
 *         self.data = <Complex64VectorData *>PyMem_Malloc(
 *             sizeof(Complex64VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  __pyx_t_1 = (!(__pyx_v_self->data != 0));
  if (unlikely(__pyx_t_1)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":488
 *             sizeof(Complex64VectorData))
 *         if not self.data:
 *             raise MemoryError()             # <<<<<<<<<<<<<<
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 */
    PyErr_NoMemory(); __PYX_ERR(2, 488, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":487
 *         self.data = <Complex64VectorData *>PyMem_Malloc(
 *             sizeof(Complex64VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":489
 *         if not self.data:
 *             raise MemoryError()
 *         self.data.n = 0             # <<<<<<<<<<<<<<
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.complex64)
 */
  __pyx_v_self->data->n = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":490
 *             raise MemoryError()
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP             # <<<<<<<<<<<<<<
 *         self.ao = np.empty(self.data.m, dtype=np.complex64)
 *         self.data.data = <khcomplex64_t*>self.ao.data
 */
  __pyx_v_self->data->m = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;

  /* "pandas/_libs/hashtable_class_helper.pxi":491
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.complex64)             # <<<<<<<<<<<<<<
 *         self.data.data = <khcomplex64_t*>self.ao.data
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 491, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_complex64); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 491, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 491, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_6);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->ao);
  __Pyx_DECREF((PyObject *)__pyx_v_self->ao);
  __pyx_v_self->ao = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":492
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.complex64)
 *         self.data.data = <khcomplex64_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     cdef resize(self):
 */
  __pyx_t_6 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_6);
  __pyx_t_7 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_6)); if (unlikely(__pyx_t_7 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 492, __pyx_L1_error)
  __pyx_v_self->data->data = ((khcomplex64_t *)__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":484
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <Complex64VectorData *>PyMem_Malloc(
 *             sizeof(Complex64VectorData))
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64Vector.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":494
 *         self.data.data = <khcomplex64_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15Complex64Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  char *__pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("resize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":495
 * 
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)             # <<<<<<<<<<<<<<
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <khcomplex64_t*>self.ao.data
 */
  __pyx_t_1 = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;
  __pyx_t_2 = (__pyx_v_self->data->m * 4);
  __pyx_t_4 = (__pyx_t_1 > __pyx_t_2);
  if (__pyx_t_4) {
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_3 = __pyx_t_2;
  }
  __pyx_v_self->data->m = __pyx_t_3;

  /* "pandas/_libs/hashtable_class_helper.pxi":496
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)             # <<<<<<<<<<<<<<
 *         self.data.data = <khcomplex64_t*>self.ao.data
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6)) __PYX_ERR(2, 496, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 496, __pyx_L1_error)
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":497
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <khcomplex64_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_8 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_8);
  __pyx_t_9 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_8)); if (unlikely(__pyx_t_9 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 497, __pyx_L1_error)
  __pyx_v_self->data->data = ((khcomplex64_t *)__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":494
 *         self.data.data = <khcomplex64_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64Vector.resize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":499
 *         self.data.data = <khcomplex64_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_3__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_15Complex64Vector_2__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_15Complex64Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":500
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  __pyx_t_1 = (__pyx_v_self->data != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":501
 *     def __dealloc__(self):
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)             # <<<<<<<<<<<<<<
 *             self.data = NULL
 * 
 */
    PyMem_Free(__pyx_v_self->data);

    /* "pandas/_libs/hashtable_class_helper.pxi":502
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 *             self.data = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
    __pyx_v_self->data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":500
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":499
 *         self.data.data = <khcomplex64_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":504
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_5__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_5__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Complex64Vector_4__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_15Complex64Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_self) {
  Py_ssize_t __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":505
 * 
 *     def __len__(self) -> int:
 *         return self.data.n             # <<<<<<<<<<<<<<
 * 
 *     cpdef ndarray to_array(self):
 */
  __pyx_r = __pyx_v_self->data->n;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":504
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":507
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_15Complex64Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_self, int __pyx_skip_dispatch) {
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_to_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 507, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_7to_array)) {
        __Pyx_XDECREF((PyObject *)__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 507, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 507, __pyx_L1_error)
        __pyx_r = ((PyArrayObject *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":508
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  __pyx_t_6 = (__pyx_v_self->data->m != __pyx_v_self->data->n);
  if (__pyx_t_6) {

    /* "pandas/_libs/hashtable_class_helper.pxi":509
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":511
 *             if self.external_view_exists:
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")             # <<<<<<<<<<<<<<
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 511, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(2, 511, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":509
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":512
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)             # <<<<<<<<<<<<<<
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 512, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 512, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 512, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 512, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 512, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 512, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 512, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":513
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n             # <<<<<<<<<<<<<<
 *         self.external_view_exists = True
 *         return self.ao
 */
    __pyx_t_7 = __pyx_v_self->data->n;
    __pyx_v_self->data->m = __pyx_t_7;

    /* "pandas/_libs/hashtable_class_helper.pxi":508
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":514
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 *         self.external_view_exists = True             # <<<<<<<<<<<<<<
 *         return self.ao
 * 
 */
  __pyx_v_self->__pyx_base.external_view_exists = 1;

  /* "pandas/_libs/hashtable_class_helper.pxi":515
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 *         return self.ao             # <<<<<<<<<<<<<<
 * 
 *     cdef void append(self, khcomplex64_t x):
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->ao);
  __pyx_r = __pyx_v_self->ao;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":507
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15Complex64Vector_7to_array = {"to_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_7to_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("to_array", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "to_array", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Complex64Vector_6to_array(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Complex64Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_6pandas_5_libs_9hashtable_15Complex64Vector_to_array(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":517
 *         return self.ao
 * 
 *     cdef void append(self, khcomplex64_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

static void __pyx_f_6pandas_5_libs_9hashtable_15Complex64Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_self, khcomplex64_t __pyx_v_x) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("append", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":519
 *     cdef void append(self, khcomplex64_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  __pyx_t_1 = __pyx_fuse_11__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_self->data); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(2, 519, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":520
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":521
 *         if needs_resize(self.data):
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "             # <<<<<<<<<<<<<<
 *                                  "Vector.resize() needed")
 *             self.resize()
 */
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 521, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(2, 521, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":520
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":523
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 *             self.resize()             # <<<<<<<<<<<<<<
 * 
 *         append_data_complex64(self.data, x)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex64Vector *)__pyx_v_self->__pyx_vtab)->resize(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 523, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":519
 *     cdef void append(self, khcomplex64_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":525
 *             self.resize()
 * 
 *         append_data_complex64(self.data, x)             # <<<<<<<<<<<<<<
 * 
 *     cdef extend(self, const khcomplex64_t[:] x):
 */
  __pyx_f_6pandas_5_libs_9hashtable_append_data_complex64(__pyx_v_self->data, __pyx_v_x); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 525, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":517
 *         return self.ao
 * 
 *     cdef void append(self, khcomplex64_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64Vector.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "pandas/_libs/hashtable_class_helper.pxi":527
 *         append_data_complex64(self.data, x)
 * 
 *     cdef extend(self, const khcomplex64_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15Complex64Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x) {
  Py_ssize_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extend", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":528
 * 
 *     cdef extend(self, const khcomplex64_t[:] x):
 *         for i in range(len(x)):             # <<<<<<<<<<<<<<
 *             self.append(x[i])
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_x); 
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "pandas/_libs/hashtable_class_helper.pxi":529
 *     cdef extend(self, const khcomplex64_t[:] x):
 *         for i in range(len(x)):
 *             self.append(x[i])             # <<<<<<<<<<<<<<
 * 
 * cdef class Float64Vector(Vector):
 */
    __pyx_t_4 = __pyx_v_i;
    __pyx_t_5 = -1;
    if (__pyx_t_4 < 0) {
      __pyx_t_4 += __pyx_v_x.shape[0];
      if (unlikely(__pyx_t_4 < 0)) __pyx_t_5 = 0;
    } else if (unlikely(__pyx_t_4 >= __pyx_v_x.shape[0])) __pyx_t_5 = 0;
    if (unlikely(__pyx_t_5 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_5);
      __PYX_ERR(2, 529, __pyx_L1_error)
    }
    ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex64Vector *)__pyx_v_self->__pyx_vtab)->append(__pyx_v_self, (*((khcomplex64_t const  *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_4 * __pyx_v_x.strides[0]) )))); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 529, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":527
 *         append_data_complex64(self.data, x)
 * 
 *     cdef extend(self, const khcomplex64_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64Vector.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15Complex64Vector_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Complex64Vector_8__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Complex64Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64Vector.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15Complex64Vector_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Complex64Vector_10__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Complex64Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":539
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <Float64VectorData *>PyMem_Malloc(
 *             sizeof(Float64VectorData))
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Float64Vector___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_13Float64Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  char *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":540
 * 
 *     def __cinit__(self):
 *         self.data = <Float64VectorData *>PyMem_Malloc(             # <<<<<<<<<<<<<<
 *             sizeof(Float64VectorData))
 *         if not self.data:
 */
  __pyx_v_self->data = ((__pyx_t_6pandas_5_libs_9hashtable_Float64VectorData *)PyMem_Malloc((sizeof(__pyx_t_6pandas_5_libs_9hashtable_Float64VectorData))));

  /* "pandas/_libs/hashtable_class_helper.pxi":542
 *         self.data = <Float64VectorData *>PyMem_Malloc(
 *             sizeof(Float64VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  __pyx_t_1 = (!(__pyx_v_self->data != 0));
  if (unlikely(__pyx_t_1)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":543
 *             sizeof(Float64VectorData))
 *         if not self.data:
 *             raise MemoryError()             # <<<<<<<<<<<<<<
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 */
    PyErr_NoMemory(); __PYX_ERR(2, 543, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":542
 *         self.data = <Float64VectorData *>PyMem_Malloc(
 *             sizeof(Float64VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":544
 *         if not self.data:
 *             raise MemoryError()
 *         self.data.n = 0             # <<<<<<<<<<<<<<
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.float64)
 */
  __pyx_v_self->data->n = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":545
 *             raise MemoryError()
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP             # <<<<<<<<<<<<<<
 *         self.ao = np.empty(self.data.m, dtype=np.float64)
 *         self.data.data = <float64_t*>self.ao.data
 */
  __pyx_v_self->data->m = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;

  /* "pandas/_libs/hashtable_class_helper.pxi":546
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.float64)             # <<<<<<<<<<<<<<
 *         self.data.data = <float64_t*>self.ao.data
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 546, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_float64); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 546, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 546, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_6);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->ao);
  __Pyx_DECREF((PyObject *)__pyx_v_self->ao);
  __pyx_v_self->ao = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":547
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.float64)
 *         self.data.data = <float64_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     cdef resize(self):
 */
  __pyx_t_6 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_6);
  __pyx_t_7 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_6)); if (unlikely(__pyx_t_7 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 547, __pyx_L1_error)
  __pyx_v_self->data->data = ((__pyx_t_5numpy_float64_t *)__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":539
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <Float64VectorData *>PyMem_Malloc(
 *             sizeof(Float64VectorData))
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64Vector.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":549
 *         self.data.data = <float64_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_13Float64Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  char *__pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("resize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":550
 * 
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)             # <<<<<<<<<<<<<<
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <float64_t*>self.ao.data
 */
  __pyx_t_1 = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;
  __pyx_t_2 = (__pyx_v_self->data->m * 4);
  __pyx_t_4 = (__pyx_t_1 > __pyx_t_2);
  if (__pyx_t_4) {
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_3 = __pyx_t_2;
  }
  __pyx_v_self->data->m = __pyx_t_3;

  /* "pandas/_libs/hashtable_class_helper.pxi":551
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)             # <<<<<<<<<<<<<<
 *         self.data.data = <float64_t*>self.ao.data
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6)) __PYX_ERR(2, 551, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 551, __pyx_L1_error)
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":552
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <float64_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_8 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_8);
  __pyx_t_9 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_8)); if (unlikely(__pyx_t_9 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 552, __pyx_L1_error)
  __pyx_v_self->data->data = ((__pyx_t_5numpy_float64_t *)__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":549
 *         self.data.data = <float64_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64Vector.resize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":554
 *         self.data.data = <float64_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_3__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_13Float64Vector_2__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_13Float64Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":555
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  __pyx_t_1 = (__pyx_v_self->data != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":556
 *     def __dealloc__(self):
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)             # <<<<<<<<<<<<<<
 *             self.data = NULL
 * 
 */
    PyMem_Free(__pyx_v_self->data);

    /* "pandas/_libs/hashtable_class_helper.pxi":557
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 *             self.data = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
    __pyx_v_self->data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":555
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":554
 *         self.data.data = <float64_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":559
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_5__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_5__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Float64Vector_4__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_13Float64Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_self) {
  Py_ssize_t __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":560
 * 
 *     def __len__(self) -> int:
 *         return self.data.n             # <<<<<<<<<<<<<<
 * 
 *     cpdef ndarray to_array(self):
 */
  __pyx_r = __pyx_v_self->data->n;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":559
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":562
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_13Float64Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_self, int __pyx_skip_dispatch) {
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_to_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 562, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_7to_array)) {
        __Pyx_XDECREF((PyObject *)__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 562, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 562, __pyx_L1_error)
        __pyx_r = ((PyArrayObject *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":563
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  __pyx_t_6 = (__pyx_v_self->data->m != __pyx_v_self->data->n);
  if (__pyx_t_6) {

    /* "pandas/_libs/hashtable_class_helper.pxi":564
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":566
 *             if self.external_view_exists:
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")             # <<<<<<<<<<<<<<
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 566, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(2, 566, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":564
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":567
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)             # <<<<<<<<<<<<<<
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 567, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 567, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 567, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 567, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 567, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 567, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 567, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":568
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n             # <<<<<<<<<<<<<<
 *         self.external_view_exists = True
 *         return self.ao
 */
    __pyx_t_7 = __pyx_v_self->data->n;
    __pyx_v_self->data->m = __pyx_t_7;

    /* "pandas/_libs/hashtable_class_helper.pxi":563
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":569
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 *         self.external_view_exists = True             # <<<<<<<<<<<<<<
 *         return self.ao
 * 
 */
  __pyx_v_self->__pyx_base.external_view_exists = 1;

  /* "pandas/_libs/hashtable_class_helper.pxi":570
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 *         return self.ao             # <<<<<<<<<<<<<<
 * 
 *     cdef void append(self, float64_t x):
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->ao);
  __pyx_r = __pyx_v_self->ao;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":562
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_13Float64Vector_7to_array = {"to_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_7to_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("to_array", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "to_array", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Float64Vector_6to_array(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Float64Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_6pandas_5_libs_9hashtable_13Float64Vector_to_array(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":572
 *         return self.ao
 * 
 *     cdef void append(self, float64_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

static void __pyx_f_6pandas_5_libs_9hashtable_13Float64Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_self, __pyx_t_5numpy_float64_t __pyx_v_x) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("append", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":574
 *     cdef void append(self, float64_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  __pyx_t_1 = __pyx_fuse_8__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_self->data); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(2, 574, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":575
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":576
 *         if needs_resize(self.data):
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "             # <<<<<<<<<<<<<<
 *                                  "Vector.resize() needed")
 *             self.resize()
 */
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 576, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(2, 576, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":575
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":578
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 *             self.resize()             # <<<<<<<<<<<<<<
 * 
 *         append_data_float64(self.data, x)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float64Vector *)__pyx_v_self->__pyx_vtab)->resize(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 578, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":574
 *     cdef void append(self, float64_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":580
 *             self.resize()
 * 
 *         append_data_float64(self.data, x)             # <<<<<<<<<<<<<<
 * 
 *     cdef extend(self, const float64_t[:] x):
 */
  __pyx_f_6pandas_5_libs_9hashtable_append_data_float64(__pyx_v_self->data, __pyx_v_x); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 580, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":572
 *         return self.ao
 * 
 *     cdef void append(self, float64_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64Vector.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "pandas/_libs/hashtable_class_helper.pxi":582
 *         append_data_float64(self.data, x)
 * 
 *     cdef extend(self, const float64_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_13Float64Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x) {
  Py_ssize_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extend", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":583
 * 
 *     cdef extend(self, const float64_t[:] x):
 *         for i in range(len(x)):             # <<<<<<<<<<<<<<
 *             self.append(x[i])
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_x); 
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "pandas/_libs/hashtable_class_helper.pxi":584
 *     cdef extend(self, const float64_t[:] x):
 *         for i in range(len(x)):
 *             self.append(x[i])             # <<<<<<<<<<<<<<
 * 
 * cdef class UInt64Vector(Vector):
 */
    __pyx_t_4 = __pyx_v_i;
    __pyx_t_5 = -1;
    if (__pyx_t_4 < 0) {
      __pyx_t_4 += __pyx_v_x.shape[0];
      if (unlikely(__pyx_t_4 < 0)) __pyx_t_5 = 0;
    } else if (unlikely(__pyx_t_4 >= __pyx_v_x.shape[0])) __pyx_t_5 = 0;
    if (unlikely(__pyx_t_5 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_5);
      __PYX_ERR(2, 584, __pyx_L1_error)
    }
    ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float64Vector *)__pyx_v_self->__pyx_vtab)->append(__pyx_v_self, (*((__pyx_t_5numpy_float64_t const  *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_4 * __pyx_v_x.strides[0]) )))); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 584, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":582
 *         append_data_float64(self.data, x)
 * 
 *     cdef extend(self, const float64_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64Vector.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_13Float64Vector_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Float64Vector_8__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Float64Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64Vector.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_13Float64Vector_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Float64Vector_10__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Float64Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":594
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <UInt64VectorData *>PyMem_Malloc(
 *             sizeof(UInt64VectorData))
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12UInt64Vector___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_12UInt64Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  char *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":595
 * 
 *     def __cinit__(self):
 *         self.data = <UInt64VectorData *>PyMem_Malloc(             # <<<<<<<<<<<<<<
 *             sizeof(UInt64VectorData))
 *         if not self.data:
 */
  __pyx_v_self->data = ((__pyx_t_6pandas_5_libs_9hashtable_UInt64VectorData *)PyMem_Malloc((sizeof(__pyx_t_6pandas_5_libs_9hashtable_UInt64VectorData))));

  /* "pandas/_libs/hashtable_class_helper.pxi":597
 *         self.data = <UInt64VectorData *>PyMem_Malloc(
 *             sizeof(UInt64VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  __pyx_t_1 = (!(__pyx_v_self->data != 0));
  if (unlikely(__pyx_t_1)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":598
 *             sizeof(UInt64VectorData))
 *         if not self.data:
 *             raise MemoryError()             # <<<<<<<<<<<<<<
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 */
    PyErr_NoMemory(); __PYX_ERR(2, 598, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":597
 *         self.data = <UInt64VectorData *>PyMem_Malloc(
 *             sizeof(UInt64VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":599
 *         if not self.data:
 *             raise MemoryError()
 *         self.data.n = 0             # <<<<<<<<<<<<<<
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.uint64)
 */
  __pyx_v_self->data->n = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":600
 *             raise MemoryError()
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP             # <<<<<<<<<<<<<<
 *         self.ao = np.empty(self.data.m, dtype=np.uint64)
 *         self.data.data = <uint64_t*>self.ao.data
 */
  __pyx_v_self->data->m = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;

  /* "pandas/_libs/hashtable_class_helper.pxi":601
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.uint64)             # <<<<<<<<<<<<<<
 *         self.data.data = <uint64_t*>self.ao.data
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 601, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_uint64); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 601, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 601, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_6);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->ao);
  __Pyx_DECREF((PyObject *)__pyx_v_self->ao);
  __pyx_v_self->ao = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":602
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.uint64)
 *         self.data.data = <uint64_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     cdef resize(self):
 */
  __pyx_t_6 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_6);
  __pyx_t_7 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_6)); if (unlikely(__pyx_t_7 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 602, __pyx_L1_error)
  __pyx_v_self->data->data = ((__pyx_t_5numpy_uint64_t *)__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":594
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <UInt64VectorData *>PyMem_Malloc(
 *             sizeof(UInt64VectorData))
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64Vector.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":604
 *         self.data.data = <uint64_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_12UInt64Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  char *__pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("resize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":605
 * 
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)             # <<<<<<<<<<<<<<
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <uint64_t*>self.ao.data
 */
  __pyx_t_1 = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;
  __pyx_t_2 = (__pyx_v_self->data->m * 4);
  __pyx_t_4 = (__pyx_t_1 > __pyx_t_2);
  if (__pyx_t_4) {
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_3 = __pyx_t_2;
  }
  __pyx_v_self->data->m = __pyx_t_3;

  /* "pandas/_libs/hashtable_class_helper.pxi":606
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)             # <<<<<<<<<<<<<<
 *         self.data.data = <uint64_t*>self.ao.data
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6)) __PYX_ERR(2, 606, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 606, __pyx_L1_error)
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":607
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <uint64_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_8 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_8);
  __pyx_t_9 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_8)); if (unlikely(__pyx_t_9 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 607, __pyx_L1_error)
  __pyx_v_self->data->data = ((__pyx_t_5numpy_uint64_t *)__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":604
 *         self.data.data = <uint64_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64Vector.resize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":609
 *         self.data.data = <uint64_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_3__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_12UInt64Vector_2__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_12UInt64Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":610
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  __pyx_t_1 = (__pyx_v_self->data != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":611
 *     def __dealloc__(self):
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)             # <<<<<<<<<<<<<<
 *             self.data = NULL
 * 
 */
    PyMem_Free(__pyx_v_self->data);

    /* "pandas/_libs/hashtable_class_helper.pxi":612
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 *             self.data = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
    __pyx_v_self->data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":610
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":609
 *         self.data.data = <uint64_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":614
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_5__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_5__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12UInt64Vector_4__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_12UInt64Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_self) {
  Py_ssize_t __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":615
 * 
 *     def __len__(self) -> int:
 *         return self.data.n             # <<<<<<<<<<<<<<
 * 
 *     cpdef ndarray to_array(self):
 */
  __pyx_r = __pyx_v_self->data->n;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":614
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":617
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_12UInt64Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_self, int __pyx_skip_dispatch) {
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_to_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 617, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_7to_array)) {
        __Pyx_XDECREF((PyObject *)__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 617, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 617, __pyx_L1_error)
        __pyx_r = ((PyArrayObject *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":618
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  __pyx_t_6 = (__pyx_v_self->data->m != __pyx_v_self->data->n);
  if (__pyx_t_6) {

    /* "pandas/_libs/hashtable_class_helper.pxi":619
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":621
 *             if self.external_view_exists:
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")             # <<<<<<<<<<<<<<
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 621, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(2, 621, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":619
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":622
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)             # <<<<<<<<<<<<<<
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 622, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 622, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 622, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 622, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 622, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 622, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 622, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":623
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n             # <<<<<<<<<<<<<<
 *         self.external_view_exists = True
 *         return self.ao
 */
    __pyx_t_7 = __pyx_v_self->data->n;
    __pyx_v_self->data->m = __pyx_t_7;

    /* "pandas/_libs/hashtable_class_helper.pxi":618
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":624
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 *         self.external_view_exists = True             # <<<<<<<<<<<<<<
 *         return self.ao
 * 
 */
  __pyx_v_self->__pyx_base.external_view_exists = 1;

  /* "pandas/_libs/hashtable_class_helper.pxi":625
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 *         return self.ao             # <<<<<<<<<<<<<<
 * 
 *     cdef void append(self, uint64_t x):
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->ao);
  __pyx_r = __pyx_v_self->ao;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":617
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_12UInt64Vector_7to_array = {"to_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_7to_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("to_array", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "to_array", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12UInt64Vector_6to_array(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12UInt64Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_6pandas_5_libs_9hashtable_12UInt64Vector_to_array(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":627
 *         return self.ao
 * 
 *     cdef void append(self, uint64_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

static void __pyx_f_6pandas_5_libs_9hashtable_12UInt64Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_self, __pyx_t_5numpy_uint64_t __pyx_v_x) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("append", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":629
 *     cdef void append(self, uint64_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  __pyx_t_1 = __pyx_fuse_4__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_self->data); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(2, 629, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":630
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":631
 *         if needs_resize(self.data):
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "             # <<<<<<<<<<<<<<
 *                                  "Vector.resize() needed")
 *             self.resize()
 */
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 631, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(2, 631, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":630
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":633
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 *             self.resize()             # <<<<<<<<<<<<<<
 * 
 *         append_data_uint64(self.data, x)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt64Vector *)__pyx_v_self->__pyx_vtab)->resize(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":629
 *     cdef void append(self, uint64_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":635
 *             self.resize()
 * 
 *         append_data_uint64(self.data, x)             # <<<<<<<<<<<<<<
 * 
 *     cdef extend(self, const uint64_t[:] x):
 */
  __pyx_f_6pandas_5_libs_9hashtable_append_data_uint64(__pyx_v_self->data, __pyx_v_x); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 635, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":627
 *         return self.ao
 * 
 *     cdef void append(self, uint64_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64Vector.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "pandas/_libs/hashtable_class_helper.pxi":637
 *         append_data_uint64(self.data, x)
 * 
 *     cdef extend(self, const uint64_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_12UInt64Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x) {
  Py_ssize_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extend", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":638
 * 
 *     cdef extend(self, const uint64_t[:] x):
 *         for i in range(len(x)):             # <<<<<<<<<<<<<<
 *             self.append(x[i])
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_x); 
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "pandas/_libs/hashtable_class_helper.pxi":639
 *     cdef extend(self, const uint64_t[:] x):
 *         for i in range(len(x)):
 *             self.append(x[i])             # <<<<<<<<<<<<<<
 * 
 * cdef class Int64Vector(Vector):
 */
    __pyx_t_4 = __pyx_v_i;
    __pyx_t_5 = -1;
    if (__pyx_t_4 < 0) {
      __pyx_t_4 += __pyx_v_x.shape[0];
      if (unlikely(__pyx_t_4 < 0)) __pyx_t_5 = 0;
    } else if (unlikely(__pyx_t_4 >= __pyx_v_x.shape[0])) __pyx_t_5 = 0;
    if (unlikely(__pyx_t_5 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_5);
      __PYX_ERR(2, 639, __pyx_L1_error)
    }
    ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt64Vector *)__pyx_v_self->__pyx_vtab)->append(__pyx_v_self, (*((__pyx_t_5numpy_uint64_t const  *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_4 * __pyx_v_x.strides[0]) )))); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 639, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":637
 *         append_data_uint64(self.data, x)
 * 
 *     cdef extend(self, const uint64_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64Vector.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_12UInt64Vector_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12UInt64Vector_8__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12UInt64Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64Vector.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_12UInt64Vector_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12UInt64Vector_10__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12UInt64Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":646
 *     # Int64Vector is the only one we need exposed for other cython files.
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <Int64VectorData *>PyMem_Malloc(
 *             sizeof(Int64VectorData))
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_11Int64Vector___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_11Int64Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  char *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":647
 * 
 *     def __cinit__(self):
 *         self.data = <Int64VectorData *>PyMem_Malloc(             # <<<<<<<<<<<<<<
 *             sizeof(Int64VectorData))
 *         if not self.data:
 */
  __pyx_v_self->data = ((struct __pyx_t_6pandas_5_libs_9hashtable_Int64VectorData *)PyMem_Malloc((sizeof(struct __pyx_t_6pandas_5_libs_9hashtable_Int64VectorData))));

  /* "pandas/_libs/hashtable_class_helper.pxi":649
 *         self.data = <Int64VectorData *>PyMem_Malloc(
 *             sizeof(Int64VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  __pyx_t_1 = (!(__pyx_v_self->data != 0));
  if (unlikely(__pyx_t_1)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":650
 *             sizeof(Int64VectorData))
 *         if not self.data:
 *             raise MemoryError()             # <<<<<<<<<<<<<<
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 */
    PyErr_NoMemory(); __PYX_ERR(2, 650, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":649
 *         self.data = <Int64VectorData *>PyMem_Malloc(
 *             sizeof(Int64VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":651
 *         if not self.data:
 *             raise MemoryError()
 *         self.data.n = 0             # <<<<<<<<<<<<<<
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.int64)
 */
  __pyx_v_self->data->n = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":652
 *             raise MemoryError()
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP             # <<<<<<<<<<<<<<
 *         self.ao = np.empty(self.data.m, dtype=np.int64)
 *         self.data.data = <int64_t*>self.ao.data
 */
  __pyx_v_self->data->m = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;

  /* "pandas/_libs/hashtable_class_helper.pxi":653
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.int64)             # <<<<<<<<<<<<<<
 *         self.data.data = <int64_t*>self.ao.data
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 653, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_int64); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 653, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_6);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->ao);
  __Pyx_DECREF((PyObject *)__pyx_v_self->ao);
  __pyx_v_self->ao = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":654
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.int64)
 *         self.data.data = <int64_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     cdef resize(self):
 */
  __pyx_t_6 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_6);
  __pyx_t_7 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_6)); if (unlikely(__pyx_t_7 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 654, __pyx_L1_error)
  __pyx_v_self->data->data = ((__pyx_t_5numpy_int64_t *)__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":646
 *     # Int64Vector is the only one we need exposed for other cython files.
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <Int64VectorData *>PyMem_Malloc(
 *             sizeof(Int64VectorData))
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64Vector.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":656
 *         self.data.data = <int64_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_11Int64Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  char *__pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("resize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":657
 * 
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)             # <<<<<<<<<<<<<<
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <int64_t*>self.ao.data
 */
  __pyx_t_1 = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;
  __pyx_t_2 = (__pyx_v_self->data->m * 4);
  __pyx_t_4 = (__pyx_t_1 > __pyx_t_2);
  if (__pyx_t_4) {
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_3 = __pyx_t_2;
  }
  __pyx_v_self->data->m = __pyx_t_3;

  /* "pandas/_libs/hashtable_class_helper.pxi":658
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)             # <<<<<<<<<<<<<<
 *         self.data.data = <int64_t*>self.ao.data
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6)) __PYX_ERR(2, 658, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 658, __pyx_L1_error)
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 658, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":659
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <int64_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_8 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_8);
  __pyx_t_9 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_8)); if (unlikely(__pyx_t_9 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 659, __pyx_L1_error)
  __pyx_v_self->data->data = ((__pyx_t_5numpy_int64_t *)__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":656
 *         self.data.data = <int64_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64Vector.resize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":661
 *         self.data.data = <int64_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_3__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_11Int64Vector_2__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_11Int64Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":662
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  __pyx_t_1 = (__pyx_v_self->data != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":663
 *     def __dealloc__(self):
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)             # <<<<<<<<<<<<<<
 *             self.data = NULL
 * 
 */
    PyMem_Free(__pyx_v_self->data);

    /* "pandas/_libs/hashtable_class_helper.pxi":664
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 *             self.data = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
    __pyx_v_self->data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":662
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":661
 *         self.data.data = <int64_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":666
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_5__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_5__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_11Int64Vector_4__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_11Int64Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_self) {
  Py_ssize_t __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":667
 * 
 *     def __len__(self) -> int:
 *         return self.data.n             # <<<<<<<<<<<<<<
 * 
 *     cpdef ndarray to_array(self):
 */
  __pyx_r = __pyx_v_self->data->n;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":666
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":669
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_11Int64Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_self, int __pyx_skip_dispatch) {
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_to_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 669, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_7to_array)) {
        __Pyx_XDECREF((PyObject *)__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 669, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 669, __pyx_L1_error)
        __pyx_r = ((PyArrayObject *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":670
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  __pyx_t_6 = (__pyx_v_self->data->m != __pyx_v_self->data->n);
  if (__pyx_t_6) {

    /* "pandas/_libs/hashtable_class_helper.pxi":671
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":673
 *             if self.external_view_exists:
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")             # <<<<<<<<<<<<<<
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 673, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(2, 673, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":671
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":674
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)             # <<<<<<<<<<<<<<
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 674, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 674, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 674, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 674, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 674, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 674, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 674, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":675
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n             # <<<<<<<<<<<<<<
 *         self.external_view_exists = True
 *         return self.ao
 */
    __pyx_t_7 = __pyx_v_self->data->n;
    __pyx_v_self->data->m = __pyx_t_7;

    /* "pandas/_libs/hashtable_class_helper.pxi":670
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":676
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 *         self.external_view_exists = True             # <<<<<<<<<<<<<<
 *         return self.ao
 * 
 */
  __pyx_v_self->__pyx_base.external_view_exists = 1;

  /* "pandas/_libs/hashtable_class_helper.pxi":677
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 *         return self.ao             # <<<<<<<<<<<<<<
 * 
 *     cdef void append(self, int64_t x):
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->ao);
  __pyx_r = __pyx_v_self->ao;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":669
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_11Int64Vector_7to_array = {"to_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_7to_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("to_array", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "to_array", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_11Int64Vector_6to_array(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11Int64Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_6pandas_5_libs_9hashtable_11Int64Vector_to_array(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":679
 *         return self.ao
 * 
 *     cdef void append(self, int64_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

static void __pyx_f_6pandas_5_libs_9hashtable_11Int64Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_x) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("append", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":681
 *     cdef void append(self, int64_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  __pyx_t_1 = __pyx_fuse_0__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_self->data); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(2, 681, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":682
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":683
 *         if needs_resize(self.data):
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "             # <<<<<<<<<<<<<<
 *                                  "Vector.resize() needed")
 *             self.resize()
 */
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 683, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(2, 683, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":682
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":685
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 *             self.resize()             # <<<<<<<<<<<<<<
 * 
 *         append_data_int64(self.data, x)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_v_self->__pyx_vtab)->resize(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 685, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":681
 *     cdef void append(self, int64_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":687
 *             self.resize()
 * 
 *         append_data_int64(self.data, x)             # <<<<<<<<<<<<<<
 * 
 *     cdef extend(self, const int64_t[:] x):
 */
  __pyx_f_6pandas_5_libs_9hashtable_append_data_int64(__pyx_v_self->data, __pyx_v_x); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 687, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":679
 *         return self.ao
 * 
 *     cdef void append(self, int64_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64Vector.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "pandas/_libs/hashtable_class_helper.pxi":689
 *         append_data_int64(self.data, x)
 * 
 *     cdef extend(self, const int64_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_11Int64Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x) {
  Py_ssize_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extend", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":690
 * 
 *     cdef extend(self, const int64_t[:] x):
 *         for i in range(len(x)):             # <<<<<<<<<<<<<<
 *             self.append(x[i])
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_x); 
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "pandas/_libs/hashtable_class_helper.pxi":691
 *     cdef extend(self, const int64_t[:] x):
 *         for i in range(len(x)):
 *             self.append(x[i])             # <<<<<<<<<<<<<<
 * 
 * cdef class Float32Vector(Vector):
 */
    __pyx_t_4 = __pyx_v_i;
    __pyx_t_5 = -1;
    if (__pyx_t_4 < 0) {
      __pyx_t_4 += __pyx_v_x.shape[0];
      if (unlikely(__pyx_t_4 < 0)) __pyx_t_5 = 0;
    } else if (unlikely(__pyx_t_4 >= __pyx_v_x.shape[0])) __pyx_t_5 = 0;
    if (unlikely(__pyx_t_5 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_5);
      __PYX_ERR(2, 691, __pyx_L1_error)
    }
    ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_v_self->__pyx_vtab)->append(__pyx_v_self, (*((__pyx_t_5numpy_int64_t const  *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_4 * __pyx_v_x.strides[0]) )))); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 691, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":689
 *         append_data_int64(self.data, x)
 * 
 *     cdef extend(self, const int64_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64Vector.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_11Int64Vector_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_11Int64Vector_8__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11Int64Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64Vector.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_11Int64Vector_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_11Int64Vector_10__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11Int64Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":701
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <Float32VectorData *>PyMem_Malloc(
 *             sizeof(Float32VectorData))
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Float32Vector___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_13Float32Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  char *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":702
 * 
 *     def __cinit__(self):
 *         self.data = <Float32VectorData *>PyMem_Malloc(             # <<<<<<<<<<<<<<
 *             sizeof(Float32VectorData))
 *         if not self.data:
 */
  __pyx_v_self->data = ((__pyx_t_6pandas_5_libs_9hashtable_Float32VectorData *)PyMem_Malloc((sizeof(__pyx_t_6pandas_5_libs_9hashtable_Float32VectorData))));

  /* "pandas/_libs/hashtable_class_helper.pxi":704
 *         self.data = <Float32VectorData *>PyMem_Malloc(
 *             sizeof(Float32VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  __pyx_t_1 = (!(__pyx_v_self->data != 0));
  if (unlikely(__pyx_t_1)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":705
 *             sizeof(Float32VectorData))
 *         if not self.data:
 *             raise MemoryError()             # <<<<<<<<<<<<<<
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 */
    PyErr_NoMemory(); __PYX_ERR(2, 705, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":704
 *         self.data = <Float32VectorData *>PyMem_Malloc(
 *             sizeof(Float32VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":706
 *         if not self.data:
 *             raise MemoryError()
 *         self.data.n = 0             # <<<<<<<<<<<<<<
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.float32)
 */
  __pyx_v_self->data->n = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":707
 *             raise MemoryError()
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP             # <<<<<<<<<<<<<<
 *         self.ao = np.empty(self.data.m, dtype=np.float32)
 *         self.data.data = <float32_t*>self.ao.data
 */
  __pyx_v_self->data->m = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;

  /* "pandas/_libs/hashtable_class_helper.pxi":708
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.float32)             # <<<<<<<<<<<<<<
 *         self.data.data = <float32_t*>self.ao.data
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 708, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_float32); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 708, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 708, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_6);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->ao);
  __Pyx_DECREF((PyObject *)__pyx_v_self->ao);
  __pyx_v_self->ao = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":709
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.float32)
 *         self.data.data = <float32_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     cdef resize(self):
 */
  __pyx_t_6 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_6);
  __pyx_t_7 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_6)); if (unlikely(__pyx_t_7 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 709, __pyx_L1_error)
  __pyx_v_self->data->data = ((__pyx_t_5numpy_float32_t *)__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":701
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <Float32VectorData *>PyMem_Malloc(
 *             sizeof(Float32VectorData))
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32Vector.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":711
 *         self.data.data = <float32_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_13Float32Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  char *__pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("resize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":712
 * 
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)             # <<<<<<<<<<<<<<
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <float32_t*>self.ao.data
 */
  __pyx_t_1 = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;
  __pyx_t_2 = (__pyx_v_self->data->m * 4);
  __pyx_t_4 = (__pyx_t_1 > __pyx_t_2);
  if (__pyx_t_4) {
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_3 = __pyx_t_2;
  }
  __pyx_v_self->data->m = __pyx_t_3;

  /* "pandas/_libs/hashtable_class_helper.pxi":713
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)             # <<<<<<<<<<<<<<
 *         self.data.data = <float32_t*>self.ao.data
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6)) __PYX_ERR(2, 713, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 713, __pyx_L1_error)
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":714
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <float32_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_8 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_8);
  __pyx_t_9 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_8)); if (unlikely(__pyx_t_9 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 714, __pyx_L1_error)
  __pyx_v_self->data->data = ((__pyx_t_5numpy_float32_t *)__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":711
 *         self.data.data = <float32_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32Vector.resize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":716
 *         self.data.data = <float32_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_3__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_13Float32Vector_2__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_13Float32Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":717
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  __pyx_t_1 = (__pyx_v_self->data != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":718
 *     def __dealloc__(self):
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)             # <<<<<<<<<<<<<<
 *             self.data = NULL
 * 
 */
    PyMem_Free(__pyx_v_self->data);

    /* "pandas/_libs/hashtable_class_helper.pxi":719
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 *             self.data = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
    __pyx_v_self->data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":717
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":716
 *         self.data.data = <float32_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":721
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_5__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_5__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Float32Vector_4__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_13Float32Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_self) {
  Py_ssize_t __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":722
 * 
 *     def __len__(self) -> int:
 *         return self.data.n             # <<<<<<<<<<<<<<
 * 
 *     cpdef ndarray to_array(self):
 */
  __pyx_r = __pyx_v_self->data->n;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":721
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":724
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_13Float32Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_self, int __pyx_skip_dispatch) {
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_to_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 724, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_7to_array)) {
        __Pyx_XDECREF((PyObject *)__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 724, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 724, __pyx_L1_error)
        __pyx_r = ((PyArrayObject *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":725
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  __pyx_t_6 = (__pyx_v_self->data->m != __pyx_v_self->data->n);
  if (__pyx_t_6) {

    /* "pandas/_libs/hashtable_class_helper.pxi":726
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":728
 *             if self.external_view_exists:
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")             # <<<<<<<<<<<<<<
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 728, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(2, 728, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":726
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":729
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)             # <<<<<<<<<<<<<<
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 729, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 729, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 729, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 729, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 729, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 729, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 729, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":730
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n             # <<<<<<<<<<<<<<
 *         self.external_view_exists = True
 *         return self.ao
 */
    __pyx_t_7 = __pyx_v_self->data->n;
    __pyx_v_self->data->m = __pyx_t_7;

    /* "pandas/_libs/hashtable_class_helper.pxi":725
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":731
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 *         self.external_view_exists = True             # <<<<<<<<<<<<<<
 *         return self.ao
 * 
 */
  __pyx_v_self->__pyx_base.external_view_exists = 1;

  /* "pandas/_libs/hashtable_class_helper.pxi":732
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 *         return self.ao             # <<<<<<<<<<<<<<
 * 
 *     cdef void append(self, float32_t x):
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->ao);
  __pyx_r = __pyx_v_self->ao;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":724
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_13Float32Vector_7to_array = {"to_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_7to_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("to_array", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "to_array", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Float32Vector_6to_array(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Float32Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_6pandas_5_libs_9hashtable_13Float32Vector_to_array(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":734
 *         return self.ao
 * 
 *     cdef void append(self, float32_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

static void __pyx_f_6pandas_5_libs_9hashtable_13Float32Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_self, __pyx_t_5numpy_float32_t __pyx_v_x) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("append", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":736
 *     cdef void append(self, float32_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  __pyx_t_1 = __pyx_fuse_9__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_self->data); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(2, 736, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":737
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":738
 *         if needs_resize(self.data):
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "             # <<<<<<<<<<<<<<
 *                                  "Vector.resize() needed")
 *             self.resize()
 */
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 738, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(2, 738, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":737
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":740
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 *             self.resize()             # <<<<<<<<<<<<<<
 * 
 *         append_data_float32(self.data, x)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float32Vector *)__pyx_v_self->__pyx_vtab)->resize(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 740, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":736
 *     cdef void append(self, float32_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":742
 *             self.resize()
 * 
 *         append_data_float32(self.data, x)             # <<<<<<<<<<<<<<
 * 
 *     cdef extend(self, const float32_t[:] x):
 */
  __pyx_f_6pandas_5_libs_9hashtable_append_data_float32(__pyx_v_self->data, __pyx_v_x); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 742, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":734
 *         return self.ao
 * 
 *     cdef void append(self, float32_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32Vector.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "pandas/_libs/hashtable_class_helper.pxi":744
 *         append_data_float32(self.data, x)
 * 
 *     cdef extend(self, const float32_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_13Float32Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x) {
  Py_ssize_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extend", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":745
 * 
 *     cdef extend(self, const float32_t[:] x):
 *         for i in range(len(x)):             # <<<<<<<<<<<<<<
 *             self.append(x[i])
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_x); 
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "pandas/_libs/hashtable_class_helper.pxi":746
 *     cdef extend(self, const float32_t[:] x):
 *         for i in range(len(x)):
 *             self.append(x[i])             # <<<<<<<<<<<<<<
 * 
 * cdef class UInt32Vector(Vector):
 */
    __pyx_t_4 = __pyx_v_i;
    __pyx_t_5 = -1;
    if (__pyx_t_4 < 0) {
      __pyx_t_4 += __pyx_v_x.shape[0];
      if (unlikely(__pyx_t_4 < 0)) __pyx_t_5 = 0;
    } else if (unlikely(__pyx_t_4 >= __pyx_v_x.shape[0])) __pyx_t_5 = 0;
    if (unlikely(__pyx_t_5 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_5);
      __PYX_ERR(2, 746, __pyx_L1_error)
    }
    ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float32Vector *)__pyx_v_self->__pyx_vtab)->append(__pyx_v_self, (*((__pyx_t_5numpy_float32_t const  *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_4 * __pyx_v_x.strides[0]) )))); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 746, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":744
 *         append_data_float32(self.data, x)
 * 
 *     cdef extend(self, const float32_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32Vector.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_13Float32Vector_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Float32Vector_8__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Float32Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32Vector.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_13Float32Vector_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Float32Vector_10__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Float32Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":756
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <UInt32VectorData *>PyMem_Malloc(
 *             sizeof(UInt32VectorData))
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12UInt32Vector___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_12UInt32Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  char *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":757
 * 
 *     def __cinit__(self):
 *         self.data = <UInt32VectorData *>PyMem_Malloc(             # <<<<<<<<<<<<<<
 *             sizeof(UInt32VectorData))
 *         if not self.data:
 */
  __pyx_v_self->data = ((__pyx_t_6pandas_5_libs_9hashtable_UInt32VectorData *)PyMem_Malloc((sizeof(__pyx_t_6pandas_5_libs_9hashtable_UInt32VectorData))));

  /* "pandas/_libs/hashtable_class_helper.pxi":759
 *         self.data = <UInt32VectorData *>PyMem_Malloc(
 *             sizeof(UInt32VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  __pyx_t_1 = (!(__pyx_v_self->data != 0));
  if (unlikely(__pyx_t_1)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":760
 *             sizeof(UInt32VectorData))
 *         if not self.data:
 *             raise MemoryError()             # <<<<<<<<<<<<<<
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 */
    PyErr_NoMemory(); __PYX_ERR(2, 760, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":759
 *         self.data = <UInt32VectorData *>PyMem_Malloc(
 *             sizeof(UInt32VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":761
 *         if not self.data:
 *             raise MemoryError()
 *         self.data.n = 0             # <<<<<<<<<<<<<<
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.uint32)
 */
  __pyx_v_self->data->n = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":762
 *             raise MemoryError()
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP             # <<<<<<<<<<<<<<
 *         self.ao = np.empty(self.data.m, dtype=np.uint32)
 *         self.data.data = <uint32_t*>self.ao.data
 */
  __pyx_v_self->data->m = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;

  /* "pandas/_libs/hashtable_class_helper.pxi":763
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.uint32)             # <<<<<<<<<<<<<<
 *         self.data.data = <uint32_t*>self.ao.data
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 763, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_uint32); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 763, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 763, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_6);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->ao);
  __Pyx_DECREF((PyObject *)__pyx_v_self->ao);
  __pyx_v_self->ao = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":764
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.uint32)
 *         self.data.data = <uint32_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     cdef resize(self):
 */
  __pyx_t_6 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_6);
  __pyx_t_7 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_6)); if (unlikely(__pyx_t_7 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 764, __pyx_L1_error)
  __pyx_v_self->data->data = ((__pyx_t_5numpy_uint32_t *)__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":756
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <UInt32VectorData *>PyMem_Malloc(
 *             sizeof(UInt32VectorData))
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32Vector.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":766
 *         self.data.data = <uint32_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_12UInt32Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  char *__pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("resize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":767
 * 
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)             # <<<<<<<<<<<<<<
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <uint32_t*>self.ao.data
 */
  __pyx_t_1 = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;
  __pyx_t_2 = (__pyx_v_self->data->m * 4);
  __pyx_t_4 = (__pyx_t_1 > __pyx_t_2);
  if (__pyx_t_4) {
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_3 = __pyx_t_2;
  }
  __pyx_v_self->data->m = __pyx_t_3;

  /* "pandas/_libs/hashtable_class_helper.pxi":768
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)             # <<<<<<<<<<<<<<
 *         self.data.data = <uint32_t*>self.ao.data
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6)) __PYX_ERR(2, 768, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 768, __pyx_L1_error)
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":769
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <uint32_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_8 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_8);
  __pyx_t_9 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_8)); if (unlikely(__pyx_t_9 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 769, __pyx_L1_error)
  __pyx_v_self->data->data = ((__pyx_t_5numpy_uint32_t *)__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":766
 *         self.data.data = <uint32_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32Vector.resize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":771
 *         self.data.data = <uint32_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_3__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_12UInt32Vector_2__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_12UInt32Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":772
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  __pyx_t_1 = (__pyx_v_self->data != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":773
 *     def __dealloc__(self):
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)             # <<<<<<<<<<<<<<
 *             self.data = NULL
 * 
 */
    PyMem_Free(__pyx_v_self->data);

    /* "pandas/_libs/hashtable_class_helper.pxi":774
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 *             self.data = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
    __pyx_v_self->data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":772
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":771
 *         self.data.data = <uint32_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":776
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_5__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_5__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12UInt32Vector_4__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_12UInt32Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_self) {
  Py_ssize_t __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":777
 * 
 *     def __len__(self) -> int:
 *         return self.data.n             # <<<<<<<<<<<<<<
 * 
 *     cpdef ndarray to_array(self):
 */
  __pyx_r = __pyx_v_self->data->n;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":776
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":779
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_12UInt32Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_self, int __pyx_skip_dispatch) {
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_to_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 779, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_7to_array)) {
        __Pyx_XDECREF((PyObject *)__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 779, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 779, __pyx_L1_error)
        __pyx_r = ((PyArrayObject *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":780
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  __pyx_t_6 = (__pyx_v_self->data->m != __pyx_v_self->data->n);
  if (__pyx_t_6) {

    /* "pandas/_libs/hashtable_class_helper.pxi":781
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":783
 *             if self.external_view_exists:
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")             # <<<<<<<<<<<<<<
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 783, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(2, 783, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":781
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":784
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)             # <<<<<<<<<<<<<<
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 784, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 784, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 784, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 784, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 784, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 784, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 784, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":785
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n             # <<<<<<<<<<<<<<
 *         self.external_view_exists = True
 *         return self.ao
 */
    __pyx_t_7 = __pyx_v_self->data->n;
    __pyx_v_self->data->m = __pyx_t_7;

    /* "pandas/_libs/hashtable_class_helper.pxi":780
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":786
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 *         self.external_view_exists = True             # <<<<<<<<<<<<<<
 *         return self.ao
 * 
 */
  __pyx_v_self->__pyx_base.external_view_exists = 1;

  /* "pandas/_libs/hashtable_class_helper.pxi":787
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 *         return self.ao             # <<<<<<<<<<<<<<
 * 
 *     cdef void append(self, uint32_t x):
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->ao);
  __pyx_r = __pyx_v_self->ao;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":779
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_12UInt32Vector_7to_array = {"to_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_7to_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("to_array", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "to_array", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12UInt32Vector_6to_array(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12UInt32Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_6pandas_5_libs_9hashtable_12UInt32Vector_to_array(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":789
 *         return self.ao
 * 
 *     cdef void append(self, uint32_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

static void __pyx_f_6pandas_5_libs_9hashtable_12UInt32Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_self, __pyx_t_5numpy_uint32_t __pyx_v_x) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("append", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":791
 *     cdef void append(self, uint32_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  __pyx_t_1 = __pyx_fuse_5__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_self->data); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(2, 791, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":792
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":793
 *         if needs_resize(self.data):
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "             # <<<<<<<<<<<<<<
 *                                  "Vector.resize() needed")
 *             self.resize()
 */
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 793, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(2, 793, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":792
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":795
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 *             self.resize()             # <<<<<<<<<<<<<<
 * 
 *         append_data_uint32(self.data, x)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt32Vector *)__pyx_v_self->__pyx_vtab)->resize(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 795, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":791
 *     cdef void append(self, uint32_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":797
 *             self.resize()
 * 
 *         append_data_uint32(self.data, x)             # <<<<<<<<<<<<<<
 * 
 *     cdef extend(self, const uint32_t[:] x):
 */
  __pyx_f_6pandas_5_libs_9hashtable_append_data_uint32(__pyx_v_self->data, __pyx_v_x); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 797, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":789
 *         return self.ao
 * 
 *     cdef void append(self, uint32_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32Vector.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "pandas/_libs/hashtable_class_helper.pxi":799
 *         append_data_uint32(self.data, x)
 * 
 *     cdef extend(self, const uint32_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_12UInt32Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x) {
  Py_ssize_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extend", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":800
 * 
 *     cdef extend(self, const uint32_t[:] x):
 *         for i in range(len(x)):             # <<<<<<<<<<<<<<
 *             self.append(x[i])
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_x); 
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "pandas/_libs/hashtable_class_helper.pxi":801
 *     cdef extend(self, const uint32_t[:] x):
 *         for i in range(len(x)):
 *             self.append(x[i])             # <<<<<<<<<<<<<<
 * 
 * cdef class Int32Vector(Vector):
 */
    __pyx_t_4 = __pyx_v_i;
    __pyx_t_5 = -1;
    if (__pyx_t_4 < 0) {
      __pyx_t_4 += __pyx_v_x.shape[0];
      if (unlikely(__pyx_t_4 < 0)) __pyx_t_5 = 0;
    } else if (unlikely(__pyx_t_4 >= __pyx_v_x.shape[0])) __pyx_t_5 = 0;
    if (unlikely(__pyx_t_5 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_5);
      __PYX_ERR(2, 801, __pyx_L1_error)
    }
    ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt32Vector *)__pyx_v_self->__pyx_vtab)->append(__pyx_v_self, (*((__pyx_t_5numpy_uint32_t const  *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_4 * __pyx_v_x.strides[0]) )))); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 801, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":799
 *         append_data_uint32(self.data, x)
 * 
 *     cdef extend(self, const uint32_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32Vector.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_12UInt32Vector_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12UInt32Vector_8__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12UInt32Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32Vector.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_12UInt32Vector_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12UInt32Vector_10__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12UInt32Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":811
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <Int32VectorData *>PyMem_Malloc(
 *             sizeof(Int32VectorData))
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_11Int32Vector___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_11Int32Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  char *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":812
 * 
 *     def __cinit__(self):
 *         self.data = <Int32VectorData *>PyMem_Malloc(             # <<<<<<<<<<<<<<
 *             sizeof(Int32VectorData))
 *         if not self.data:
 */
  __pyx_v_self->data = ((__pyx_t_6pandas_5_libs_9hashtable_Int32VectorData *)PyMem_Malloc((sizeof(__pyx_t_6pandas_5_libs_9hashtable_Int32VectorData))));

  /* "pandas/_libs/hashtable_class_helper.pxi":814
 *         self.data = <Int32VectorData *>PyMem_Malloc(
 *             sizeof(Int32VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  __pyx_t_1 = (!(__pyx_v_self->data != 0));
  if (unlikely(__pyx_t_1)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":815
 *             sizeof(Int32VectorData))
 *         if not self.data:
 *             raise MemoryError()             # <<<<<<<<<<<<<<
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 */
    PyErr_NoMemory(); __PYX_ERR(2, 815, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":814
 *         self.data = <Int32VectorData *>PyMem_Malloc(
 *             sizeof(Int32VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":816
 *         if not self.data:
 *             raise MemoryError()
 *         self.data.n = 0             # <<<<<<<<<<<<<<
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.int32)
 */
  __pyx_v_self->data->n = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":817
 *             raise MemoryError()
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP             # <<<<<<<<<<<<<<
 *         self.ao = np.empty(self.data.m, dtype=np.int32)
 *         self.data.data = <int32_t*>self.ao.data
 */
  __pyx_v_self->data->m = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;

  /* "pandas/_libs/hashtable_class_helper.pxi":818
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.int32)             # <<<<<<<<<<<<<<
 *         self.data.data = <int32_t*>self.ao.data
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 818, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_int32); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 818, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 818, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 818, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_6);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->ao);
  __Pyx_DECREF((PyObject *)__pyx_v_self->ao);
  __pyx_v_self->ao = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":819
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.int32)
 *         self.data.data = <int32_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     cdef resize(self):
 */
  __pyx_t_6 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_6);
  __pyx_t_7 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_6)); if (unlikely(__pyx_t_7 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 819, __pyx_L1_error)
  __pyx_v_self->data->data = ((__pyx_t_5numpy_int32_t *)__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":811
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <Int32VectorData *>PyMem_Malloc(
 *             sizeof(Int32VectorData))
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32Vector.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":821
 *         self.data.data = <int32_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_11Int32Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  char *__pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("resize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":822
 * 
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)             # <<<<<<<<<<<<<<
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <int32_t*>self.ao.data
 */
  __pyx_t_1 = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;
  __pyx_t_2 = (__pyx_v_self->data->m * 4);
  __pyx_t_4 = (__pyx_t_1 > __pyx_t_2);
  if (__pyx_t_4) {
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_3 = __pyx_t_2;
  }
  __pyx_v_self->data->m = __pyx_t_3;

  /* "pandas/_libs/hashtable_class_helper.pxi":823
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)             # <<<<<<<<<<<<<<
 *         self.data.data = <int32_t*>self.ao.data
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6)) __PYX_ERR(2, 823, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 823, __pyx_L1_error)
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":824
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <int32_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_8 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_8);
  __pyx_t_9 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_8)); if (unlikely(__pyx_t_9 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 824, __pyx_L1_error)
  __pyx_v_self->data->data = ((__pyx_t_5numpy_int32_t *)__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":821
 *         self.data.data = <int32_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32Vector.resize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":826
 *         self.data.data = <int32_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_3__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_11Int32Vector_2__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_11Int32Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":827
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  __pyx_t_1 = (__pyx_v_self->data != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":828
 *     def __dealloc__(self):
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)             # <<<<<<<<<<<<<<
 *             self.data = NULL
 * 
 */
    PyMem_Free(__pyx_v_self->data);

    /* "pandas/_libs/hashtable_class_helper.pxi":829
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 *             self.data = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
    __pyx_v_self->data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":827
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":826
 *         self.data.data = <int32_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":831
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_5__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_5__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_11Int32Vector_4__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_11Int32Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_self) {
  Py_ssize_t __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":832
 * 
 *     def __len__(self) -> int:
 *         return self.data.n             # <<<<<<<<<<<<<<
 * 
 *     cpdef ndarray to_array(self):
 */
  __pyx_r = __pyx_v_self->data->n;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":831
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":834
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_11Int32Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_self, int __pyx_skip_dispatch) {
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_to_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 834, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_7to_array)) {
        __Pyx_XDECREF((PyObject *)__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 834, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 834, __pyx_L1_error)
        __pyx_r = ((PyArrayObject *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":835
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  __pyx_t_6 = (__pyx_v_self->data->m != __pyx_v_self->data->n);
  if (__pyx_t_6) {

    /* "pandas/_libs/hashtable_class_helper.pxi":836
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":838
 *             if self.external_view_exists:
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")             # <<<<<<<<<<<<<<
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 838, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(2, 838, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":836
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":839
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)             # <<<<<<<<<<<<<<
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 839, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 839, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 839, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 839, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 839, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 839, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 839, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":840
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n             # <<<<<<<<<<<<<<
 *         self.external_view_exists = True
 *         return self.ao
 */
    __pyx_t_7 = __pyx_v_self->data->n;
    __pyx_v_self->data->m = __pyx_t_7;

    /* "pandas/_libs/hashtable_class_helper.pxi":835
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":841
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 *         self.external_view_exists = True             # <<<<<<<<<<<<<<
 *         return self.ao
 * 
 */
  __pyx_v_self->__pyx_base.external_view_exists = 1;

  /* "pandas/_libs/hashtable_class_helper.pxi":842
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 *         return self.ao             # <<<<<<<<<<<<<<
 * 
 *     cdef void append(self, int32_t x):
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->ao);
  __pyx_r = __pyx_v_self->ao;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":834
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_11Int32Vector_7to_array = {"to_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_7to_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("to_array", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "to_array", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_11Int32Vector_6to_array(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11Int32Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_6pandas_5_libs_9hashtable_11Int32Vector_to_array(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":844
 *         return self.ao
 * 
 *     cdef void append(self, int32_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

static void __pyx_f_6pandas_5_libs_9hashtable_11Int32Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_self, __pyx_t_5numpy_int32_t __pyx_v_x) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("append", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":846
 *     cdef void append(self, int32_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  __pyx_t_1 = __pyx_fuse_1__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_self->data); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(2, 846, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":847
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":848
 *         if needs_resize(self.data):
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "             # <<<<<<<<<<<<<<
 *                                  "Vector.resize() needed")
 *             self.resize()
 */
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 848, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(2, 848, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":847
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":850
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 *             self.resize()             # <<<<<<<<<<<<<<
 * 
 *         append_data_int32(self.data, x)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_v_self->__pyx_vtab)->resize(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 850, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":846
 *     cdef void append(self, int32_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":852
 *             self.resize()
 * 
 *         append_data_int32(self.data, x)             # <<<<<<<<<<<<<<
 * 
 *     cdef extend(self, const int32_t[:] x):
 */
  __pyx_f_6pandas_5_libs_9hashtable_append_data_int32(__pyx_v_self->data, __pyx_v_x); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 852, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":844
 *         return self.ao
 * 
 *     cdef void append(self, int32_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32Vector.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "pandas/_libs/hashtable_class_helper.pxi":854
 *         append_data_int32(self.data, x)
 * 
 *     cdef extend(self, const int32_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_11Int32Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x) {
  Py_ssize_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extend", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":855
 * 
 *     cdef extend(self, const int32_t[:] x):
 *         for i in range(len(x)):             # <<<<<<<<<<<<<<
 *             self.append(x[i])
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_x); 
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "pandas/_libs/hashtable_class_helper.pxi":856
 *     cdef extend(self, const int32_t[:] x):
 *         for i in range(len(x)):
 *             self.append(x[i])             # <<<<<<<<<<<<<<
 * 
 * cdef class UInt16Vector(Vector):
 */
    __pyx_t_4 = __pyx_v_i;
    __pyx_t_5 = -1;
    if (__pyx_t_4 < 0) {
      __pyx_t_4 += __pyx_v_x.shape[0];
      if (unlikely(__pyx_t_4 < 0)) __pyx_t_5 = 0;
    } else if (unlikely(__pyx_t_4 >= __pyx_v_x.shape[0])) __pyx_t_5 = 0;
    if (unlikely(__pyx_t_5 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_5);
      __PYX_ERR(2, 856, __pyx_L1_error)
    }
    ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_v_self->__pyx_vtab)->append(__pyx_v_self, (*((__pyx_t_5numpy_int32_t const  *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_4 * __pyx_v_x.strides[0]) )))); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 856, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":854
 *         append_data_int32(self.data, x)
 * 
 *     cdef extend(self, const int32_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32Vector.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_11Int32Vector_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_11Int32Vector_8__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11Int32Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32Vector.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_11Int32Vector_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_11Int32Vector_10__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11Int32Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":866
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <UInt16VectorData *>PyMem_Malloc(
 *             sizeof(UInt16VectorData))
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12UInt16Vector___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_12UInt16Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  char *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":867
 * 
 *     def __cinit__(self):
 *         self.data = <UInt16VectorData *>PyMem_Malloc(             # <<<<<<<<<<<<<<
 *             sizeof(UInt16VectorData))
 *         if not self.data:
 */
  __pyx_v_self->data = ((__pyx_t_6pandas_5_libs_9hashtable_UInt16VectorData *)PyMem_Malloc((sizeof(__pyx_t_6pandas_5_libs_9hashtable_UInt16VectorData))));

  /* "pandas/_libs/hashtable_class_helper.pxi":869
 *         self.data = <UInt16VectorData *>PyMem_Malloc(
 *             sizeof(UInt16VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  __pyx_t_1 = (!(__pyx_v_self->data != 0));
  if (unlikely(__pyx_t_1)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":870
 *             sizeof(UInt16VectorData))
 *         if not self.data:
 *             raise MemoryError()             # <<<<<<<<<<<<<<
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 */
    PyErr_NoMemory(); __PYX_ERR(2, 870, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":869
 *         self.data = <UInt16VectorData *>PyMem_Malloc(
 *             sizeof(UInt16VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":871
 *         if not self.data:
 *             raise MemoryError()
 *         self.data.n = 0             # <<<<<<<<<<<<<<
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.uint16)
 */
  __pyx_v_self->data->n = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":872
 *             raise MemoryError()
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP             # <<<<<<<<<<<<<<
 *         self.ao = np.empty(self.data.m, dtype=np.uint16)
 *         self.data.data = <uint16_t*>self.ao.data
 */
  __pyx_v_self->data->m = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;

  /* "pandas/_libs/hashtable_class_helper.pxi":873
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.uint16)             # <<<<<<<<<<<<<<
 *         self.data.data = <uint16_t*>self.ao.data
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 873, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 873, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 873, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 873, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 873, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 873, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 873, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_uint16); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 873, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 873, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 873, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 873, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_6);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->ao);
  __Pyx_DECREF((PyObject *)__pyx_v_self->ao);
  __pyx_v_self->ao = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":874
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.uint16)
 *         self.data.data = <uint16_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     cdef resize(self):
 */
  __pyx_t_6 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_6);
  __pyx_t_7 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_6)); if (unlikely(__pyx_t_7 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 874, __pyx_L1_error)
  __pyx_v_self->data->data = ((__pyx_t_5numpy_uint16_t *)__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":866
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <UInt16VectorData *>PyMem_Malloc(
 *             sizeof(UInt16VectorData))
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16Vector.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":876
 *         self.data.data = <uint16_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_12UInt16Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  char *__pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("resize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":877
 * 
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)             # <<<<<<<<<<<<<<
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <uint16_t*>self.ao.data
 */
  __pyx_t_1 = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;
  __pyx_t_2 = (__pyx_v_self->data->m * 4);
  __pyx_t_4 = (__pyx_t_1 > __pyx_t_2);
  if (__pyx_t_4) {
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_3 = __pyx_t_2;
  }
  __pyx_v_self->data->m = __pyx_t_3;

  /* "pandas/_libs/hashtable_class_helper.pxi":878
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)             # <<<<<<<<<<<<<<
 *         self.data.data = <uint16_t*>self.ao.data
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6)) __PYX_ERR(2, 878, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 878, __pyx_L1_error)
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 878, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":879
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <uint16_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_8 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_8);
  __pyx_t_9 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_8)); if (unlikely(__pyx_t_9 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 879, __pyx_L1_error)
  __pyx_v_self->data->data = ((__pyx_t_5numpy_uint16_t *)__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":876
 *         self.data.data = <uint16_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16Vector.resize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":881
 *         self.data.data = <uint16_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_3__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_12UInt16Vector_2__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_12UInt16Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":882
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  __pyx_t_1 = (__pyx_v_self->data != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":883
 *     def __dealloc__(self):
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)             # <<<<<<<<<<<<<<
 *             self.data = NULL
 * 
 */
    PyMem_Free(__pyx_v_self->data);

    /* "pandas/_libs/hashtable_class_helper.pxi":884
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 *             self.data = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
    __pyx_v_self->data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":882
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":881
 *         self.data.data = <uint16_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":886
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_5__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_5__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12UInt16Vector_4__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_12UInt16Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_self) {
  Py_ssize_t __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":887
 * 
 *     def __len__(self) -> int:
 *         return self.data.n             # <<<<<<<<<<<<<<
 * 
 *     cpdef ndarray to_array(self):
 */
  __pyx_r = __pyx_v_self->data->n;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":886
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":889
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_12UInt16Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_self, int __pyx_skip_dispatch) {
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_to_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 889, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_7to_array)) {
        __Pyx_XDECREF((PyObject *)__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 889, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 889, __pyx_L1_error)
        __pyx_r = ((PyArrayObject *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":890
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  __pyx_t_6 = (__pyx_v_self->data->m != __pyx_v_self->data->n);
  if (__pyx_t_6) {

    /* "pandas/_libs/hashtable_class_helper.pxi":891
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":893
 *             if self.external_view_exists:
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")             # <<<<<<<<<<<<<<
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 893, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(2, 893, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":891
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":894
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)             # <<<<<<<<<<<<<<
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 894, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 894, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 894, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 894, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 894, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 894, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 894, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":895
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n             # <<<<<<<<<<<<<<
 *         self.external_view_exists = True
 *         return self.ao
 */
    __pyx_t_7 = __pyx_v_self->data->n;
    __pyx_v_self->data->m = __pyx_t_7;

    /* "pandas/_libs/hashtable_class_helper.pxi":890
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":896
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 *         self.external_view_exists = True             # <<<<<<<<<<<<<<
 *         return self.ao
 * 
 */
  __pyx_v_self->__pyx_base.external_view_exists = 1;

  /* "pandas/_libs/hashtable_class_helper.pxi":897
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 *         return self.ao             # <<<<<<<<<<<<<<
 * 
 *     cdef void append(self, uint16_t x):
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->ao);
  __pyx_r = __pyx_v_self->ao;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":889
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_12UInt16Vector_7to_array = {"to_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_7to_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("to_array", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "to_array", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12UInt16Vector_6to_array(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12UInt16Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_6pandas_5_libs_9hashtable_12UInt16Vector_to_array(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":899
 *         return self.ao
 * 
 *     cdef void append(self, uint16_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

static void __pyx_f_6pandas_5_libs_9hashtable_12UInt16Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_self, __pyx_t_5numpy_uint16_t __pyx_v_x) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("append", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":901
 *     cdef void append(self, uint16_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  __pyx_t_1 = __pyx_fuse_6__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_self->data); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(2, 901, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":902
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":903
 *         if needs_resize(self.data):
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "             # <<<<<<<<<<<<<<
 *                                  "Vector.resize() needed")
 *             self.resize()
 */
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 903, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(2, 903, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":902
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":905
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 *             self.resize()             # <<<<<<<<<<<<<<
 * 
 *         append_data_uint16(self.data, x)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt16Vector *)__pyx_v_self->__pyx_vtab)->resize(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 905, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":901
 *     cdef void append(self, uint16_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":907
 *             self.resize()
 * 
 *         append_data_uint16(self.data, x)             # <<<<<<<<<<<<<<
 * 
 *     cdef extend(self, const uint16_t[:] x):
 */
  __pyx_f_6pandas_5_libs_9hashtable_append_data_uint16(__pyx_v_self->data, __pyx_v_x); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 907, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":899
 *         return self.ao
 * 
 *     cdef void append(self, uint16_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16Vector.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "pandas/_libs/hashtable_class_helper.pxi":909
 *         append_data_uint16(self.data, x)
 * 
 *     cdef extend(self, const uint16_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_12UInt16Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x) {
  Py_ssize_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extend", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":910
 * 
 *     cdef extend(self, const uint16_t[:] x):
 *         for i in range(len(x)):             # <<<<<<<<<<<<<<
 *             self.append(x[i])
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_x); 
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "pandas/_libs/hashtable_class_helper.pxi":911
 *     cdef extend(self, const uint16_t[:] x):
 *         for i in range(len(x)):
 *             self.append(x[i])             # <<<<<<<<<<<<<<
 * 
 * cdef class Int16Vector(Vector):
 */
    __pyx_t_4 = __pyx_v_i;
    __pyx_t_5 = -1;
    if (__pyx_t_4 < 0) {
      __pyx_t_4 += __pyx_v_x.shape[0];
      if (unlikely(__pyx_t_4 < 0)) __pyx_t_5 = 0;
    } else if (unlikely(__pyx_t_4 >= __pyx_v_x.shape[0])) __pyx_t_5 = 0;
    if (unlikely(__pyx_t_5 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_5);
      __PYX_ERR(2, 911, __pyx_L1_error)
    }
    ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt16Vector *)__pyx_v_self->__pyx_vtab)->append(__pyx_v_self, (*((__pyx_t_5numpy_uint16_t const  *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_4 * __pyx_v_x.strides[0]) )))); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 911, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":909
 *         append_data_uint16(self.data, x)
 * 
 *     cdef extend(self, const uint16_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16Vector.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_12UInt16Vector_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12UInt16Vector_8__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12UInt16Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16Vector.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_12UInt16Vector_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12UInt16Vector_10__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12UInt16Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":921
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <Int16VectorData *>PyMem_Malloc(
 *             sizeof(Int16VectorData))
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_11Int16Vector___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_11Int16Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  char *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":922
 * 
 *     def __cinit__(self):
 *         self.data = <Int16VectorData *>PyMem_Malloc(             # <<<<<<<<<<<<<<
 *             sizeof(Int16VectorData))
 *         if not self.data:
 */
  __pyx_v_self->data = ((__pyx_t_6pandas_5_libs_9hashtable_Int16VectorData *)PyMem_Malloc((sizeof(__pyx_t_6pandas_5_libs_9hashtable_Int16VectorData))));

  /* "pandas/_libs/hashtable_class_helper.pxi":924
 *         self.data = <Int16VectorData *>PyMem_Malloc(
 *             sizeof(Int16VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  __pyx_t_1 = (!(__pyx_v_self->data != 0));
  if (unlikely(__pyx_t_1)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":925
 *             sizeof(Int16VectorData))
 *         if not self.data:
 *             raise MemoryError()             # <<<<<<<<<<<<<<
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 */
    PyErr_NoMemory(); __PYX_ERR(2, 925, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":924
 *         self.data = <Int16VectorData *>PyMem_Malloc(
 *             sizeof(Int16VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":926
 *         if not self.data:
 *             raise MemoryError()
 *         self.data.n = 0             # <<<<<<<<<<<<<<
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.int16)
 */
  __pyx_v_self->data->n = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":927
 *             raise MemoryError()
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP             # <<<<<<<<<<<<<<
 *         self.ao = np.empty(self.data.m, dtype=np.int16)
 *         self.data.data = <int16_t*>self.ao.data
 */
  __pyx_v_self->data->m = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;

  /* "pandas/_libs/hashtable_class_helper.pxi":928
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.int16)             # <<<<<<<<<<<<<<
 *         self.data.data = <int16_t*>self.ao.data
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 928, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_int16); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 928, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 928, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_6);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->ao);
  __Pyx_DECREF((PyObject *)__pyx_v_self->ao);
  __pyx_v_self->ao = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":929
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.int16)
 *         self.data.data = <int16_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     cdef resize(self):
 */
  __pyx_t_6 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_6);
  __pyx_t_7 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_6)); if (unlikely(__pyx_t_7 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 929, __pyx_L1_error)
  __pyx_v_self->data->data = ((__pyx_t_5numpy_int16_t *)__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":921
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <Int16VectorData *>PyMem_Malloc(
 *             sizeof(Int16VectorData))
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16Vector.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":931
 *         self.data.data = <int16_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_11Int16Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  char *__pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("resize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":932
 * 
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)             # <<<<<<<<<<<<<<
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <int16_t*>self.ao.data
 */
  __pyx_t_1 = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;
  __pyx_t_2 = (__pyx_v_self->data->m * 4);
  __pyx_t_4 = (__pyx_t_1 > __pyx_t_2);
  if (__pyx_t_4) {
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_3 = __pyx_t_2;
  }
  __pyx_v_self->data->m = __pyx_t_3;

  /* "pandas/_libs/hashtable_class_helper.pxi":933
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)             # <<<<<<<<<<<<<<
 *         self.data.data = <int16_t*>self.ao.data
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6)) __PYX_ERR(2, 933, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 933, __pyx_L1_error)
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":934
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <int16_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_8 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_8);
  __pyx_t_9 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_8)); if (unlikely(__pyx_t_9 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 934, __pyx_L1_error)
  __pyx_v_self->data->data = ((__pyx_t_5numpy_int16_t *)__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":931
 *         self.data.data = <int16_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16Vector.resize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":936
 *         self.data.data = <int16_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_3__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_11Int16Vector_2__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_11Int16Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":937
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  __pyx_t_1 = (__pyx_v_self->data != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":938
 *     def __dealloc__(self):
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)             # <<<<<<<<<<<<<<
 *             self.data = NULL
 * 
 */
    PyMem_Free(__pyx_v_self->data);

    /* "pandas/_libs/hashtable_class_helper.pxi":939
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 *             self.data = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
    __pyx_v_self->data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":937
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":936
 *         self.data.data = <int16_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":941
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_5__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_5__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_11Int16Vector_4__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_11Int16Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_self) {
  Py_ssize_t __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":942
 * 
 *     def __len__(self) -> int:
 *         return self.data.n             # <<<<<<<<<<<<<<
 * 
 *     cpdef ndarray to_array(self):
 */
  __pyx_r = __pyx_v_self->data->n;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":941
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":944
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_11Int16Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_self, int __pyx_skip_dispatch) {
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_to_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 944, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_7to_array)) {
        __Pyx_XDECREF((PyObject *)__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 944, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 944, __pyx_L1_error)
        __pyx_r = ((PyArrayObject *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":945
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  __pyx_t_6 = (__pyx_v_self->data->m != __pyx_v_self->data->n);
  if (__pyx_t_6) {

    /* "pandas/_libs/hashtable_class_helper.pxi":946
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":948
 *             if self.external_view_exists:
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")             # <<<<<<<<<<<<<<
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 948, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(2, 948, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":946
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":949
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)             # <<<<<<<<<<<<<<
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 949, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 949, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 949, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 949, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 949, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 949, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 949, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":950
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n             # <<<<<<<<<<<<<<
 *         self.external_view_exists = True
 *         return self.ao
 */
    __pyx_t_7 = __pyx_v_self->data->n;
    __pyx_v_self->data->m = __pyx_t_7;

    /* "pandas/_libs/hashtable_class_helper.pxi":945
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":951
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 *         self.external_view_exists = True             # <<<<<<<<<<<<<<
 *         return self.ao
 * 
 */
  __pyx_v_self->__pyx_base.external_view_exists = 1;

  /* "pandas/_libs/hashtable_class_helper.pxi":952
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 *         return self.ao             # <<<<<<<<<<<<<<
 * 
 *     cdef void append(self, int16_t x):
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->ao);
  __pyx_r = __pyx_v_self->ao;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":944
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_11Int16Vector_7to_array = {"to_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_7to_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("to_array", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "to_array", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_11Int16Vector_6to_array(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11Int16Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_6pandas_5_libs_9hashtable_11Int16Vector_to_array(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":954
 *         return self.ao
 * 
 *     cdef void append(self, int16_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

static void __pyx_f_6pandas_5_libs_9hashtable_11Int16Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_self, __pyx_t_5numpy_int16_t __pyx_v_x) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("append", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":956
 *     cdef void append(self, int16_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  __pyx_t_1 = __pyx_fuse_2__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_self->data); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(2, 956, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":957
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":958
 *         if needs_resize(self.data):
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "             # <<<<<<<<<<<<<<
 *                                  "Vector.resize() needed")
 *             self.resize()
 */
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 958, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(2, 958, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":957
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":960
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 *             self.resize()             # <<<<<<<<<<<<<<
 * 
 *         append_data_int16(self.data, x)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int16Vector *)__pyx_v_self->__pyx_vtab)->resize(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 960, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":956
 *     cdef void append(self, int16_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":962
 *             self.resize()
 * 
 *         append_data_int16(self.data, x)             # <<<<<<<<<<<<<<
 * 
 *     cdef extend(self, const int16_t[:] x):
 */
  __pyx_f_6pandas_5_libs_9hashtable_append_data_int16(__pyx_v_self->data, __pyx_v_x); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 962, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":954
 *         return self.ao
 * 
 *     cdef void append(self, int16_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16Vector.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "pandas/_libs/hashtable_class_helper.pxi":964
 *         append_data_int16(self.data, x)
 * 
 *     cdef extend(self, const int16_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_11Int16Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x) {
  Py_ssize_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extend", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":965
 * 
 *     cdef extend(self, const int16_t[:] x):
 *         for i in range(len(x)):             # <<<<<<<<<<<<<<
 *             self.append(x[i])
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_x); 
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "pandas/_libs/hashtable_class_helper.pxi":966
 *     cdef extend(self, const int16_t[:] x):
 *         for i in range(len(x)):
 *             self.append(x[i])             # <<<<<<<<<<<<<<
 * 
 * cdef class UInt8Vector(Vector):
 */
    __pyx_t_4 = __pyx_v_i;
    __pyx_t_5 = -1;
    if (__pyx_t_4 < 0) {
      __pyx_t_4 += __pyx_v_x.shape[0];
      if (unlikely(__pyx_t_4 < 0)) __pyx_t_5 = 0;
    } else if (unlikely(__pyx_t_4 >= __pyx_v_x.shape[0])) __pyx_t_5 = 0;
    if (unlikely(__pyx_t_5 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_5);
      __PYX_ERR(2, 966, __pyx_L1_error)
    }
    ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int16Vector *)__pyx_v_self->__pyx_vtab)->append(__pyx_v_self, (*((__pyx_t_5numpy_int16_t const  *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_4 * __pyx_v_x.strides[0]) )))); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 966, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":964
 *         append_data_int16(self.data, x)
 * 
 *     cdef extend(self, const int16_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16Vector.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_11Int16Vector_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_11Int16Vector_8__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11Int16Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16Vector.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_11Int16Vector_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_11Int16Vector_10__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11Int16Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":976
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <UInt8VectorData *>PyMem_Malloc(
 *             sizeof(UInt8VectorData))
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_11UInt8Vector___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_11UInt8Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  char *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":977
 * 
 *     def __cinit__(self):
 *         self.data = <UInt8VectorData *>PyMem_Malloc(             # <<<<<<<<<<<<<<
 *             sizeof(UInt8VectorData))
 *         if not self.data:
 */
  __pyx_v_self->data = ((__pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *)PyMem_Malloc((sizeof(__pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData))));

  /* "pandas/_libs/hashtable_class_helper.pxi":979
 *         self.data = <UInt8VectorData *>PyMem_Malloc(
 *             sizeof(UInt8VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  __pyx_t_1 = (!(__pyx_v_self->data != 0));
  if (unlikely(__pyx_t_1)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":980
 *             sizeof(UInt8VectorData))
 *         if not self.data:
 *             raise MemoryError()             # <<<<<<<<<<<<<<
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 */
    PyErr_NoMemory(); __PYX_ERR(2, 980, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":979
 *         self.data = <UInt8VectorData *>PyMem_Malloc(
 *             sizeof(UInt8VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":981
 *         if not self.data:
 *             raise MemoryError()
 *         self.data.n = 0             # <<<<<<<<<<<<<<
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.uint8)
 */
  __pyx_v_self->data->n = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":982
 *             raise MemoryError()
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP             # <<<<<<<<<<<<<<
 *         self.ao = np.empty(self.data.m, dtype=np.uint8)
 *         self.data.data = <uint8_t*>self.ao.data
 */
  __pyx_v_self->data->m = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;

  /* "pandas/_libs/hashtable_class_helper.pxi":983
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.uint8)             # <<<<<<<<<<<<<<
 *         self.data.data = <uint8_t*>self.ao.data
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 983, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_uint8); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 983, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 983, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 983, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_6);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->ao);
  __Pyx_DECREF((PyObject *)__pyx_v_self->ao);
  __pyx_v_self->ao = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":984
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.uint8)
 *         self.data.data = <uint8_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     cdef resize(self):
 */
  __pyx_t_6 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_6);
  __pyx_t_7 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_6)); if (unlikely(__pyx_t_7 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 984, __pyx_L1_error)
  __pyx_v_self->data->data = ((__pyx_t_5numpy_uint8_t *)__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":976
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <UInt8VectorData *>PyMem_Malloc(
 *             sizeof(UInt8VectorData))
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8Vector.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":986
 *         self.data.data = <uint8_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_11UInt8Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  char *__pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("resize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":987
 * 
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)             # <<<<<<<<<<<<<<
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <uint8_t*>self.ao.data
 */
  __pyx_t_1 = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;
  __pyx_t_2 = (__pyx_v_self->data->m * 4);
  __pyx_t_4 = (__pyx_t_1 > __pyx_t_2);
  if (__pyx_t_4) {
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_3 = __pyx_t_2;
  }
  __pyx_v_self->data->m = __pyx_t_3;

  /* "pandas/_libs/hashtable_class_helper.pxi":988
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)             # <<<<<<<<<<<<<<
 *         self.data.data = <uint8_t*>self.ao.data
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6)) __PYX_ERR(2, 988, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 988, __pyx_L1_error)
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":989
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <uint8_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_8 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_8);
  __pyx_t_9 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_8)); if (unlikely(__pyx_t_9 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 989, __pyx_L1_error)
  __pyx_v_self->data->data = ((__pyx_t_5numpy_uint8_t *)__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":986
 *         self.data.data = <uint8_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8Vector.resize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":991
 *         self.data.data = <uint8_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_3__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_11UInt8Vector_2__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_11UInt8Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":992
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  __pyx_t_1 = (__pyx_v_self->data != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":993
 *     def __dealloc__(self):
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)             # <<<<<<<<<<<<<<
 *             self.data = NULL
 * 
 */
    PyMem_Free(__pyx_v_self->data);

    /* "pandas/_libs/hashtable_class_helper.pxi":994
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 *             self.data = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
    __pyx_v_self->data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":992
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":991
 *         self.data.data = <uint8_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":996
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_5__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_5__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_11UInt8Vector_4__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_11UInt8Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_self) {
  Py_ssize_t __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":997
 * 
 *     def __len__(self) -> int:
 *         return self.data.n             # <<<<<<<<<<<<<<
 * 
 *     cpdef ndarray to_array(self):
 */
  __pyx_r = __pyx_v_self->data->n;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":996
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":999
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_11UInt8Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_self, int __pyx_skip_dispatch) {
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_to_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 999, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_7to_array)) {
        __Pyx_XDECREF((PyObject *)__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 999, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 999, __pyx_L1_error)
        __pyx_r = ((PyArrayObject *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1000
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  __pyx_t_6 = (__pyx_v_self->data->m != __pyx_v_self->data->n);
  if (__pyx_t_6) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1001
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":1003
 *             if self.external_view_exists:
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")             # <<<<<<<<<<<<<<
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1003, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(2, 1003, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":1001
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":1004
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)             # <<<<<<<<<<<<<<
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 1004, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 1004, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1004, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":1005
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n             # <<<<<<<<<<<<<<
 *         self.external_view_exists = True
 *         return self.ao
 */
    __pyx_t_7 = __pyx_v_self->data->n;
    __pyx_v_self->data->m = __pyx_t_7;

    /* "pandas/_libs/hashtable_class_helper.pxi":1000
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1006
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 *         self.external_view_exists = True             # <<<<<<<<<<<<<<
 *         return self.ao
 * 
 */
  __pyx_v_self->__pyx_base.external_view_exists = 1;

  /* "pandas/_libs/hashtable_class_helper.pxi":1007
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 *         return self.ao             # <<<<<<<<<<<<<<
 * 
 *     cdef void append(self, uint8_t x):
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->ao);
  __pyx_r = __pyx_v_self->ao;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":999
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_11UInt8Vector_7to_array = {"to_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_7to_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("to_array", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "to_array", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_11UInt8Vector_6to_array(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11UInt8Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_6pandas_5_libs_9hashtable_11UInt8Vector_to_array(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1009
 *         return self.ao
 * 
 *     cdef void append(self, uint8_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

static void __pyx_f_6pandas_5_libs_9hashtable_11UInt8Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_self, __pyx_t_5numpy_uint8_t __pyx_v_x) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("append", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1011
 *     cdef void append(self, uint8_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  __pyx_t_1 = __pyx_fuse_7__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_self->data); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1011, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1012
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":1013
 *         if needs_resize(self.data):
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "             # <<<<<<<<<<<<<<
 *                                  "Vector.resize() needed")
 *             self.resize()
 */
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1013, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(2, 1013, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":1012
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":1015
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 *             self.resize()             # <<<<<<<<<<<<<<
 * 
 *         append_data_uint8(self.data, x)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_self->__pyx_vtab)->resize(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1015, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":1011
 *     cdef void append(self, uint8_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1017
 *             self.resize()
 * 
 *         append_data_uint8(self.data, x)             # <<<<<<<<<<<<<<
 * 
 *     cdef extend(self, const uint8_t[:] x):
 */
  __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_self->data, __pyx_v_x); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1017, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1009
 *         return self.ao
 * 
 *     cdef void append(self, uint8_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8Vector.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "pandas/_libs/hashtable_class_helper.pxi":1019
 *         append_data_uint8(self.data, x)
 * 
 *     cdef extend(self, const uint8_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_11UInt8Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x) {
  Py_ssize_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extend", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1020
 * 
 *     cdef extend(self, const uint8_t[:] x):
 *         for i in range(len(x)):             # <<<<<<<<<<<<<<
 *             self.append(x[i])
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_x); 
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "pandas/_libs/hashtable_class_helper.pxi":1021
 *     cdef extend(self, const uint8_t[:] x):
 *         for i in range(len(x)):
 *             self.append(x[i])             # <<<<<<<<<<<<<<
 * 
 * cdef class Int8Vector(Vector):
 */
    __pyx_t_4 = __pyx_v_i;
    __pyx_t_5 = -1;
    if (__pyx_t_4 < 0) {
      __pyx_t_4 += __pyx_v_x.shape[0];
      if (unlikely(__pyx_t_4 < 0)) __pyx_t_5 = 0;
    } else if (unlikely(__pyx_t_4 >= __pyx_v_x.shape[0])) __pyx_t_5 = 0;
    if (unlikely(__pyx_t_5 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_5);
      __PYX_ERR(2, 1021, __pyx_L1_error)
    }
    ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_self->__pyx_vtab)->append(__pyx_v_self, (*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_4 * __pyx_v_x.strides[0]) )))); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1021, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1019
 *         append_data_uint8(self.data, x)
 * 
 *     cdef extend(self, const uint8_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8Vector.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_11UInt8Vector_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_11UInt8Vector_8__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11UInt8Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8Vector.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_11UInt8Vector_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_11UInt8Vector_10__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_11UInt8Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1031
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <Int8VectorData *>PyMem_Malloc(
 *             sizeof(Int8VectorData))
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_10Int8Vector___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_10Int8Vector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  char *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1032
 * 
 *     def __cinit__(self):
 *         self.data = <Int8VectorData *>PyMem_Malloc(             # <<<<<<<<<<<<<<
 *             sizeof(Int8VectorData))
 *         if not self.data:
 */
  __pyx_v_self->data = ((__pyx_t_6pandas_5_libs_9hashtable_Int8VectorData *)PyMem_Malloc((sizeof(__pyx_t_6pandas_5_libs_9hashtable_Int8VectorData))));

  /* "pandas/_libs/hashtable_class_helper.pxi":1034
 *         self.data = <Int8VectorData *>PyMem_Malloc(
 *             sizeof(Int8VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  __pyx_t_1 = (!(__pyx_v_self->data != 0));
  if (unlikely(__pyx_t_1)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1035
 *             sizeof(Int8VectorData))
 *         if not self.data:
 *             raise MemoryError()             # <<<<<<<<<<<<<<
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 */
    PyErr_NoMemory(); __PYX_ERR(2, 1035, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":1034
 *         self.data = <Int8VectorData *>PyMem_Malloc(
 *             sizeof(Int8VectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1036
 *         if not self.data:
 *             raise MemoryError()
 *         self.data.n = 0             # <<<<<<<<<<<<<<
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.int8)
 */
  __pyx_v_self->data->n = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1037
 *             raise MemoryError()
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP             # <<<<<<<<<<<<<<
 *         self.ao = np.empty(self.data.m, dtype=np.int8)
 *         self.data.data = <int8_t*>self.ao.data
 */
  __pyx_v_self->data->m = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;

  /* "pandas/_libs/hashtable_class_helper.pxi":1038
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.int8)             # <<<<<<<<<<<<<<
 *         self.data.data = <int8_t*>self.ao.data
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 1038, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_int8); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 1038, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1038, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 1038, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_6);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->ao);
  __Pyx_DECREF((PyObject *)__pyx_v_self->ao);
  __pyx_v_self->ao = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1039
 *         self.data.m = _INIT_VEC_CAP
 *         self.ao = np.empty(self.data.m, dtype=np.int8)
 *         self.data.data = <int8_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     cdef resize(self):
 */
  __pyx_t_6 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_6);
  __pyx_t_7 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_6)); if (unlikely(__pyx_t_7 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 1039, __pyx_L1_error)
  __pyx_v_self->data->data = ((__pyx_t_5numpy_int8_t *)__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1031
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <Int8VectorData *>PyMem_Malloc(
 *             sizeof(Int8VectorData))
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8Vector.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1041
 *         self.data.data = <int8_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_10Int8Vector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  char *__pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("resize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1042
 * 
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)             # <<<<<<<<<<<<<<
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <int8_t*>self.ao.data
 */
  __pyx_t_1 = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;
  __pyx_t_2 = (__pyx_v_self->data->m * 4);
  __pyx_t_4 = (__pyx_t_1 > __pyx_t_2);
  if (__pyx_t_4) {
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_3 = __pyx_t_2;
  }
  __pyx_v_self->data->m = __pyx_t_3;

  /* "pandas/_libs/hashtable_class_helper.pxi":1043
 *     cdef resize(self):
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)             # <<<<<<<<<<<<<<
 *         self.data.data = <int8_t*>self.ao.data
 * 
 */
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyInt_FromSsize_t(__pyx_v_self->data->m); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6)) __PYX_ERR(2, 1043, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 1043, __pyx_L1_error)
  __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1044
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 *         self.data.data = <int8_t*>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_8 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_8);
  __pyx_t_9 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_8)); if (unlikely(__pyx_t_9 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 1044, __pyx_L1_error)
  __pyx_v_self->data->data = ((__pyx_t_5numpy_int8_t *)__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1041
 *         self.data.data = <int8_t*>self.ao.data
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 *         self.ao.resize(self.data.m, refcheck=False)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8Vector.resize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1046
 *         self.data.data = <int8_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_3__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_10Int8Vector_2__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_10Int8Vector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":1047
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  __pyx_t_1 = (__pyx_v_self->data != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1048
 *     def __dealloc__(self):
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)             # <<<<<<<<<<<<<<
 *             self.data = NULL
 * 
 */
    PyMem_Free(__pyx_v_self->data);

    /* "pandas/_libs/hashtable_class_helper.pxi":1049
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 *             self.data = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
    __pyx_v_self->data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":1047
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1046
 *         self.data.data = <int8_t*>self.ao.data
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             PyMem_Free(self.data)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":1051
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_5__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_5__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_10Int8Vector_4__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_10Int8Vector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_self) {
  Py_ssize_t __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":1052
 * 
 *     def __len__(self) -> int:
 *         return self.data.n             # <<<<<<<<<<<<<<
 * 
 *     cpdef ndarray to_array(self):
 */
  __pyx_r = __pyx_v_self->data->n;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1051
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1054
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_10Int8Vector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_self, int __pyx_skip_dispatch) {
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_to_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1054, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_7to_array)) {
        __Pyx_XDECREF((PyObject *)__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1054, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 1054, __pyx_L1_error)
        __pyx_r = ((PyArrayObject *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1055
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  __pyx_t_6 = (__pyx_v_self->data->m != __pyx_v_self->data->n);
  if (__pyx_t_6) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1056
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":1058
 *             if self.external_view_exists:
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")             # <<<<<<<<<<<<<<
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1058, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(2, 1058, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":1056
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":1059
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)             # <<<<<<<<<<<<<<
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->data->n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 1059, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 1059, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":1060
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n             # <<<<<<<<<<<<<<
 *         self.external_view_exists = True
 *         return self.ao
 */
    __pyx_t_7 = __pyx_v_self->data->n;
    __pyx_v_self->data->m = __pyx_t_7;

    /* "pandas/_libs/hashtable_class_helper.pxi":1055
 * 
 *     cpdef ndarray to_array(self):
 *         if self.data.m != self.data.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 # should never happen
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1061
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 *         self.external_view_exists = True             # <<<<<<<<<<<<<<
 *         return self.ao
 * 
 */
  __pyx_v_self->__pyx_base.external_view_exists = 1;

  /* "pandas/_libs/hashtable_class_helper.pxi":1062
 *             self.data.m = self.data.n
 *         self.external_view_exists = True
 *         return self.ao             # <<<<<<<<<<<<<<
 * 
 *     cdef void append(self, int8_t x):
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->ao);
  __pyx_r = __pyx_v_self->ao;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1054
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_10Int8Vector_7to_array = {"to_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_7to_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("to_array", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "to_array", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_10Int8Vector_6to_array(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_10Int8Vector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_6pandas_5_libs_9hashtable_10Int8Vector_to_array(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8Vector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1064
 *         return self.ao
 * 
 *     cdef void append(self, int8_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

static void __pyx_f_6pandas_5_libs_9hashtable_10Int8Vector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_self, __pyx_t_5numpy_int8_t __pyx_v_x) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("append", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1066
 *     cdef void append(self, int8_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  __pyx_t_1 = __pyx_fuse_3__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_self->data); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1066, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1067
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":1068
 *         if needs_resize(self.data):
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "             # <<<<<<<<<<<<<<
 *                                  "Vector.resize() needed")
 *             self.resize()
 */
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1068, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(2, 1068, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":1067
 * 
 *         if needs_resize(self.data):
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":1070
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 *             self.resize()             # <<<<<<<<<<<<<<
 * 
 *         append_data_int8(self.data, x)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int8Vector *)__pyx_v_self->__pyx_vtab)->resize(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1070, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":1066
 *     cdef void append(self, int8_t x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1072
 *             self.resize()
 * 
 *         append_data_int8(self.data, x)             # <<<<<<<<<<<<<<
 * 
 *     cdef extend(self, const int8_t[:] x):
 */
  __pyx_f_6pandas_5_libs_9hashtable_append_data_int8(__pyx_v_self->data, __pyx_v_x); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1072, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1064
 *         return self.ao
 * 
 *     cdef void append(self, int8_t x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8Vector.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "pandas/_libs/hashtable_class_helper.pxi":1074
 *         append_data_int8(self.data, x)
 * 
 *     cdef extend(self, const int8_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_10Int8Vector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_self, __Pyx_memviewslice __pyx_v_x) {
  Py_ssize_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extend", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1075
 * 
 *     cdef extend(self, const int8_t[:] x):
 *         for i in range(len(x)):             # <<<<<<<<<<<<<<
 *             self.append(x[i])
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_x); 
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "pandas/_libs/hashtable_class_helper.pxi":1076
 *     cdef extend(self, const int8_t[:] x):
 *         for i in range(len(x)):
 *             self.append(x[i])             # <<<<<<<<<<<<<<
 * 
 * cdef class StringVector(Vector):
 */
    __pyx_t_4 = __pyx_v_i;
    __pyx_t_5 = -1;
    if (__pyx_t_4 < 0) {
      __pyx_t_4 += __pyx_v_x.shape[0];
      if (unlikely(__pyx_t_4 < 0)) __pyx_t_5 = 0;
    } else if (unlikely(__pyx_t_4 >= __pyx_v_x.shape[0])) __pyx_t_5 = 0;
    if (unlikely(__pyx_t_5 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_5);
      __PYX_ERR(2, 1076, __pyx_L1_error)
    }
    ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int8Vector *)__pyx_v_self->__pyx_vtab)->append(__pyx_v_self, (*((__pyx_t_5numpy_int8_t const  *) ( /* dim=0 */ (__pyx_v_x.data + __pyx_t_4 * __pyx_v_x.strides[0]) )))); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1076, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1074
 *         append_data_int8(self.data, x)
 * 
 *     cdef extend(self, const int8_t[:] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8Vector.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_10Int8Vector_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_10Int8Vector_8__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_10Int8Vector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8Vector.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_10Int8Vector_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_10Int8Vector_10__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_10Int8Vector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8Vector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1083
 *         StringVectorData *data
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <StringVectorData *>PyMem_Malloc(sizeof(StringVectorData))
 *         if not self.data:
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_12StringVector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_12StringVector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12StringVector___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_12StringVector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *__pyx_v_self) {
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1084
 * 
 *     def __cinit__(self):
 *         self.data = <StringVectorData *>PyMem_Malloc(sizeof(StringVectorData))             # <<<<<<<<<<<<<<
 *         if not self.data:
 *             raise MemoryError()
 */
  __pyx_v_self->data = ((__pyx_t_6pandas_5_libs_9hashtable_StringVectorData *)PyMem_Malloc((sizeof(__pyx_t_6pandas_5_libs_9hashtable_StringVectorData))));

  /* "pandas/_libs/hashtable_class_helper.pxi":1085
 *     def __cinit__(self):
 *         self.data = <StringVectorData *>PyMem_Malloc(sizeof(StringVectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  __pyx_t_1 = (!(__pyx_v_self->data != 0));
  if (unlikely(__pyx_t_1)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1086
 *         self.data = <StringVectorData *>PyMem_Malloc(sizeof(StringVectorData))
 *         if not self.data:
 *             raise MemoryError()             # <<<<<<<<<<<<<<
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 */
    PyErr_NoMemory(); __PYX_ERR(2, 1086, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":1085
 *     def __cinit__(self):
 *         self.data = <StringVectorData *>PyMem_Malloc(sizeof(StringVectorData))
 *         if not self.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         self.data.n = 0
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1087
 *         if not self.data:
 *             raise MemoryError()
 *         self.data.n = 0             # <<<<<<<<<<<<<<
 *         self.data.m = _INIT_VEC_CAP
 *         self.data.data = <char **>malloc(self.data.m * sizeof(char *))
 */
  __pyx_v_self->data->n = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1088
 *             raise MemoryError()
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP             # <<<<<<<<<<<<<<
 *         self.data.data = <char **>malloc(self.data.m * sizeof(char *))
 *         if not self.data.data:
 */
  __pyx_v_self->data->m = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;

  /* "pandas/_libs/hashtable_class_helper.pxi":1089
 *         self.data.n = 0
 *         self.data.m = _INIT_VEC_CAP
 *         self.data.data = <char **>malloc(self.data.m * sizeof(char *))             # <<<<<<<<<<<<<<
 *         if not self.data.data:
 *             raise MemoryError()
 */
  __pyx_v_self->data->data = ((char **)malloc((__pyx_v_self->data->m * (sizeof(char *)))));

  /* "pandas/_libs/hashtable_class_helper.pxi":1090
 *         self.data.m = _INIT_VEC_CAP
 *         self.data.data = <char **>malloc(self.data.m * sizeof(char *))
 *         if not self.data.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 * 
 */
  __pyx_t_1 = (!(__pyx_v_self->data->data != 0));
  if (unlikely(__pyx_t_1)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1091
 *         self.data.data = <char **>malloc(self.data.m * sizeof(char *))
 *         if not self.data.data:
 *             raise MemoryError()             # <<<<<<<<<<<<<<
 * 
 *     cdef resize(self):
 */
    PyErr_NoMemory(); __PYX_ERR(2, 1091, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":1090
 *         self.data.m = _INIT_VEC_CAP
 *         self.data.data = <char **>malloc(self.data.m * sizeof(char *))
 *         if not self.data.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1083
 *         StringVectorData *data
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.data = <StringVectorData *>PyMem_Malloc(sizeof(StringVectorData))
 *         if not self.data:
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.StringVector.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1093
 *             raise MemoryError()
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             char **orig_data
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_12StringVector_resize(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *__pyx_v_self) {
  char **__pyx_v_orig_data;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_m;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  int __pyx_t_4;
  char **__pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("resize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1098
 *             Py_ssize_t i, m
 * 
 *         m = self.data.m             # <<<<<<<<<<<<<<
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 * 
 */
  __pyx_t_1 = __pyx_v_self->data->m;
  __pyx_v_m = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":1099
 * 
 *         m = self.data.m
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)             # <<<<<<<<<<<<<<
 * 
 *         orig_data = self.data.data
 */
  __pyx_t_1 = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;
  __pyx_t_2 = (__pyx_v_self->data->m * 4);
  __pyx_t_4 = (__pyx_t_1 > __pyx_t_2);
  if (__pyx_t_4) {
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_3 = __pyx_t_2;
  }
  __pyx_v_self->data->m = __pyx_t_3;

  /* "pandas/_libs/hashtable_class_helper.pxi":1101
 *         self.data.m = max(self.data.m * 4, _INIT_VEC_CAP)
 * 
 *         orig_data = self.data.data             # <<<<<<<<<<<<<<
 *         self.data.data = <char **>malloc(self.data.m * sizeof(char *))
 *         if not self.data.data:
 */
  __pyx_t_5 = __pyx_v_self->data->data;
  __pyx_v_orig_data = __pyx_t_5;

  /* "pandas/_libs/hashtable_class_helper.pxi":1102
 * 
 *         orig_data = self.data.data
 *         self.data.data = <char **>malloc(self.data.m * sizeof(char *))             # <<<<<<<<<<<<<<
 *         if not self.data.data:
 *             raise MemoryError()
 */
  __pyx_v_self->data->data = ((char **)malloc((__pyx_v_self->data->m * (sizeof(char *)))));

  /* "pandas/_libs/hashtable_class_helper.pxi":1103
 *         orig_data = self.data.data
 *         self.data.data = <char **>malloc(self.data.m * sizeof(char *))
 *         if not self.data.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         for i in range(m):
 */
  __pyx_t_4 = (!(__pyx_v_self->data->data != 0));
  if (unlikely(__pyx_t_4)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1104
 *         self.data.data = <char **>malloc(self.data.m * sizeof(char *))
 *         if not self.data.data:
 *             raise MemoryError()             # <<<<<<<<<<<<<<
 *         for i in range(m):
 *             self.data.data[i] = orig_data[i]
 */
    PyErr_NoMemory(); __PYX_ERR(2, 1104, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":1103
 *         orig_data = self.data.data
 *         self.data.data = <char **>malloc(self.data.m * sizeof(char *))
 *         if not self.data.data:             # <<<<<<<<<<<<<<
 *             raise MemoryError()
 *         for i in range(m):
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1105
 *         if not self.data.data:
 *             raise MemoryError()
 *         for i in range(m):             # <<<<<<<<<<<<<<
 *             self.data.data[i] = orig_data[i]
 * 
 */
  __pyx_t_3 = __pyx_v_m;
  __pyx_t_1 = __pyx_t_3;
  for (__pyx_t_2 = 0; __pyx_t_2 < __pyx_t_1; __pyx_t_2+=1) {
    __pyx_v_i = __pyx_t_2;

    /* "pandas/_libs/hashtable_class_helper.pxi":1106
 *             raise MemoryError()
 *         for i in range(m):
 *             self.data.data[i] = orig_data[i]             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
    (__pyx_v_self->data->data[__pyx_v_i]) = (__pyx_v_orig_data[__pyx_v_i]);
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1093
 *             raise MemoryError()
 * 
 *     cdef resize(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             char **orig_data
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.StringVector.resize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1108
 *             self.data.data[i] = orig_data[i]
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             if self.data.data is not NULL:
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_12StringVector_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_12StringVector_3__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_12StringVector_2__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_12StringVector_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":1109
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             if self.data.data is not NULL:
 *                 free(self.data.data)
 */
  __pyx_t_1 = (__pyx_v_self->data != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1110
 *     def __dealloc__(self):
 *         if self.data is not NULL:
 *             if self.data.data is not NULL:             # <<<<<<<<<<<<<<
 *                 free(self.data.data)
 *             PyMem_Free(self.data)
 */
    __pyx_t_1 = (__pyx_v_self->data->data != NULL);
    if (__pyx_t_1) {

      /* "pandas/_libs/hashtable_class_helper.pxi":1111
 *         if self.data is not NULL:
 *             if self.data.data is not NULL:
 *                 free(self.data.data)             # <<<<<<<<<<<<<<
 *             PyMem_Free(self.data)
 *             self.data = NULL
 */
      free(__pyx_v_self->data->data);

      /* "pandas/_libs/hashtable_class_helper.pxi":1110
 *     def __dealloc__(self):
 *         if self.data is not NULL:
 *             if self.data.data is not NULL:             # <<<<<<<<<<<<<<
 *                 free(self.data.data)
 *             PyMem_Free(self.data)
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":1112
 *             if self.data.data is not NULL:
 *                 free(self.data.data)
 *             PyMem_Free(self.data)             # <<<<<<<<<<<<<<
 *             self.data = NULL
 * 
 */
    PyMem_Free(__pyx_v_self->data);

    /* "pandas/_libs/hashtable_class_helper.pxi":1113
 *                 free(self.data.data)
 *             PyMem_Free(self.data)
 *             self.data = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
    __pyx_v_self->data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":1109
 * 
 *     def __dealloc__(self):
 *         if self.data is not NULL:             # <<<<<<<<<<<<<<
 *             if self.data.data is not NULL:
 *                 free(self.data.data)
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1108
 *             self.data.data[i] = orig_data[i]
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.data is not NULL:
 *             if self.data.data is not NULL:
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":1115
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_12StringVector_5__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_12StringVector_5__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12StringVector_4__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_12StringVector_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *__pyx_v_self) {
  Py_ssize_t __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":1116
 * 
 *     def __len__(self) -> int:
 *         return self.data.n             # <<<<<<<<<<<<<<
 * 
 *     cpdef ndarray[object, ndim=1] to_array(self):
 */
  __pyx_r = __pyx_v_self->data->n;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1115
 *             self.data = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.data.n
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1118
 *         return self.data.n
 * 
 *     cpdef ndarray[object, ndim=1] to_array(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             ndarray ao
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12StringVector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_12StringVector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *__pyx_v_self, int __pyx_skip_dispatch) {
  PyArrayObject *__pyx_v_ao = 0;
  PyObject *__pyx_v_val = 0;
  Py_ssize_t __pyx_v_i;
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  Py_ssize_t __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_to_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1118, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_12StringVector_7to_array)) {
        __Pyx_XDECREF((PyObject *)__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1118, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 1118, __pyx_L1_error)
        __pyx_r = ((PyArrayObject *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1124
 *             object val
 * 
 *         ao = np.empty(self.data.n, dtype=object)             # <<<<<<<<<<<<<<
 *         for i in range(self.data.n):
 *             val = self.data.data[i]
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_empty); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_self->data->n); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(2, 1124, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_builtin_object) < 0) __PYX_ERR(2, 1124, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1124, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 1124, __pyx_L1_error)
  __pyx_v_ao = ((PyArrayObject *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1125
 * 
 *         ao = np.empty(self.data.n, dtype=object)
 *         for i in range(self.data.n):             # <<<<<<<<<<<<<<
 *             val = self.data.data[i]
 *             ao[i] = val
 */
  __pyx_t_6 = __pyx_v_self->data->n;
  __pyx_t_7 = __pyx_t_6;
  for (__pyx_t_8 = 0; __pyx_t_8 < __pyx_t_7; __pyx_t_8+=1) {
    __pyx_v_i = __pyx_t_8;

    /* "pandas/_libs/hashtable_class_helper.pxi":1126
 *         ao = np.empty(self.data.n, dtype=object)
 *         for i in range(self.data.n):
 *             val = self.data.data[i]             # <<<<<<<<<<<<<<
 *             ao[i] = val
 *         self.external_view_exists = True
 */
    __pyx_t_4 = __Pyx_PyBytes_FromString((__pyx_v_self->data->data[__pyx_v_i])); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_XDECREF_SET(__pyx_v_val, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":1127
 *         for i in range(self.data.n):
 *             val = self.data.data[i]
 *             ao[i] = val             # <<<<<<<<<<<<<<
 *         self.external_view_exists = True
 *         self.data.m = self.data.n
 */
    if (unlikely((__Pyx_SetItemInt(((PyObject *)__pyx_v_ao), __pyx_v_i, __pyx_v_val, Py_ssize_t, 1, PyInt_FromSsize_t, 0, 1, 1) < 0))) __PYX_ERR(2, 1127, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1128
 *             val = self.data.data[i]
 *             ao[i] = val
 *         self.external_view_exists = True             # <<<<<<<<<<<<<<
 *         self.data.m = self.data.n
 *         return ao
 */
  __pyx_v_self->__pyx_base.external_view_exists = 1;

  /* "pandas/_libs/hashtable_class_helper.pxi":1129
 *             ao[i] = val
 *         self.external_view_exists = True
 *         self.data.m = self.data.n             # <<<<<<<<<<<<<<
 *         return ao
 * 
 */
  __pyx_t_6 = __pyx_v_self->data->n;
  __pyx_v_self->data->m = __pyx_t_6;

  /* "pandas/_libs/hashtable_class_helper.pxi":1130
 *         self.external_view_exists = True
 *         self.data.m = self.data.n
 *         return ao             # <<<<<<<<<<<<<<
 * 
 *     cdef void append(self, char *x):
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_ao);
  __pyx_r = ((PyArrayObject *)__pyx_v_ao);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1118
 *         return self.data.n
 * 
 *     cpdef ndarray[object, ndim=1] to_array(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             ndarray ao
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.StringVector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_ao);
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12StringVector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_12StringVector_7to_array = {"to_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12StringVector_7to_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12StringVector_7to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("to_array", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "to_array", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12StringVector_6to_array(((struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12StringVector_6to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_6pandas_5_libs_9hashtable_12StringVector_to_array(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.StringVector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1132
 *         return ao
 * 
 *     cdef void append(self, char *x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

static void __pyx_f_6pandas_5_libs_9hashtable_12StringVector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *__pyx_v_self, char *__pyx_v_x) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("append", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1134
 *     cdef void append(self, char *x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             self.resize()
 * 
 */
  __pyx_t_1 = __pyx_fuse_12__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_self->data); if (unlikely(__pyx_t_1 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1134, __pyx_L1_error)
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1135
 * 
 *         if needs_resize(self.data):
 *             self.resize()             # <<<<<<<<<<<<<<
 * 
 *         append_data_string(self.data, x)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_StringVector *)__pyx_v_self->__pyx_vtab)->resize(__pyx_v_self); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1135, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":1134
 *     cdef void append(self, char *x):
 * 
 *         if needs_resize(self.data):             # <<<<<<<<<<<<<<
 *             self.resize()
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1137
 *             self.resize()
 * 
 *         append_data_string(self.data, x)             # <<<<<<<<<<<<<<
 * 
 *     cdef extend(self, ndarray[object] x):
 */
  __pyx_f_6pandas_5_libs_9hashtable_append_data_string(__pyx_v_self->data, __pyx_v_x); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1137, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1132
 *         return ao
 * 
 *     cdef void append(self, char *x):             # <<<<<<<<<<<<<<
 * 
 *         if needs_resize(self.data):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.StringVector.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "pandas/_libs/hashtable_class_helper.pxi":1139
 *         append_data_string(self.data, x)
 * 
 *     cdef extend(self, ndarray[object] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_12StringVector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *__pyx_v_self, PyArrayObject *__pyx_v_x) {
  Py_ssize_t __pyx_v_i;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_x;
  __Pyx_Buffer __pyx_pybuffer_x;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  char *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extend", 1);
  __pyx_pybuffer_x.pybuffer.buf = NULL;
  __pyx_pybuffer_x.refcount = 0;
  __pyx_pybuffernd_x.data = NULL;
  __pyx_pybuffernd_x.rcbuffer = &__pyx_pybuffer_x;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_x.rcbuffer->pybuffer, (PyObject*)__pyx_v_x, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(2, 1139, __pyx_L1_error)
  }
  __pyx_pybuffernd_x.diminfo[0].strides = __pyx_pybuffernd_x.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_x.diminfo[0].shape = __pyx_pybuffernd_x.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_class_helper.pxi":1140
 * 
 *     cdef extend(self, ndarray[object] x):
 *         for i in range(len(x)):             # <<<<<<<<<<<<<<
 *             self.append(x[i])
 * 
 */
  __pyx_t_1 = PyObject_Length(((PyObject *)__pyx_v_x)); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(2, 1140, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "pandas/_libs/hashtable_class_helper.pxi":1141
 *     cdef extend(self, ndarray[object] x):
 *         for i in range(len(x)):
 *             self.append(x[i])             # <<<<<<<<<<<<<<
 * 
 * 
 */
    __pyx_t_5 = __pyx_v_i;
    __pyx_t_6 = -1;
    if (__pyx_t_5 < 0) {
      __pyx_t_5 += __pyx_pybuffernd_x.diminfo[0].shape;
      if (unlikely(__pyx_t_5 < 0)) __pyx_t_6 = 0;
    } else if (unlikely(__pyx_t_5 >= __pyx_pybuffernd_x.diminfo[0].shape)) __pyx_t_6 = 0;
    if (unlikely(__pyx_t_6 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_6);
      __PYX_ERR(2, 1141, __pyx_L1_error)
    }
    __pyx_t_4 = (PyObject *) *__Pyx_BufPtrStrided1d(PyObject **, __pyx_pybuffernd_x.rcbuffer->pybuffer.buf, __pyx_t_5, __pyx_pybuffernd_x.diminfo[0].strides);
    if (unlikely(__pyx_t_4 == NULL)) __pyx_t_4 = Py_None;
    __Pyx_INCREF((PyObject*)__pyx_t_4);
    __pyx_t_7 = __Pyx_PyObject_AsWritableString(__pyx_t_4); if (unlikely((!__pyx_t_7) && PyErr_Occurred())) __PYX_ERR(2, 1141, __pyx_L1_error)
    ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_StringVector *)__pyx_v_self->__pyx_vtab)->append(__pyx_v_self, __pyx_t_7); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1141, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1139
 *         append_data_string(self.data, x)
 * 
 *     cdef extend(self, ndarray[object] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_x.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.StringVector.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_x.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12StringVector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_12StringVector_9__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12StringVector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12StringVector_9__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12StringVector_8__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12StringVector_8__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.StringVector.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12StringVector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_12StringVector_11__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12StringVector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12StringVector_11__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.StringVector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12StringVector_10__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12StringVector_10__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.StringVector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1151
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.n = 0
 *         self.m = _INIT_VEC_CAP
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_12ObjectVector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_12ObjectVector_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 0, 0, __pyx_nargs); return -1;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_VARARGS(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__cinit__", 0))) return -1;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12ObjectVector___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_12ObjectVector___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  char *__pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1152
 * 
 *     def __cinit__(self):
 *         self.n = 0             # <<<<<<<<<<<<<<
 *         self.m = _INIT_VEC_CAP
 *         self.ao = np.empty(_INIT_VEC_CAP, dtype=object)
 */
  __pyx_v_self->n = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1153
 *     def __cinit__(self):
 *         self.n = 0
 *         self.m = _INIT_VEC_CAP             # <<<<<<<<<<<<<<
 *         self.ao = np.empty(_INIT_VEC_CAP, dtype=object)
 *         self.data = <PyObject**>self.ao.data
 */
  __pyx_v_self->m = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;

  /* "pandas/_libs/hashtable_class_helper.pxi":1154
 *         self.n = 0
 *         self.m = _INIT_VEC_CAP
 *         self.ao = np.empty(_INIT_VEC_CAP, dtype=object)             # <<<<<<<<<<<<<<
 *         self.data = <PyObject**>self.ao.data
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_empty); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(2, 1154, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_builtin_object) < 0) __PYX_ERR(2, 1154, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1154, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 1154, __pyx_L1_error)
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->ao);
  __Pyx_DECREF((PyObject *)__pyx_v_self->ao);
  __pyx_v_self->ao = ((PyArrayObject *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1155
 *         self.m = _INIT_VEC_CAP
 *         self.ao = np.empty(_INIT_VEC_CAP, dtype=object)
 *         self.data = <PyObject**>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
  __pyx_t_4 = ((PyObject *)__pyx_v_self->ao);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_t_5 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_4)); if (unlikely(__pyx_t_5 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 1155, __pyx_L1_error)
  __pyx_v_self->data = ((PyObject **)__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1151
 *         ndarray ao
 * 
 *     def __cinit__(self):             # <<<<<<<<<<<<<<
 *         self.n = 0
 *         self.m = _INIT_VEC_CAP
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.ObjectVector.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1157
 *         self.data = <PyObject**>self.ao.data
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.n
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_12ObjectVector_3__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_12ObjectVector_3__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12ObjectVector_2__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_12ObjectVector_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_self) {
  Py_ssize_t __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":1158
 * 
 *     def __len__(self) -> int:
 *         return self.n             # <<<<<<<<<<<<<<
 * 
 *     cdef append(self, object obj):
 */
  __pyx_r = __pyx_v_self->n;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1157
 *         self.data = <PyObject**>self.ao.data
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.n
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1160
 *         return self.n
 * 
 *     cdef append(self, object obj):             # <<<<<<<<<<<<<<
 *         if self.n == self.m:
 *             if self.external_view_exists:
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_12ObjectVector_append(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_self, PyObject *__pyx_v_obj) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  char *__pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("append", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1161
 * 
 *     cdef append(self, object obj):
 *         if self.n == self.m:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  __pyx_t_1 = (__pyx_v_self->n == __pyx_v_self->m);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1162
 *     cdef append(self, object obj):
 *         if self.n == self.m:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":1163
 *         if self.n == self.m:
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "             # <<<<<<<<<<<<<<
 *                                  "Vector.resize() needed")
 *             self.m = max(self.m * 2, _INIT_VEC_CAP)
 */
      __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1163, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_Raise(__pyx_t_2, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __PYX_ERR(2, 1163, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":1162
 *     cdef append(self, object obj):
 *         if self.n == self.m:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":1165
 *                 raise ValueError("external reference but "
 *                                  "Vector.resize() needed")
 *             self.m = max(self.m * 2, _INIT_VEC_CAP)             # <<<<<<<<<<<<<<
 *             self.ao.resize(self.m, refcheck=False)
 *             self.data = <PyObject**>self.ao.data
 */
    __pyx_t_3 = __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP;
    __pyx_t_4 = (__pyx_v_self->m * 2);
    __pyx_t_1 = (__pyx_t_3 > __pyx_t_4);
    if (__pyx_t_1) {
      __pyx_t_5 = __pyx_t_3;
    } else {
      __pyx_t_5 = __pyx_t_4;
    }
    __pyx_v_self->m = __pyx_t_5;

    /* "pandas/_libs/hashtable_class_helper.pxi":1166
 *                                  "Vector.resize() needed")
 *             self.m = max(self.m * 2, _INIT_VEC_CAP)
 *             self.ao.resize(self.m, refcheck=False)             # <<<<<<<<<<<<<<
 *             self.data = <PyObject**>self.ao.data
 * 
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1166, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_6 = PyInt_FromSsize_t(__pyx_v_self->m); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1166, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1166, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_6);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_6)) __PYX_ERR(2, 1166, __pyx_L1_error);
    __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1166, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 1166, __pyx_L1_error)
    __pyx_t_8 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_7, __pyx_t_6); if (unlikely(!__pyx_t_8)) __PYX_ERR(2, 1166, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":1167
 *             self.m = max(self.m * 2, _INIT_VEC_CAP)
 *             self.ao.resize(self.m, refcheck=False)
 *             self.data = <PyObject**>self.ao.data             # <<<<<<<<<<<<<<
 * 
 *         Py_INCREF(obj)
 */
    __pyx_t_8 = ((PyObject *)__pyx_v_self->ao);
    __Pyx_INCREF(__pyx_t_8);
    __pyx_t_9 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_t_8)); if (unlikely(__pyx_t_9 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 1167, __pyx_L1_error)
    __pyx_v_self->data = ((PyObject **)__pyx_t_9);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":1161
 * 
 *     cdef append(self, object obj):
 *         if self.n == self.m:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1169
 *             self.data = <PyObject**>self.ao.data
 * 
 *         Py_INCREF(obj)             # <<<<<<<<<<<<<<
 *         self.data[self.n] = <PyObject*>obj
 *         self.n += 1
 */
  Py_INCREF(__pyx_v_obj);

  /* "pandas/_libs/hashtable_class_helper.pxi":1170
 * 
 *         Py_INCREF(obj)
 *         self.data[self.n] = <PyObject*>obj             # <<<<<<<<<<<<<<
 *         self.n += 1
 * 
 */
  (__pyx_v_self->data[__pyx_v_self->n]) = ((PyObject *)__pyx_v_obj);

  /* "pandas/_libs/hashtable_class_helper.pxi":1171
 *         Py_INCREF(obj)
 *         self.data[self.n] = <PyObject*>obj
 *         self.n += 1             # <<<<<<<<<<<<<<
 * 
 *     cpdef ndarray[object, ndim=1] to_array(self):
 */
  __pyx_v_self->n = (__pyx_v_self->n + 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1160
 *         return self.n
 * 
 *     cdef append(self, object obj):             # <<<<<<<<<<<<<<
 *         if self.n == self.m:
 *             if self.external_view_exists:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("pandas._libs.hashtable.ObjectVector.append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1173
 *         self.n += 1
 * 
 *     cpdef ndarray[object, ndim=1] to_array(self):             # <<<<<<<<<<<<<<
 *         if self.m != self.n:
 *             if self.external_view_exists:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12ObjectVector_5to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyArrayObject *__pyx_f_6pandas_5_libs_9hashtable_12ObjectVector_to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_self, int __pyx_skip_dispatch) {
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_to_array); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1173, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_12ObjectVector_5to_array)) {
        __Pyx_XDECREF((PyObject *)__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1173, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 1173, __pyx_L1_error)
        __pyx_r = ((PyArrayObject *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1174
 * 
 *     cpdef ndarray[object, ndim=1] to_array(self):
 *         if self.m != self.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("should have raised on append()")
 */
  __pyx_t_6 = (__pyx_v_self->m != __pyx_v_self->n);
  if (__pyx_t_6) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1175
 *     cpdef ndarray[object, ndim=1] to_array(self):
 *         if self.m != self.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.n, refcheck=False)
 */
    if (unlikely(__pyx_v_self->__pyx_base.external_view_exists)) {

      /* "pandas/_libs/hashtable_class_helper.pxi":1176
 *         if self.m != self.n:
 *             if self.external_view_exists:
 *                 raise ValueError("should have raised on append()")             # <<<<<<<<<<<<<<
 *             self.ao.resize(self.n, refcheck=False)
 *             self.m = self.n
 */
      __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1176, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_Raise(__pyx_t_1, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __PYX_ERR(2, 1176, __pyx_L1_error)

      /* "pandas/_libs/hashtable_class_helper.pxi":1175
 *     cpdef ndarray[object, ndim=1] to_array(self):
 *         if self.m != self.n:
 *             if self.external_view_exists:             # <<<<<<<<<<<<<<
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.n, refcheck=False)
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":1177
 *             if self.external_view_exists:
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.n, refcheck=False)             # <<<<<<<<<<<<<<
 *             self.m = self.n
 *         self.external_view_exists = True
 */
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->ao), __pyx_n_s_resize); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1177, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_self->n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1177, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1177, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 1177, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1177, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_refcheck, Py_False) < 0) __PYX_ERR(2, 1177, __pyx_L1_error)
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1177, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":1178
 *                 raise ValueError("should have raised on append()")
 *             self.ao.resize(self.n, refcheck=False)
 *             self.m = self.n             # <<<<<<<<<<<<<<
 *         self.external_view_exists = True
 *         return self.ao
 */
    __pyx_t_7 = __pyx_v_self->n;
    __pyx_v_self->m = __pyx_t_7;

    /* "pandas/_libs/hashtable_class_helper.pxi":1174
 * 
 *     cpdef ndarray[object, ndim=1] to_array(self):
 *         if self.m != self.n:             # <<<<<<<<<<<<<<
 *             if self.external_view_exists:
 *                 raise ValueError("should have raised on append()")
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1179
 *             self.ao.resize(self.n, refcheck=False)
 *             self.m = self.n
 *         self.external_view_exists = True             # <<<<<<<<<<<<<<
 *         return self.ao
 * 
 */
  __pyx_v_self->__pyx_base.external_view_exists = 1;

  /* "pandas/_libs/hashtable_class_helper.pxi":1180
 *             self.m = self.n
 *         self.external_view_exists = True
 *         return self.ao             # <<<<<<<<<<<<<<
 * 
 *     cdef extend(self, ndarray[object] x):
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->ao);
  __pyx_r = ((PyArrayObject *)__pyx_v_self->ao);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1173
 *         self.n += 1
 * 
 *     cpdef ndarray[object, ndim=1] to_array(self):             # <<<<<<<<<<<<<<
 *         if self.m != self.n:
 *             if self.external_view_exists:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.ObjectVector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12ObjectVector_5to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_12ObjectVector_5to_array = {"to_array", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12ObjectVector_5to_array, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12ObjectVector_5to_array(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_array (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("to_array", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "to_array", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12ObjectVector_4to_array(((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12ObjectVector_4to_array(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_array", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_6pandas_5_libs_9hashtable_12ObjectVector_to_array(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.ObjectVector.to_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1182
 *         return self.ao
 * 
 *     cdef extend(self, ndarray[object] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_12ObjectVector_extend(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_self, PyArrayObject *__pyx_v_x) {
  Py_ssize_t __pyx_v_i;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_x;
  __Pyx_Buffer __pyx_pybuffer_x;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("extend", 1);
  __pyx_pybuffer_x.pybuffer.buf = NULL;
  __pyx_pybuffer_x.refcount = 0;
  __pyx_pybuffernd_x.data = NULL;
  __pyx_pybuffernd_x.rcbuffer = &__pyx_pybuffer_x;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_x.rcbuffer->pybuffer, (PyObject*)__pyx_v_x, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(2, 1182, __pyx_L1_error)
  }
  __pyx_pybuffernd_x.diminfo[0].strides = __pyx_pybuffernd_x.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_x.diminfo[0].shape = __pyx_pybuffernd_x.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_class_helper.pxi":1183
 * 
 *     cdef extend(self, ndarray[object] x):
 *         for i in range(len(x)):             # <<<<<<<<<<<<<<
 *             self.append(x[i])
 * 
 */
  __pyx_t_1 = PyObject_Length(((PyObject *)__pyx_v_x)); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(2, 1183, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "pandas/_libs/hashtable_class_helper.pxi":1184
 *     cdef extend(self, ndarray[object] x):
 *         for i in range(len(x)):
 *             self.append(x[i])             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
    __pyx_t_5 = __pyx_v_i;
    __pyx_t_6 = -1;
    if (__pyx_t_5 < 0) {
      __pyx_t_5 += __pyx_pybuffernd_x.diminfo[0].shape;
      if (unlikely(__pyx_t_5 < 0)) __pyx_t_6 = 0;
    } else if (unlikely(__pyx_t_5 >= __pyx_pybuffernd_x.diminfo[0].shape)) __pyx_t_6 = 0;
    if (unlikely(__pyx_t_6 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_6);
      __PYX_ERR(2, 1184, __pyx_L1_error)
    }
    __pyx_t_4 = (PyObject *) *__Pyx_BufPtrStrided1d(PyObject **, __pyx_pybuffernd_x.rcbuffer->pybuffer.buf, __pyx_t_5, __pyx_pybuffernd_x.diminfo[0].strides);
    if (unlikely(__pyx_t_4 == NULL)) __pyx_t_4 = Py_None;
    __Pyx_INCREF((PyObject*)__pyx_t_4);
    __pyx_t_7 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_v_self->__pyx_vtab)->append(__pyx_v_self, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1184, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1182
 *         return self.ao
 * 
 *     cdef extend(self, ndarray[object] x):             # <<<<<<<<<<<<<<
 *         for i in range(len(x)):
 *             self.append(x[i])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_x.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ObjectVector.extend", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_x.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12ObjectVector_7__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_12ObjectVector_7__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12ObjectVector_7__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12ObjectVector_7__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12ObjectVector_6__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12ObjectVector_6__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.ObjectVector.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12ObjectVector_9__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_12ObjectVector_9__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12ObjectVector_9__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_12ObjectVector_9__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.ObjectVector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12ObjectVector_8__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12ObjectVector_8__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.ObjectVector.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_9HashTable_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_9HashTable_1__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_9HashTable_1__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_9HashTable_1__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_9HashTable___reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_9HashTable___reduce_cython__(struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable *__pyx_v_self) {
  PyObject *__pyx_v_state = 0;
  PyObject *__pyx_v__dict = 0;
  int __pyx_v_use_setstate;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = ()             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
  __Pyx_INCREF(__pyx_empty_tuple);
  __pyx_v_state = __pyx_empty_tuple;

  /* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
  __pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v__dict = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":7
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  __pyx_t_2 = (__pyx_v__dict != Py_None);
  if (__pyx_t_2) {

    /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v__dict);
    __Pyx_GIVEREF(__pyx_v__dict);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict)) __PYX_ERR(1, 8, __pyx_L1_error);
    __pyx_t_3 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 8, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = False
 */
    __pyx_v_use_setstate = 1;

    /* "(tree fragment)":7
 *     state = ()
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
    goto __pyx_L3;
  }

  /* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = False             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_HashTable, (type(self), 0xe3b0c44, None), state
 */
  /*else*/ {
    __pyx_v_use_setstate = 0;
  }
  __pyx_L3:;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = False
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_HashTable, (type(self), 0xe3b0c44, None), state
 *     else:
 */
  if (__pyx_v_use_setstate) {

    /* "(tree fragment)":13
 *         use_setstate = False
 *     if use_setstate:
 *         return __pyx_unpickle_HashTable, (type(self), 0xe3b0c44, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_HashTable, (type(self), 0xe3b0c44, state)
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_pyx_unpickle_HashTable); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))))) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_int_238750788);
    __Pyx_GIVEREF(__pyx_int_238750788);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_238750788)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None)) __PYX_ERR(1, 13, __pyx_L1_error);
    __pyx_t_4 = PyTuple_New(3); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 2, __pyx_v_state)) __PYX_ERR(1, 13, __pyx_L1_error);
    __pyx_t_3 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "(tree fragment)":12
 *     else:
 *         use_setstate = False
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_HashTable, (type(self), 0xe3b0c44, None), state
 *     else:
 */
  }

  /* "(tree fragment)":15
 *         return __pyx_unpickle_HashTable, (type(self), 0xe3b0c44, None), state
 *     else:
 *         return __pyx_unpickle_HashTable, (type(self), 0xe3b0c44, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_HashTable__set_state(self, __pyx_state)
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_HashTable); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))))) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_int_238750788);
    __Pyx_GIVEREF(__pyx_int_238750788);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_238750788)) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_INCREF(__pyx_v_state);
    __Pyx_GIVEREF(__pyx_v_state);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state)) __PYX_ERR(1, 15, __pyx_L1_error);
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 15, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error);
    __pyx_t_4 = 0;
    __pyx_t_1 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;
  }

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.HashTable.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_state);
  __Pyx_XDECREF(__pyx_v__dict);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_HashTable, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_HashTable__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_9HashTable_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_9HashTable_3__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_9HashTable_3__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_9HashTable_3__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 16, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 16, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 16, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_9HashTable_2__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_9HashTable_2__setstate_cython__(struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":17
 *         return __pyx_unpickle_HashTable, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_HashTable__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(1, 17, __pyx_L1_error)
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable___pyx_unpickle_HashTable__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_HashTable, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_HashTable__set_state(self, __pyx_state)
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1197
 * cdef class Complex128HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_complex128()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __pyx_t_5numpy_int64_t __pyx_v_size_hint;
  int __pyx_v_uses_mask;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,&__pyx_n_s_uses_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1197, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uses_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1197, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 1197, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_size_hint = __Pyx_PyInt_As_npy_int64(values[0]); if (unlikely((__pyx_v_size_hint == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 1197, __pyx_L3_error)
    } else {
      __pyx_v_size_hint = ((__pyx_t_5numpy_int64_t)1);
    }
    if (values[1]) {
      __pyx_v_uses_mask = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_uses_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1197, __pyx_L3_error)
    } else {
      __pyx_v_uses_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 0, 2, __pyx_nargs); __PYX_ERR(2, 1197, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)__pyx_v_self), __pyx_v_size_hint, __pyx_v_uses_mask);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  khuint_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __pyx_t_5numpy_int64_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1198
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_complex128()             # <<<<<<<<<<<<<<
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_complex128(self.table, size_hint)
 */
  __pyx_v_self->table = kh_init_complex128();

  /* "pandas/_libs/hashtable_class_helper.pxi":1199
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_complex128()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)             # <<<<<<<<<<<<<<
 *         kh_resize_complex128(self.table, size_hint)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = kh_needed_n_buckets(__pyx_v_size_hint);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_1, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1199, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(2, 1199, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_6) {
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_5 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1199, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_int64(__pyx_t_3); if (unlikely((__pyx_t_7 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 1199, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_size_hint = __pyx_t_7;

  /* "pandas/_libs/hashtable_class_helper.pxi":1200
 *         self.table = kh_init_complex128()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_complex128(self.table, size_hint)             # <<<<<<<<<<<<<<
 * 
 *         self.uses_mask = uses_mask
 */
  kh_resize_complex128(__pyx_v_self->table, __pyx_v_size_hint);

  /* "pandas/_libs/hashtable_class_helper.pxi":1202
 *         kh_resize_complex128(self.table, size_hint)
 * 
 *         self.uses_mask = uses_mask             # <<<<<<<<<<<<<<
 *         self.na_position = -1
 * 
 */
  __pyx_v_self->uses_mask = __pyx_v_uses_mask;

  /* "pandas/_libs/hashtable_class_helper.pxi":1203
 * 
 *         self.uses_mask = uses_mask
 *         self.na_position = -1             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
  __pyx_v_self->na_position = -1LL;

  /* "pandas/_libs/hashtable_class_helper.pxi":1197
 * cdef class Complex128HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_complex128()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1205
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_3__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_3__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_2__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  long __pyx_t_1;
  int __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":1206
 * 
 *     def __len__(self) -> int:
 *         return self.table.size + (0 if self.na_position == -1 else 1)             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_2 = (__pyx_v_self->na_position == -1LL);
  if (__pyx_t_2) {
    __pyx_t_1 = 0;
  } else {
    __pyx_t_1 = 1;
  }
  __pyx_r = (__pyx_v_self->table->size + __pyx_t_1);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1205
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1208
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_complex128(self.table)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_5__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_5__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_4__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":1209
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_complex128(self.table)
 *             self.table = NULL
 */
  __pyx_t_1 = (__pyx_v_self->table != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1210
 *     def __dealloc__(self):
 *         if self.table is not NULL:
 *             kh_destroy_complex128(self.table)             # <<<<<<<<<<<<<<
 *             self.table = NULL
 * 
 */
    kh_destroy_complex128(__pyx_v_self->table);

    /* "pandas/_libs/hashtable_class_helper.pxi":1211
 *         if self.table is not NULL:
 *             kh_destroy_complex128(self.table)
 *             self.table = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __contains__(self, object key) -> bool:
 */
    __pyx_v_self->table = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":1209
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_complex128(self.table)
 *             self.table = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1208
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_complex128(self.table)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":1213
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__contains__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_6__contains__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)__pyx_v_self), ((PyObject *)__pyx_v_key));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, PyObject *__pyx_v_key) {
  khiter_t __pyx_v_k;
  khcomplex128_t __pyx_v_ckey;
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  __pyx_t_double_complex __pyx_t_3;
  khcomplex128_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1220
 *             khcomplex128_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_1 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_7missing_checknull(__pyx_v_key, 0, NULL); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1220, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1221
 * 
 *         if self.uses_mask and checknull(key):
 *             return -1 != self.na_position             # <<<<<<<<<<<<<<
 * 
 *         ckey = to_khcomplex128_t(key)
 */
    __pyx_r = (-1LL != __pyx_v_self->na_position);
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":1220
 *             khcomplex128_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1223
 *             return -1 != self.na_position
 * 
 *         ckey = to_khcomplex128_t(key)             # <<<<<<<<<<<<<<
 *         k = kh_get_complex128(self.table, ckey)
 *         return k != self.table.n_buckets
 */
  __pyx_t_3 = __Pyx_PyComplex_As___pyx_t_double_complex(__pyx_v_key); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1223, __pyx_L1_error)
  __pyx_t_4 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex128_t(__pyx_t_3); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1223, __pyx_L1_error)
  __pyx_v_ckey = __pyx_t_4;

  /* "pandas/_libs/hashtable_class_helper.pxi":1224
 * 
 *         ckey = to_khcomplex128_t(key)
 *         k = kh_get_complex128(self.table, ckey)             # <<<<<<<<<<<<<<
 *         return k != self.table.n_buckets
 * 
 */
  __pyx_v_k = kh_get_complex128(__pyx_v_self->table, __pyx_v_ckey);

  /* "pandas/_libs/hashtable_class_helper.pxi":1225
 *         ckey = to_khcomplex128_t(key)
 *         k = kh_get_complex128(self.table, ckey)
 *         return k != self.table.n_buckets             # <<<<<<<<<<<<<<
 * 
 *     def sizeof(self, deep: bool = False) -> int:
 */
  __pyx_r = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1213
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1227
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_19Complex128HashTable_8sizeof, " return the size of my table in bytes ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_9sizeof = {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_19Complex128HashTable_8sizeof};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_deep = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sizeof (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_deep,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_deep);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1227, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "sizeof") < 0)) __PYX_ERR(2, 1227, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_deep = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sizeof", 0, 0, 1, __pyx_nargs); __PYX_ERR(2, 1227, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_8sizeof(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)__pyx_v_self), __pyx_v_deep);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep) {
  PyObject *__pyx_v_overhead = NULL;
  PyObject *__pyx_v_for_flags = NULL;
  PyObject *__pyx_v_for_pairs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  long __pyx_t_2;
  long __pyx_t_3;
  long __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sizeof", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1229
 *     def sizeof(self, deep: bool = False) -> int:
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)             # <<<<<<<<<<<<<<
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(complex128_t) + # keys
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(((4 * (sizeof(__pyx_t_5numpy_uint32_t))) + (3 * (sizeof(__pyx_t_5numpy_uint32_t *))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_overhead = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1230
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)             # <<<<<<<<<<<<<<
 *         for_pairs =  self.table.n_buckets * (sizeof(complex128_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 */
  __pyx_t_2 = (__pyx_v_self->table->n_buckets >> 5);
  __pyx_t_3 = 1;
  __pyx_t_5 = (__pyx_t_2 > __pyx_t_3);
  if (__pyx_t_5) {
    __pyx_t_4 = __pyx_t_2;
  } else {
    __pyx_t_4 = __pyx_t_3;
  }
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_t_4 * (sizeof(__pyx_t_5numpy_uint32_t)))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_flags = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1231
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(complex128_t) + # keys             # <<<<<<<<<<<<<<
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->n_buckets * ((sizeof(__pyx_t_double_complex)) + (sizeof(Py_ssize_t))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1231, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_pairs = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1233
 *         for_pairs =  self.table.n_buckets * (sizeof(complex128_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs             # <<<<<<<<<<<<<<
 * 
 *     def get_state(self) -> dict[str, int]:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Add(__pyx_v_overhead, __pyx_v_for_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyNumber_Add(__pyx_t_1, __pyx_v_for_pairs); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1233, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(__Pyx_Py3Int_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None) || __Pyx_RaiseUnexpectedTypeError("int", __pyx_t_6))) __PYX_ERR(2, 1233, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1227
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_overhead);
  __Pyx_XDECREF(__pyx_v_for_flags);
  __Pyx_XDECREF(__pyx_v_for_pairs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1235
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_19Complex128HashTable_10get_state, " returns infos about the state of the hashtable");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_11get_state = {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_19Complex128HashTable_10get_state};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_state (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_state", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_state", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_10get_state(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_state", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1237
 *     def get_state(self) -> dict[str, int]:
 *         """ returns infos about the state of the hashtable"""
 *         return {             # <<<<<<<<<<<<<<
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 */
  __Pyx_XDECREF(__pyx_r);

  /* "pandas/_libs/hashtable_class_helper.pxi":1238
 *         """ returns infos about the state of the hashtable"""
 *         return {
 *             'n_buckets' : self.table.n_buckets,             # <<<<<<<<<<<<<<
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_buckets); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1238, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_buckets, __pyx_t_2) < 0) __PYX_ERR(2, 1238, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1239
 *         return {
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,             # <<<<<<<<<<<<<<
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->size); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1239, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_size, __pyx_t_2) < 0) __PYX_ERR(2, 1238, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1240
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,             # <<<<<<<<<<<<<<
 *             'upper_bound' : self.table.upper_bound,
 *         }
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_occupied); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1240, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_occupied, __pyx_t_2) < 0) __PYX_ERR(2, 1238, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1241
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,             # <<<<<<<<<<<<<<
 *         }
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->upper_bound); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1241, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_upper_bound, __pyx_t_2) < 0) __PYX_ERR(2, 1238, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1235
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.get_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1244
 *         }
 * 
 *     cpdef get_item(self, complex128_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_19Complex128HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, __pyx_t_double_complex __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  khcomplex128_t __pyx_v_cval;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  khcomplex128_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1244, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_13get_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __pyx_PyComplex_FromComplex(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1244, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1244, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1263
 *             khcomplex128_t cval
 * 
 *         cval = to_khcomplex128_t(val)             # <<<<<<<<<<<<<<
 *         k = kh_get_complex128(self.table, cval)
 *         if k != self.table.n_buckets:
 */
  __pyx_t_7 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex128_t(__pyx_v_val); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1263, __pyx_L1_error)
  __pyx_v_cval = __pyx_t_7;

  /* "pandas/_libs/hashtable_class_helper.pxi":1264
 * 
 *         cval = to_khcomplex128_t(val)
 *         k = kh_get_complex128(self.table, cval)             # <<<<<<<<<<<<<<
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]
 */
  __pyx_v_k = kh_get_complex128(__pyx_v_self->table, __pyx_v_cval);

  /* "pandas/_libs/hashtable_class_helper.pxi":1265
 *         cval = to_khcomplex128_t(val)
 *         k = kh_get_complex128(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  __pyx_t_8 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  if (likely(__pyx_t_8)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1266
 *         k = kh_get_complex128(self.table, cval)
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(val)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->vals[__pyx_v_k])); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1266, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":1265
 *         cval = to_khcomplex128_t(val)
 *         k = kh_get_complex128(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1268
 *             return self.table.vals[k]
 *         else:
 *             raise KeyError(val)             # <<<<<<<<<<<<<<
 * 
 *     cpdef get_na(self):
 */
  /*else*/ {
    __pyx_t_1 = __pyx_PyComplex_FromComplex(__pyx_v_val); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1268, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1268, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 1268, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1244
 *         }
 * 
 *     cpdef get_item(self, complex128_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_19Complex128HashTable_12get_item, "Extracts the position of val from the hashtable.\n\n        Parameters\n        ----------\n        val : Scalar\n            The value that is looked up in the hashtable\n\n        Returns\n        -------\n        The position of the requested integer.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_13get_item = {"get_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_13get_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_19Complex128HashTable_12get_item};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_double_complex __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1244, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_item") < 0)) __PYX_ERR(2, 1244, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __Pyx_PyComplex_As___pyx_t_double_complex(values[0]); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1244, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_item", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 1244, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_12get_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, __pyx_t_double_complex __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_19Complex128HashTable_get_item(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1270
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_19Complex128HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1270, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_15get_na)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1270, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1278
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_6 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1279
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         if self.na_position == -1:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 1279, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":1278
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1281
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  __pyx_t_6 = (__pyx_v_self->na_position == -1LL);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1282
 * 
 *         if self.na_position == -1:
 *             raise KeyError("NA")             # <<<<<<<<<<<<<<
 *         return self.na_position
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_KeyError, __pyx_tuple__13, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1282, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(2, 1282, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":1281
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1283
 *         if self.na_position == -1:
 *             raise KeyError("NA")
 *         return self.na_position             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_item(self, complex128_t key, Py_ssize_t val):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->na_position); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1270
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_19Complex128HashTable_14get_na, "Extracts the position of na_value from the hashtable.\n\n        Returns\n        -------\n        The position of the last na value.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_15get_na = {"get_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_15get_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_19Complex128HashTable_14get_na};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_na", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_na", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_14get_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_19Complex128HashTable_get_na(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1285
 *         return self.na_position
 * 
 *     cpdef set_item(self, complex128_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_19Complex128HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, __pyx_t_double_complex __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  khcomplex128_t __pyx_v_ckey;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  khcomplex128_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1285, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_17set_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __pyx_PyComplex_FromComplex(__pyx_v_key); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1285, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1285, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_5 = __pyx_t_1; __pyx_t_6 = NULL;
        __pyx_t_7 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_7 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_3, __pyx_t_4};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1285, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1290
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             khcomplex128_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1293
 *             khcomplex128_t ckey
 * 
 *         ckey = to_khcomplex128_t(key)             # <<<<<<<<<<<<<<
 *         k = kh_put_complex128(self.table, ckey, &ret)
 *         if kh_exist_complex128(self.table, k):
 */
  __pyx_t_8 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex128_t(__pyx_v_key); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1293, __pyx_L1_error)
  __pyx_v_ckey = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":1294
 * 
 *         ckey = to_khcomplex128_t(key)
 *         k = kh_put_complex128(self.table, ckey, &ret)             # <<<<<<<<<<<<<<
 *         if kh_exist_complex128(self.table, k):
 *             self.table.vals[k] = val
 */
  __pyx_v_k = kh_put_complex128(__pyx_v_self->table, __pyx_v_ckey, (&__pyx_v_ret));

  /* "pandas/_libs/hashtable_class_helper.pxi":1295
 *         ckey = to_khcomplex128_t(key)
 *         k = kh_put_complex128(self.table, ckey, &ret)
 *         if kh_exist_complex128(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
  __pyx_t_9 = kh_exist_complex128(__pyx_v_self->table, __pyx_v_k);
  if (likely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1296
 *         k = kh_put_complex128(self.table, ckey, &ret)
 *         if kh_exist_complex128(self.table, k):
 *             self.table.vals[k] = val             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(key)
 */
    (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_val;

    /* "pandas/_libs/hashtable_class_helper.pxi":1295
 *         ckey = to_khcomplex128_t(key)
 *         k = kh_put_complex128(self.table, ckey, &ret)
 *         if kh_exist_complex128(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1298
 *             self.table.vals[k] = val
 *         else:
 *             raise KeyError(key)             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_na(self, Py_ssize_t val):
 */
  /*else*/ {
    __pyx_t_1 = __pyx_PyComplex_FromComplex(__pyx_v_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1298, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 1298, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "pandas/_libs/hashtable_class_helper.pxi":1285
 *         return self.na_position
 * 
 *     cpdef set_item(self, complex128_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_17set_item = {"set_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_17set_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_double_complex __pyx_v_key;
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key,&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1285, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1285, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, 1); __PYX_ERR(2, 1285, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_item") < 0)) __PYX_ERR(2, 1285, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_key = __Pyx_PyComplex_As___pyx_t_double_complex(values[0]); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1285, __pyx_L3_error)
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 1285, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, __pyx_nargs); __PYX_ERR(2, 1285, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_16set_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)__pyx_v_self), __pyx_v_key, __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, __pyx_t_double_complex __pyx_v_key, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_19Complex128HashTable_set_item(__pyx_v_self, __pyx_v_key, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1300
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_19Complex128HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  CYTHON_UNUSED int __pyx_v_ret;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1300, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_19set_na)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1300, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1300, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1304
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             khcomplex128_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1307
 *             khcomplex128_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_7 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_7)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1308
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         self.na_position = val
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 1308, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":1307
 *             khcomplex128_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1310
 *             raise NotImplementedError
 * 
 *         self.na_position = val             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->na_position = __pyx_v_val;

  /* "pandas/_libs/hashtable_class_helper.pxi":1300
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_19set_na = {"set_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_19set_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1300, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_na") < 0)) __PYX_ERR(2, 1300, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[0]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 1300, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_na", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 1300, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_18set_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_19Complex128HashTable_set_na(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1313
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const complex128_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_21map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_21map_locations = {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_21map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_21map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("map_locations (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1313, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1313, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "map_locations") < 0)) __PYX_ERR(2, 1313, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_double_complex__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 1314, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 1314, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__14;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("map_locations", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 1313, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_20map_locations(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_20map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  int __pyx_v_ret;
  khcomplex128_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  __pyx_t_5numpy_int64_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  khcomplex128_t __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("map_locations", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1317
 *         # Used in libindex, safe_sort
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             khcomplex128_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":1318
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             khcomplex128_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1321
 *             khcomplex128_t val
 *             khiter_t k
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_2 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":1323
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_3 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_3)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1324
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 1324, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":1323
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1326
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":1327
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
        if (__pyx_v_self->uses_mask) {

          /* "pandas/_libs/hashtable_class_helper.pxi":1328
 *         with nogil:
 *             if self.uses_mask:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     if mask[i]:
 *                         na_position = i
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":1329
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_mask.shape[0];
            __pyx_t_3 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) ))) != 0);
            if (__pyx_t_3) {

              /* "pandas/_libs/hashtable_class_helper.pxi":1330
 *                 for i in range(n):
 *                     if mask[i]:
 *                         na_position = i             # <<<<<<<<<<<<<<
 *                     else:
 *                         val= to_khcomplex128_t(values[i])
 */
              __pyx_v_na_position = __pyx_v_i;

              /* "pandas/_libs/hashtable_class_helper.pxi":1329
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
              goto __pyx_L12;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":1332
 *                         na_position = i
 *                     else:
 *                         val= to_khcomplex128_t(values[i])             # <<<<<<<<<<<<<<
 *                         k = kh_put_complex128(self.table, val, &ret)
 *                         self.table.vals[k] = i
 */
            /*else*/ {
              __pyx_t_7 = __pyx_v_i;
              if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
              __pyx_t_8 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex128_t((*((__pyx_t_double_complex const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )))); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 1332, __pyx_L7_error)
              __pyx_v_val = __pyx_t_8;

              /* "pandas/_libs/hashtable_class_helper.pxi":1333
 *                     else:
 *                         val= to_khcomplex128_t(values[i])
 *                         k = kh_put_complex128(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = i
 *             else:
 */
              __pyx_v_k = kh_put_complex128(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

              /* "pandas/_libs/hashtable_class_helper.pxi":1334
 *                         val= to_khcomplex128_t(values[i])
 *                         k = kh_put_complex128(self.table, val, &ret)
 *                         self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *             else:
 *                 for i in range(n):
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
            }
            __pyx_L12:;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":1327
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
          goto __pyx_L9;
        }

        /* "pandas/_libs/hashtable_class_helper.pxi":1336
 *                         self.table.vals[k] = i
 *             else:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     val= to_khcomplex128_t(values[i])
 *                     k = kh_put_complex128(self.table, val, &ret)
 */
        /*else*/ {
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":1337
 *             else:
 *                 for i in range(n):
 *                     val= to_khcomplex128_t(values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_put_complex128(self.table, val, &ret)
 *                     self.table.vals[k] = i
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
            __pyx_t_8 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex128_t((*((__pyx_t_double_complex const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )))); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 1337, __pyx_L7_error)
            __pyx_v_val = __pyx_t_8;

            /* "pandas/_libs/hashtable_class_helper.pxi":1338
 *                 for i in range(n):
 *                     val= to_khcomplex128_t(values[i])
 *                     k = kh_put_complex128(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                     self.table.vals[k] = i
 *         self.na_position = na_position
 */
            __pyx_v_k = kh_put_complex128(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":1339
 *                     val= to_khcomplex128_t(values[i])
 *                     k = kh_put_complex128(self.table, val, &ret)
 *                     self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *         self.na_position = na_position
 * 
 */
            (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
          }
        }
        __pyx_L9:;
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":1326
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L7_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1340
 *                     k = kh_put_complex128(self.table, val, &ret)
 *                     self.table.vals[k] = i
 *         self.na_position = na_position             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __pyx_v_self->na_position = __pyx_v_na_position;

  /* "pandas/_libs/hashtable_class_helper.pxi":1313
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const complex128_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1342
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const complex128_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

/* Python wrapper */
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_23lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_23lookup = {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_23lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_23lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyArrayObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lookup (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1342, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1342, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lookup") < 0)) __PYX_ERR(2, 1342, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_double_complex__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 1343, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 1343, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__15;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lookup", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 1342, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_22lookup(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_22lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  CYTHON_UNUSED int __pyx_v_ret;
  khcomplex128_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __Pyx_memviewslice __pyx_v_locs = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  khcomplex128_t __pyx_t_14;
  int __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lookup", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1347
 *         # Used in safe_sort, IndexEngine.get_indexer
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             khcomplex128_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":1348
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             khcomplex128_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1351
 *             khcomplex128_t val
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *             int8_t na_position = self.na_position
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 1351, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 1351, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 1351, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_locs = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":1352
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_8 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":1354
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_9 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_10 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_9 = __pyx_t_10;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1355
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 1355, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":1354
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1357
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":1358
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_11 = __pyx_t_1;
        for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
          __pyx_v_i = __pyx_t_12;

          /* "pandas/_libs/hashtable_class_helper.pxi":1359
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
          if (__pyx_v_self->uses_mask) {
          } else {
            __pyx_t_9 = __pyx_v_self->uses_mask;
            goto __pyx_L12_bool_binop_done;
          }
          __pyx_t_13 = __pyx_v_i;
          if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_mask.shape[0];
          __pyx_t_10 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_13 * __pyx_v_mask.strides[0]) ))) != 0);
          __pyx_t_9 = __pyx_t_10;
          __pyx_L12_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":1360
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position             # <<<<<<<<<<<<<<
 *                 else:
 *                     val = to_khcomplex128_t(values[i])
 */
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = __pyx_v_na_position;

            /* "pandas/_libs/hashtable_class_helper.pxi":1359
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
            goto __pyx_L11;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":1362
 *                     locs[i] = na_position
 *                 else:
 *                     val = to_khcomplex128_t(values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_complex128(self.table, val)
 *                     if k != self.table.n_buckets:
 */
          /*else*/ {
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_values.shape[0];
            __pyx_t_14 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex128_t((*((__pyx_t_double_complex const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_13 * __pyx_v_values.strides[0]) )))); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 1362, __pyx_L7_error)
            __pyx_v_val = __pyx_t_14;

            /* "pandas/_libs/hashtable_class_helper.pxi":1363
 *                 else:
 *                     val = to_khcomplex128_t(values[i])
 *                     k = kh_get_complex128(self.table, val)             # <<<<<<<<<<<<<<
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]
 */
            __pyx_v_k = kh_get_complex128(__pyx_v_self->table, __pyx_v_val);

            /* "pandas/_libs/hashtable_class_helper.pxi":1364
 *                     val = to_khcomplex128_t(values[i])
 *                     k = kh_get_complex128(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
            __pyx_t_9 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":1365
 *                     k = kh_get_complex128(self.table, val)
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     else:
 *                         locs[i] = -1
 */
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = (__pyx_v_self->table->vals[__pyx_v_k]);

              /* "pandas/_libs/hashtable_class_helper.pxi":1364
 *                     val = to_khcomplex128_t(values[i])
 *                     k = kh_get_complex128(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
              goto __pyx_L14;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":1367
 *                         locs[i] = self.table.vals[k]
 *                     else:
 *                         locs[i] = -1             # <<<<<<<<<<<<<<
 * 
 *         return np.asarray(locs)
 */
            /*else*/ {
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = -1;
            }
            __pyx_L14:;
          }
          __pyx_L11:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":1357
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L7_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1369
 *                         locs[i] = -1
 * 
 *         return np.asarray(locs)             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_locs, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_15 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_15 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_15, 1+__pyx_t_15);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1369, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 1369, __pyx_L1_error)
  __pyx_r = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1342
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const complex128_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_locs, 1);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1371
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const complex128_t[:] values, Complex128Vector uniques,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_25_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_19Complex128HashTable_24_unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[complex128]\n            Array of values of which unique will be calculated\n        uniques : Complex128Vector\n            Vector into which uniques will be written\n        count_prior : Py_ssize_t, default 0\n            Number of existing entries in uniques\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        ignore_na : bool, default False\n            Whether NA-values should be ignored for calculating the uniques. If\n            True, the labels corresponding to missing values will be set to\n            na_sentinel.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        use_result_mask: bool, default False\n            Whether to create a result mask for the unique values. Not supported\n            with return_inverse=True.\n\n        Returns\n        -------\n        uniques : ndarray[complex128]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse=True)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if use_result_mask is true\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_25_unique = {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_25_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_19Complex128HashTable_24_unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_25_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  int __pyx_v_ignore_na;
  PyObject *__pyx_v_mask = 0;
  int __pyx_v_return_inverse;
  int __pyx_v_use_result_mask;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[9] = {0,0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_ignore_na,&__pyx_n_s_mask,&__pyx_n_s_return_inverse,&__pyx_n_s_use_result_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":1375
 *     def _unique(self, const complex128_t[:] values, Complex128Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));

    /* "pandas/_libs/hashtable_class_helper.pxi":1376
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[6] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1371, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1371, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, 1); __PYX_ERR(2, 1371, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1371, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1371, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1371, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1371, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[6] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1371, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[7] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1371, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_use_result_mask);
          if (value) { values[8] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1371, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_unique") < 0)) __PYX_ERR(2, 1371, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_double_complex__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 1373, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 1374, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 1374, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    if (values[5]) {
      __pyx_v_ignore_na = __Pyx_PyObject_IsTrue(values[5]); if (unlikely((__pyx_v_ignore_na == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1375, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":1375
 *     def _unique(self, const complex128_t[:] values, Complex128Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
      __pyx_v_ignore_na = ((int)0);
    }
    __pyx_v_mask = values[6];
    if (values[7]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[7]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1376, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":1376
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
      __pyx_v_return_inverse = ((int)0);
    }
    if (values[8]) {
      __pyx_v_use_result_mask = __Pyx_PyObject_IsTrue(values[8]); if (unlikely((__pyx_v_use_result_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1376, __pyx_L3_error)
    } else {
      __pyx_v_use_result_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, __pyx_nargs); __PYX_ERR(2, 1371, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector, 1, "uniques", 0))) __PYX_ERR(2, 1373, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_24_unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_ignore_na, __pyx_v_mask, __pyx_v_return_inverse, __pyx_v_use_result_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":1371
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const complex128_t[:] values, Complex128Vector uniques,
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_24_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_idx;
  Py_ssize_t __pyx_v_count;
  Py_ssize_t __pyx_v_n;
  __Pyx_memviewslice __pyx_v_labels = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_ret;
  khcomplex128_t __pyx_v_val;
  khcomplex128_t __pyx_v_na_value2;
  khiter_t __pyx_v_k;
  __pyx_t_6pandas_5_libs_9hashtable_Complex128VectorData *__pyx_v_ud;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_result_mask = 0;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_v_rmd;
  int __pyx_v_use_na_value;
  int __pyx_v_use_mask;
  int __pyx_v_seen_na;
  __Pyx_memviewslice __pyx_v_mask_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_6pandas_5_libs_9hashtable_Complex128VectorData *__pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_t_11;
  int __pyx_t_12;
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_double_complex __pyx_t_14;
  khcomplex128_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  Py_ssize_t __pyx_t_18;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1420
 *         """
 *         cdef:
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)             # <<<<<<<<<<<<<<
 *             intp_t[::1] labels
 *             int ret = 0
 */
  __pyx_v_count = __pyx_v_count_prior;
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":1422
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)
 *             intp_t[::1] labels
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             khcomplex128_t val, na_value2
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1428
 *             UInt8Vector result_mask
 *             UInt8VectorData *rmd
 *             bint use_na_value, use_mask, seen_na = False             # <<<<<<<<<<<<<<
 *             uint8_t[:] mask_values
 * 
 */
  __pyx_v_seen_na = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1431
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1432
 * 
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 1432, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 1432, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1432, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 1432, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_labels = __pyx_t_7;
    __pyx_t_7.memview = NULL;
    __pyx_t_7.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":1431
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1433
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data             # <<<<<<<<<<<<<<
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 */
  __pyx_t_8 = __pyx_v_uniques->data;
  __pyx_v_ud = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":1434
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 *         use_na_value = na_value is not None             # <<<<<<<<<<<<<<
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 */
  __pyx_t_9 = (__pyx_v_na_value != Py_None);
  __pyx_v_use_na_value = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":1435
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None             # <<<<<<<<<<<<<<
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover
 */
  __pyx_t_9 = (__pyx_v_mask != Py_None);
  __pyx_v_use_mask = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":1436
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  __pyx_t_10 = (!__pyx_v_use_mask);
  if (__pyx_t_10) {
  } else {
    __pyx_t_9 = __pyx_t_10;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_use_result_mask;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1437
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         if use_result_mask and return_inverse:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 1437, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":1436
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1439
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_use_result_mask) {
  } else {
    __pyx_t_9 = __pyx_v_use_result_mask;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_return_inverse;
  __pyx_L8_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1440
 * 
 *         if use_result_mask and return_inverse:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         result_mask = UInt8Vector()
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 1440, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":1439
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1442
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         result_mask = UInt8Vector()             # <<<<<<<<<<<<<<
 *         rmd = result_mask.data
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_v_result_mask = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1443
 * 
 *         result_mask = UInt8Vector()
 *         rmd = result_mask.data             # <<<<<<<<<<<<<<
 * 
 *         if use_mask:
 */
  __pyx_t_11 = __pyx_v_result_mask->data;
  __pyx_v_rmd = __pyx_t_11;

  /* "pandas/_libs/hashtable_class_helper.pxi":1445
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  if (__pyx_v_use_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1446
 * 
 *         if use_mask:
 *             mask_values = mask.view("uint8")             # <<<<<<<<<<<<<<
 * 
 *         if use_na_value:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_mask, __pyx_n_s_view); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1446, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    __pyx_t_12 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_12 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_uint8};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_12, 1+__pyx_t_12);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1446, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(2, 1446, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_mask_values = __pyx_t_13;
    __pyx_t_13.memview = NULL;
    __pyx_t_13.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":1445
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1448
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
  if (__pyx_v_use_na_value) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1454
 *             # for the parameter. To please the compiler, we use na_value2,
 *             # which is only used if it's *specified*.
 *             na_value2 = to_khcomplex128_t(na_value)             # <<<<<<<<<<<<<<
 *         else:
 *             na_value2 = to_khcomplex128_t(0)
 */
    __pyx_t_14 = __Pyx_PyComplex_As___pyx_t_double_complex(__pyx_v_na_value); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1454, __pyx_L1_error)
    __pyx_t_15 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex128_t(__pyx_t_14); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1454, __pyx_L1_error)
    __pyx_v_na_value2 = __pyx_t_15;

    /* "pandas/_libs/hashtable_class_helper.pxi":1448
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
    goto __pyx_L11;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1456
 *             na_value2 = to_khcomplex128_t(na_value)
 *         else:
 *             na_value2 = to_khcomplex128_t(0)             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
  /*else*/ {
    __pyx_t_15 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex128_t(__pyx_t_double_complex_from_parts(0, 0)); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1456, __pyx_L1_error)
    __pyx_v_na_value2 = __pyx_t_15;
  }
  __pyx_L11:;

  /* "pandas/_libs/hashtable_class_helper.pxi":1458
 *             na_value2 = to_khcomplex128_t(0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = to_khcomplex128_t(values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":1459
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 val = to_khcomplex128_t(values[i])
 * 
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_16 = __pyx_t_1;
        for (__pyx_t_17 = 0; __pyx_t_17 < __pyx_t_16; __pyx_t_17+=1) {
          __pyx_v_i = __pyx_t_17;

          /* "pandas/_libs/hashtable_class_helper.pxi":1460
 *         with nogil:
 *             for i in range(n):
 *                 val = to_khcomplex128_t(values[i])             # <<<<<<<<<<<<<<
 * 
 *                 if ignore_na and use_mask:
 */
          __pyx_t_18 = __pyx_v_i;
          __pyx_t_15 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex128_t((*((__pyx_t_double_complex const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_18 * __pyx_v_values.strides[0]) )))); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 1460, __pyx_L13_error)
          __pyx_v_val = __pyx_t_15;

          /* "pandas/_libs/hashtable_class_helper.pxi":1462
 *                 val = to_khcomplex128_t(values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L18_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_mask;
          __pyx_L18_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":1463
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 1463, __pyx_L13_error) }
            __pyx_t_18 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_18 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":1464
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                         continue
 *                 elif ignore_na and (
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 1464, __pyx_L13_error) }
              __pyx_t_18 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_18)) )) = __pyx_v_na_sentinel;

              /* "pandas/_libs/hashtable_class_helper.pxi":1465
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 *                         continue             # <<<<<<<<<<<<<<
 *                 elif ignore_na and (
 *                    is_nan_khcomplex128_t(val) or
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":1463
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":1462
 *                 val = to_khcomplex128_t(values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
            goto __pyx_L17;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":1466
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_khcomplex128_t(val) or
 *                    (use_na_value and are_equivalent_khcomplex128_t(val, na_value2))
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":1467
 *                         continue
 *                 elif ignore_na and (
 *                    is_nan_khcomplex128_t(val) or             # <<<<<<<<<<<<<<
 *                    (use_na_value and are_equivalent_khcomplex128_t(val, na_value2))
 *                 ):
 */
          __pyx_t_10 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_khcomplex128_t(__pyx_v_val); if (unlikely(__pyx_t_10 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 1467, __pyx_L13_error)
          if (!__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":1468
 *                 elif ignore_na and (
 *                    is_nan_khcomplex128_t(val) or
 *                    (use_na_value and are_equivalent_khcomplex128_t(val, na_value2))             # <<<<<<<<<<<<<<
 *                 ):
 *                     # if missing values do not count as unique values (i.e. if
 */
          if (__pyx_v_use_na_value) {
          } else {
            __pyx_t_9 = __pyx_v_use_na_value;
            goto __pyx_L21_bool_binop_done;
          }
          __pyx_t_10 = kh_complex_hash_equal(__pyx_v_val, __pyx_v_na_value2);
          __pyx_t_9 = __pyx_t_10;
          __pyx_L21_bool_binop_done:;

          /* "pandas/_libs/hashtable_class_helper.pxi":1466
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_khcomplex128_t(val) or
 *                    (use_na_value and are_equivalent_khcomplex128_t(val, na_value2))
 */
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":1473
 *                     # ignore_na is True), skip the hashtable entry for them,
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 1473, __pyx_L13_error) }
            __pyx_t_18 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_18)) )) = __pyx_v_na_sentinel;

            /* "pandas/_libs/hashtable_class_helper.pxi":1474
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel
 *                     continue             # <<<<<<<<<<<<<<
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 */
            goto __pyx_L15_continue;

            /* "pandas/_libs/hashtable_class_helper.pxi":1466
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_khcomplex128_t(val) or
 *                    (use_na_value and are_equivalent_khcomplex128_t(val, na_value2))
 */
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":1475
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          __pyx_t_10 = (!__pyx_v_ignore_na);
          if (__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L25_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_result_mask;
          __pyx_L25_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":1476
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 1476, __pyx_L13_error) }
            __pyx_t_18 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_18 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":1477
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_class_helper.pxi":1478
 *                     if mask_values[i]:
 *                         if seen_na:
 *                             continue             # <<<<<<<<<<<<<<
 * 
 *                         seen_na = True
 */
                goto __pyx_L15_continue;

                /* "pandas/_libs/hashtable_class_helper.pxi":1477
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":1480
 *                             continue
 * 
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         if needs_resize(ud):
 *                             with gil:
 */
              __pyx_v_seen_na = 1;

              /* "pandas/_libs/hashtable_class_helper.pxi":1481
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              __pyx_t_9 = __pyx_fuse_10__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 1481, __pyx_L13_error)
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_class_helper.pxi":1482
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                {
                    #ifdef WITH_THREAD
                    PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                    #endif
                    /*try:*/ {

                      /* "pandas/_libs/hashtable_class_helper.pxi":1483
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":1484
 *                             with gil:
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1484, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 1484, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":1483
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":1487
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex128Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1487, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":1488
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":1489
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1489, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 1489, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":1488
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":1492
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                         append_data_complex128(ud, val)
 *                         append_data_uint8(rmd, 1)
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1492, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":1482
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    /*finally:*/ {
                      /*normal exit:*/{
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L34;
                      }
                      __pyx_L33_error: {
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L13_error;
                      }
                      __pyx_L34:;
                    }
                }

                /* "pandas/_libs/hashtable_class_helper.pxi":1481
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":1493
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                         append_data_complex128(ud, val)             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 1)
 *                         continue
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_complex128(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 1493, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":1494
 *                                 result_mask.resize()
 *                         append_data_complex128(ud, val)
 *                         append_data_uint8(rmd, 1)             # <<<<<<<<<<<<<<
 *                         continue
 * 
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 1); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 1494, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":1495
 *                         append_data_complex128(ud, val)
 *                         append_data_uint8(rmd, 1)
 *                         continue             # <<<<<<<<<<<<<<
 * 
 *                 k = kh_get_complex128(self.table, val)
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":1476
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":1475
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          }
          __pyx_L17:;

          /* "pandas/_libs/hashtable_class_helper.pxi":1497
 *                         continue
 * 
 *                 k = kh_get_complex128(self.table, val)             # <<<<<<<<<<<<<<
 * 
 *                 if k == self.table.n_buckets:
 */
          __pyx_v_k = kh_get_complex128(__pyx_v_self->table, __pyx_v_val);

          /* "pandas/_libs/hashtable_class_helper.pxi":1499
 *                 k = kh_get_complex128(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_complex128(self.table, val, &ret)
 */
          __pyx_t_9 = (__pyx_v_k == __pyx_v_self->table->n_buckets);
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":1501
 *                 if k == self.table.n_buckets:
 *                     # k hasn't been seen yet
 *                     k = kh_put_complex128(self.table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *                     if needs_resize(ud):
 */
            __pyx_v_k = kh_put_complex128(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":1503
 *                     k = kh_put_complex128(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            __pyx_t_9 = __pyx_fuse_10__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 1503, __pyx_L13_error)
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":1504
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
              {
                  #ifdef WITH_THREAD
                  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                  #endif
                  /*try:*/ {

                    /* "pandas/_libs/hashtable_class_helper.pxi":1505
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":1506
 *                         with gil:
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 */
                      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1506, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                      __PYX_ERR(2, 1506, __pyx_L42_error)

                      /* "pandas/_libs/hashtable_class_helper.pxi":1505
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":1509
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()             # <<<<<<<<<<<<<<
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 */
                    __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex128Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1509, __pyx_L42_error)
                    __Pyx_GOTREF(__pyx_t_6);
                    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                    /* "pandas/_libs/hashtable_class_helper.pxi":1510
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    if (__pyx_v_use_result_mask) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":1511
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":1512
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1512, __pyx_L42_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 1512, __pyx_L42_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":1511
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":1515
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                     append_data_complex128(ud, val)
 *                     if use_result_mask:
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1515, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":1510
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    }
                  }

                  /* "pandas/_libs/hashtable_class_helper.pxi":1504
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
                  /*finally:*/ {
                    /*normal exit:*/{
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L43;
                    }
                    __pyx_L42_error: {
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L13_error;
                    }
                    __pyx_L43:;
                  }
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":1503
 *                     k = kh_put_complex128(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":1516
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                     append_data_complex128(ud, val)             # <<<<<<<<<<<<<<
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)
 */
            __pyx_f_6pandas_5_libs_9hashtable_append_data_complex128(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 1516, __pyx_L13_error)

            /* "pandas/_libs/hashtable_class_helper.pxi":1517
 *                                 result_mask.resize()
 *                     append_data_complex128(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            if (__pyx_v_use_result_mask) {

              /* "pandas/_libs/hashtable_class_helper.pxi":1518
 *                     append_data_complex128(ud, val)
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)             # <<<<<<<<<<<<<<
 * 
 *                     if return_inverse:
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 0); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 1518, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":1517
 *                                 result_mask.resize()
 *                     append_data_complex128(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":1520
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            if (__pyx_v_return_inverse) {

              /* "pandas/_libs/hashtable_class_helper.pxi":1521
 * 
 *                     if return_inverse:
 *                         self.table.vals[k] = count             # <<<<<<<<<<<<<<
 *                         labels[i] = count
 *                         count += 1
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":1522
 *                     if return_inverse:
 *                         self.table.vals[k] = count
 *                         labels[i] = count             # <<<<<<<<<<<<<<
 *                         count += 1
 *                 elif return_inverse:
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 1522, __pyx_L13_error) }
              __pyx_t_18 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_18)) )) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":1523
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 *                         count += 1             # <<<<<<<<<<<<<<
 *                 elif return_inverse:
 *                     # k falls into a previous bucket
 */
              __pyx_v_count = (__pyx_v_count + 1);

              /* "pandas/_libs/hashtable_class_helper.pxi":1520
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":1499
 *                 k = kh_get_complex128(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_complex128(self.table, val, &ret)
 */
            goto __pyx_L37;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":1524
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          if (__pyx_v_return_inverse) {

            /* "pandas/_libs/hashtable_class_helper.pxi":1527
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     labels[i] = idx
 * 
 */
            __pyx_v_idx = (__pyx_v_self->table->vals[__pyx_v_k]);

            /* "pandas/_libs/hashtable_class_helper.pxi":1528
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]
 *                     labels[i] = idx             # <<<<<<<<<<<<<<
 * 
 *         if return_inverse:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 1528, __pyx_L13_error) }
            __pyx_t_18 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_18)) )) = __pyx_v_idx;

            /* "pandas/_libs/hashtable_class_helper.pxi":1524
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          }
          __pyx_L37:;
          __pyx_L15_continue:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":1458
 *             na_value2 = to_khcomplex128_t(0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = to_khcomplex128_t(values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L14;
        }
        __pyx_L13_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L14:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1530
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1531
 * 
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray             # <<<<<<<<<<<<<<
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex128Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1531, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundLocalError("labels"); __PYX_ERR(2, 1531, __pyx_L1_error) }
    __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_labels, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1531, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_base); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1531, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1531, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_6);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_6)) __PYX_ERR(2, 1531, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4)) __PYX_ERR(2, 1531, __pyx_L1_error);
    __pyx_t_6 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":1530
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1532
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  if (__pyx_v_use_result_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1533
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()             # <<<<<<<<<<<<<<
 *         return uniques.to_array()
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex128Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1533, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->to_array(__pyx_v_result_mask, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1533, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1533, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2)) __PYX_ERR(2, 1533, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4)) __PYX_ERR(2, 1533, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":1532
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1534
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()             # <<<<<<<<<<<<<<
 * 
 *     def unique(self, const complex128_t[:] values, bint return_inverse=False, object mask=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex128Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1371
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const complex128_t[:] values, Complex128Vector uniques,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_13, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_labels, 1);
  __Pyx_XDECREF((PyObject *)__pyx_v_result_mask);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask_values, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1536
 *         return uniques.to_array()
 * 
 *     def unique(self, const complex128_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_27unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_19Complex128HashTable_26unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[complex128]\n            Array of values of which unique will be calculated\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n\n        Returns\n        -------\n        uniques : ndarray[complex128]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if mask is given as input\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_27unique = {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_27unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_19Complex128HashTable_26unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_27unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_return_inverse;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_return_inverse,&__pyx_n_s_mask,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1536, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1536, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1536, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "unique") < 0)) __PYX_ERR(2, 1536, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_double_complex__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 1536, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1536, __pyx_L3_error)
    } else {
      __pyx_v_return_inverse = ((int)0);
    }
    __pyx_v_mask = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("unique", 0, 1, 3, __pyx_nargs); __PYX_ERR(2, 1536, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_26unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_return_inverse, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_26unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_uniques = NULL;
  int __pyx_v_use_result_mask;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1560
 *             The mask for the result values.
 *         """
 *         uniques = Complex128Vector()             # <<<<<<<<<<<<<<
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1561
 *         """
 *         uniques = Complex128Vector()
 *         use_result_mask = True if mask is not None else False             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 */
  __pyx_t_3 = (__pyx_v_mask != Py_None);
  if (__pyx_t_3) {
    __pyx_t_2 = 1;
  } else {
    __pyx_t_2 = 0;
  }
  __pyx_v_use_result_mask = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":1562
 *         uniques = Complex128Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get___pyx_t_double_complex__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4)) __PYX_ERR(2, 1562, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 1562, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ignore_na, Py_False) < 0) __PYX_ERR(2, 1562, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1563
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const complex128_t[:] values, Py_ssize_t na_sentinel=-1,
 */
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_return_inverse); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return_inverse, __pyx_t_6) < 0) __PYX_ERR(2, 1562, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 1562, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_use_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_use_result_mask, __pyx_t_6) < 0) __PYX_ERR(2, 1562, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1562
 *         uniques = Complex128Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1536
 *         return uniques.to_array()
 * 
 *     def unique(self, const complex128_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1565
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const complex128_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_29factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_19Complex128HashTable_28factorize, "\n        Calculate unique values and labels (no sorting!)\n\n        Missing values are not included in the \"uniques\" for this method.\n        The labels for any missing values will be set to \"na_sentinel\"\n\n        Parameters\n        ----------\n        values : ndarray[complex128]\n            Array of values of which unique will be calculated\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n\n        Returns\n        -------\n        uniques : ndarray[complex128]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t]\n            The labels from values to uniques\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_29factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_29factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_19Complex128HashTable_28factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_29factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  PyObject *__pyx_v_ignore_na = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,&__pyx_n_s_ignore_na,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":1566
 * 
 *     def factorize(self, const complex128_t[:] values, Py_ssize_t na_sentinel=-1,
 *                   object na_value=None, object mask=None, ignore_na=True):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_True));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1565, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1565, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1565, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1565, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1565, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 1565, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_double_complex__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 1565, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 1565, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
    __pyx_v_ignore_na = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 5, __pyx_nargs); __PYX_ERR(2, 1565, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_28factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask, __pyx_v_ignore_na);

  /* "pandas/_libs/hashtable_class_helper.pxi":1565
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const complex128_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_28factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_uniques_vector = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1596
 *             The labels from values to uniques
 *         """
 *         uniques_vector = Complex128Vector()             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques_vector = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1597
 *         """
 *         uniques_vector = Complex128Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get___pyx_t_double_complex__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 1597, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques_vector);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques_vector))) __PYX_ERR(2, 1597, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 1597, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1598
 *         uniques_vector = Complex128Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,             # <<<<<<<<<<<<<<
 *                             return_inverse=True)
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 1597, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, __pyx_v_ignore_na) < 0) __PYX_ERR(2, 1597, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 1597, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1599
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)             # <<<<<<<<<<<<<<
 * 
 *     def get_labels(self, const complex128_t[:] values, Complex128Vector uniques,
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 1597, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1597
 *         """
 *         uniques_vector = Complex128Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1565
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const complex128_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1601
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const complex128_t[:] values, Complex128Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_31get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_31get_labels = {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_31get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_31get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_labels (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":1603
 *     def get_labels(self, const complex128_t[:] values, Complex128Vector uniques,
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1601, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1601, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, 1); __PYX_ERR(2, 1601, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1601, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1601, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1601, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1601, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_labels") < 0)) __PYX_ERR(2, 1601, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_double_complex__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 1601, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 1602, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 1602, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    __pyx_v_mask = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, __pyx_nargs); __PYX_ERR(2, 1601, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector, 1, "uniques", 0))) __PYX_ERR(2, 1601, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_30get_labels(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":1601
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const complex128_t[:] values, Complex128Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_30get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_v_labels = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_labels", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1605
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get___pyx_t_double_complex__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 1605, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 1605, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_count_prior); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_count_prior, __pyx_t_4) < 0) __PYX_ERR(2, 1605, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1606
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,             # <<<<<<<<<<<<<<
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 1605, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 1605, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1607
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, Py_True) < 0) __PYX_ERR(2, 1605, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 1605, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 1605, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1605
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1605, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
    PyObject* sequence = __pyx_t_4;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(2, 1605, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1605, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1605, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1605, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
    index = 0; __pyx_t_2 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_1), 2) < 0) __PYX_ERR(2, 1605, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(2, 1605, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v__ = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_labels = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1608
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_labels);
  __pyx_r = __pyx_v_labels;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1601
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const complex128_t[:] values, Complex128Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XDECREF(__pyx_v_labels);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_33__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_33__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_33__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_33__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_32__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_32__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_35__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_35__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_35__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_35__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_34__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex128HashTable_34__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1617
 *         Complex128Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = Complex128HashTable(size_hint)
 *         self.uniques = Complex128Vector()
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_size_hint = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1617, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 1617, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_size_hint = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 1617, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_size_hint), (&PyInt_Type), 0, "size_hint", 1))) __PYX_ERR(2, 1617, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *)__pyx_v_self), __pyx_v_size_hint);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1618
 * 
 *     def __cinit__(self, size_hint: int):
 *         self.table = Complex128HashTable(size_hint)             # <<<<<<<<<<<<<<
 *         self.uniques = Complex128Vector()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable), __pyx_v_size_hint); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1619
 *     def __cinit__(self, size_hint: int):
 *         self.table = Complex128HashTable(size_hint)
 *         self.uniques = Complex128Vector()             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const khcomplex128_t[:] values,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1617
 *         Complex128Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = Complex128HashTable(size_hint)
 *         self.uniques = Complex128Vector()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1621
 *         self.uniques = Complex128Vector()
 * 
 *     def factorize(self, const khcomplex128_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_20Complex128Factorizer_2factorize, "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = Complex128Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"complex128\"), na_sentinel=20)\n        array([0, 1, 2])\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_20Complex128Factorizer_3factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_20Complex128Factorizer_2factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_v_na_sentinel = 0;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_neg_1));

    /* "pandas/_libs/hashtable_class_helper.pxi":1622
 * 
 *     def factorize(self, const khcomplex128_t[:] values,
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:             # <<<<<<<<<<<<<<
 *         """
 *         Returns
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1621, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1621, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1621, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1621, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 1621, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn_khcomplex128_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 1621, __pyx_L3_error)
    __pyx_v_na_sentinel = values[1];
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 4, __pyx_nargs); __PYX_ERR(2, 1621, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_2factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":1621
 *         self.uniques = Complex128Vector()
 * 
 *     def factorize(self, const khcomplex128_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  PyArrayObject *__pyx_v_labels = 0;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_uniques = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_labels;
  __Pyx_Buffer __pyx_pybuffer_labels;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);
  __pyx_pybuffer_labels.pybuffer.buf = NULL;
  __pyx_pybuffer_labels.refcount = 0;
  __pyx_pybuffernd_labels.data = NULL;
  __pyx_pybuffernd_labels.rcbuffer = &__pyx_pybuffer_labels;

  /* "pandas/_libs/hashtable_class_helper.pxi":1639
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = Complex128Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  if (__pyx_v_self->uniques->__pyx_base.external_view_exists) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1640
 * 
 *         if self.uniques.external_view_exists:
 *             uniques = Complex128Vector()             # <<<<<<<<<<<<<<
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 */
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":1641
 *         if self.uniques.external_view_exists:
 *             uniques = Complex128Vector()
 *             uniques.extend(self.uniques.to_array())             # <<<<<<<<<<<<<<
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 */
    __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex128Vector *)__pyx_v_self->uniques->__pyx_vtab)->to_array(__pyx_v_self->uniques, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1641, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn_khcomplex128_t__const__(__pyx_t_1, 0); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(2, 1641, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex128Vector *)__pyx_v_uniques->__pyx_vtab)->extend(__pyx_v_uniques, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1641, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
    __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":1642
 *             uniques = Complex128Vector()
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques             # <<<<<<<<<<<<<<
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 */
    __Pyx_INCREF((PyObject *)__pyx_v_uniques);
    __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
    __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
    __pyx_v_self->uniques = __pyx_v_uniques;

    /* "pandas/_libs/hashtable_class_helper.pxi":1639
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = Complex128Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1643
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->table), __pyx_n_s_get_labels); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn_khcomplex128_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "pandas/_libs/hashtable_class_helper.pxi":1644
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,             # <<<<<<<<<<<<<<
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_self->__pyx_base.count); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1644, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "pandas/_libs/hashtable_class_helper.pxi":1643
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_5 = PyTuple_New(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3)) __PYX_ERR(2, 1643, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self->uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_self->uniques))) __PYX_ERR(2, 1643, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_4)) __PYX_ERR(2, 1643, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_na_sentinel);
  __Pyx_GIVEREF(__pyx_v_na_sentinel);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_v_na_sentinel)) __PYX_ERR(2, 1643, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1645
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)             # <<<<<<<<<<<<<<
 *         self.count = len(self.uniques)
 *         return labels
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 1645, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 1645, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1643
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1643, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 1643, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
    __pyx_t_7 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_7 < 0)) {
      PyErr_Fetch(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_v_labels, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      }
      __pyx_t_8 = __pyx_t_9 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_labels.diminfo[0].strides = __pyx_pybuffernd_labels.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_labels.diminfo[0].shape = __pyx_pybuffernd_labels.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(2, 1643, __pyx_L1_error)
  }
  __pyx_t_6 = 0;
  __pyx_v_labels = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1646
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  __pyx_t_3 = ((PyObject *)__pyx_v_self->uniques);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_11 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(2, 1646, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_self->__pyx_base.count = __pyx_t_11;

  /* "pandas/_libs/hashtable_class_helper.pxi":1647
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * cdef class Float64HashTable(HashTable):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_labels);
  __pyx_r = ((PyObject *)__pyx_v_labels);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1621
 *         self.uniques = Complex128Vector()
 * 
 *     def factorize(self, const khcomplex128_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_labels);
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1614
 * cdef class Complex128Factorizer(Factorizer):
 *     cdef public:
 *         Complex128HashTable table             # <<<<<<<<<<<<<<
 *         Complex128Vector uniques
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_5table_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_5table_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_5table___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->table);
  __pyx_r = ((PyObject *)__pyx_v_self->table);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_5table_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable))))) __PYX_ERR(2, 1614, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128Factorizer.table.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_5table_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_5table_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_5table_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1615
 *     cdef public:
 *         Complex128HashTable table
 *         Complex128Vector uniques             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, size_hint: int):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_7uniques_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_7uniques_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_7uniques___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __pyx_r = ((PyObject *)__pyx_v_self->uniques);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_7uniques_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector))))) __PYX_ERR(2, 1615, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128Factorizer.uniques.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_7uniques_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_7uniques_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_7uniques_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_20Complex128Factorizer_5__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_4__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128Factorizer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_20Complex128Factorizer_7__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_6__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_20Complex128Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex128Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1651
 * cdef class Float64HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_float64()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __pyx_t_5numpy_int64_t __pyx_v_size_hint;
  int __pyx_v_uses_mask;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,&__pyx_n_s_uses_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1651, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uses_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1651, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 1651, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_size_hint = __Pyx_PyInt_As_npy_int64(values[0]); if (unlikely((__pyx_v_size_hint == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 1651, __pyx_L3_error)
    } else {
      __pyx_v_size_hint = ((__pyx_t_5numpy_int64_t)1);
    }
    if (values[1]) {
      __pyx_v_uses_mask = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_uses_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1651, __pyx_L3_error)
    } else {
      __pyx_v_uses_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 0, 2, __pyx_nargs); __PYX_ERR(2, 1651, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)__pyx_v_self), __pyx_v_size_hint, __pyx_v_uses_mask);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  khuint_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __pyx_t_5numpy_int64_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1652
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_float64()             # <<<<<<<<<<<<<<
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_float64(self.table, size_hint)
 */
  __pyx_v_self->table = kh_init_float64();

  /* "pandas/_libs/hashtable_class_helper.pxi":1653
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_float64()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)             # <<<<<<<<<<<<<<
 *         kh_resize_float64(self.table, size_hint)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = kh_needed_n_buckets(__pyx_v_size_hint);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_1, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(2, 1653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_6) {
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_5 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_int64(__pyx_t_3); if (unlikely((__pyx_t_7 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 1653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_size_hint = __pyx_t_7;

  /* "pandas/_libs/hashtable_class_helper.pxi":1654
 *         self.table = kh_init_float64()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_float64(self.table, size_hint)             # <<<<<<<<<<<<<<
 * 
 *         self.uses_mask = uses_mask
 */
  kh_resize_float64(__pyx_v_self->table, __pyx_v_size_hint);

  /* "pandas/_libs/hashtable_class_helper.pxi":1656
 *         kh_resize_float64(self.table, size_hint)
 * 
 *         self.uses_mask = uses_mask             # <<<<<<<<<<<<<<
 *         self.na_position = -1
 * 
 */
  __pyx_v_self->uses_mask = __pyx_v_uses_mask;

  /* "pandas/_libs/hashtable_class_helper.pxi":1657
 * 
 *         self.uses_mask = uses_mask
 *         self.na_position = -1             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
  __pyx_v_self->na_position = -1LL;

  /* "pandas/_libs/hashtable_class_helper.pxi":1651
 * cdef class Float64HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_float64()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1659
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_3__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_3__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_2__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  long __pyx_t_1;
  int __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":1660
 * 
 *     def __len__(self) -> int:
 *         return self.table.size + (0 if self.na_position == -1 else 1)             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_2 = (__pyx_v_self->na_position == -1LL);
  if (__pyx_t_2) {
    __pyx_t_1 = 0;
  } else {
    __pyx_t_1 = 1;
  }
  __pyx_r = (__pyx_v_self->table->size + __pyx_t_1);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1659
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1662
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_float64(self.table)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_5__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_5__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_4__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":1663
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_float64(self.table)
 *             self.table = NULL
 */
  __pyx_t_1 = (__pyx_v_self->table != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1664
 *     def __dealloc__(self):
 *         if self.table is not NULL:
 *             kh_destroy_float64(self.table)             # <<<<<<<<<<<<<<
 *             self.table = NULL
 * 
 */
    kh_destroy_float64(__pyx_v_self->table);

    /* "pandas/_libs/hashtable_class_helper.pxi":1665
 *         if self.table is not NULL:
 *             kh_destroy_float64(self.table)
 *             self.table = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __contains__(self, object key) -> bool:
 */
    __pyx_v_self->table = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":1663
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_float64(self.table)
 *             self.table = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1662
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_float64(self.table)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":1667
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__contains__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_6__contains__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)__pyx_v_self), ((PyObject *)__pyx_v_key));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, PyObject *__pyx_v_key) {
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_float64_t __pyx_v_ckey;
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  __pyx_t_5numpy_float64_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1674
 *             float64_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_1 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_7missing_checknull(__pyx_v_key, 0, NULL); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1674, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1675
 * 
 *         if self.uses_mask and checknull(key):
 *             return -1 != self.na_position             # <<<<<<<<<<<<<<
 * 
 *         ckey = (key)
 */
    __pyx_r = (-1LL != __pyx_v_self->na_position);
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":1674
 *             float64_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1677
 *             return -1 != self.na_position
 * 
 *         ckey = (key)             # <<<<<<<<<<<<<<
 *         k = kh_get_float64(self.table, ckey)
 *         return k != self.table.n_buckets
 */
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_v_key); if (unlikely((__pyx_t_3 == ((npy_float64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 1677, __pyx_L1_error)
  __pyx_v_ckey = __pyx_t_3;

  /* "pandas/_libs/hashtable_class_helper.pxi":1678
 * 
 *         ckey = (key)
 *         k = kh_get_float64(self.table, ckey)             # <<<<<<<<<<<<<<
 *         return k != self.table.n_buckets
 * 
 */
  __pyx_v_k = kh_get_float64(__pyx_v_self->table, __pyx_v_ckey);

  /* "pandas/_libs/hashtable_class_helper.pxi":1679
 *         ckey = (key)
 *         k = kh_get_float64(self.table, ckey)
 *         return k != self.table.n_buckets             # <<<<<<<<<<<<<<
 * 
 *     def sizeof(self, deep: bool = False) -> int:
 */
  __pyx_r = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1667
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1681
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_16Float64HashTable_8sizeof, " return the size of my table in bytes ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_9sizeof = {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float64HashTable_8sizeof};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_deep = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sizeof (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_deep,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_deep);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1681, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "sizeof") < 0)) __PYX_ERR(2, 1681, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_deep = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sizeof", 0, 0, 1, __pyx_nargs); __PYX_ERR(2, 1681, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_8sizeof(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)__pyx_v_self), __pyx_v_deep);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep) {
  PyObject *__pyx_v_overhead = NULL;
  PyObject *__pyx_v_for_flags = NULL;
  PyObject *__pyx_v_for_pairs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  long __pyx_t_2;
  long __pyx_t_3;
  long __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sizeof", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1683
 *     def sizeof(self, deep: bool = False) -> int:
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)             # <<<<<<<<<<<<<<
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(float64_t) + # keys
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(((4 * (sizeof(__pyx_t_5numpy_uint32_t))) + (3 * (sizeof(__pyx_t_5numpy_uint32_t *))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_overhead = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1684
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)             # <<<<<<<<<<<<<<
 *         for_pairs =  self.table.n_buckets * (sizeof(float64_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 */
  __pyx_t_2 = (__pyx_v_self->table->n_buckets >> 5);
  __pyx_t_3 = 1;
  __pyx_t_5 = (__pyx_t_2 > __pyx_t_3);
  if (__pyx_t_5) {
    __pyx_t_4 = __pyx_t_2;
  } else {
    __pyx_t_4 = __pyx_t_3;
  }
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_t_4 * (sizeof(__pyx_t_5numpy_uint32_t)))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_flags = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1685
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(float64_t) + # keys             # <<<<<<<<<<<<<<
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->n_buckets * ((sizeof(__pyx_t_5numpy_float64_t)) + (sizeof(Py_ssize_t))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1685, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_pairs = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1687
 *         for_pairs =  self.table.n_buckets * (sizeof(float64_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs             # <<<<<<<<<<<<<<
 * 
 *     def get_state(self) -> dict[str, int]:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Add(__pyx_v_overhead, __pyx_v_for_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyNumber_Add(__pyx_t_1, __pyx_v_for_pairs); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1687, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(__Pyx_Py3Int_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None) || __Pyx_RaiseUnexpectedTypeError("int", __pyx_t_6))) __PYX_ERR(2, 1687, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1681
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_overhead);
  __Pyx_XDECREF(__pyx_v_for_flags);
  __Pyx_XDECREF(__pyx_v_for_pairs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1689
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_16Float64HashTable_10get_state, " returns infos about the state of the hashtable");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_11get_state = {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float64HashTable_10get_state};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_state (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_state", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_state", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_10get_state(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_state", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1691
 *     def get_state(self) -> dict[str, int]:
 *         """ returns infos about the state of the hashtable"""
 *         return {             # <<<<<<<<<<<<<<
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 */
  __Pyx_XDECREF(__pyx_r);

  /* "pandas/_libs/hashtable_class_helper.pxi":1692
 *         """ returns infos about the state of the hashtable"""
 *         return {
 *             'n_buckets' : self.table.n_buckets,             # <<<<<<<<<<<<<<
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_buckets); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_buckets, __pyx_t_2) < 0) __PYX_ERR(2, 1692, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1693
 *         return {
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,             # <<<<<<<<<<<<<<
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->size); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_size, __pyx_t_2) < 0) __PYX_ERR(2, 1692, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1694
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,             # <<<<<<<<<<<<<<
 *             'upper_bound' : self.table.upper_bound,
 *         }
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_occupied); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1694, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_occupied, __pyx_t_2) < 0) __PYX_ERR(2, 1692, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1695
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,             # <<<<<<<<<<<<<<
 *         }
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->upper_bound); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1695, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_upper_bound, __pyx_t_2) < 0) __PYX_ERR(2, 1692, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1689
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.get_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1698
 *         }
 * 
 *     cpdef get_item(self, float64_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_16Float64HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, __pyx_t_5numpy_float64_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_float64_t __pyx_v_cval;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1698, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_13get_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = PyFloat_FromDouble(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1698, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1698, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1717
 *             float64_t cval
 * 
 *         cval = (val)             # <<<<<<<<<<<<<<
 *         k = kh_get_float64(self.table, cval)
 *         if k != self.table.n_buckets:
 */
  __pyx_v_cval = __pyx_v_val;

  /* "pandas/_libs/hashtable_class_helper.pxi":1718
 * 
 *         cval = (val)
 *         k = kh_get_float64(self.table, cval)             # <<<<<<<<<<<<<<
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]
 */
  __pyx_v_k = kh_get_float64(__pyx_v_self->table, __pyx_v_cval);

  /* "pandas/_libs/hashtable_class_helper.pxi":1719
 *         cval = (val)
 *         k = kh_get_float64(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  __pyx_t_7 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  if (likely(__pyx_t_7)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1720
 *         k = kh_get_float64(self.table, cval)
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(val)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->vals[__pyx_v_k])); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1720, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":1719
 *         cval = (val)
 *         k = kh_get_float64(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1722
 *             return self.table.vals[k]
 *         else:
 *             raise KeyError(val)             # <<<<<<<<<<<<<<
 * 
 *     cpdef get_na(self):
 */
  /*else*/ {
    __pyx_t_1 = PyFloat_FromDouble(__pyx_v_val); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1722, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1722, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 1722, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1698
 *         }
 * 
 *     cpdef get_item(self, float64_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_16Float64HashTable_12get_item, "Extracts the position of val from the hashtable.\n\n        Parameters\n        ----------\n        val : Scalar\n            The value that is looked up in the hashtable\n\n        Returns\n        -------\n        The position of the requested integer.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_13get_item = {"get_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_13get_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float64HashTable_12get_item};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_5numpy_float64_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1698, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_item") < 0)) __PYX_ERR(2, 1698, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_val == ((npy_float64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 1698, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_item", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 1698, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_12get_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, __pyx_t_5numpy_float64_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_16Float64HashTable_get_item(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1724
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_16Float64HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1724, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_15get_na)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1724, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1732
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_6 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1733
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         if self.na_position == -1:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 1733, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":1732
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1735
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  __pyx_t_6 = (__pyx_v_self->na_position == -1LL);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1736
 * 
 *         if self.na_position == -1:
 *             raise KeyError("NA")             # <<<<<<<<<<<<<<
 *         return self.na_position
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_KeyError, __pyx_tuple__13, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1736, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(2, 1736, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":1735
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1737
 *         if self.na_position == -1:
 *             raise KeyError("NA")
 *         return self.na_position             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_item(self, float64_t key, Py_ssize_t val):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->na_position); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1724
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_16Float64HashTable_14get_na, "Extracts the position of na_value from the hashtable.\n\n        Returns\n        -------\n        The position of the last na value.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_15get_na = {"get_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_15get_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float64HashTable_14get_na};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_na", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_na", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_14get_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_16Float64HashTable_get_na(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1739
 *         return self.na_position
 * 
 *     cpdef set_item(self, float64_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_16Float64HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, __pyx_t_5numpy_float64_t __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  __pyx_t_5numpy_float64_t __pyx_v_ckey;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1739, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_17set_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = PyFloat_FromDouble(__pyx_v_key); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1739, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1739, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_5 = __pyx_t_1; __pyx_t_6 = NULL;
        __pyx_t_7 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_7 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_3, __pyx_t_4};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1739, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1744
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             float64_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1747
 *             float64_t ckey
 * 
 *         ckey = (key)             # <<<<<<<<<<<<<<
 *         k = kh_put_float64(self.table, ckey, &ret)
 *         if kh_exist_float64(self.table, k):
 */
  __pyx_v_ckey = __pyx_v_key;

  /* "pandas/_libs/hashtable_class_helper.pxi":1748
 * 
 *         ckey = (key)
 *         k = kh_put_float64(self.table, ckey, &ret)             # <<<<<<<<<<<<<<
 *         if kh_exist_float64(self.table, k):
 *             self.table.vals[k] = val
 */
  __pyx_v_k = kh_put_float64(__pyx_v_self->table, __pyx_v_ckey, (&__pyx_v_ret));

  /* "pandas/_libs/hashtable_class_helper.pxi":1749
 *         ckey = (key)
 *         k = kh_put_float64(self.table, ckey, &ret)
 *         if kh_exist_float64(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
  __pyx_t_8 = kh_exist_float64(__pyx_v_self->table, __pyx_v_k);
  if (likely(__pyx_t_8)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1750
 *         k = kh_put_float64(self.table, ckey, &ret)
 *         if kh_exist_float64(self.table, k):
 *             self.table.vals[k] = val             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(key)
 */
    (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_val;

    /* "pandas/_libs/hashtable_class_helper.pxi":1749
 *         ckey = (key)
 *         k = kh_put_float64(self.table, ckey, &ret)
 *         if kh_exist_float64(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1752
 *             self.table.vals[k] = val
 *         else:
 *             raise KeyError(key)             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_na(self, Py_ssize_t val):
 */
  /*else*/ {
    __pyx_t_1 = PyFloat_FromDouble(__pyx_v_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1752, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1752, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 1752, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "pandas/_libs/hashtable_class_helper.pxi":1739
 *         return self.na_position
 * 
 *     cpdef set_item(self, float64_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_17set_item = {"set_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_17set_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_5numpy_float64_t __pyx_v_key;
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key,&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1739, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1739, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, 1); __PYX_ERR(2, 1739, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_item") < 0)) __PYX_ERR(2, 1739, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_key = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_key == ((npy_float64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 1739, __pyx_L3_error)
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 1739, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, __pyx_nargs); __PYX_ERR(2, 1739, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_16set_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)__pyx_v_self), __pyx_v_key, __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, __pyx_t_5numpy_float64_t __pyx_v_key, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_16Float64HashTable_set_item(__pyx_v_self, __pyx_v_key, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1754
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_16Float64HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  CYTHON_UNUSED int __pyx_v_ret;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1754, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_19set_na)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1754, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1754, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1758
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             float64_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1761
 *             float64_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_7 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_7)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1762
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         self.na_position = val
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 1762, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":1761
 *             float64_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1764
 *             raise NotImplementedError
 * 
 *         self.na_position = val             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->na_position = __pyx_v_val;

  /* "pandas/_libs/hashtable_class_helper.pxi":1754
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_19set_na = {"set_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_19set_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1754, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_na") < 0)) __PYX_ERR(2, 1754, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[0]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 1754, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_na", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 1754, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_18set_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_16Float64HashTable_set_na(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1767
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const float64_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_21map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_21map_locations = {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_21map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_21map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("map_locations (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1767, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1767, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "map_locations") < 0)) __PYX_ERR(2, 1767, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float64_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 1768, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 1768, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__18;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("map_locations", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 1767, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_20map_locations(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_20map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  int __pyx_v_ret;
  __pyx_t_5numpy_float64_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  __pyx_t_5numpy_int64_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("map_locations", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1771
 *         # Used in libindex, safe_sort
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             float64_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":1772
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             float64_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1775
 *             float64_t val
 *             khiter_t k
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_2 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":1777
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_3 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_3)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1778
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 1778, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":1777
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1780
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":1781
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
        if (__pyx_v_self->uses_mask) {

          /* "pandas/_libs/hashtable_class_helper.pxi":1782
 *         with nogil:
 *             if self.uses_mask:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     if mask[i]:
 *                         na_position = i
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":1783
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_mask.shape[0];
            __pyx_t_3 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) ))) != 0);
            if (__pyx_t_3) {

              /* "pandas/_libs/hashtable_class_helper.pxi":1784
 *                 for i in range(n):
 *                     if mask[i]:
 *                         na_position = i             # <<<<<<<<<<<<<<
 *                     else:
 *                         val= (values[i])
 */
              __pyx_v_na_position = __pyx_v_i;

              /* "pandas/_libs/hashtable_class_helper.pxi":1783
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
              goto __pyx_L12;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":1786
 *                         na_position = i
 *                     else:
 *                         val= (values[i])             # <<<<<<<<<<<<<<
 *                         k = kh_put_float64(self.table, val, &ret)
 *                         self.table.vals[k] = i
 */
            /*else*/ {
              __pyx_t_7 = __pyx_v_i;
              if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
              __pyx_v_val = (*((__pyx_t_5numpy_float64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_class_helper.pxi":1787
 *                     else:
 *                         val= (values[i])
 *                         k = kh_put_float64(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = i
 *             else:
 */
              __pyx_v_k = kh_put_float64(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

              /* "pandas/_libs/hashtable_class_helper.pxi":1788
 *                         val= (values[i])
 *                         k = kh_put_float64(self.table, val, &ret)
 *                         self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *             else:
 *                 for i in range(n):
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
            }
            __pyx_L12:;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":1781
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
          goto __pyx_L9;
        }

        /* "pandas/_libs/hashtable_class_helper.pxi":1790
 *                         self.table.vals[k] = i
 *             else:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     val= (values[i])
 *                     k = kh_put_float64(self.table, val, &ret)
 */
        /*else*/ {
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":1791
 *             else:
 *                 for i in range(n):
 *                     val= (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_put_float64(self.table, val, &ret)
 *                     self.table.vals[k] = i
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
            __pyx_v_val = (*((__pyx_t_5numpy_float64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

            /* "pandas/_libs/hashtable_class_helper.pxi":1792
 *                 for i in range(n):
 *                     val= (values[i])
 *                     k = kh_put_float64(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                     self.table.vals[k] = i
 *         self.na_position = na_position
 */
            __pyx_v_k = kh_put_float64(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":1793
 *                     val= (values[i])
 *                     k = kh_put_float64(self.table, val, &ret)
 *                     self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *         self.na_position = na_position
 * 
 */
            (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
          }
        }
        __pyx_L9:;
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":1780
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1794
 *                     k = kh_put_float64(self.table, val, &ret)
 *                     self.table.vals[k] = i
 *         self.na_position = na_position             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __pyx_v_self->na_position = __pyx_v_na_position;

  /* "pandas/_libs/hashtable_class_helper.pxi":1767
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const float64_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1796
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const float64_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

/* Python wrapper */
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_23lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_23lookup = {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_23lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_23lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyArrayObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lookup (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1796, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1796, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lookup") < 0)) __PYX_ERR(2, 1796, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float64_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 1797, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 1797, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__19;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lookup", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 1796, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_22lookup(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_22lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  CYTHON_UNUSED int __pyx_v_ret;
  __pyx_t_5numpy_float64_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __Pyx_memviewslice __pyx_v_locs = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lookup", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1801
 *         # Used in safe_sort, IndexEngine.get_indexer
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             float64_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":1802
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             float64_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1805
 *             float64_t val
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *             int8_t na_position = self.na_position
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 1805, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 1805, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 1805, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_locs = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":1806
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_8 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":1808
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_9 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_10 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_9 = __pyx_t_10;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1809
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 1809, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":1808
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1811
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":1812
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_11 = __pyx_t_1;
        for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
          __pyx_v_i = __pyx_t_12;

          /* "pandas/_libs/hashtable_class_helper.pxi":1813
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
          if (__pyx_v_self->uses_mask) {
          } else {
            __pyx_t_9 = __pyx_v_self->uses_mask;
            goto __pyx_L12_bool_binop_done;
          }
          __pyx_t_13 = __pyx_v_i;
          if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_mask.shape[0];
          __pyx_t_10 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_13 * __pyx_v_mask.strides[0]) ))) != 0);
          __pyx_t_9 = __pyx_t_10;
          __pyx_L12_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":1814
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position             # <<<<<<<<<<<<<<
 *                 else:
 *                     val = (values[i])
 */
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = __pyx_v_na_position;

            /* "pandas/_libs/hashtable_class_helper.pxi":1813
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
            goto __pyx_L11;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":1816
 *                     locs[i] = na_position
 *                 else:
 *                     val = (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_float64(self.table, val)
 *                     if k != self.table.n_buckets:
 */
          /*else*/ {
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_values.shape[0];
            __pyx_v_val = (*((__pyx_t_5numpy_float64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_13 * __pyx_v_values.strides[0]) )));

            /* "pandas/_libs/hashtable_class_helper.pxi":1817
 *                 else:
 *                     val = (values[i])
 *                     k = kh_get_float64(self.table, val)             # <<<<<<<<<<<<<<
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]
 */
            __pyx_v_k = kh_get_float64(__pyx_v_self->table, __pyx_v_val);

            /* "pandas/_libs/hashtable_class_helper.pxi":1818
 *                     val = (values[i])
 *                     k = kh_get_float64(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
            __pyx_t_9 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":1819
 *                     k = kh_get_float64(self.table, val)
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     else:
 *                         locs[i] = -1
 */
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = (__pyx_v_self->table->vals[__pyx_v_k]);

              /* "pandas/_libs/hashtable_class_helper.pxi":1818
 *                     val = (values[i])
 *                     k = kh_get_float64(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
              goto __pyx_L14;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":1821
 *                         locs[i] = self.table.vals[k]
 *                     else:
 *                         locs[i] = -1             # <<<<<<<<<<<<<<
 * 
 *         return np.asarray(locs)
 */
            /*else*/ {
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = -1;
            }
            __pyx_L14:;
          }
          __pyx_L11:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":1811
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1823
 *                         locs[i] = -1
 * 
 *         return np.asarray(locs)             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_locs, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1823, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_14 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_14 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1823, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 1823, __pyx_L1_error)
  __pyx_r = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1796
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const float64_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_locs, 1);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1825
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const float64_t[:] values, Float64Vector uniques,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_25_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_16Float64HashTable_24_unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[float64]\n            Array of values of which unique will be calculated\n        uniques : Float64Vector\n            Vector into which uniques will be written\n        count_prior : Py_ssize_t, default 0\n            Number of existing entries in uniques\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        ignore_na : bool, default False\n            Whether NA-values should be ignored for calculating the uniques. If\n            True, the labels corresponding to missing values will be set to\n            na_sentinel.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        use_result_mask: bool, default False\n            Whether to create a result mask for the unique values. Not supported\n            with return_inverse=True.\n\n        Returns\n        -------\n        uniques : ndarray[float64]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse=True)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if use_result_mask is true\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_25_unique = {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_25_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float64HashTable_24_unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_25_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  int __pyx_v_ignore_na;
  PyObject *__pyx_v_mask = 0;
  int __pyx_v_return_inverse;
  int __pyx_v_use_result_mask;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[9] = {0,0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_ignore_na,&__pyx_n_s_mask,&__pyx_n_s_return_inverse,&__pyx_n_s_use_result_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":1829
 *     def _unique(self, const float64_t[:] values, Float64Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));

    /* "pandas/_libs/hashtable_class_helper.pxi":1830
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[6] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1825, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1825, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, 1); __PYX_ERR(2, 1825, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1825, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1825, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1825, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1825, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[6] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1825, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[7] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1825, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_use_result_mask);
          if (value) { values[8] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1825, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_unique") < 0)) __PYX_ERR(2, 1825, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float64_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 1827, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 1828, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 1828, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    if (values[5]) {
      __pyx_v_ignore_na = __Pyx_PyObject_IsTrue(values[5]); if (unlikely((__pyx_v_ignore_na == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1829, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":1829
 *     def _unique(self, const float64_t[:] values, Float64Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
      __pyx_v_ignore_na = ((int)0);
    }
    __pyx_v_mask = values[6];
    if (values[7]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[7]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1830, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":1830
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
      __pyx_v_return_inverse = ((int)0);
    }
    if (values[8]) {
      __pyx_v_use_result_mask = __Pyx_PyObject_IsTrue(values[8]); if (unlikely((__pyx_v_use_result_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1830, __pyx_L3_error)
    } else {
      __pyx_v_use_result_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, __pyx_nargs); __PYX_ERR(2, 1825, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector, 1, "uniques", 0))) __PYX_ERR(2, 1827, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_24_unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_ignore_na, __pyx_v_mask, __pyx_v_return_inverse, __pyx_v_use_result_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":1825
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const float64_t[:] values, Float64Vector uniques,
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_24_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_idx;
  Py_ssize_t __pyx_v_count;
  Py_ssize_t __pyx_v_n;
  __Pyx_memviewslice __pyx_v_labels = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_ret;
  __pyx_t_5numpy_float64_t __pyx_v_val;
  __pyx_t_5numpy_float64_t __pyx_v_na_value2;
  khiter_t __pyx_v_k;
  __pyx_t_6pandas_5_libs_9hashtable_Float64VectorData *__pyx_v_ud;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_result_mask = 0;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_v_rmd;
  int __pyx_v_use_na_value;
  int __pyx_v_use_mask;
  int __pyx_v_seen_na;
  __Pyx_memviewslice __pyx_v_mask_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_6pandas_5_libs_9hashtable_Float64VectorData *__pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_t_11;
  int __pyx_t_12;
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_float64_t __pyx_t_14;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":1874
 *         """
 *         cdef:
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)             # <<<<<<<<<<<<<<
 *             intp_t[::1] labels
 *             int ret = 0
 */
  __pyx_v_count = __pyx_v_count_prior;
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":1876
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)
 *             intp_t[::1] labels
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             float64_t val, na_value2
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1882
 *             UInt8Vector result_mask
 *             UInt8VectorData *rmd
 *             bint use_na_value, use_mask, seen_na = False             # <<<<<<<<<<<<<<
 *             uint8_t[:] mask_values
 * 
 */
  __pyx_v_seen_na = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1885
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1886
 * 
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1886, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 1886, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1886, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1886, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 1886, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1886, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1886, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1886, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 1886, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1886, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 1886, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_labels = __pyx_t_7;
    __pyx_t_7.memview = NULL;
    __pyx_t_7.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":1885
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1887
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data             # <<<<<<<<<<<<<<
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 */
  __pyx_t_8 = __pyx_v_uniques->data;
  __pyx_v_ud = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":1888
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 *         use_na_value = na_value is not None             # <<<<<<<<<<<<<<
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 */
  __pyx_t_9 = (__pyx_v_na_value != Py_None);
  __pyx_v_use_na_value = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":1889
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None             # <<<<<<<<<<<<<<
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover
 */
  __pyx_t_9 = (__pyx_v_mask != Py_None);
  __pyx_v_use_mask = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":1890
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  __pyx_t_10 = (!__pyx_v_use_mask);
  if (__pyx_t_10) {
  } else {
    __pyx_t_9 = __pyx_t_10;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_use_result_mask;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1891
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         if use_result_mask and return_inverse:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 1891, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":1890
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1893
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_use_result_mask) {
  } else {
    __pyx_t_9 = __pyx_v_use_result_mask;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_return_inverse;
  __pyx_L8_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1894
 * 
 *         if use_result_mask and return_inverse:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         result_mask = UInt8Vector()
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 1894, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":1893
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1896
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         result_mask = UInt8Vector()             # <<<<<<<<<<<<<<
 *         rmd = result_mask.data
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1896, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_v_result_mask = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1897
 * 
 *         result_mask = UInt8Vector()
 *         rmd = result_mask.data             # <<<<<<<<<<<<<<
 * 
 *         if use_mask:
 */
  __pyx_t_11 = __pyx_v_result_mask->data;
  __pyx_v_rmd = __pyx_t_11;

  /* "pandas/_libs/hashtable_class_helper.pxi":1899
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  if (__pyx_v_use_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1900
 * 
 *         if use_mask:
 *             mask_values = mask.view("uint8")             # <<<<<<<<<<<<<<
 * 
 *         if use_na_value:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_mask, __pyx_n_s_view); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1900, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    __pyx_t_12 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_12 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_uint8};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_12, 1+__pyx_t_12);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1900, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(2, 1900, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_mask_values = __pyx_t_13;
    __pyx_t_13.memview = NULL;
    __pyx_t_13.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":1899
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1902
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
  if (__pyx_v_use_na_value) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1908
 *             # for the parameter. To please the compiler, we use na_value2,
 *             # which is only used if it's *specified*.
 *             na_value2 = (na_value)             # <<<<<<<<<<<<<<
 *         else:
 *             na_value2 = (0)
 */
    __pyx_t_14 = __pyx_PyFloat_AsDouble(__pyx_v_na_value); if (unlikely((__pyx_t_14 == ((npy_float64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 1908, __pyx_L1_error)
    __pyx_v_na_value2 = __pyx_t_14;

    /* "pandas/_libs/hashtable_class_helper.pxi":1902
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
    goto __pyx_L11;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1910
 *             na_value2 = (na_value)
 *         else:
 *             na_value2 = (0)             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
  /*else*/ {
    __pyx_v_na_value2 = 0.0;
  }
  __pyx_L11:;

  /* "pandas/_libs/hashtable_class_helper.pxi":1912
 *             na_value2 = (0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = (values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":1913
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 val = (values[i])
 * 
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_15 = __pyx_t_1;
        for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
          __pyx_v_i = __pyx_t_16;

          /* "pandas/_libs/hashtable_class_helper.pxi":1914
 *         with nogil:
 *             for i in range(n):
 *                 val = (values[i])             # <<<<<<<<<<<<<<
 * 
 *                 if ignore_na and use_mask:
 */
          __pyx_t_17 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_float64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_17 * __pyx_v_values.strides[0]) )));

          /* "pandas/_libs/hashtable_class_helper.pxi":1916
 *                 val = (values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L18_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_mask;
          __pyx_L18_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":1917
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 1917, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_17 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":1918
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                         continue
 *                 elif ignore_na and (
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 1918, __pyx_L13_error) }
              __pyx_t_17 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_na_sentinel;

              /* "pandas/_libs/hashtable_class_helper.pxi":1919
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 *                         continue             # <<<<<<<<<<<<<<
 *                 elif ignore_na and (
 *                    is_nan_float64_t(val) or
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":1917
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":1916
 *                 val = (values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
            goto __pyx_L17;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":1920
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_float64_t(val) or
 *                    (use_na_value and are_equivalent_float64_t(val, na_value2))
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":1921
 *                         continue
 *                 elif ignore_na and (
 *                    is_nan_float64_t(val) or             # <<<<<<<<<<<<<<
 *                    (use_na_value and are_equivalent_float64_t(val, na_value2))
 *                 ):
 */
          __pyx_t_10 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_float64_t(__pyx_v_val); if (unlikely(__pyx_t_10 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 1921, __pyx_L13_error)
          if (!__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":1922
 *                 elif ignore_na and (
 *                    is_nan_float64_t(val) or
 *                    (use_na_value and are_equivalent_float64_t(val, na_value2))             # <<<<<<<<<<<<<<
 *                 ):
 *                     # if missing values do not count as unique values (i.e. if
 */
          if (__pyx_v_use_na_value) {
          } else {
            __pyx_t_9 = __pyx_v_use_na_value;
            goto __pyx_L21_bool_binop_done;
          }
          __pyx_t_10 = kh_floats_hash_equal(__pyx_v_val, __pyx_v_na_value2);
          __pyx_t_9 = __pyx_t_10;
          __pyx_L21_bool_binop_done:;

          /* "pandas/_libs/hashtable_class_helper.pxi":1920
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_float64_t(val) or
 *                    (use_na_value and are_equivalent_float64_t(val, na_value2))
 */
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":1927
 *                     # ignore_na is True), skip the hashtable entry for them,
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 1927, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_na_sentinel;

            /* "pandas/_libs/hashtable_class_helper.pxi":1928
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel
 *                     continue             # <<<<<<<<<<<<<<
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 */
            goto __pyx_L15_continue;

            /* "pandas/_libs/hashtable_class_helper.pxi":1920
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_float64_t(val) or
 *                    (use_na_value and are_equivalent_float64_t(val, na_value2))
 */
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":1929
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          __pyx_t_10 = (!__pyx_v_ignore_na);
          if (__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L25_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_result_mask;
          __pyx_L25_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":1930
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 1930, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_17 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":1931
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_class_helper.pxi":1932
 *                     if mask_values[i]:
 *                         if seen_na:
 *                             continue             # <<<<<<<<<<<<<<
 * 
 *                         seen_na = True
 */
                goto __pyx_L15_continue;

                /* "pandas/_libs/hashtable_class_helper.pxi":1931
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":1934
 *                             continue
 * 
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         if needs_resize(ud):
 *                             with gil:
 */
              __pyx_v_seen_na = 1;

              /* "pandas/_libs/hashtable_class_helper.pxi":1935
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              __pyx_t_9 = __pyx_fuse_8__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 1935, __pyx_L13_error)
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_class_helper.pxi":1936
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                {
                    #ifdef WITH_THREAD
                    PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                    #endif
                    /*try:*/ {

                      /* "pandas/_libs/hashtable_class_helper.pxi":1937
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":1938
 *                             with gil:
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1938, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 1938, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":1937
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":1941
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float64Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1941, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":1942
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":1943
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1943, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 1943, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":1942
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":1946
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                         append_data_float64(ud, val)
 *                         append_data_uint8(rmd, 1)
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1946, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":1936
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    /*finally:*/ {
                      /*normal exit:*/{
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L34;
                      }
                      __pyx_L33_error: {
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L13_error;
                      }
                      __pyx_L34:;
                    }
                }

                /* "pandas/_libs/hashtable_class_helper.pxi":1935
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":1947
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                         append_data_float64(ud, val)             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 1)
 *                         continue
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_float64(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 1947, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":1948
 *                                 result_mask.resize()
 *                         append_data_float64(ud, val)
 *                         append_data_uint8(rmd, 1)             # <<<<<<<<<<<<<<
 *                         continue
 * 
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 1); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 1948, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":1949
 *                         append_data_float64(ud, val)
 *                         append_data_uint8(rmd, 1)
 *                         continue             # <<<<<<<<<<<<<<
 * 
 *                 k = kh_get_float64(self.table, val)
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":1930
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":1929
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          }
          __pyx_L17:;

          /* "pandas/_libs/hashtable_class_helper.pxi":1951
 *                         continue
 * 
 *                 k = kh_get_float64(self.table, val)             # <<<<<<<<<<<<<<
 * 
 *                 if k == self.table.n_buckets:
 */
          __pyx_v_k = kh_get_float64(__pyx_v_self->table, __pyx_v_val);

          /* "pandas/_libs/hashtable_class_helper.pxi":1953
 *                 k = kh_get_float64(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_float64(self.table, val, &ret)
 */
          __pyx_t_9 = (__pyx_v_k == __pyx_v_self->table->n_buckets);
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":1955
 *                 if k == self.table.n_buckets:
 *                     # k hasn't been seen yet
 *                     k = kh_put_float64(self.table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *                     if needs_resize(ud):
 */
            __pyx_v_k = kh_put_float64(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":1957
 *                     k = kh_put_float64(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            __pyx_t_9 = __pyx_fuse_8__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 1957, __pyx_L13_error)
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":1958
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
              {
                  #ifdef WITH_THREAD
                  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                  #endif
                  /*try:*/ {

                    /* "pandas/_libs/hashtable_class_helper.pxi":1959
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":1960
 *                         with gil:
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 */
                      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1960, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                      __PYX_ERR(2, 1960, __pyx_L42_error)

                      /* "pandas/_libs/hashtable_class_helper.pxi":1959
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":1963
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()             # <<<<<<<<<<<<<<
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 */
                    __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float64Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1963, __pyx_L42_error)
                    __Pyx_GOTREF(__pyx_t_6);
                    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                    /* "pandas/_libs/hashtable_class_helper.pxi":1964
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    if (__pyx_v_use_result_mask) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":1965
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":1966
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1966, __pyx_L42_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 1966, __pyx_L42_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":1965
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":1969
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                     append_data_float64(ud, val)
 *                     if use_result_mask:
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1969, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":1964
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    }
                  }

                  /* "pandas/_libs/hashtable_class_helper.pxi":1958
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
                  /*finally:*/ {
                    /*normal exit:*/{
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L43;
                    }
                    __pyx_L42_error: {
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L13_error;
                    }
                    __pyx_L43:;
                  }
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":1957
 *                     k = kh_put_float64(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":1970
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                     append_data_float64(ud, val)             # <<<<<<<<<<<<<<
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)
 */
            __pyx_f_6pandas_5_libs_9hashtable_append_data_float64(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 1970, __pyx_L13_error)

            /* "pandas/_libs/hashtable_class_helper.pxi":1971
 *                                 result_mask.resize()
 *                     append_data_float64(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            if (__pyx_v_use_result_mask) {

              /* "pandas/_libs/hashtable_class_helper.pxi":1972
 *                     append_data_float64(ud, val)
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)             # <<<<<<<<<<<<<<
 * 
 *                     if return_inverse:
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 0); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 1972, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":1971
 *                                 result_mask.resize()
 *                     append_data_float64(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":1974
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            if (__pyx_v_return_inverse) {

              /* "pandas/_libs/hashtable_class_helper.pxi":1975
 * 
 *                     if return_inverse:
 *                         self.table.vals[k] = count             # <<<<<<<<<<<<<<
 *                         labels[i] = count
 *                         count += 1
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":1976
 *                     if return_inverse:
 *                         self.table.vals[k] = count
 *                         labels[i] = count             # <<<<<<<<<<<<<<
 *                         count += 1
 *                 elif return_inverse:
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 1976, __pyx_L13_error) }
              __pyx_t_17 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":1977
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 *                         count += 1             # <<<<<<<<<<<<<<
 *                 elif return_inverse:
 *                     # k falls into a previous bucket
 */
              __pyx_v_count = (__pyx_v_count + 1);

              /* "pandas/_libs/hashtable_class_helper.pxi":1974
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":1953
 *                 k = kh_get_float64(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_float64(self.table, val, &ret)
 */
            goto __pyx_L37;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":1978
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          if (__pyx_v_return_inverse) {

            /* "pandas/_libs/hashtable_class_helper.pxi":1981
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     labels[i] = idx
 * 
 */
            __pyx_v_idx = (__pyx_v_self->table->vals[__pyx_v_k]);

            /* "pandas/_libs/hashtable_class_helper.pxi":1982
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]
 *                     labels[i] = idx             # <<<<<<<<<<<<<<
 * 
 *         if return_inverse:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 1982, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_idx;

            /* "pandas/_libs/hashtable_class_helper.pxi":1978
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          }
          __pyx_L37:;
          __pyx_L15_continue:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":1912
 *             na_value2 = (0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = (values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L14;
        }
        __pyx_L13_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L14:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1984
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1985
 * 
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray             # <<<<<<<<<<<<<<
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float64Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1985, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundLocalError("labels"); __PYX_ERR(2, 1985, __pyx_L1_error) }
    __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_labels, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1985, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_base); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1985, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1985, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_6);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_6)) __PYX_ERR(2, 1985, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4)) __PYX_ERR(2, 1985, __pyx_L1_error);
    __pyx_t_6 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":1984
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1986
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  if (__pyx_v_use_result_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":1987
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()             # <<<<<<<<<<<<<<
 *         return uniques.to_array()
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float64Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 1987, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->to_array(__pyx_v_result_mask, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1987, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1987, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2)) __PYX_ERR(2, 1987, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4)) __PYX_ERR(2, 1987, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":1986
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":1988
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()             # <<<<<<<<<<<<<<
 * 
 *     def unique(self, const float64_t[:] values, bint return_inverse=False, object mask=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float64Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 1988, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1825
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const float64_t[:] values, Float64Vector uniques,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_13, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_labels, 1);
  __Pyx_XDECREF((PyObject *)__pyx_v_result_mask);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask_values, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":1990
 *         return uniques.to_array()
 * 
 *     def unique(self, const float64_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_27unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_16Float64HashTable_26unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[float64]\n            Array of values of which unique will be calculated\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n\n        Returns\n        -------\n        uniques : ndarray[float64]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if mask is given as input\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_27unique = {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_27unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float64HashTable_26unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_27unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_return_inverse;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_return_inverse,&__pyx_n_s_mask,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1990, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1990, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 1990, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "unique") < 0)) __PYX_ERR(2, 1990, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float64_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 1990, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 1990, __pyx_L3_error)
    } else {
      __pyx_v_return_inverse = ((int)0);
    }
    __pyx_v_mask = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("unique", 0, 1, 3, __pyx_nargs); __PYX_ERR(2, 1990, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_26unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_return_inverse, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_26unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_uniques = NULL;
  int __pyx_v_use_result_mask;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2014
 *             The mask for the result values.
 *         """
 *         uniques = Float64Vector()             # <<<<<<<<<<<<<<
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2015
 *         """
 *         uniques = Float64Vector()
 *         use_result_mask = True if mask is not None else False             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 */
  __pyx_t_3 = (__pyx_v_mask != Py_None);
  if (__pyx_t_3) {
    __pyx_t_2 = 1;
  } else {
    __pyx_t_2 = 0;
  }
  __pyx_v_use_result_mask = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":2016
 *         uniques = Float64Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2016, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_float64_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2016, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2016, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4)) __PYX_ERR(2, 2016, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 2016, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2016, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ignore_na, Py_False) < 0) __PYX_ERR(2, 2016, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2017
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const float64_t[:] values, Py_ssize_t na_sentinel=-1,
 */
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_return_inverse); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return_inverse, __pyx_t_6) < 0) __PYX_ERR(2, 2016, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 2016, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_use_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_use_result_mask, __pyx_t_6) < 0) __PYX_ERR(2, 2016, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2016
 *         uniques = Float64Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2016, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1990
 *         return uniques.to_array()
 * 
 *     def unique(self, const float64_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2019
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const float64_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_29factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_16Float64HashTable_28factorize, "\n        Calculate unique values and labels (no sorting!)\n\n        Missing values are not included in the \"uniques\" for this method.\n        The labels for any missing values will be set to \"na_sentinel\"\n\n        Parameters\n        ----------\n        values : ndarray[float64]\n            Array of values of which unique will be calculated\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n\n        Returns\n        -------\n        uniques : ndarray[float64]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t]\n            The labels from values to uniques\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_29factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_29factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float64HashTable_28factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_29factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  PyObject *__pyx_v_ignore_na = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,&__pyx_n_s_ignore_na,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":2020
 * 
 *     def factorize(self, const float64_t[:] values, Py_ssize_t na_sentinel=-1,
 *                   object na_value=None, object mask=None, ignore_na=True):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_True));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2019, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2019, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2019, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2019, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2019, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 2019, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float64_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 2019, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 2019, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
    __pyx_v_ignore_na = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 5, __pyx_nargs); __PYX_ERR(2, 2019, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_28factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask, __pyx_v_ignore_na);

  /* "pandas/_libs/hashtable_class_helper.pxi":2019
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const float64_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_28factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_uniques_vector = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2050
 *             The labels from values to uniques
 *         """
 *         uniques_vector = Float64Vector()             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2050, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques_vector = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2051
 *         """
 *         uniques_vector = Float64Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_float64_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 2051, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques_vector);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques_vector))) __PYX_ERR(2, 2051, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 2051, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2052
 *         uniques_vector = Float64Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,             # <<<<<<<<<<<<<<
 *                             return_inverse=True)
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 2051, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, __pyx_v_ignore_na) < 0) __PYX_ERR(2, 2051, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 2051, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2053
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)             # <<<<<<<<<<<<<<
 * 
 *     def get_labels(self, const float64_t[:] values, Float64Vector uniques,
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 2051, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2051
 *         """
 *         uniques_vector = Float64Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2051, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2019
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const float64_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2055
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const float64_t[:] values, Float64Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_31get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_31get_labels = {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_31get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_31get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_labels (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":2057
 *     def get_labels(self, const float64_t[:] values, Float64Vector uniques,
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2055, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2055, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, 1); __PYX_ERR(2, 2055, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2055, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2055, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2055, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2055, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_labels") < 0)) __PYX_ERR(2, 2055, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float64_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 2055, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 2056, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 2056, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    __pyx_v_mask = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, __pyx_nargs); __PYX_ERR(2, 2055, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector, 1, "uniques", 0))) __PYX_ERR(2, 2055, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_30get_labels(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":2055
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const float64_t[:] values, Float64Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_30get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_v_labels = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_labels", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2059
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2059, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_float64_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2059, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2059, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 2059, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 2059, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2059, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_count_prior); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2059, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_count_prior, __pyx_t_4) < 0) __PYX_ERR(2, 2059, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2060
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,             # <<<<<<<<<<<<<<
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2060, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 2059, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 2059, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2061
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, Py_True) < 0) __PYX_ERR(2, 2059, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 2059, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 2059, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2059
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2059, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
    PyObject* sequence = __pyx_t_4;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(2, 2059, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2059, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
    index = 0; __pyx_t_2 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_1), 2) < 0) __PYX_ERR(2, 2059, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(2, 2059, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v__ = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_labels = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2062
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_labels);
  __pyx_r = __pyx_v_labels;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2055
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const float64_t[:] values, Float64Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XDECREF(__pyx_v_labels);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_33__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_33__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_33__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_33__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_32__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_32__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_35__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_35__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_35__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_35__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_34__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float64HashTable_34__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2071
 *         Float64Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = Float64HashTable(size_hint)
 *         self.uniques = Float64Vector()
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_size_hint = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2071, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 2071, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_size_hint = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 2071, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_size_hint), (&PyInt_Type), 0, "size_hint", 1))) __PYX_ERR(2, 2071, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *)__pyx_v_self), __pyx_v_size_hint);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2072
 * 
 *     def __cinit__(self, size_hint: int):
 *         self.table = Float64HashTable(size_hint)             # <<<<<<<<<<<<<<
 *         self.uniques = Float64Vector()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable), __pyx_v_size_hint); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2072, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2073
 *     def __cinit__(self, size_hint: int):
 *         self.table = Float64HashTable(size_hint)
 *         self.uniques = Float64Vector()             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const float64_t[:] values,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2073, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2071
 *         Float64Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = Float64HashTable(size_hint)
 *         self.uniques = Float64Vector()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2075
 *         self.uniques = Float64Vector()
 * 
 *     def factorize(self, const float64_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_17Float64Factorizer_2factorize, "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = Float64Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"float64\"), na_sentinel=20)\n        array([0, 1, 2])\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_17Float64Factorizer_3factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_17Float64Factorizer_2factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_v_na_sentinel = 0;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_neg_1));

    /* "pandas/_libs/hashtable_class_helper.pxi":2076
 * 
 *     def factorize(self, const float64_t[:] values,
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:             # <<<<<<<<<<<<<<
 *         """
 *         Returns
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2075, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2075, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2075, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2075, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 2075, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float64_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 2075, __pyx_L3_error)
    __pyx_v_na_sentinel = values[1];
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 4, __pyx_nargs); __PYX_ERR(2, 2075, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_2factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":2075
 *         self.uniques = Float64Vector()
 * 
 *     def factorize(self, const float64_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  PyArrayObject *__pyx_v_labels = 0;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_uniques = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_labels;
  __Pyx_Buffer __pyx_pybuffer_labels;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);
  __pyx_pybuffer_labels.pybuffer.buf = NULL;
  __pyx_pybuffer_labels.refcount = 0;
  __pyx_pybuffernd_labels.data = NULL;
  __pyx_pybuffernd_labels.rcbuffer = &__pyx_pybuffer_labels;

  /* "pandas/_libs/hashtable_class_helper.pxi":2093
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = Float64Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  if (__pyx_v_self->uniques->__pyx_base.external_view_exists) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2094
 * 
 *         if self.uniques.external_view_exists:
 *             uniques = Float64Vector()             # <<<<<<<<<<<<<<
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 */
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2094, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":2095
 *         if self.uniques.external_view_exists:
 *             uniques = Float64Vector()
 *             uniques.extend(self.uniques.to_array())             # <<<<<<<<<<<<<<
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 */
    __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float64Vector *)__pyx_v_self->uniques->__pyx_vtab)->to_array(__pyx_v_self->uniques, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2095, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float64_t__const__(__pyx_t_1, 0); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(2, 2095, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float64Vector *)__pyx_v_uniques->__pyx_vtab)->extend(__pyx_v_uniques, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2095, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
    __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":2096
 *             uniques = Float64Vector()
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques             # <<<<<<<<<<<<<<
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 */
    __Pyx_INCREF((PyObject *)__pyx_v_uniques);
    __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
    __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
    __pyx_v_self->uniques = __pyx_v_uniques;

    /* "pandas/_libs/hashtable_class_helper.pxi":2093
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = Float64Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2097
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->table), __pyx_n_s_get_labels); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_float64_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "pandas/_libs/hashtable_class_helper.pxi":2098
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,             # <<<<<<<<<<<<<<
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_self->__pyx_base.count); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2098, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "pandas/_libs/hashtable_class_helper.pxi":2097
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_5 = PyTuple_New(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3)) __PYX_ERR(2, 2097, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self->uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_self->uniques))) __PYX_ERR(2, 2097, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_4)) __PYX_ERR(2, 2097, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_na_sentinel);
  __Pyx_GIVEREF(__pyx_v_na_sentinel);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_v_na_sentinel)) __PYX_ERR(2, 2097, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2099
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)             # <<<<<<<<<<<<<<
 *         self.count = len(self.uniques)
 *         return labels
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2099, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 2099, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 2099, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2097
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2097, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 2097, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
    __pyx_t_7 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_7 < 0)) {
      PyErr_Fetch(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_v_labels, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      }
      __pyx_t_8 = __pyx_t_9 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_labels.diminfo[0].strides = __pyx_pybuffernd_labels.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_labels.diminfo[0].shape = __pyx_pybuffernd_labels.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(2, 2097, __pyx_L1_error)
  }
  __pyx_t_6 = 0;
  __pyx_v_labels = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2100
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  __pyx_t_3 = ((PyObject *)__pyx_v_self->uniques);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_11 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(2, 2100, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_self->__pyx_base.count = __pyx_t_11;

  /* "pandas/_libs/hashtable_class_helper.pxi":2101
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * cdef class UInt64HashTable(HashTable):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_labels);
  __pyx_r = ((PyObject *)__pyx_v_labels);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2075
 *         self.uniques = Float64Vector()
 * 
 *     def factorize(self, const float64_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_labels);
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2068
 * cdef class Float64Factorizer(Factorizer):
 *     cdef public:
 *         Float64HashTable table             # <<<<<<<<<<<<<<
 *         Float64Vector uniques
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_5table_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_5table_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_5table___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->table);
  __pyx_r = ((PyObject *)__pyx_v_self->table);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_5table_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable))))) __PYX_ERR(2, 2068, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64Factorizer.table.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_5table_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_5table_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_5table_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2069
 *     cdef public:
 *         Float64HashTable table
 *         Float64Vector uniques             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, size_hint: int):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_7uniques_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_7uniques_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_7uniques___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __pyx_r = ((PyObject *)__pyx_v_self->uniques);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_7uniques_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector))))) __PYX_ERR(2, 2069, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64Factorizer.uniques.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_7uniques_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_7uniques_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_7uniques_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_17Float64Factorizer_5__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_4__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64Factorizer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_17Float64Factorizer_7__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_6__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17Float64Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Float64Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2105
 * cdef class UInt64HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_uint64()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __pyx_t_5numpy_int64_t __pyx_v_size_hint;
  int __pyx_v_uses_mask;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,&__pyx_n_s_uses_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2105, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uses_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2105, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 2105, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_size_hint = __Pyx_PyInt_As_npy_int64(values[0]); if (unlikely((__pyx_v_size_hint == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 2105, __pyx_L3_error)
    } else {
      __pyx_v_size_hint = ((__pyx_t_5numpy_int64_t)1);
    }
    if (values[1]) {
      __pyx_v_uses_mask = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_uses_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 2105, __pyx_L3_error)
    } else {
      __pyx_v_uses_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 0, 2, __pyx_nargs); __PYX_ERR(2, 2105, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)__pyx_v_self), __pyx_v_size_hint, __pyx_v_uses_mask);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  khuint_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __pyx_t_5numpy_int64_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2106
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_uint64()             # <<<<<<<<<<<<<<
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_uint64(self.table, size_hint)
 */
  __pyx_v_self->table = kh_init_uint64();

  /* "pandas/_libs/hashtable_class_helper.pxi":2107
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_uint64()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)             # <<<<<<<<<<<<<<
 *         kh_resize_uint64(self.table, size_hint)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = kh_needed_n_buckets(__pyx_v_size_hint);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_1, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2107, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(2, 2107, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_6) {
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_5 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2107, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_int64(__pyx_t_3); if (unlikely((__pyx_t_7 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 2107, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_size_hint = __pyx_t_7;

  /* "pandas/_libs/hashtable_class_helper.pxi":2108
 *         self.table = kh_init_uint64()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_uint64(self.table, size_hint)             # <<<<<<<<<<<<<<
 * 
 *         self.uses_mask = uses_mask
 */
  kh_resize_uint64(__pyx_v_self->table, __pyx_v_size_hint);

  /* "pandas/_libs/hashtable_class_helper.pxi":2110
 *         kh_resize_uint64(self.table, size_hint)
 * 
 *         self.uses_mask = uses_mask             # <<<<<<<<<<<<<<
 *         self.na_position = -1
 * 
 */
  __pyx_v_self->uses_mask = __pyx_v_uses_mask;

  /* "pandas/_libs/hashtable_class_helper.pxi":2111
 * 
 *         self.uses_mask = uses_mask
 *         self.na_position = -1             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
  __pyx_v_self->na_position = -1LL;

  /* "pandas/_libs/hashtable_class_helper.pxi":2105
 * cdef class UInt64HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_uint64()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2113
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_3__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_3__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_2__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  long __pyx_t_1;
  int __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":2114
 * 
 *     def __len__(self) -> int:
 *         return self.table.size + (0 if self.na_position == -1 else 1)             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_2 = (__pyx_v_self->na_position == -1LL);
  if (__pyx_t_2) {
    __pyx_t_1 = 0;
  } else {
    __pyx_t_1 = 1;
  }
  __pyx_r = (__pyx_v_self->table->size + __pyx_t_1);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2113
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2116
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_uint64(self.table)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_5__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_5__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_4__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":2117
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_uint64(self.table)
 *             self.table = NULL
 */
  __pyx_t_1 = (__pyx_v_self->table != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2118
 *     def __dealloc__(self):
 *         if self.table is not NULL:
 *             kh_destroy_uint64(self.table)             # <<<<<<<<<<<<<<
 *             self.table = NULL
 * 
 */
    kh_destroy_uint64(__pyx_v_self->table);

    /* "pandas/_libs/hashtable_class_helper.pxi":2119
 *         if self.table is not NULL:
 *             kh_destroy_uint64(self.table)
 *             self.table = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __contains__(self, object key) -> bool:
 */
    __pyx_v_self->table = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":2117
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_uint64(self.table)
 *             self.table = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2116
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_uint64(self.table)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":2121
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__contains__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_6__contains__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)__pyx_v_self), ((PyObject *)__pyx_v_key));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, PyObject *__pyx_v_key) {
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_uint64_t __pyx_v_ckey;
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  __pyx_t_5numpy_uint64_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2128
 *             uint64_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_1 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_7missing_checknull(__pyx_v_key, 0, NULL); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2128, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2129
 * 
 *         if self.uses_mask and checknull(key):
 *             return -1 != self.na_position             # <<<<<<<<<<<<<<
 * 
 *         ckey = (key)
 */
    __pyx_r = (-1LL != __pyx_v_self->na_position);
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":2128
 *             uint64_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2131
 *             return -1 != self.na_position
 * 
 *         ckey = (key)             # <<<<<<<<<<<<<<
 *         k = kh_get_uint64(self.table, ckey)
 *         return k != self.table.n_buckets
 */
  __pyx_t_3 = __Pyx_PyInt_As_npy_uint64(__pyx_v_key); if (unlikely((__pyx_t_3 == ((npy_uint64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 2131, __pyx_L1_error)
  __pyx_v_ckey = __pyx_t_3;

  /* "pandas/_libs/hashtable_class_helper.pxi":2132
 * 
 *         ckey = (key)
 *         k = kh_get_uint64(self.table, ckey)             # <<<<<<<<<<<<<<
 *         return k != self.table.n_buckets
 * 
 */
  __pyx_v_k = kh_get_uint64(__pyx_v_self->table, __pyx_v_ckey);

  /* "pandas/_libs/hashtable_class_helper.pxi":2133
 *         ckey = (key)
 *         k = kh_get_uint64(self.table, ckey)
 *         return k != self.table.n_buckets             # <<<<<<<<<<<<<<
 * 
 *     def sizeof(self, deep: bool = False) -> int:
 */
  __pyx_r = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2121
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2135
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15UInt64HashTable_8sizeof, " return the size of my table in bytes ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_9sizeof = {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt64HashTable_8sizeof};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_deep = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sizeof (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_deep,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_deep);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2135, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "sizeof") < 0)) __PYX_ERR(2, 2135, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_deep = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sizeof", 0, 0, 1, __pyx_nargs); __PYX_ERR(2, 2135, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_8sizeof(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)__pyx_v_self), __pyx_v_deep);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep) {
  PyObject *__pyx_v_overhead = NULL;
  PyObject *__pyx_v_for_flags = NULL;
  PyObject *__pyx_v_for_pairs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  long __pyx_t_2;
  long __pyx_t_3;
  long __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sizeof", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2137
 *     def sizeof(self, deep: bool = False) -> int:
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)             # <<<<<<<<<<<<<<
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(uint64_t) + # keys
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(((4 * (sizeof(__pyx_t_5numpy_uint32_t))) + (3 * (sizeof(__pyx_t_5numpy_uint32_t *))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_overhead = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2138
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)             # <<<<<<<<<<<<<<
 *         for_pairs =  self.table.n_buckets * (sizeof(uint64_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 */
  __pyx_t_2 = (__pyx_v_self->table->n_buckets >> 5);
  __pyx_t_3 = 1;
  __pyx_t_5 = (__pyx_t_2 > __pyx_t_3);
  if (__pyx_t_5) {
    __pyx_t_4 = __pyx_t_2;
  } else {
    __pyx_t_4 = __pyx_t_3;
  }
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_t_4 * (sizeof(__pyx_t_5numpy_uint32_t)))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_flags = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2139
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(uint64_t) + # keys             # <<<<<<<<<<<<<<
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->n_buckets * ((sizeof(__pyx_t_5numpy_uint64_t)) + (sizeof(Py_ssize_t))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_pairs = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2141
 *         for_pairs =  self.table.n_buckets * (sizeof(uint64_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs             # <<<<<<<<<<<<<<
 * 
 *     def get_state(self) -> dict[str, int]:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Add(__pyx_v_overhead, __pyx_v_for_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyNumber_Add(__pyx_t_1, __pyx_v_for_pairs); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(__Pyx_Py3Int_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None) || __Pyx_RaiseUnexpectedTypeError("int", __pyx_t_6))) __PYX_ERR(2, 2141, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2135
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_overhead);
  __Pyx_XDECREF(__pyx_v_for_flags);
  __Pyx_XDECREF(__pyx_v_for_pairs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2143
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15UInt64HashTable_10get_state, " returns infos about the state of the hashtable");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_11get_state = {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt64HashTable_10get_state};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_state (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_state", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_state", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_10get_state(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_state", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2145
 *     def get_state(self) -> dict[str, int]:
 *         """ returns infos about the state of the hashtable"""
 *         return {             # <<<<<<<<<<<<<<
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 */
  __Pyx_XDECREF(__pyx_r);

  /* "pandas/_libs/hashtable_class_helper.pxi":2146
 *         """ returns infos about the state of the hashtable"""
 *         return {
 *             'n_buckets' : self.table.n_buckets,             # <<<<<<<<<<<<<<
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_buckets); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2146, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_buckets, __pyx_t_2) < 0) __PYX_ERR(2, 2146, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2147
 *         return {
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,             # <<<<<<<<<<<<<<
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->size); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2147, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_size, __pyx_t_2) < 0) __PYX_ERR(2, 2146, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2148
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,             # <<<<<<<<<<<<<<
 *             'upper_bound' : self.table.upper_bound,
 *         }
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_occupied); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_occupied, __pyx_t_2) < 0) __PYX_ERR(2, 2146, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2149
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,             # <<<<<<<<<<<<<<
 *         }
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->upper_bound); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2149, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_upper_bound, __pyx_t_2) < 0) __PYX_ERR(2, 2146, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2143
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.get_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2152
 *         }
 * 
 *     cpdef get_item(self, uint64_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt64HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, __pyx_t_5numpy_uint64_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_uint64_t __pyx_v_cval;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2152, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_13get_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyInt_From_npy_uint64(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2152, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2152, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2171
 *             uint64_t cval
 * 
 *         cval = (val)             # <<<<<<<<<<<<<<
 *         k = kh_get_uint64(self.table, cval)
 *         if k != self.table.n_buckets:
 */
  __pyx_v_cval = __pyx_v_val;

  /* "pandas/_libs/hashtable_class_helper.pxi":2172
 * 
 *         cval = (val)
 *         k = kh_get_uint64(self.table, cval)             # <<<<<<<<<<<<<<
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]
 */
  __pyx_v_k = kh_get_uint64(__pyx_v_self->table, __pyx_v_cval);

  /* "pandas/_libs/hashtable_class_helper.pxi":2173
 *         cval = (val)
 *         k = kh_get_uint64(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  __pyx_t_7 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  if (likely(__pyx_t_7)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2174
 *         k = kh_get_uint64(self.table, cval)
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(val)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->vals[__pyx_v_k])); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2174, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":2173
 *         cval = (val)
 *         k = kh_get_uint64(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2176
 *             return self.table.vals[k]
 *         else:
 *             raise KeyError(val)             # <<<<<<<<<<<<<<
 * 
 *     cpdef get_na(self):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyInt_From_npy_uint64(__pyx_v_val); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2176, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2176, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 2176, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2152
 *         }
 * 
 *     cpdef get_item(self, uint64_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15UInt64HashTable_12get_item, "Extracts the position of val from the hashtable.\n\n        Parameters\n        ----------\n        val : Scalar\n            The value that is looked up in the hashtable\n\n        Returns\n        -------\n        The position of the requested integer.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_13get_item = {"get_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_13get_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt64HashTable_12get_item};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_5numpy_uint64_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2152, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_item") < 0)) __PYX_ERR(2, 2152, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __Pyx_PyInt_As_npy_uint64(values[0]); if (unlikely((__pyx_v_val == ((npy_uint64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 2152, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_item", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 2152, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_12get_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, __pyx_t_5numpy_uint64_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_15UInt64HashTable_get_item(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2178
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt64HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2178, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_15get_na)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2178, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2186
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_6 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2187
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         if self.na_position == -1:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 2187, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":2186
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2189
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  __pyx_t_6 = (__pyx_v_self->na_position == -1LL);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2190
 * 
 *         if self.na_position == -1:
 *             raise KeyError("NA")             # <<<<<<<<<<<<<<
 *         return self.na_position
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_KeyError, __pyx_tuple__13, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(2, 2190, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":2189
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2191
 *         if self.na_position == -1:
 *             raise KeyError("NA")
 *         return self.na_position             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_item(self, uint64_t key, Py_ssize_t val):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->na_position); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2178
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15UInt64HashTable_14get_na, "Extracts the position of na_value from the hashtable.\n\n        Returns\n        -------\n        The position of the last na value.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_15get_na = {"get_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_15get_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt64HashTable_14get_na};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_na", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_na", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_14get_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_15UInt64HashTable_get_na(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2193
 *         return self.na_position
 * 
 *     cpdef set_item(self, uint64_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt64HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, __pyx_t_5numpy_uint64_t __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  __pyx_t_5numpy_uint64_t __pyx_v_ckey;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2193, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_17set_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyInt_From_npy_uint64(__pyx_v_key); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2193, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2193, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_5 = __pyx_t_1; __pyx_t_6 = NULL;
        __pyx_t_7 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_7 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_3, __pyx_t_4};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2193, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2198
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             uint64_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2201
 *             uint64_t ckey
 * 
 *         ckey = (key)             # <<<<<<<<<<<<<<
 *         k = kh_put_uint64(self.table, ckey, &ret)
 *         if kh_exist_uint64(self.table, k):
 */
  __pyx_v_ckey = __pyx_v_key;

  /* "pandas/_libs/hashtable_class_helper.pxi":2202
 * 
 *         ckey = (key)
 *         k = kh_put_uint64(self.table, ckey, &ret)             # <<<<<<<<<<<<<<
 *         if kh_exist_uint64(self.table, k):
 *             self.table.vals[k] = val
 */
  __pyx_v_k = kh_put_uint64(__pyx_v_self->table, __pyx_v_ckey, (&__pyx_v_ret));

  /* "pandas/_libs/hashtable_class_helper.pxi":2203
 *         ckey = (key)
 *         k = kh_put_uint64(self.table, ckey, &ret)
 *         if kh_exist_uint64(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
  __pyx_t_8 = kh_exist_uint64(__pyx_v_self->table, __pyx_v_k);
  if (likely(__pyx_t_8)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2204
 *         k = kh_put_uint64(self.table, ckey, &ret)
 *         if kh_exist_uint64(self.table, k):
 *             self.table.vals[k] = val             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(key)
 */
    (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_val;

    /* "pandas/_libs/hashtable_class_helper.pxi":2203
 *         ckey = (key)
 *         k = kh_put_uint64(self.table, ckey, &ret)
 *         if kh_exist_uint64(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2206
 *             self.table.vals[k] = val
 *         else:
 *             raise KeyError(key)             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_na(self, Py_ssize_t val):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyInt_From_npy_uint64(__pyx_v_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2206, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 2206, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "pandas/_libs/hashtable_class_helper.pxi":2193
 *         return self.na_position
 * 
 *     cpdef set_item(self, uint64_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_17set_item = {"set_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_17set_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_5numpy_uint64_t __pyx_v_key;
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key,&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2193, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2193, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, 1); __PYX_ERR(2, 2193, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_item") < 0)) __PYX_ERR(2, 2193, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_key = __Pyx_PyInt_As_npy_uint64(values[0]); if (unlikely((__pyx_v_key == ((npy_uint64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 2193, __pyx_L3_error)
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 2193, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, __pyx_nargs); __PYX_ERR(2, 2193, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_16set_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)__pyx_v_self), __pyx_v_key, __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, __pyx_t_5numpy_uint64_t __pyx_v_key, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_15UInt64HashTable_set_item(__pyx_v_self, __pyx_v_key, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2208
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt64HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  CYTHON_UNUSED int __pyx_v_ret;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2208, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_19set_na)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2208, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2208, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2212
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             uint64_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2215
 *             uint64_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_7 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_7)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2216
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         self.na_position = val
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 2216, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":2215
 *             uint64_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2218
 *             raise NotImplementedError
 * 
 *         self.na_position = val             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->na_position = __pyx_v_val;

  /* "pandas/_libs/hashtable_class_helper.pxi":2208
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_19set_na = {"set_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_19set_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2208, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_na") < 0)) __PYX_ERR(2, 2208, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[0]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 2208, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_na", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 2208, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_18set_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_15UInt64HashTable_set_na(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2221
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const uint64_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_21map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_21map_locations = {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_21map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_21map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("map_locations (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2221, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2221, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "map_locations") < 0)) __PYX_ERR(2, 2221, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint64_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 2222, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 2222, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__20;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("map_locations", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 2221, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_20map_locations(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_20map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  int __pyx_v_ret;
  __pyx_t_5numpy_uint64_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  __pyx_t_5numpy_int64_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("map_locations", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2225
 *         # Used in libindex, safe_sort
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             uint64_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":2226
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             uint64_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2229
 *             uint64_t val
 *             khiter_t k
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_2 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":2231
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_3 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_3)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2232
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 2232, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":2231
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2234
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":2235
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
        if (__pyx_v_self->uses_mask) {

          /* "pandas/_libs/hashtable_class_helper.pxi":2236
 *         with nogil:
 *             if self.uses_mask:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     if mask[i]:
 *                         na_position = i
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":2237
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_mask.shape[0];
            __pyx_t_3 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) ))) != 0);
            if (__pyx_t_3) {

              /* "pandas/_libs/hashtable_class_helper.pxi":2238
 *                 for i in range(n):
 *                     if mask[i]:
 *                         na_position = i             # <<<<<<<<<<<<<<
 *                     else:
 *                         val= (values[i])
 */
              __pyx_v_na_position = __pyx_v_i;

              /* "pandas/_libs/hashtable_class_helper.pxi":2237
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
              goto __pyx_L12;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":2240
 *                         na_position = i
 *                     else:
 *                         val= (values[i])             # <<<<<<<<<<<<<<
 *                         k = kh_put_uint64(self.table, val, &ret)
 *                         self.table.vals[k] = i
 */
            /*else*/ {
              __pyx_t_7 = __pyx_v_i;
              if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
              __pyx_v_val = (*((__pyx_t_5numpy_uint64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_class_helper.pxi":2241
 *                     else:
 *                         val= (values[i])
 *                         k = kh_put_uint64(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = i
 *             else:
 */
              __pyx_v_k = kh_put_uint64(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

              /* "pandas/_libs/hashtable_class_helper.pxi":2242
 *                         val= (values[i])
 *                         k = kh_put_uint64(self.table, val, &ret)
 *                         self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *             else:
 *                 for i in range(n):
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
            }
            __pyx_L12:;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":2235
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
          goto __pyx_L9;
        }

        /* "pandas/_libs/hashtable_class_helper.pxi":2244
 *                         self.table.vals[k] = i
 *             else:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     val= (values[i])
 *                     k = kh_put_uint64(self.table, val, &ret)
 */
        /*else*/ {
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":2245
 *             else:
 *                 for i in range(n):
 *                     val= (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_put_uint64(self.table, val, &ret)
 *                     self.table.vals[k] = i
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
            __pyx_v_val = (*((__pyx_t_5numpy_uint64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

            /* "pandas/_libs/hashtable_class_helper.pxi":2246
 *                 for i in range(n):
 *                     val= (values[i])
 *                     k = kh_put_uint64(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                     self.table.vals[k] = i
 *         self.na_position = na_position
 */
            __pyx_v_k = kh_put_uint64(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":2247
 *                     val= (values[i])
 *                     k = kh_put_uint64(self.table, val, &ret)
 *                     self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *         self.na_position = na_position
 * 
 */
            (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
          }
        }
        __pyx_L9:;
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":2234
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2248
 *                     k = kh_put_uint64(self.table, val, &ret)
 *                     self.table.vals[k] = i
 *         self.na_position = na_position             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __pyx_v_self->na_position = __pyx_v_na_position;

  /* "pandas/_libs/hashtable_class_helper.pxi":2221
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const uint64_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2250
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const uint64_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

/* Python wrapper */
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_23lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_23lookup = {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_23lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_23lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyArrayObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lookup (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2250, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2250, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lookup") < 0)) __PYX_ERR(2, 2250, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint64_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 2251, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 2251, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__21;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lookup", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 2250, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_22lookup(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_22lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  CYTHON_UNUSED int __pyx_v_ret;
  __pyx_t_5numpy_uint64_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __Pyx_memviewslice __pyx_v_locs = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lookup", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2255
 *         # Used in safe_sort, IndexEngine.get_indexer
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             uint64_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":2256
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             uint64_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2259
 *             uint64_t val
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *             int8_t na_position = self.na_position
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 2259, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 2259, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 2259, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_locs = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":2260
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_8 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":2262
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_9 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_10 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_9 = __pyx_t_10;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2263
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 2263, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":2262
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2265
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":2266
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_11 = __pyx_t_1;
        for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
          __pyx_v_i = __pyx_t_12;

          /* "pandas/_libs/hashtable_class_helper.pxi":2267
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
          if (__pyx_v_self->uses_mask) {
          } else {
            __pyx_t_9 = __pyx_v_self->uses_mask;
            goto __pyx_L12_bool_binop_done;
          }
          __pyx_t_13 = __pyx_v_i;
          if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_mask.shape[0];
          __pyx_t_10 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_13 * __pyx_v_mask.strides[0]) ))) != 0);
          __pyx_t_9 = __pyx_t_10;
          __pyx_L12_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":2268
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position             # <<<<<<<<<<<<<<
 *                 else:
 *                     val = (values[i])
 */
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = __pyx_v_na_position;

            /* "pandas/_libs/hashtable_class_helper.pxi":2267
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
            goto __pyx_L11;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":2270
 *                     locs[i] = na_position
 *                 else:
 *                     val = (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_uint64(self.table, val)
 *                     if k != self.table.n_buckets:
 */
          /*else*/ {
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_values.shape[0];
            __pyx_v_val = (*((__pyx_t_5numpy_uint64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_13 * __pyx_v_values.strides[0]) )));

            /* "pandas/_libs/hashtable_class_helper.pxi":2271
 *                 else:
 *                     val = (values[i])
 *                     k = kh_get_uint64(self.table, val)             # <<<<<<<<<<<<<<
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]
 */
            __pyx_v_k = kh_get_uint64(__pyx_v_self->table, __pyx_v_val);

            /* "pandas/_libs/hashtable_class_helper.pxi":2272
 *                     val = (values[i])
 *                     k = kh_get_uint64(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
            __pyx_t_9 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":2273
 *                     k = kh_get_uint64(self.table, val)
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     else:
 *                         locs[i] = -1
 */
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = (__pyx_v_self->table->vals[__pyx_v_k]);

              /* "pandas/_libs/hashtable_class_helper.pxi":2272
 *                     val = (values[i])
 *                     k = kh_get_uint64(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
              goto __pyx_L14;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":2275
 *                         locs[i] = self.table.vals[k]
 *                     else:
 *                         locs[i] = -1             # <<<<<<<<<<<<<<
 * 
 *         return np.asarray(locs)
 */
            /*else*/ {
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = -1;
            }
            __pyx_L14:;
          }
          __pyx_L11:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":2265
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2277
 *                         locs[i] = -1
 * 
 *         return np.asarray(locs)             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_locs, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2277, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_14 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_14 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2277, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 2277, __pyx_L1_error)
  __pyx_r = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2250
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const uint64_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_locs, 1);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2279
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const uint64_t[:] values, UInt64Vector uniques,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_25_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15UInt64HashTable_24_unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[uint64]\n            Array of values of which unique will be calculated\n        uniques : UInt64Vector\n            Vector into which uniques will be written\n        count_prior : Py_ssize_t, default 0\n            Number of existing entries in uniques\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        ignore_na : bool, default False\n            Whether NA-values should be ignored for calculating the uniques. If\n            True, the labels corresponding to missing values will be set to\n            na_sentinel.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        use_result_mask: bool, default False\n            Whether to create a result mask for the unique values. Not supported\n            with return_inverse=True.\n\n        Returns\n        -------\n        uniques : ndarray[uint64]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse=True)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if use_result_mask is true\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_25_unique = {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_25_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt64HashTable_24_unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_25_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  int __pyx_v_ignore_na;
  PyObject *__pyx_v_mask = 0;
  int __pyx_v_return_inverse;
  int __pyx_v_use_result_mask;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[9] = {0,0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_ignore_na,&__pyx_n_s_mask,&__pyx_n_s_return_inverse,&__pyx_n_s_use_result_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":2283
 *     def _unique(self, const uint64_t[:] values, UInt64Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));

    /* "pandas/_libs/hashtable_class_helper.pxi":2284
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[6] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2279, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2279, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, 1); __PYX_ERR(2, 2279, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2279, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2279, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2279, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2279, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[6] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2279, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[7] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2279, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_use_result_mask);
          if (value) { values[8] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2279, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_unique") < 0)) __PYX_ERR(2, 2279, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint64_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 2281, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 2282, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 2282, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    if (values[5]) {
      __pyx_v_ignore_na = __Pyx_PyObject_IsTrue(values[5]); if (unlikely((__pyx_v_ignore_na == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 2283, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":2283
 *     def _unique(self, const uint64_t[:] values, UInt64Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
      __pyx_v_ignore_na = ((int)0);
    }
    __pyx_v_mask = values[6];
    if (values[7]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[7]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 2284, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":2284
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
      __pyx_v_return_inverse = ((int)0);
    }
    if (values[8]) {
      __pyx_v_use_result_mask = __Pyx_PyObject_IsTrue(values[8]); if (unlikely((__pyx_v_use_result_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 2284, __pyx_L3_error)
    } else {
      __pyx_v_use_result_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, __pyx_nargs); __PYX_ERR(2, 2279, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector, 1, "uniques", 0))) __PYX_ERR(2, 2281, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_24_unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_ignore_na, __pyx_v_mask, __pyx_v_return_inverse, __pyx_v_use_result_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":2279
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const uint64_t[:] values, UInt64Vector uniques,
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_24_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_idx;
  Py_ssize_t __pyx_v_count;
  Py_ssize_t __pyx_v_n;
  __Pyx_memviewslice __pyx_v_labels = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_ret;
  __pyx_t_5numpy_uint64_t __pyx_v_val;
  __pyx_t_5numpy_uint64_t __pyx_v_na_value2;
  khiter_t __pyx_v_k;
  __pyx_t_6pandas_5_libs_9hashtable_UInt64VectorData *__pyx_v_ud;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_result_mask = 0;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_v_rmd;
  int __pyx_v_use_na_value;
  int __pyx_v_use_mask;
  int __pyx_v_seen_na;
  __Pyx_memviewslice __pyx_v_mask_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_6pandas_5_libs_9hashtable_UInt64VectorData *__pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_t_11;
  int __pyx_t_12;
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_uint64_t __pyx_t_14;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2328
 *         """
 *         cdef:
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)             # <<<<<<<<<<<<<<
 *             intp_t[::1] labels
 *             int ret = 0
 */
  __pyx_v_count = __pyx_v_count_prior;
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":2330
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)
 *             intp_t[::1] labels
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             uint64_t val, na_value2
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2336
 *             UInt8Vector result_mask
 *             UInt8VectorData *rmd
 *             bint use_na_value, use_mask, seen_na = False             # <<<<<<<<<<<<<<
 *             uint8_t[:] mask_values
 * 
 */
  __pyx_v_seen_na = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2339
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2340
 * 
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 2340, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 2340, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2340, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 2340, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_labels = __pyx_t_7;
    __pyx_t_7.memview = NULL;
    __pyx_t_7.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":2339
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2341
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data             # <<<<<<<<<<<<<<
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 */
  __pyx_t_8 = __pyx_v_uniques->data;
  __pyx_v_ud = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":2342
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 *         use_na_value = na_value is not None             # <<<<<<<<<<<<<<
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 */
  __pyx_t_9 = (__pyx_v_na_value != Py_None);
  __pyx_v_use_na_value = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":2343
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None             # <<<<<<<<<<<<<<
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover
 */
  __pyx_t_9 = (__pyx_v_mask != Py_None);
  __pyx_v_use_mask = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":2344
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  __pyx_t_10 = (!__pyx_v_use_mask);
  if (__pyx_t_10) {
  } else {
    __pyx_t_9 = __pyx_t_10;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_use_result_mask;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2345
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         if use_result_mask and return_inverse:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 2345, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":2344
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2347
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_use_result_mask) {
  } else {
    __pyx_t_9 = __pyx_v_use_result_mask;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_return_inverse;
  __pyx_L8_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2348
 * 
 *         if use_result_mask and return_inverse:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         result_mask = UInt8Vector()
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 2348, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":2347
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2350
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         result_mask = UInt8Vector()             # <<<<<<<<<<<<<<
 *         rmd = result_mask.data
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_v_result_mask = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2351
 * 
 *         result_mask = UInt8Vector()
 *         rmd = result_mask.data             # <<<<<<<<<<<<<<
 * 
 *         if use_mask:
 */
  __pyx_t_11 = __pyx_v_result_mask->data;
  __pyx_v_rmd = __pyx_t_11;

  /* "pandas/_libs/hashtable_class_helper.pxi":2353
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  if (__pyx_v_use_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2354
 * 
 *         if use_mask:
 *             mask_values = mask.view("uint8")             # <<<<<<<<<<<<<<
 * 
 *         if use_na_value:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_mask, __pyx_n_s_view); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2354, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    __pyx_t_12 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_12 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_uint8};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_12, 1+__pyx_t_12);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2354, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(2, 2354, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_mask_values = __pyx_t_13;
    __pyx_t_13.memview = NULL;
    __pyx_t_13.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":2353
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2356
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
  if (__pyx_v_use_na_value) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2362
 *             # for the parameter. To please the compiler, we use na_value2,
 *             # which is only used if it's *specified*.
 *             na_value2 = (na_value)             # <<<<<<<<<<<<<<
 *         else:
 *             na_value2 = (0)
 */
    __pyx_t_14 = __Pyx_PyInt_As_npy_uint64(__pyx_v_na_value); if (unlikely((__pyx_t_14 == ((npy_uint64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 2362, __pyx_L1_error)
    __pyx_v_na_value2 = __pyx_t_14;

    /* "pandas/_libs/hashtable_class_helper.pxi":2356
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
    goto __pyx_L11;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2364
 *             na_value2 = (na_value)
 *         else:
 *             na_value2 = (0)             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
  /*else*/ {
    __pyx_v_na_value2 = 0;
  }
  __pyx_L11:;

  /* "pandas/_libs/hashtable_class_helper.pxi":2366
 *             na_value2 = (0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = (values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":2367
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 val = (values[i])
 * 
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_15 = __pyx_t_1;
        for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
          __pyx_v_i = __pyx_t_16;

          /* "pandas/_libs/hashtable_class_helper.pxi":2368
 *         with nogil:
 *             for i in range(n):
 *                 val = (values[i])             # <<<<<<<<<<<<<<
 * 
 *                 if ignore_na and use_mask:
 */
          __pyx_t_17 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_uint64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_17 * __pyx_v_values.strides[0]) )));

          /* "pandas/_libs/hashtable_class_helper.pxi":2370
 *                 val = (values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L18_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_mask;
          __pyx_L18_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":2371
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 2371, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_17 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":2372
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                         continue
 *                 elif ignore_na and (
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 2372, __pyx_L13_error) }
              __pyx_t_17 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_na_sentinel;

              /* "pandas/_libs/hashtable_class_helper.pxi":2373
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 *                         continue             # <<<<<<<<<<<<<<
 *                 elif ignore_na and (
 *                    is_nan_uint64_t(val) or
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":2371
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":2370
 *                 val = (values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
            goto __pyx_L17;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":2374
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_uint64_t(val) or
 *                    (use_na_value and are_equivalent_uint64_t(val, na_value2))
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":2375
 *                         continue
 *                 elif ignore_na and (
 *                    is_nan_uint64_t(val) or             # <<<<<<<<<<<<<<
 *                    (use_na_value and are_equivalent_uint64_t(val, na_value2))
 *                 ):
 */
          __pyx_t_10 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_uint64_t(__pyx_v_val); if (unlikely(__pyx_t_10 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 2375, __pyx_L13_error)
          if (!__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":2376
 *                 elif ignore_na and (
 *                    is_nan_uint64_t(val) or
 *                    (use_na_value and are_equivalent_uint64_t(val, na_value2))             # <<<<<<<<<<<<<<
 *                 ):
 *                     # if missing values do not count as unique values (i.e. if
 */
          if (__pyx_v_use_na_value) {
          } else {
            __pyx_t_9 = __pyx_v_use_na_value;
            goto __pyx_L21_bool_binop_done;
          }
          __pyx_t_10 = __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_uint64_t(__pyx_v_val, __pyx_v_na_value2); if (unlikely(__pyx_t_10 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 2376, __pyx_L13_error)
          __pyx_t_9 = __pyx_t_10;
          __pyx_L21_bool_binop_done:;

          /* "pandas/_libs/hashtable_class_helper.pxi":2374
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_uint64_t(val) or
 *                    (use_na_value and are_equivalent_uint64_t(val, na_value2))
 */
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":2381
 *                     # ignore_na is True), skip the hashtable entry for them,
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 2381, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_na_sentinel;

            /* "pandas/_libs/hashtable_class_helper.pxi":2382
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel
 *                     continue             # <<<<<<<<<<<<<<
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 */
            goto __pyx_L15_continue;

            /* "pandas/_libs/hashtable_class_helper.pxi":2374
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_uint64_t(val) or
 *                    (use_na_value and are_equivalent_uint64_t(val, na_value2))
 */
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":2383
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          __pyx_t_10 = (!__pyx_v_ignore_na);
          if (__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L25_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_result_mask;
          __pyx_L25_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":2384
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 2384, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_17 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":2385
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_class_helper.pxi":2386
 *                     if mask_values[i]:
 *                         if seen_na:
 *                             continue             # <<<<<<<<<<<<<<
 * 
 *                         seen_na = True
 */
                goto __pyx_L15_continue;

                /* "pandas/_libs/hashtable_class_helper.pxi":2385
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":2388
 *                             continue
 * 
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         if needs_resize(ud):
 *                             with gil:
 */
              __pyx_v_seen_na = 1;

              /* "pandas/_libs/hashtable_class_helper.pxi":2389
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              __pyx_t_9 = __pyx_fuse_4__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 2389, __pyx_L13_error)
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_class_helper.pxi":2390
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                {
                    #ifdef WITH_THREAD
                    PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                    #endif
                    /*try:*/ {

                      /* "pandas/_libs/hashtable_class_helper.pxi":2391
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":2392
 *                             with gil:
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2392, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 2392, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":2391
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":2395
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt64Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2395, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":2396
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":2397
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2397, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 2397, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":2396
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":2400
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                         append_data_uint64(ud, val)
 *                         append_data_uint8(rmd, 1)
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2400, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":2390
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    /*finally:*/ {
                      /*normal exit:*/{
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L34;
                      }
                      __pyx_L33_error: {
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L13_error;
                      }
                      __pyx_L34:;
                    }
                }

                /* "pandas/_libs/hashtable_class_helper.pxi":2389
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":2401
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                         append_data_uint64(ud, val)             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 1)
 *                         continue
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint64(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 2401, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":2402
 *                                 result_mask.resize()
 *                         append_data_uint64(ud, val)
 *                         append_data_uint8(rmd, 1)             # <<<<<<<<<<<<<<
 *                         continue
 * 
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 1); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 2402, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":2403
 *                         append_data_uint64(ud, val)
 *                         append_data_uint8(rmd, 1)
 *                         continue             # <<<<<<<<<<<<<<
 * 
 *                 k = kh_get_uint64(self.table, val)
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":2384
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":2383
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          }
          __pyx_L17:;

          /* "pandas/_libs/hashtable_class_helper.pxi":2405
 *                         continue
 * 
 *                 k = kh_get_uint64(self.table, val)             # <<<<<<<<<<<<<<
 * 
 *                 if k == self.table.n_buckets:
 */
          __pyx_v_k = kh_get_uint64(__pyx_v_self->table, __pyx_v_val);

          /* "pandas/_libs/hashtable_class_helper.pxi":2407
 *                 k = kh_get_uint64(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_uint64(self.table, val, &ret)
 */
          __pyx_t_9 = (__pyx_v_k == __pyx_v_self->table->n_buckets);
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":2409
 *                 if k == self.table.n_buckets:
 *                     # k hasn't been seen yet
 *                     k = kh_put_uint64(self.table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *                     if needs_resize(ud):
 */
            __pyx_v_k = kh_put_uint64(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":2411
 *                     k = kh_put_uint64(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            __pyx_t_9 = __pyx_fuse_4__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 2411, __pyx_L13_error)
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":2412
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
              {
                  #ifdef WITH_THREAD
                  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                  #endif
                  /*try:*/ {

                    /* "pandas/_libs/hashtable_class_helper.pxi":2413
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":2414
 *                         with gil:
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 */
                      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2414, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                      __PYX_ERR(2, 2414, __pyx_L42_error)

                      /* "pandas/_libs/hashtable_class_helper.pxi":2413
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":2417
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()             # <<<<<<<<<<<<<<
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 */
                    __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt64Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2417, __pyx_L42_error)
                    __Pyx_GOTREF(__pyx_t_6);
                    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                    /* "pandas/_libs/hashtable_class_helper.pxi":2418
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    if (__pyx_v_use_result_mask) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":2419
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":2420
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2420, __pyx_L42_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 2420, __pyx_L42_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":2419
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":2423
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                     append_data_uint64(ud, val)
 *                     if use_result_mask:
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2423, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":2418
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    }
                  }

                  /* "pandas/_libs/hashtable_class_helper.pxi":2412
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
                  /*finally:*/ {
                    /*normal exit:*/{
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L43;
                    }
                    __pyx_L42_error: {
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L13_error;
                    }
                    __pyx_L43:;
                  }
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":2411
 *                     k = kh_put_uint64(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":2424
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                     append_data_uint64(ud, val)             # <<<<<<<<<<<<<<
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)
 */
            __pyx_f_6pandas_5_libs_9hashtable_append_data_uint64(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 2424, __pyx_L13_error)

            /* "pandas/_libs/hashtable_class_helper.pxi":2425
 *                                 result_mask.resize()
 *                     append_data_uint64(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            if (__pyx_v_use_result_mask) {

              /* "pandas/_libs/hashtable_class_helper.pxi":2426
 *                     append_data_uint64(ud, val)
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)             # <<<<<<<<<<<<<<
 * 
 *                     if return_inverse:
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 0); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 2426, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":2425
 *                                 result_mask.resize()
 *                     append_data_uint64(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":2428
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            if (__pyx_v_return_inverse) {

              /* "pandas/_libs/hashtable_class_helper.pxi":2429
 * 
 *                     if return_inverse:
 *                         self.table.vals[k] = count             # <<<<<<<<<<<<<<
 *                         labels[i] = count
 *                         count += 1
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":2430
 *                     if return_inverse:
 *                         self.table.vals[k] = count
 *                         labels[i] = count             # <<<<<<<<<<<<<<
 *                         count += 1
 *                 elif return_inverse:
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 2430, __pyx_L13_error) }
              __pyx_t_17 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":2431
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 *                         count += 1             # <<<<<<<<<<<<<<
 *                 elif return_inverse:
 *                     # k falls into a previous bucket
 */
              __pyx_v_count = (__pyx_v_count + 1);

              /* "pandas/_libs/hashtable_class_helper.pxi":2428
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":2407
 *                 k = kh_get_uint64(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_uint64(self.table, val, &ret)
 */
            goto __pyx_L37;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":2432
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          if (__pyx_v_return_inverse) {

            /* "pandas/_libs/hashtable_class_helper.pxi":2435
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     labels[i] = idx
 * 
 */
            __pyx_v_idx = (__pyx_v_self->table->vals[__pyx_v_k]);

            /* "pandas/_libs/hashtable_class_helper.pxi":2436
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]
 *                     labels[i] = idx             # <<<<<<<<<<<<<<
 * 
 *         if return_inverse:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 2436, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_idx;

            /* "pandas/_libs/hashtable_class_helper.pxi":2432
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          }
          __pyx_L37:;
          __pyx_L15_continue:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":2366
 *             na_value2 = (0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = (values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L14;
        }
        __pyx_L13_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L14:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2438
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2439
 * 
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray             # <<<<<<<<<<<<<<
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt64Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2439, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundLocalError("labels"); __PYX_ERR(2, 2439, __pyx_L1_error) }
    __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_labels, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2439, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_base); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2439, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2439, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_6);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_6)) __PYX_ERR(2, 2439, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4)) __PYX_ERR(2, 2439, __pyx_L1_error);
    __pyx_t_6 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":2438
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2440
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  if (__pyx_v_use_result_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2441
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()             # <<<<<<<<<<<<<<
 *         return uniques.to_array()
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt64Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2441, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->to_array(__pyx_v_result_mask, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2441, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2441, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2)) __PYX_ERR(2, 2441, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4)) __PYX_ERR(2, 2441, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":2440
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2442
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()             # <<<<<<<<<<<<<<
 * 
 *     def unique(self, const uint64_t[:] values, bint return_inverse=False, object mask=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt64Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2442, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2279
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const uint64_t[:] values, UInt64Vector uniques,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_13, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_labels, 1);
  __Pyx_XDECREF((PyObject *)__pyx_v_result_mask);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask_values, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2444
 *         return uniques.to_array()
 * 
 *     def unique(self, const uint64_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_27unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15UInt64HashTable_26unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[uint64]\n            Array of values of which unique will be calculated\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n\n        Returns\n        -------\n        uniques : ndarray[uint64]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if mask is given as input\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_27unique = {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_27unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt64HashTable_26unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_27unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_return_inverse;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_return_inverse,&__pyx_n_s_mask,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2444, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2444, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2444, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "unique") < 0)) __PYX_ERR(2, 2444, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint64_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 2444, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 2444, __pyx_L3_error)
    } else {
      __pyx_v_return_inverse = ((int)0);
    }
    __pyx_v_mask = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("unique", 0, 1, 3, __pyx_nargs); __PYX_ERR(2, 2444, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_26unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_return_inverse, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_26unique(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_uniques = NULL;
  int __pyx_v_use_result_mask;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2468
 *             The mask for the result values.
 *         """
 *         uniques = UInt64Vector()             # <<<<<<<<<<<<<<
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2468, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2469
 *         """
 *         uniques = UInt64Vector()
 *         use_result_mask = True if mask is not None else False             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 */
  __pyx_t_3 = (__pyx_v_mask != Py_None);
  if (__pyx_t_3) {
    __pyx_t_2 = 1;
  } else {
    __pyx_t_2 = 0;
  }
  __pyx_v_use_result_mask = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":2470
 *         uniques = UInt64Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint64_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4)) __PYX_ERR(2, 2470, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 2470, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ignore_na, Py_False) < 0) __PYX_ERR(2, 2470, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2471
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const uint64_t[:] values, Py_ssize_t na_sentinel=-1,
 */
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_return_inverse); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return_inverse, __pyx_t_6) < 0) __PYX_ERR(2, 2470, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 2470, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_use_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_use_result_mask, __pyx_t_6) < 0) __PYX_ERR(2, 2470, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2470
 *         uniques = UInt64Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2444
 *         return uniques.to_array()
 * 
 *     def unique(self, const uint64_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2473
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const uint64_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_29factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15UInt64HashTable_28factorize, "\n        Calculate unique values and labels (no sorting!)\n\n        Missing values are not included in the \"uniques\" for this method.\n        The labels for any missing values will be set to \"na_sentinel\"\n\n        Parameters\n        ----------\n        values : ndarray[uint64]\n            Array of values of which unique will be calculated\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n\n        Returns\n        -------\n        uniques : ndarray[uint64]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t]\n            The labels from values to uniques\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_29factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_29factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt64HashTable_28factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_29factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  PyObject *__pyx_v_ignore_na = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,&__pyx_n_s_ignore_na,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":2474
 * 
 *     def factorize(self, const uint64_t[:] values, Py_ssize_t na_sentinel=-1,
 *                   object na_value=None, object mask=None, ignore_na=True):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_True));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2473, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2473, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2473, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2473, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2473, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 2473, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint64_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 2473, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 2473, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
    __pyx_v_ignore_na = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 5, __pyx_nargs); __PYX_ERR(2, 2473, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_28factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask, __pyx_v_ignore_na);

  /* "pandas/_libs/hashtable_class_helper.pxi":2473
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const uint64_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_28factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_uniques_vector = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2504
 *             The labels from values to uniques
 *         """
 *         uniques_vector = UInt64Vector()             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2504, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques_vector = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2505
 *         """
 *         uniques_vector = UInt64Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint64_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 2505, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques_vector);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques_vector))) __PYX_ERR(2, 2505, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 2505, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2506
 *         uniques_vector = UInt64Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,             # <<<<<<<<<<<<<<
 *                             return_inverse=True)
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 2505, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, __pyx_v_ignore_na) < 0) __PYX_ERR(2, 2505, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 2505, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2507
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)             # <<<<<<<<<<<<<<
 * 
 *     def get_labels(self, const uint64_t[:] values, UInt64Vector uniques,
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 2505, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2505
 *         """
 *         uniques_vector = UInt64Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2505, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2473
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const uint64_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2509
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const uint64_t[:] values, UInt64Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_31get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_31get_labels = {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_31get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_31get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_labels (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":2511
 *     def get_labels(self, const uint64_t[:] values, UInt64Vector uniques,
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2509, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2509, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, 1); __PYX_ERR(2, 2509, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2509, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2509, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2509, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2509, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_labels") < 0)) __PYX_ERR(2, 2509, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint64_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 2509, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 2510, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 2510, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    __pyx_v_mask = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, __pyx_nargs); __PYX_ERR(2, 2509, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector, 1, "uniques", 0))) __PYX_ERR(2, 2509, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_30get_labels(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":2509
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const uint64_t[:] values, UInt64Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_30get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_v_labels = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_labels", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2513
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint64_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 2513, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 2513, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_count_prior); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_count_prior, __pyx_t_4) < 0) __PYX_ERR(2, 2513, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2514
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,             # <<<<<<<<<<<<<<
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2514, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 2513, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 2513, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2515
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, Py_True) < 0) __PYX_ERR(2, 2513, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 2513, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 2513, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2513
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2513, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
    PyObject* sequence = __pyx_t_4;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(2, 2513, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2513, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2513, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2513, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
    index = 0; __pyx_t_2 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_1), 2) < 0) __PYX_ERR(2, 2513, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(2, 2513, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v__ = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_labels = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2516
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_labels);
  __pyx_r = __pyx_v_labels;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2509
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const uint64_t[:] values, UInt64Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XDECREF(__pyx_v_labels);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_33__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_33__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_33__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_33__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_32__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_32__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_35__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_35__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_35__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_35__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_34__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt64HashTable_34__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2525
 *         UInt64Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = UInt64HashTable(size_hint)
 *         self.uniques = UInt64Vector()
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_size_hint = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2525, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 2525, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_size_hint = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 2525, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_size_hint), (&PyInt_Type), 0, "size_hint", 1))) __PYX_ERR(2, 2525, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *)__pyx_v_self), __pyx_v_size_hint);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2526
 * 
 *     def __cinit__(self, size_hint: int):
 *         self.table = UInt64HashTable(size_hint)             # <<<<<<<<<<<<<<
 *         self.uniques = UInt64Vector()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable), __pyx_v_size_hint); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2526, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2527
 *     def __cinit__(self, size_hint: int):
 *         self.table = UInt64HashTable(size_hint)
 *         self.uniques = UInt64Vector()             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const uint64_t[:] values,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2525
 *         UInt64Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = UInt64HashTable(size_hint)
 *         self.uniques = UInt64Vector()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2529
 *         self.uniques = UInt64Vector()
 * 
 *     def factorize(self, const uint64_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_16UInt64Factorizer_2factorize, "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = UInt64Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"uint64\"), na_sentinel=20)\n        array([0, 1, 2])\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16UInt64Factorizer_3factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16UInt64Factorizer_2factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_v_na_sentinel = 0;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_neg_1));

    /* "pandas/_libs/hashtable_class_helper.pxi":2530
 * 
 *     def factorize(self, const uint64_t[:] values,
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:             # <<<<<<<<<<<<<<
 *         """
 *         Returns
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2529, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2529, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2529, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2529, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 2529, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint64_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 2529, __pyx_L3_error)
    __pyx_v_na_sentinel = values[1];
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 4, __pyx_nargs); __PYX_ERR(2, 2529, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_2factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":2529
 *         self.uniques = UInt64Vector()
 * 
 *     def factorize(self, const uint64_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  PyArrayObject *__pyx_v_labels = 0;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_uniques = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_labels;
  __Pyx_Buffer __pyx_pybuffer_labels;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);
  __pyx_pybuffer_labels.pybuffer.buf = NULL;
  __pyx_pybuffer_labels.refcount = 0;
  __pyx_pybuffernd_labels.data = NULL;
  __pyx_pybuffernd_labels.rcbuffer = &__pyx_pybuffer_labels;

  /* "pandas/_libs/hashtable_class_helper.pxi":2547
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = UInt64Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  if (__pyx_v_self->uniques->__pyx_base.external_view_exists) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2548
 * 
 *         if self.uniques.external_view_exists:
 *             uniques = UInt64Vector()             # <<<<<<<<<<<<<<
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 */
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2548, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":2549
 *         if self.uniques.external_view_exists:
 *             uniques = UInt64Vector()
 *             uniques.extend(self.uniques.to_array())             # <<<<<<<<<<<<<<
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 */
    __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt64Vector *)__pyx_v_self->uniques->__pyx_vtab)->to_array(__pyx_v_self->uniques, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2549, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint64_t__const__(__pyx_t_1, 0); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(2, 2549, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt64Vector *)__pyx_v_uniques->__pyx_vtab)->extend(__pyx_v_uniques, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2549, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
    __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":2550
 *             uniques = UInt64Vector()
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques             # <<<<<<<<<<<<<<
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 */
    __Pyx_INCREF((PyObject *)__pyx_v_uniques);
    __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
    __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
    __pyx_v_self->uniques = __pyx_v_uniques;

    /* "pandas/_libs/hashtable_class_helper.pxi":2547
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = UInt64Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2551
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->table), __pyx_n_s_get_labels); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint64_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "pandas/_libs/hashtable_class_helper.pxi":2552
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,             # <<<<<<<<<<<<<<
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_self->__pyx_base.count); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "pandas/_libs/hashtable_class_helper.pxi":2551
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_5 = PyTuple_New(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3)) __PYX_ERR(2, 2551, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self->uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_self->uniques))) __PYX_ERR(2, 2551, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_4)) __PYX_ERR(2, 2551, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_na_sentinel);
  __Pyx_GIVEREF(__pyx_v_na_sentinel);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_v_na_sentinel)) __PYX_ERR(2, 2551, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2553
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)             # <<<<<<<<<<<<<<
 *         self.count = len(self.uniques)
 *         return labels
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 2553, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 2553, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2551
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2551, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 2551, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
    __pyx_t_7 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_7 < 0)) {
      PyErr_Fetch(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_v_labels, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      }
      __pyx_t_8 = __pyx_t_9 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_labels.diminfo[0].strides = __pyx_pybuffernd_labels.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_labels.diminfo[0].shape = __pyx_pybuffernd_labels.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(2, 2551, __pyx_L1_error)
  }
  __pyx_t_6 = 0;
  __pyx_v_labels = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2554
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  __pyx_t_3 = ((PyObject *)__pyx_v_self->uniques);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_11 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(2, 2554, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_self->__pyx_base.count = __pyx_t_11;

  /* "pandas/_libs/hashtable_class_helper.pxi":2555
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * cdef class Int64HashTable(HashTable):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_labels);
  __pyx_r = ((PyObject *)__pyx_v_labels);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2529
 *         self.uniques = UInt64Vector()
 * 
 *     def factorize(self, const uint64_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_labels);
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2522
 * cdef class UInt64Factorizer(Factorizer):
 *     cdef public:
 *         UInt64HashTable table             # <<<<<<<<<<<<<<
 *         UInt64Vector uniques
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_5table_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_5table_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_5table___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->table);
  __pyx_r = ((PyObject *)__pyx_v_self->table);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_5table_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable))))) __PYX_ERR(2, 2522, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64Factorizer.table.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_5table_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_5table_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_5table_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2523
 *     cdef public:
 *         UInt64HashTable table
 *         UInt64Vector uniques             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, size_hint: int):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_7uniques_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_7uniques_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_7uniques___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __pyx_r = ((PyObject *)__pyx_v_self->uniques);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_7uniques_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector))))) __PYX_ERR(2, 2523, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64Factorizer.uniques.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_7uniques_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_7uniques_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_7uniques_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16UInt64Factorizer_5__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_4__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64Factorizer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16UInt64Factorizer_7__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_6__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt64Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt64Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2559
 * cdef class Int64HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_int64()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __pyx_t_5numpy_int64_t __pyx_v_size_hint;
  int __pyx_v_uses_mask;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,&__pyx_n_s_uses_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2559, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uses_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2559, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 2559, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_size_hint = __Pyx_PyInt_As_npy_int64(values[0]); if (unlikely((__pyx_v_size_hint == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 2559, __pyx_L3_error)
    } else {
      __pyx_v_size_hint = ((__pyx_t_5numpy_int64_t)1);
    }
    if (values[1]) {
      __pyx_v_uses_mask = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_uses_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 2559, __pyx_L3_error)
    } else {
      __pyx_v_uses_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 0, 2, __pyx_nargs); __PYX_ERR(2, 2559, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)__pyx_v_self), __pyx_v_size_hint, __pyx_v_uses_mask);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  khuint_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __pyx_t_5numpy_int64_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2560
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_int64()             # <<<<<<<<<<<<<<
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_int64(self.table, size_hint)
 */
  __pyx_v_self->table = kh_init_int64();

  /* "pandas/_libs/hashtable_class_helper.pxi":2561
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_int64()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)             # <<<<<<<<<<<<<<
 *         kh_resize_int64(self.table, size_hint)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = kh_needed_n_buckets(__pyx_v_size_hint);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_1, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2561, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(2, 2561, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_6) {
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_5 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2561, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_int64(__pyx_t_3); if (unlikely((__pyx_t_7 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 2561, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_size_hint = __pyx_t_7;

  /* "pandas/_libs/hashtable_class_helper.pxi":2562
 *         self.table = kh_init_int64()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_int64(self.table, size_hint)             # <<<<<<<<<<<<<<
 * 
 *         self.uses_mask = uses_mask
 */
  kh_resize_int64(__pyx_v_self->table, __pyx_v_size_hint);

  /* "pandas/_libs/hashtable_class_helper.pxi":2564
 *         kh_resize_int64(self.table, size_hint)
 * 
 *         self.uses_mask = uses_mask             # <<<<<<<<<<<<<<
 *         self.na_position = -1
 * 
 */
  __pyx_v_self->uses_mask = __pyx_v_uses_mask;

  /* "pandas/_libs/hashtable_class_helper.pxi":2565
 * 
 *         self.uses_mask = uses_mask
 *         self.na_position = -1             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
  __pyx_v_self->na_position = -1LL;

  /* "pandas/_libs/hashtable_class_helper.pxi":2559
 * cdef class Int64HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_int64()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2567
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_3__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_3__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_2__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  long __pyx_t_1;
  int __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":2568
 * 
 *     def __len__(self) -> int:
 *         return self.table.size + (0 if self.na_position == -1 else 1)             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_2 = (__pyx_v_self->na_position == -1LL);
  if (__pyx_t_2) {
    __pyx_t_1 = 0;
  } else {
    __pyx_t_1 = 1;
  }
  __pyx_r = (__pyx_v_self->table->size + __pyx_t_1);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2567
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2570
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_int64(self.table)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_5__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_5__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_4__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":2571
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_int64(self.table)
 *             self.table = NULL
 */
  __pyx_t_1 = (__pyx_v_self->table != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2572
 *     def __dealloc__(self):
 *         if self.table is not NULL:
 *             kh_destroy_int64(self.table)             # <<<<<<<<<<<<<<
 *             self.table = NULL
 * 
 */
    kh_destroy_int64(__pyx_v_self->table);

    /* "pandas/_libs/hashtable_class_helper.pxi":2573
 *         if self.table is not NULL:
 *             kh_destroy_int64(self.table)
 *             self.table = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __contains__(self, object key) -> bool:
 */
    __pyx_v_self->table = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":2571
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_int64(self.table)
 *             self.table = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2570
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_int64(self.table)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":2575
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__contains__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_6__contains__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)__pyx_v_self), ((PyObject *)__pyx_v_key));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, PyObject *__pyx_v_key) {
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int64_t __pyx_v_ckey;
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  __pyx_t_5numpy_int64_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2582
 *             int64_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_1 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_7missing_checknull(__pyx_v_key, 0, NULL); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2582, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2583
 * 
 *         if self.uses_mask and checknull(key):
 *             return -1 != self.na_position             # <<<<<<<<<<<<<<
 * 
 *         ckey = (key)
 */
    __pyx_r = (-1LL != __pyx_v_self->na_position);
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":2582
 *             int64_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2585
 *             return -1 != self.na_position
 * 
 *         ckey = (key)             # <<<<<<<<<<<<<<
 *         k = kh_get_int64(self.table, ckey)
 *         return k != self.table.n_buckets
 */
  __pyx_t_3 = __Pyx_PyInt_As_npy_int64(__pyx_v_key); if (unlikely((__pyx_t_3 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 2585, __pyx_L1_error)
  __pyx_v_ckey = __pyx_t_3;

  /* "pandas/_libs/hashtable_class_helper.pxi":2586
 * 
 *         ckey = (key)
 *         k = kh_get_int64(self.table, ckey)             # <<<<<<<<<<<<<<
 *         return k != self.table.n_buckets
 * 
 */
  __pyx_v_k = kh_get_int64(__pyx_v_self->table, __pyx_v_ckey);

  /* "pandas/_libs/hashtable_class_helper.pxi":2587
 *         ckey = (key)
 *         k = kh_get_int64(self.table, ckey)
 *         return k != self.table.n_buckets             # <<<<<<<<<<<<<<
 * 
 *     def sizeof(self, deep: bool = False) -> int:
 */
  __pyx_r = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2575
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2589
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14Int64HashTable_8sizeof, " return the size of my table in bytes ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_9sizeof = {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int64HashTable_8sizeof};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_deep = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sizeof (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_deep,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_deep);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2589, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "sizeof") < 0)) __PYX_ERR(2, 2589, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_deep = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sizeof", 0, 0, 1, __pyx_nargs); __PYX_ERR(2, 2589, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_8sizeof(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)__pyx_v_self), __pyx_v_deep);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep) {
  PyObject *__pyx_v_overhead = NULL;
  PyObject *__pyx_v_for_flags = NULL;
  PyObject *__pyx_v_for_pairs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  long __pyx_t_2;
  long __pyx_t_3;
  long __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sizeof", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2591
 *     def sizeof(self, deep: bool = False) -> int:
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)             # <<<<<<<<<<<<<<
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(int64_t) + # keys
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(((4 * (sizeof(__pyx_t_5numpy_uint32_t))) + (3 * (sizeof(__pyx_t_5numpy_uint32_t *))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_overhead = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2592
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)             # <<<<<<<<<<<<<<
 *         for_pairs =  self.table.n_buckets * (sizeof(int64_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 */
  __pyx_t_2 = (__pyx_v_self->table->n_buckets >> 5);
  __pyx_t_3 = 1;
  __pyx_t_5 = (__pyx_t_2 > __pyx_t_3);
  if (__pyx_t_5) {
    __pyx_t_4 = __pyx_t_2;
  } else {
    __pyx_t_4 = __pyx_t_3;
  }
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_t_4 * (sizeof(__pyx_t_5numpy_uint32_t)))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_flags = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2593
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(int64_t) + # keys             # <<<<<<<<<<<<<<
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->n_buckets * ((sizeof(__pyx_t_5numpy_int64_t)) + (sizeof(Py_ssize_t))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_pairs = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2595
 *         for_pairs =  self.table.n_buckets * (sizeof(int64_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs             # <<<<<<<<<<<<<<
 * 
 *     def get_state(self) -> dict[str, int]:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Add(__pyx_v_overhead, __pyx_v_for_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyNumber_Add(__pyx_t_1, __pyx_v_for_pairs); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2595, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(__Pyx_Py3Int_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None) || __Pyx_RaiseUnexpectedTypeError("int", __pyx_t_6))) __PYX_ERR(2, 2595, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2589
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_overhead);
  __Pyx_XDECREF(__pyx_v_for_flags);
  __Pyx_XDECREF(__pyx_v_for_pairs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2597
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14Int64HashTable_10get_state, " returns infos about the state of the hashtable");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_11get_state = {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int64HashTable_10get_state};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_state (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_state", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_state", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_10get_state(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_state", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2599
 *     def get_state(self) -> dict[str, int]:
 *         """ returns infos about the state of the hashtable"""
 *         return {             # <<<<<<<<<<<<<<
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 */
  __Pyx_XDECREF(__pyx_r);

  /* "pandas/_libs/hashtable_class_helper.pxi":2600
 *         """ returns infos about the state of the hashtable"""
 *         return {
 *             'n_buckets' : self.table.n_buckets,             # <<<<<<<<<<<<<<
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_buckets); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2600, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_buckets, __pyx_t_2) < 0) __PYX_ERR(2, 2600, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2601
 *         return {
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,             # <<<<<<<<<<<<<<
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->size); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_size, __pyx_t_2) < 0) __PYX_ERR(2, 2600, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2602
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,             # <<<<<<<<<<<<<<
 *             'upper_bound' : self.table.upper_bound,
 *         }
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_occupied); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_occupied, __pyx_t_2) < 0) __PYX_ERR(2, 2600, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2603
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,             # <<<<<<<<<<<<<<
 *         }
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->upper_bound); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2603, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_upper_bound, __pyx_t_2) < 0) __PYX_ERR(2, 2600, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2597
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.get_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2606
 *         }
 * 
 *     cpdef get_item(self, int64_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int64HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int64_t __pyx_v_cval;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2606, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_13get_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyInt_From_npy_int64(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2606, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2606, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2625
 *             int64_t cval
 * 
 *         cval = (val)             # <<<<<<<<<<<<<<
 *         k = kh_get_int64(self.table, cval)
 *         if k != self.table.n_buckets:
 */
  __pyx_v_cval = __pyx_v_val;

  /* "pandas/_libs/hashtable_class_helper.pxi":2626
 * 
 *         cval = (val)
 *         k = kh_get_int64(self.table, cval)             # <<<<<<<<<<<<<<
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]
 */
  __pyx_v_k = kh_get_int64(__pyx_v_self->table, __pyx_v_cval);

  /* "pandas/_libs/hashtable_class_helper.pxi":2627
 *         cval = (val)
 *         k = kh_get_int64(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  __pyx_t_7 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  if (likely(__pyx_t_7)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2628
 *         k = kh_get_int64(self.table, cval)
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(val)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->vals[__pyx_v_k])); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2628, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":2627
 *         cval = (val)
 *         k = kh_get_int64(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2630
 *             return self.table.vals[k]
 *         else:
 *             raise KeyError(val)             # <<<<<<<<<<<<<<
 * 
 *     cpdef get_na(self):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_val); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2630, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2630, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 2630, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2606
 *         }
 * 
 *     cpdef get_item(self, int64_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14Int64HashTable_12get_item, "Extracts the position of val from the hashtable.\n\n        Parameters\n        ----------\n        val : Scalar\n            The value that is looked up in the hashtable\n\n        Returns\n        -------\n        The position of the requested integer.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_13get_item = {"get_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_13get_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int64HashTable_12get_item};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_5numpy_int64_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2606, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_item") < 0)) __PYX_ERR(2, 2606, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __Pyx_PyInt_As_npy_int64(values[0]); if (unlikely((__pyx_v_val == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 2606, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_item", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 2606, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_12get_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_14Int64HashTable_get_item(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2632
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int64HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2632, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_15get_na)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2632, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2640
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_6 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2641
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         if self.na_position == -1:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 2641, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":2640
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2643
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  __pyx_t_6 = (__pyx_v_self->na_position == -1LL);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2644
 * 
 *         if self.na_position == -1:
 *             raise KeyError("NA")             # <<<<<<<<<<<<<<
 *         return self.na_position
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_KeyError, __pyx_tuple__13, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2644, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(2, 2644, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":2643
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2645
 *         if self.na_position == -1:
 *             raise KeyError("NA")
 *         return self.na_position             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_item(self, int64_t key, Py_ssize_t val):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->na_position); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2632
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14Int64HashTable_14get_na, "Extracts the position of na_value from the hashtable.\n\n        Returns\n        -------\n        The position of the last na value.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_15get_na = {"get_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_15get_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int64HashTable_14get_na};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_na", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_na", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_14get_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_14Int64HashTable_get_na(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2647
 *         return self.na_position
 * 
 *     cpdef set_item(self, int64_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int64HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  __pyx_t_5numpy_int64_t __pyx_v_ckey;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2647, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_17set_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyInt_From_npy_int64(__pyx_v_key); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2647, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2647, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_5 = __pyx_t_1; __pyx_t_6 = NULL;
        __pyx_t_7 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_7 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_3, __pyx_t_4};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2647, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2652
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             int64_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2655
 *             int64_t ckey
 * 
 *         ckey = (key)             # <<<<<<<<<<<<<<
 *         k = kh_put_int64(self.table, ckey, &ret)
 *         if kh_exist_int64(self.table, k):
 */
  __pyx_v_ckey = __pyx_v_key;

  /* "pandas/_libs/hashtable_class_helper.pxi":2656
 * 
 *         ckey = (key)
 *         k = kh_put_int64(self.table, ckey, &ret)             # <<<<<<<<<<<<<<
 *         if kh_exist_int64(self.table, k):
 *             self.table.vals[k] = val
 */
  __pyx_v_k = kh_put_int64(__pyx_v_self->table, __pyx_v_ckey, (&__pyx_v_ret));

  /* "pandas/_libs/hashtable_class_helper.pxi":2657
 *         ckey = (key)
 *         k = kh_put_int64(self.table, ckey, &ret)
 *         if kh_exist_int64(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
  __pyx_t_8 = kh_exist_int64(__pyx_v_self->table, __pyx_v_k);
  if (likely(__pyx_t_8)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2658
 *         k = kh_put_int64(self.table, ckey, &ret)
 *         if kh_exist_int64(self.table, k):
 *             self.table.vals[k] = val             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(key)
 */
    (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_val;

    /* "pandas/_libs/hashtable_class_helper.pxi":2657
 *         ckey = (key)
 *         k = kh_put_int64(self.table, ckey, &ret)
 *         if kh_exist_int64(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2660
 *             self.table.vals[k] = val
 *         else:
 *             raise KeyError(key)             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_na(self, Py_ssize_t val):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2660, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2660, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 2660, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "pandas/_libs/hashtable_class_helper.pxi":2647
 *         return self.na_position
 * 
 *     cpdef set_item(self, int64_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_17set_item = {"set_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_17set_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_5numpy_int64_t __pyx_v_key;
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key,&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2647, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2647, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, 1); __PYX_ERR(2, 2647, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_item") < 0)) __PYX_ERR(2, 2647, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_key = __Pyx_PyInt_As_npy_int64(values[0]); if (unlikely((__pyx_v_key == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 2647, __pyx_L3_error)
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 2647, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, __pyx_nargs); __PYX_ERR(2, 2647, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_16set_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)__pyx_v_self), __pyx_v_key, __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_key, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_14Int64HashTable_set_item(__pyx_v_self, __pyx_v_key, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2662
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int64HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  CYTHON_UNUSED int __pyx_v_ret;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2662, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_19set_na)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2662, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2662, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2666
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             int64_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2669
 *             int64_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_7 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_7)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2670
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         self.na_position = val
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 2670, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":2669
 *             int64_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2672
 *             raise NotImplementedError
 * 
 *         self.na_position = val             # <<<<<<<<<<<<<<
 * 
 *     # We only use this for int64, can reduce build size and make .pyi
 */
  __pyx_v_self->na_position = __pyx_v_val;

  /* "pandas/_libs/hashtable_class_helper.pxi":2662
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_19set_na = {"set_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_19set_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2662, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_na") < 0)) __PYX_ERR(2, 2662, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[0]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 2662, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_na", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 2662, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_18set_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_14Int64HashTable_set_na(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2676
 *     # We only use this for int64, can reduce build size and make .pyi
 *     #  more accurate by only implementing it for int64
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_keys_to_values(
 *         self, const int64_t[:] keys, const int64_t[:] values
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_21map_keys_to_values(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_21map_keys_to_values = {"map_keys_to_values", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_21map_keys_to_values, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_21map_keys_to_values(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_keys = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("map_keys_to_values (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_keys,&__pyx_n_s_values,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_keys)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2676, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2676, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("map_keys_to_values", 1, 2, 2, 1); __PYX_ERR(2, 2676, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "map_keys_to_values") < 0)) __PYX_ERR(2, 2676, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_keys = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t__const__(values[0], 0); if (unlikely(!__pyx_v_keys.memview)) __PYX_ERR(2, 2678, __pyx_L3_error)
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t__const__(values[1], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 2678, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("map_keys_to_values", 1, 2, 2, __pyx_nargs); __PYX_ERR(2, 2676, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_keys, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.map_keys_to_values", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_20map_keys_to_values(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)__pyx_v_self), __pyx_v_keys, __pyx_v_values);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_keys, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_20map_keys_to_values(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_keys, __Pyx_memviewslice __pyx_v_values) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  int __pyx_v_ret;
  __pyx_t_5numpy_int64_t __pyx_v_key;
  khiter_t __pyx_v_k;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  __Pyx_RefNannySetupContext("map_keys_to_values", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2681
 *     ) -> None:
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             int64_t key
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":2682
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             int64_t key
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2686
 *             khiter_t k
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 key = (keys[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":2687
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 key = (keys[i])
 *                 k = kh_put_int64(self.table, key, &ret)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_class_helper.pxi":2688
 *         with nogil:
 *             for i in range(n):
 *                 key = (keys[i])             # <<<<<<<<<<<<<<
 *                 k = kh_put_int64(self.table, key, &ret)
 *                 self.table.vals[k] = <Py_ssize_t>values[i]
 */
          __pyx_t_4 = __pyx_v_i;
          if (__pyx_t_4 < 0) __pyx_t_4 += __pyx_v_keys.shape[0];
          __pyx_v_key = (*((__pyx_t_5numpy_int64_t const  *) ( /* dim=0 */ (__pyx_v_keys.data + __pyx_t_4 * __pyx_v_keys.strides[0]) )));

          /* "pandas/_libs/hashtable_class_helper.pxi":2689
 *             for i in range(n):
 *                 key = (keys[i])
 *                 k = kh_put_int64(self.table, key, &ret)             # <<<<<<<<<<<<<<
 *                 self.table.vals[k] = <Py_ssize_t>values[i]
 * 
 */
          __pyx_v_k = kh_put_int64(__pyx_v_self->table, __pyx_v_key, (&__pyx_v_ret));

          /* "pandas/_libs/hashtable_class_helper.pxi":2690
 *                 key = (keys[i])
 *                 k = kh_put_int64(self.table, key, &ret)
 *                 self.table.vals[k] = <Py_ssize_t>values[i]             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
          __pyx_t_4 = __pyx_v_i;
          if (__pyx_t_4 < 0) __pyx_t_4 += __pyx_v_values.shape[0];
          (__pyx_v_self->table->vals[__pyx_v_k]) = ((Py_ssize_t)(*((__pyx_t_5numpy_int64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_4 * __pyx_v_values.strides[0]) ))));
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":2686
 *             khiter_t k
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 key = (keys[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2676
 *     # We only use this for int64, can reduce build size and make .pyi
 *     #  more accurate by only implementing it for int64
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_keys_to_values(
 *         self, const int64_t[:] keys, const int64_t[:] values
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2692
 *                 self.table.vals[k] = <Py_ssize_t>values[i]
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const int64_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_23map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_23map_locations = {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_23map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_23map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("map_locations (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2692, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2692, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "map_locations") < 0)) __PYX_ERR(2, 2692, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 2693, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 2693, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__22;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("map_locations", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 2692, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_22map_locations(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_22map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  int __pyx_v_ret;
  __pyx_t_5numpy_int64_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  __pyx_t_5numpy_int64_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("map_locations", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2696
 *         # Used in libindex, safe_sort
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             int64_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":2697
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             int64_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2700
 *             int64_t val
 *             khiter_t k
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_2 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":2702
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_3 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_3)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2703
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 2703, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":2702
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2705
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":2706
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
        if (__pyx_v_self->uses_mask) {

          /* "pandas/_libs/hashtable_class_helper.pxi":2707
 *         with nogil:
 *             if self.uses_mask:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     if mask[i]:
 *                         na_position = i
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":2708
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_mask.shape[0];
            __pyx_t_3 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) ))) != 0);
            if (__pyx_t_3) {

              /* "pandas/_libs/hashtable_class_helper.pxi":2709
 *                 for i in range(n):
 *                     if mask[i]:
 *                         na_position = i             # <<<<<<<<<<<<<<
 *                     else:
 *                         val= (values[i])
 */
              __pyx_v_na_position = __pyx_v_i;

              /* "pandas/_libs/hashtable_class_helper.pxi":2708
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
              goto __pyx_L12;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":2711
 *                         na_position = i
 *                     else:
 *                         val= (values[i])             # <<<<<<<<<<<<<<
 *                         k = kh_put_int64(self.table, val, &ret)
 *                         self.table.vals[k] = i
 */
            /*else*/ {
              __pyx_t_7 = __pyx_v_i;
              if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
              __pyx_v_val = (*((__pyx_t_5numpy_int64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_class_helper.pxi":2712
 *                     else:
 *                         val= (values[i])
 *                         k = kh_put_int64(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = i
 *             else:
 */
              __pyx_v_k = kh_put_int64(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

              /* "pandas/_libs/hashtable_class_helper.pxi":2713
 *                         val= (values[i])
 *                         k = kh_put_int64(self.table, val, &ret)
 *                         self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *             else:
 *                 for i in range(n):
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
            }
            __pyx_L12:;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":2706
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
          goto __pyx_L9;
        }

        /* "pandas/_libs/hashtable_class_helper.pxi":2715
 *                         self.table.vals[k] = i
 *             else:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     val= (values[i])
 *                     k = kh_put_int64(self.table, val, &ret)
 */
        /*else*/ {
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":2716
 *             else:
 *                 for i in range(n):
 *                     val= (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_put_int64(self.table, val, &ret)
 *                     self.table.vals[k] = i
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
            __pyx_v_val = (*((__pyx_t_5numpy_int64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

            /* "pandas/_libs/hashtable_class_helper.pxi":2717
 *                 for i in range(n):
 *                     val= (values[i])
 *                     k = kh_put_int64(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                     self.table.vals[k] = i
 *         self.na_position = na_position
 */
            __pyx_v_k = kh_put_int64(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":2718
 *                     val= (values[i])
 *                     k = kh_put_int64(self.table, val, &ret)
 *                     self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *         self.na_position = na_position
 * 
 */
            (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
          }
        }
        __pyx_L9:;
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":2705
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2719
 *                     k = kh_put_int64(self.table, val, &ret)
 *                     self.table.vals[k] = i
 *         self.na_position = na_position             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __pyx_v_self->na_position = __pyx_v_na_position;

  /* "pandas/_libs/hashtable_class_helper.pxi":2692
 *                 self.table.vals[k] = <Py_ssize_t>values[i]
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const int64_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2721
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const int64_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

/* Python wrapper */
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_25lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_25lookup = {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_25lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_25lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyArrayObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lookup (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2721, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2721, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lookup") < 0)) __PYX_ERR(2, 2721, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 2722, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 2722, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__23;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lookup", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 2721, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_24lookup(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_24lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  CYTHON_UNUSED int __pyx_v_ret;
  __pyx_t_5numpy_int64_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __Pyx_memviewslice __pyx_v_locs = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lookup", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2726
 *         # Used in safe_sort, IndexEngine.get_indexer
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             int64_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":2727
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             int64_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2730
 *             int64_t val
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *             int8_t na_position = self.na_position
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 2730, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 2730, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2730, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 2730, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_locs = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":2731
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_8 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":2733
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_9 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_10 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_9 = __pyx_t_10;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2734
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 2734, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":2733
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2736
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":2737
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_11 = __pyx_t_1;
        for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
          __pyx_v_i = __pyx_t_12;

          /* "pandas/_libs/hashtable_class_helper.pxi":2738
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
          if (__pyx_v_self->uses_mask) {
          } else {
            __pyx_t_9 = __pyx_v_self->uses_mask;
            goto __pyx_L12_bool_binop_done;
          }
          __pyx_t_13 = __pyx_v_i;
          if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_mask.shape[0];
          __pyx_t_10 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_13 * __pyx_v_mask.strides[0]) ))) != 0);
          __pyx_t_9 = __pyx_t_10;
          __pyx_L12_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":2739
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position             # <<<<<<<<<<<<<<
 *                 else:
 *                     val = (values[i])
 */
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = __pyx_v_na_position;

            /* "pandas/_libs/hashtable_class_helper.pxi":2738
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
            goto __pyx_L11;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":2741
 *                     locs[i] = na_position
 *                 else:
 *                     val = (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_int64(self.table, val)
 *                     if k != self.table.n_buckets:
 */
          /*else*/ {
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_values.shape[0];
            __pyx_v_val = (*((__pyx_t_5numpy_int64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_13 * __pyx_v_values.strides[0]) )));

            /* "pandas/_libs/hashtable_class_helper.pxi":2742
 *                 else:
 *                     val = (values[i])
 *                     k = kh_get_int64(self.table, val)             # <<<<<<<<<<<<<<
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]
 */
            __pyx_v_k = kh_get_int64(__pyx_v_self->table, __pyx_v_val);

            /* "pandas/_libs/hashtable_class_helper.pxi":2743
 *                     val = (values[i])
 *                     k = kh_get_int64(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
            __pyx_t_9 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":2744
 *                     k = kh_get_int64(self.table, val)
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     else:
 *                         locs[i] = -1
 */
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = (__pyx_v_self->table->vals[__pyx_v_k]);

              /* "pandas/_libs/hashtable_class_helper.pxi":2743
 *                     val = (values[i])
 *                     k = kh_get_int64(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
              goto __pyx_L14;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":2746
 *                         locs[i] = self.table.vals[k]
 *                     else:
 *                         locs[i] = -1             # <<<<<<<<<<<<<<
 * 
 *         return np.asarray(locs)
 */
            /*else*/ {
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = -1;
            }
            __pyx_L14:;
          }
          __pyx_L11:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":2736
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2748
 *                         locs[i] = -1
 * 
 *         return np.asarray(locs)             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_locs, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_14 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_14 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2748, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 2748, __pyx_L1_error)
  __pyx_r = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2721
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const int64_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_locs, 1);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2750
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const int64_t[:] values, Int64Vector uniques,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_27_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14Int64HashTable_26_unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[int64]\n            Array of values of which unique will be calculated\n        uniques : Int64Vector\n            Vector into which uniques will be written\n        count_prior : Py_ssize_t, default 0\n            Number of existing entries in uniques\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        ignore_na : bool, default False\n            Whether NA-values should be ignored for calculating the uniques. If\n            True, the labels corresponding to missing values will be set to\n            na_sentinel.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        use_result_mask: bool, default False\n            Whether to create a result mask for the unique values. Not supported\n            with return_inverse=True.\n\n        Returns\n        -------\n        uniques : ndarray[int64]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse=True)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if use_result_mask is true\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_27_unique = {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_27_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int64HashTable_26_unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_27_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  int __pyx_v_ignore_na;
  PyObject *__pyx_v_mask = 0;
  int __pyx_v_return_inverse;
  int __pyx_v_use_result_mask;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[9] = {0,0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_ignore_na,&__pyx_n_s_mask,&__pyx_n_s_return_inverse,&__pyx_n_s_use_result_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":2754
 *     def _unique(self, const int64_t[:] values, Int64Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));

    /* "pandas/_libs/hashtable_class_helper.pxi":2755
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[6] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2750, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2750, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, 1); __PYX_ERR(2, 2750, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2750, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2750, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2750, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2750, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[6] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2750, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[7] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2750, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_use_result_mask);
          if (value) { values[8] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2750, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_unique") < 0)) __PYX_ERR(2, 2750, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 2752, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 2753, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 2753, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    if (values[5]) {
      __pyx_v_ignore_na = __Pyx_PyObject_IsTrue(values[5]); if (unlikely((__pyx_v_ignore_na == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 2754, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":2754
 *     def _unique(self, const int64_t[:] values, Int64Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
      __pyx_v_ignore_na = ((int)0);
    }
    __pyx_v_mask = values[6];
    if (values[7]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[7]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 2755, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":2755
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
      __pyx_v_return_inverse = ((int)0);
    }
    if (values[8]) {
      __pyx_v_use_result_mask = __Pyx_PyObject_IsTrue(values[8]); if (unlikely((__pyx_v_use_result_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 2755, __pyx_L3_error)
    } else {
      __pyx_v_use_result_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, __pyx_nargs); __PYX_ERR(2, 2750, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector, 1, "uniques", 0))) __PYX_ERR(2, 2752, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_26_unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_ignore_na, __pyx_v_mask, __pyx_v_return_inverse, __pyx_v_use_result_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":2750
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const int64_t[:] values, Int64Vector uniques,
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_26_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_idx;
  Py_ssize_t __pyx_v_count;
  Py_ssize_t __pyx_v_n;
  __Pyx_memviewslice __pyx_v_labels = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_ret;
  __pyx_t_5numpy_int64_t __pyx_v_val;
  __pyx_t_5numpy_int64_t __pyx_v_na_value2;
  khiter_t __pyx_v_k;
  struct __pyx_t_6pandas_5_libs_9hashtable_Int64VectorData *__pyx_v_ud;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_result_mask = 0;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_v_rmd;
  int __pyx_v_use_na_value;
  int __pyx_v_use_mask;
  int __pyx_v_seen_na;
  __Pyx_memviewslice __pyx_v_mask_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_t_6pandas_5_libs_9hashtable_Int64VectorData *__pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_t_11;
  int __pyx_t_12;
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_t_14;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2799
 *         """
 *         cdef:
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)             # <<<<<<<<<<<<<<
 *             intp_t[::1] labels
 *             int ret = 0
 */
  __pyx_v_count = __pyx_v_count_prior;
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":2801
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)
 *             intp_t[::1] labels
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             int64_t val, na_value2
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2807
 *             UInt8Vector result_mask
 *             UInt8VectorData *rmd
 *             bint use_na_value, use_mask, seen_na = False             # <<<<<<<<<<<<<<
 *             uint8_t[:] mask_values
 * 
 */
  __pyx_v_seen_na = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2810
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2811
 * 
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 2811, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 2811, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2811, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 2811, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_labels = __pyx_t_7;
    __pyx_t_7.memview = NULL;
    __pyx_t_7.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":2810
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2812
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data             # <<<<<<<<<<<<<<
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 */
  __pyx_t_8 = __pyx_v_uniques->data;
  __pyx_v_ud = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":2813
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 *         use_na_value = na_value is not None             # <<<<<<<<<<<<<<
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 */
  __pyx_t_9 = (__pyx_v_na_value != Py_None);
  __pyx_v_use_na_value = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":2814
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None             # <<<<<<<<<<<<<<
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover
 */
  __pyx_t_9 = (__pyx_v_mask != Py_None);
  __pyx_v_use_mask = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":2815
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  __pyx_t_10 = (!__pyx_v_use_mask);
  if (__pyx_t_10) {
  } else {
    __pyx_t_9 = __pyx_t_10;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_use_result_mask;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2816
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         if use_result_mask and return_inverse:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 2816, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":2815
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2818
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_use_result_mask) {
  } else {
    __pyx_t_9 = __pyx_v_use_result_mask;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_return_inverse;
  __pyx_L8_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2819
 * 
 *         if use_result_mask and return_inverse:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         result_mask = UInt8Vector()
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 2819, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":2818
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2821
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         result_mask = UInt8Vector()             # <<<<<<<<<<<<<<
 *         rmd = result_mask.data
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2821, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_v_result_mask = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2822
 * 
 *         result_mask = UInt8Vector()
 *         rmd = result_mask.data             # <<<<<<<<<<<<<<
 * 
 *         if use_mask:
 */
  __pyx_t_11 = __pyx_v_result_mask->data;
  __pyx_v_rmd = __pyx_t_11;

  /* "pandas/_libs/hashtable_class_helper.pxi":2824
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  if (__pyx_v_use_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2825
 * 
 *         if use_mask:
 *             mask_values = mask.view("uint8")             # <<<<<<<<<<<<<<
 * 
 *         if use_na_value:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_mask, __pyx_n_s_view); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2825, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    __pyx_t_12 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_12 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_uint8};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_12, 1+__pyx_t_12);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2825, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(2, 2825, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_mask_values = __pyx_t_13;
    __pyx_t_13.memview = NULL;
    __pyx_t_13.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":2824
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2827
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
  if (__pyx_v_use_na_value) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2833
 *             # for the parameter. To please the compiler, we use na_value2,
 *             # which is only used if it's *specified*.
 *             na_value2 = (na_value)             # <<<<<<<<<<<<<<
 *         else:
 *             na_value2 = (0)
 */
    __pyx_t_14 = __Pyx_PyInt_As_npy_int64(__pyx_v_na_value); if (unlikely((__pyx_t_14 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 2833, __pyx_L1_error)
    __pyx_v_na_value2 = __pyx_t_14;

    /* "pandas/_libs/hashtable_class_helper.pxi":2827
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
    goto __pyx_L11;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2835
 *             na_value2 = (na_value)
 *         else:
 *             na_value2 = (0)             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
  /*else*/ {
    __pyx_v_na_value2 = 0;
  }
  __pyx_L11:;

  /* "pandas/_libs/hashtable_class_helper.pxi":2837
 *             na_value2 = (0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = (values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":2838
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 val = (values[i])
 * 
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_15 = __pyx_t_1;
        for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
          __pyx_v_i = __pyx_t_16;

          /* "pandas/_libs/hashtable_class_helper.pxi":2839
 *         with nogil:
 *             for i in range(n):
 *                 val = (values[i])             # <<<<<<<<<<<<<<
 * 
 *                 if ignore_na and use_mask:
 */
          __pyx_t_17 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_int64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_17 * __pyx_v_values.strides[0]) )));

          /* "pandas/_libs/hashtable_class_helper.pxi":2841
 *                 val = (values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L18_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_mask;
          __pyx_L18_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":2842
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 2842, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_17 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":2843
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                         continue
 *                 elif ignore_na and (
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 2843, __pyx_L13_error) }
              __pyx_t_17 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_na_sentinel;

              /* "pandas/_libs/hashtable_class_helper.pxi":2844
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 *                         continue             # <<<<<<<<<<<<<<
 *                 elif ignore_na and (
 *                    is_nan_int64_t(val) or
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":2842
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":2841
 *                 val = (values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
            goto __pyx_L17;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":2845
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_int64_t(val) or
 *                    (use_na_value and are_equivalent_int64_t(val, na_value2))
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":2846
 *                         continue
 *                 elif ignore_na and (
 *                    is_nan_int64_t(val) or             # <<<<<<<<<<<<<<
 *                    (use_na_value and are_equivalent_int64_t(val, na_value2))
 *                 ):
 */
          __pyx_t_10 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_int64_t(__pyx_v_val); if (unlikely(__pyx_t_10 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 2846, __pyx_L13_error)
          if (!__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":2847
 *                 elif ignore_na and (
 *                    is_nan_int64_t(val) or
 *                    (use_na_value and are_equivalent_int64_t(val, na_value2))             # <<<<<<<<<<<<<<
 *                 ):
 *                     # if missing values do not count as unique values (i.e. if
 */
          if (__pyx_v_use_na_value) {
          } else {
            __pyx_t_9 = __pyx_v_use_na_value;
            goto __pyx_L21_bool_binop_done;
          }
          __pyx_t_10 = __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_int64_t(__pyx_v_val, __pyx_v_na_value2); if (unlikely(__pyx_t_10 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 2847, __pyx_L13_error)
          __pyx_t_9 = __pyx_t_10;
          __pyx_L21_bool_binop_done:;

          /* "pandas/_libs/hashtable_class_helper.pxi":2845
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_int64_t(val) or
 *                    (use_na_value and are_equivalent_int64_t(val, na_value2))
 */
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":2852
 *                     # ignore_na is True), skip the hashtable entry for them,
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 2852, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_na_sentinel;

            /* "pandas/_libs/hashtable_class_helper.pxi":2853
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel
 *                     continue             # <<<<<<<<<<<<<<
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 */
            goto __pyx_L15_continue;

            /* "pandas/_libs/hashtable_class_helper.pxi":2845
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_int64_t(val) or
 *                    (use_na_value and are_equivalent_int64_t(val, na_value2))
 */
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":2854
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          __pyx_t_10 = (!__pyx_v_ignore_na);
          if (__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L25_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_result_mask;
          __pyx_L25_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":2855
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 2855, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_17 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":2856
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_class_helper.pxi":2857
 *                     if mask_values[i]:
 *                         if seen_na:
 *                             continue             # <<<<<<<<<<<<<<
 * 
 *                         seen_na = True
 */
                goto __pyx_L15_continue;

                /* "pandas/_libs/hashtable_class_helper.pxi":2856
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":2859
 *                             continue
 * 
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         if needs_resize(ud):
 *                             with gil:
 */
              __pyx_v_seen_na = 1;

              /* "pandas/_libs/hashtable_class_helper.pxi":2860
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              __pyx_t_9 = __pyx_fuse_0__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 2860, __pyx_L13_error)
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_class_helper.pxi":2861
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                {
                    #ifdef WITH_THREAD
                    PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                    #endif
                    /*try:*/ {

                      /* "pandas/_libs/hashtable_class_helper.pxi":2862
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":2863
 *                             with gil:
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2863, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 2863, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":2862
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":2866
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2866, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":2867
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":2868
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2868, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 2868, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":2867
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":2871
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                         append_data_int64(ud, val)
 *                         append_data_uint8(rmd, 1)
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2871, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":2861
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    /*finally:*/ {
                      /*normal exit:*/{
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L34;
                      }
                      __pyx_L33_error: {
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L13_error;
                      }
                      __pyx_L34:;
                    }
                }

                /* "pandas/_libs/hashtable_class_helper.pxi":2860
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":2872
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                         append_data_int64(ud, val)             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 1)
 *                         continue
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_int64(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 2872, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":2873
 *                                 result_mask.resize()
 *                         append_data_int64(ud, val)
 *                         append_data_uint8(rmd, 1)             # <<<<<<<<<<<<<<
 *                         continue
 * 
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 1); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 2873, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":2874
 *                         append_data_int64(ud, val)
 *                         append_data_uint8(rmd, 1)
 *                         continue             # <<<<<<<<<<<<<<
 * 
 *                 k = kh_get_int64(self.table, val)
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":2855
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":2854
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          }
          __pyx_L17:;

          /* "pandas/_libs/hashtable_class_helper.pxi":2876
 *                         continue
 * 
 *                 k = kh_get_int64(self.table, val)             # <<<<<<<<<<<<<<
 * 
 *                 if k == self.table.n_buckets:
 */
          __pyx_v_k = kh_get_int64(__pyx_v_self->table, __pyx_v_val);

          /* "pandas/_libs/hashtable_class_helper.pxi":2878
 *                 k = kh_get_int64(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_int64(self.table, val, &ret)
 */
          __pyx_t_9 = (__pyx_v_k == __pyx_v_self->table->n_buckets);
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":2880
 *                 if k == self.table.n_buckets:
 *                     # k hasn't been seen yet
 *                     k = kh_put_int64(self.table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *                     if needs_resize(ud):
 */
            __pyx_v_k = kh_put_int64(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":2882
 *                     k = kh_put_int64(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            __pyx_t_9 = __pyx_fuse_0__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 2882, __pyx_L13_error)
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":2883
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
              {
                  #ifdef WITH_THREAD
                  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                  #endif
                  /*try:*/ {

                    /* "pandas/_libs/hashtable_class_helper.pxi":2884
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":2885
 *                         with gil:
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 */
                      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2885, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                      __PYX_ERR(2, 2885, __pyx_L42_error)

                      /* "pandas/_libs/hashtable_class_helper.pxi":2884
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":2888
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()             # <<<<<<<<<<<<<<
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 */
                    __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2888, __pyx_L42_error)
                    __Pyx_GOTREF(__pyx_t_6);
                    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                    /* "pandas/_libs/hashtable_class_helper.pxi":2889
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    if (__pyx_v_use_result_mask) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":2890
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":2891
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2891, __pyx_L42_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 2891, __pyx_L42_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":2890
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":2894
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                     append_data_int64(ud, val)
 *                     if use_result_mask:
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2894, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":2889
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    }
                  }

                  /* "pandas/_libs/hashtable_class_helper.pxi":2883
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
                  /*finally:*/ {
                    /*normal exit:*/{
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L43;
                    }
                    __pyx_L42_error: {
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L13_error;
                    }
                    __pyx_L43:;
                  }
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":2882
 *                     k = kh_put_int64(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":2895
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                     append_data_int64(ud, val)             # <<<<<<<<<<<<<<
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)
 */
            __pyx_f_6pandas_5_libs_9hashtable_append_data_int64(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 2895, __pyx_L13_error)

            /* "pandas/_libs/hashtable_class_helper.pxi":2896
 *                                 result_mask.resize()
 *                     append_data_int64(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            if (__pyx_v_use_result_mask) {

              /* "pandas/_libs/hashtable_class_helper.pxi":2897
 *                     append_data_int64(ud, val)
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)             # <<<<<<<<<<<<<<
 * 
 *                     if return_inverse:
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 0); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 2897, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":2896
 *                                 result_mask.resize()
 *                     append_data_int64(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":2899
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            if (__pyx_v_return_inverse) {

              /* "pandas/_libs/hashtable_class_helper.pxi":2900
 * 
 *                     if return_inverse:
 *                         self.table.vals[k] = count             # <<<<<<<<<<<<<<
 *                         labels[i] = count
 *                         count += 1
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":2901
 *                     if return_inverse:
 *                         self.table.vals[k] = count
 *                         labels[i] = count             # <<<<<<<<<<<<<<
 *                         count += 1
 *                 elif return_inverse:
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 2901, __pyx_L13_error) }
              __pyx_t_17 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":2902
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 *                         count += 1             # <<<<<<<<<<<<<<
 *                 elif return_inverse:
 *                     # k falls into a previous bucket
 */
              __pyx_v_count = (__pyx_v_count + 1);

              /* "pandas/_libs/hashtable_class_helper.pxi":2899
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":2878
 *                 k = kh_get_int64(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_int64(self.table, val, &ret)
 */
            goto __pyx_L37;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":2903
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          if (__pyx_v_return_inverse) {

            /* "pandas/_libs/hashtable_class_helper.pxi":2906
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     labels[i] = idx
 * 
 */
            __pyx_v_idx = (__pyx_v_self->table->vals[__pyx_v_k]);

            /* "pandas/_libs/hashtable_class_helper.pxi":2907
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]
 *                     labels[i] = idx             # <<<<<<<<<<<<<<
 * 
 *         if return_inverse:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 2907, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_idx;

            /* "pandas/_libs/hashtable_class_helper.pxi":2903
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          }
          __pyx_L37:;
          __pyx_L15_continue:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":2837
 *             na_value2 = (0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = (values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L14;
        }
        __pyx_L13_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L14:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2909
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2910
 * 
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray             # <<<<<<<<<<<<<<
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundLocalError("labels"); __PYX_ERR(2, 2910, __pyx_L1_error) }
    __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_labels, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_base); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2910, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_6);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_6)) __PYX_ERR(2, 2910, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4)) __PYX_ERR(2, 2910, __pyx_L1_error);
    __pyx_t_6 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":2909
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2911
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  if (__pyx_v_use_result_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":2912
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()             # <<<<<<<<<<<<<<
 *         return uniques.to_array()
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2912, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->to_array(__pyx_v_result_mask, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2912, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2912, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2)) __PYX_ERR(2, 2912, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4)) __PYX_ERR(2, 2912, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":2911
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":2913
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()             # <<<<<<<<<<<<<<
 * 
 *     def unique(self, const int64_t[:] values, bint return_inverse=False, object mask=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2750
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const int64_t[:] values, Int64Vector uniques,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_13, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_labels, 1);
  __Pyx_XDECREF((PyObject *)__pyx_v_result_mask);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask_values, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2915
 *         return uniques.to_array()
 * 
 *     def unique(self, const int64_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_29unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14Int64HashTable_28unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[int64]\n            Array of values of which unique will be calculated\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n\n        Returns\n        -------\n        uniques : ndarray[int64]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if mask is given as input\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_29unique = {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_29unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int64HashTable_28unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_29unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_return_inverse;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_return_inverse,&__pyx_n_s_mask,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2915, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2915, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2915, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "unique") < 0)) __PYX_ERR(2, 2915, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 2915, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 2915, __pyx_L3_error)
    } else {
      __pyx_v_return_inverse = ((int)0);
    }
    __pyx_v_mask = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("unique", 0, 1, 3, __pyx_nargs); __PYX_ERR(2, 2915, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_28unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_return_inverse, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_28unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_uniques = NULL;
  int __pyx_v_use_result_mask;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2939
 *             The mask for the result values.
 *         """
 *         uniques = Int64Vector()             # <<<<<<<<<<<<<<
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2939, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2940
 *         """
 *         uniques = Int64Vector()
 *         use_result_mask = True if mask is not None else False             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 */
  __pyx_t_3 = (__pyx_v_mask != Py_None);
  if (__pyx_t_3) {
    __pyx_t_2 = 1;
  } else {
    __pyx_t_2 = 0;
  }
  __pyx_v_use_result_mask = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":2941
 *         uniques = Int64Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int64_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4)) __PYX_ERR(2, 2941, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 2941, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ignore_na, Py_False) < 0) __PYX_ERR(2, 2941, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2942
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const int64_t[:] values, Py_ssize_t na_sentinel=-1,
 */
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_return_inverse); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2942, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return_inverse, __pyx_t_6) < 0) __PYX_ERR(2, 2941, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 2941, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_use_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2942, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_use_result_mask, __pyx_t_6) < 0) __PYX_ERR(2, 2941, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2941
 *         uniques = Int64Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 2941, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2915
 *         return uniques.to_array()
 * 
 *     def unique(self, const int64_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2944
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const int64_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_31factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14Int64HashTable_30factorize, "\n        Calculate unique values and labels (no sorting!)\n\n        Missing values are not included in the \"uniques\" for this method.\n        The labels for any missing values will be set to \"na_sentinel\"\n\n        Parameters\n        ----------\n        values : ndarray[int64]\n            Array of values of which unique will be calculated\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n\n        Returns\n        -------\n        uniques : ndarray[int64]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t]\n            The labels from values to uniques\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_31factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_31factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int64HashTable_30factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_31factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  PyObject *__pyx_v_ignore_na = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,&__pyx_n_s_ignore_na,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":2945
 * 
 *     def factorize(self, const int64_t[:] values, Py_ssize_t na_sentinel=-1,
 *                   object na_value=None, object mask=None, ignore_na=True):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_True));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2944, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2944, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2944, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2944, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2944, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 2944, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 2944, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 2944, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
    __pyx_v_ignore_na = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 5, __pyx_nargs); __PYX_ERR(2, 2944, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_30factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask, __pyx_v_ignore_na);

  /* "pandas/_libs/hashtable_class_helper.pxi":2944
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const int64_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_30factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_uniques_vector = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2975
 *             The labels from values to uniques
 *         """
 *         uniques_vector = Int64Vector()             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques_vector = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2976
 *         """
 *         uniques_vector = Int64Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int64_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 2976, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques_vector);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques_vector))) __PYX_ERR(2, 2976, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 2976, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2977
 *         uniques_vector = Int64Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,             # <<<<<<<<<<<<<<
 *                             return_inverse=True)
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 2976, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, __pyx_v_ignore_na) < 0) __PYX_ERR(2, 2976, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 2976, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2978
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)             # <<<<<<<<<<<<<<
 * 
 *     def get_labels(self, const int64_t[:] values, Int64Vector uniques,
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 2976, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2976
 *         """
 *         uniques_vector = Int64Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2944
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const int64_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2980
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const int64_t[:] values, Int64Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_33get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_33get_labels = {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_33get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_33get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_labels (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":2982
 *     def get_labels(self, const int64_t[:] values, Int64Vector uniques,
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2980, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2980, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, 1); __PYX_ERR(2, 2980, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2980, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2980, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2980, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2980, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_labels") < 0)) __PYX_ERR(2, 2980, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 2980, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 2981, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 2981, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    __pyx_v_mask = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, __pyx_nargs); __PYX_ERR(2, 2980, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector, 1, "uniques", 0))) __PYX_ERR(2, 2980, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_32get_labels(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":2980
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const int64_t[:] values, Int64Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_32get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_v_labels = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_labels", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2984
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int64_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 2984, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 2984, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_count_prior); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_count_prior, __pyx_t_4) < 0) __PYX_ERR(2, 2984, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2985
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,             # <<<<<<<<<<<<<<
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 2984, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 2984, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2986
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, Py_True) < 0) __PYX_ERR(2, 2984, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 2984, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 2984, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2984
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
    PyObject* sequence = __pyx_t_4;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(2, 2984, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 2984, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 2984, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2984, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
    index = 0; __pyx_t_2 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_1), 2) < 0) __PYX_ERR(2, 2984, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(2, 2984, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v__ = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_labels = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2987
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_labels);
  __pyx_r = __pyx_v_labels;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2980
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const int64_t[:] values, Int64Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XDECREF(__pyx_v_labels);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":2989
 *         return labels
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def get_labels_groupby(
 *         self, const int64_t[:] values
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_35get_labels_groupby(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_35get_labels_groupby = {"get_labels_groupby", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_35get_labels_groupby, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_35get_labels_groupby(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_labels_groupby (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 2989, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_labels_groupby") < 0)) __PYX_ERR(2, 2989, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 2991, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_labels_groupby", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 2989, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.get_labels_groupby", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_34get_labels_groupby(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)__pyx_v_self), __pyx_v_values);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_34get_labels_groupby(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  __Pyx_memviewslice __pyx_v_labels = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_v_idx;
  Py_ssize_t __pyx_v_count;
  int __pyx_v_ret;
  __pyx_t_5numpy_int64_t __pyx_v_val;
  khiter_t __pyx_v_k;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_uniques = 0;
  struct __pyx_t_6pandas_5_libs_9hashtable_Int64VectorData *__pyx_v_ud;
  PyArrayObject *__pyx_v_arr_uniques = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_t_6pandas_5_libs_9hashtable_Int64VectorData *__pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_labels_groupby", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":2995
 *         # tuple[np.ndarray[np.intp], np.ndarray[int64]]
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             intp_t[::1] labels
 *             Py_ssize_t idx, count = 0
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":2997
 *             Py_ssize_t i, n = len(values)
 *             intp_t[::1] labels
 *             Py_ssize_t idx, count = 0             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             int64_t val
 */
  __pyx_v_count = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2998
 *             intp_t[::1] labels
 *             Py_ssize_t idx, count = 0
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             int64_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3001
 *             int64_t val
 *             khiter_t k
 *             Int64Vector uniques = Int64Vector()             # <<<<<<<<<<<<<<
 *             Int64VectorData *ud
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3001, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3004
 *             Int64VectorData *ud
 * 
 *         labels = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *         ud = uniques.data
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 3004, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 3004, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3004, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 3004, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_labels = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":3005
 * 
 *         labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
  __pyx_t_8 = __pyx_v_uniques->data;
  __pyx_v_ud = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":3007
 *         ud = uniques.data
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = (values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":3008
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 val = (values[i])
 * 
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_9 = __pyx_t_1;
        for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
          __pyx_v_i = __pyx_t_10;

          /* "pandas/_libs/hashtable_class_helper.pxi":3009
 *         with nogil:
 *             for i in range(n):
 *                 val = (values[i])             # <<<<<<<<<<<<<<
 * 
 *                 # specific for groupby
 */
          __pyx_t_11 = __pyx_v_i;
          if (__pyx_t_11 < 0) __pyx_t_11 += __pyx_v_values.shape[0];
          __pyx_v_val = (*((__pyx_t_5numpy_int64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_11 * __pyx_v_values.strides[0]) )));

          /* "pandas/_libs/hashtable_class_helper.pxi":3012
 * 
 *                 # specific for groupby
 *                 if val < 0:             # <<<<<<<<<<<<<<
 *                     labels[i] = -1
 *                     continue
 */
          __pyx_t_12 = (__pyx_v_val < 0);
          if (__pyx_t_12) {

            /* "pandas/_libs/hashtable_class_helper.pxi":3013
 *                 # specific for groupby
 *                 if val < 0:
 *                     labels[i] = -1             # <<<<<<<<<<<<<<
 *                     continue
 * 
 */
            __pyx_t_11 = __pyx_v_i;
            if (__pyx_t_11 < 0) __pyx_t_11 += __pyx_v_labels.shape[0];
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_11)) )) = -1;

            /* "pandas/_libs/hashtable_class_helper.pxi":3014
 *                 if val < 0:
 *                     labels[i] = -1
 *                     continue             # <<<<<<<<<<<<<<
 * 
 *                 k = kh_get_int64(self.table, val)
 */
            goto __pyx_L6_continue;

            /* "pandas/_libs/hashtable_class_helper.pxi":3012
 * 
 *                 # specific for groupby
 *                 if val < 0:             # <<<<<<<<<<<<<<
 *                     labels[i] = -1
 *                     continue
 */
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":3016
 *                     continue
 * 
 *                 k = kh_get_int64(self.table, val)             # <<<<<<<<<<<<<<
 *                 if k != self.table.n_buckets:
 *                     idx = self.table.vals[k]
 */
          __pyx_v_k = kh_get_int64(__pyx_v_self->table, __pyx_v_val);

          /* "pandas/_libs/hashtable_class_helper.pxi":3017
 * 
 *                 k = kh_get_int64(self.table, val)
 *                 if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     idx = self.table.vals[k]
 *                     labels[i] = idx
 */
          __pyx_t_12 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
          if (__pyx_t_12) {

            /* "pandas/_libs/hashtable_class_helper.pxi":3018
 *                 k = kh_get_int64(self.table, val)
 *                 if k != self.table.n_buckets:
 *                     idx = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     labels[i] = idx
 *                 else:
 */
            __pyx_v_idx = (__pyx_v_self->table->vals[__pyx_v_k]);

            /* "pandas/_libs/hashtable_class_helper.pxi":3019
 *                 if k != self.table.n_buckets:
 *                     idx = self.table.vals[k]
 *                     labels[i] = idx             # <<<<<<<<<<<<<<
 *                 else:
 *                     k = kh_put_int64(self.table, val, &ret)
 */
            __pyx_t_11 = __pyx_v_i;
            if (__pyx_t_11 < 0) __pyx_t_11 += __pyx_v_labels.shape[0];
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_11)) )) = __pyx_v_idx;

            /* "pandas/_libs/hashtable_class_helper.pxi":3017
 * 
 *                 k = kh_get_int64(self.table, val)
 *                 if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     idx = self.table.vals[k]
 *                     labels[i] = idx
 */
            goto __pyx_L9;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":3021
 *                     labels[i] = idx
 *                 else:
 *                     k = kh_put_int64(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                     self.table.vals[k] = count
 * 
 */
          /*else*/ {
            __pyx_v_k = kh_put_int64(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":3022
 *                 else:
 *                     k = kh_put_int64(self.table, val, &ret)
 *                     self.table.vals[k] = count             # <<<<<<<<<<<<<<
 * 
 *                     if needs_resize(ud):
 */
            (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_count;

            /* "pandas/_libs/hashtable_class_helper.pxi":3024
 *                     self.table.vals[k] = count
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             uniques.resize()
 */
            __pyx_t_12 = __pyx_fuse_0__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_12 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 3024, __pyx_L4_error)
            if (__pyx_t_12) {

              /* "pandas/_libs/hashtable_class_helper.pxi":3025
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             uniques.resize()
 *                     append_data_int64(ud, val)
 */
              {
                  #ifdef WITH_THREAD
                  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                  #endif
                  /*try:*/ {

                    /* "pandas/_libs/hashtable_class_helper.pxi":3026
 *                     if needs_resize(ud):
 *                         with gil:
 *                             uniques.resize()             # <<<<<<<<<<<<<<
 *                     append_data_int64(ud, val)
 *                     labels[i] = count
 */
                    __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3026, __pyx_L14_error)
                    __Pyx_GOTREF(__pyx_t_6);
                    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                  }

                  /* "pandas/_libs/hashtable_class_helper.pxi":3025
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             uniques.resize()
 *                     append_data_int64(ud, val)
 */
                  /*finally:*/ {
                    /*normal exit:*/{
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L15;
                    }
                    __pyx_L14_error: {
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L4_error;
                    }
                    __pyx_L15:;
                  }
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":3024
 *                     self.table.vals[k] = count
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             uniques.resize()
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":3027
 *                         with gil:
 *                             uniques.resize()
 *                     append_data_int64(ud, val)             # <<<<<<<<<<<<<<
 *                     labels[i] = count
 *                     count += 1
 */
            __pyx_f_6pandas_5_libs_9hashtable_append_data_int64(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 3027, __pyx_L4_error)

            /* "pandas/_libs/hashtable_class_helper.pxi":3028
 *                             uniques.resize()
 *                     append_data_int64(ud, val)
 *                     labels[i] = count             # <<<<<<<<<<<<<<
 *                     count += 1
 * 
 */
            __pyx_t_11 = __pyx_v_i;
            if (__pyx_t_11 < 0) __pyx_t_11 += __pyx_v_labels.shape[0];
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_11)) )) = __pyx_v_count;

            /* "pandas/_libs/hashtable_class_helper.pxi":3029
 *                     append_data_int64(ud, val)
 *                     labels[i] = count
 *                     count += 1             # <<<<<<<<<<<<<<
 * 
 *         arr_uniques = uniques.to_array()
 */
            __pyx_v_count = (__pyx_v_count + 1);
          }
          __pyx_L9:;
          __pyx_L6_continue:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":3007
 *         ud = uniques.data
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = (values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3031
 *                     count += 1
 * 
 *         arr_uniques = uniques.to_array()             # <<<<<<<<<<<<<<
 * 
 *         return np.asarray(labels), arr_uniques
 */
  __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_v_arr_uniques = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3033
 *         arr_uniques = uniques.to_array()
 * 
 *         return np.asarray(labels), arr_uniques             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_labels, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_13 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_13 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_13, 1+__pyx_t_13);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3033, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3033, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6)) __PYX_ERR(2, 3033, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_arr_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_arr_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, ((PyObject *)__pyx_v_arr_uniques))) __PYX_ERR(2, 3033, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_r = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2989
 *         return labels
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def get_labels_groupby(
 *         self, const int64_t[:] values
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.get_labels_groupby", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_labels, 1);
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XDECREF((PyObject *)__pyx_v_arr_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_37__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_37__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_37__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_37__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_36__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_36__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_39__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_39__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_39__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_39__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_38__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int64HashTable_38__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3041
 *         Int64Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = Int64HashTable(size_hint)
 *         self.uniques = Int64Vector()
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_size_hint = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3041, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 3041, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_size_hint = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 3041, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_size_hint), (&PyInt_Type), 0, "size_hint", 1))) __PYX_ERR(2, 3041, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *)__pyx_v_self), __pyx_v_size_hint);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":3042
 * 
 *     def __cinit__(self, size_hint: int):
 *         self.table = Int64HashTable(size_hint)             # <<<<<<<<<<<<<<
 *         self.uniques = Int64Vector()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable), __pyx_v_size_hint); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3042, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3043
 *     def __cinit__(self, size_hint: int):
 *         self.table = Int64HashTable(size_hint)
 *         self.uniques = Int64Vector()             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const int64_t[:] values,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3043, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3041
 *         Int64Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = Int64HashTable(size_hint)
 *         self.uniques = Int64Vector()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3045
 *         self.uniques = Int64Vector()
 * 
 *     def factorize(self, const int64_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15Int64Factorizer_2factorize, "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = Int64Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"int64\"), na_sentinel=20)\n        array([0, 1, 2])\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15Int64Factorizer_3factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15Int64Factorizer_2factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_v_na_sentinel = 0;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_neg_1));

    /* "pandas/_libs/hashtable_class_helper.pxi":3046
 * 
 *     def factorize(self, const int64_t[:] values,
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:             # <<<<<<<<<<<<<<
 *         """
 *         Returns
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3045, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3045, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3045, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3045, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 3045, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 3045, __pyx_L3_error)
    __pyx_v_na_sentinel = values[1];
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 4, __pyx_nargs); __PYX_ERR(2, 3045, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_2factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":3045
 *         self.uniques = Int64Vector()
 * 
 *     def factorize(self, const int64_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  PyArrayObject *__pyx_v_labels = 0;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_uniques = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_labels;
  __Pyx_Buffer __pyx_pybuffer_labels;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);
  __pyx_pybuffer_labels.pybuffer.buf = NULL;
  __pyx_pybuffer_labels.refcount = 0;
  __pyx_pybuffernd_labels.data = NULL;
  __pyx_pybuffernd_labels.rcbuffer = &__pyx_pybuffer_labels;

  /* "pandas/_libs/hashtable_class_helper.pxi":3063
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = Int64Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  if (__pyx_v_self->uniques->__pyx_base.external_view_exists) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3064
 * 
 *         if self.uniques.external_view_exists:
 *             uniques = Int64Vector()             # <<<<<<<<<<<<<<
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 */
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3064, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":3065
 *         if self.uniques.external_view_exists:
 *             uniques = Int64Vector()
 *             uniques.extend(self.uniques.to_array())             # <<<<<<<<<<<<<<
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 */
    __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_v_self->uniques->__pyx_vtab)->to_array(__pyx_v_self->uniques, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3065, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t(__pyx_t_1, PyBUF_WRITABLE); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(2, 3065, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_v_uniques->__pyx_vtab)->extend(__pyx_v_uniques, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3065, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
    __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":3066
 *             uniques = Int64Vector()
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques             # <<<<<<<<<<<<<<
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 */
    __Pyx_INCREF((PyObject *)__pyx_v_uniques);
    __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
    __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
    __pyx_v_self->uniques = __pyx_v_uniques;

    /* "pandas/_libs/hashtable_class_helper.pxi":3063
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = Int64Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3067
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->table), __pyx_n_s_get_labels); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int64_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "pandas/_libs/hashtable_class_helper.pxi":3068
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,             # <<<<<<<<<<<<<<
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_self->__pyx_base.count); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "pandas/_libs/hashtable_class_helper.pxi":3067
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_5 = PyTuple_New(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3)) __PYX_ERR(2, 3067, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self->uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_self->uniques))) __PYX_ERR(2, 3067, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_4)) __PYX_ERR(2, 3067, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_na_sentinel);
  __Pyx_GIVEREF(__pyx_v_na_sentinel);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_v_na_sentinel)) __PYX_ERR(2, 3067, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3069
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)             # <<<<<<<<<<<<<<
 *         self.count = len(self.uniques)
 *         return labels
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 3069, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 3069, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3067
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3067, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 3067, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
    __pyx_t_7 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_7 < 0)) {
      PyErr_Fetch(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_v_labels, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      }
      __pyx_t_8 = __pyx_t_9 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_labels.diminfo[0].strides = __pyx_pybuffernd_labels.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_labels.diminfo[0].shape = __pyx_pybuffernd_labels.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(2, 3067, __pyx_L1_error)
  }
  __pyx_t_6 = 0;
  __pyx_v_labels = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3070
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  __pyx_t_3 = ((PyObject *)__pyx_v_self->uniques);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_11 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(2, 3070, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_self->__pyx_base.count = __pyx_t_11;

  /* "pandas/_libs/hashtable_class_helper.pxi":3071
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * cdef class Complex64HashTable(HashTable):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_labels);
  __pyx_r = ((PyObject *)__pyx_v_labels);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3045
 *         self.uniques = Int64Vector()
 * 
 *     def factorize(self, const int64_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_labels);
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3038
 * cdef class Int64Factorizer(Factorizer):
 *     cdef public:
 *         Int64HashTable table             # <<<<<<<<<<<<<<
 *         Int64Vector uniques
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_5table_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_5table_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_5table___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->table);
  __pyx_r = ((PyObject *)__pyx_v_self->table);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_5table_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable))))) __PYX_ERR(2, 3038, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64Factorizer.table.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_5table_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_5table_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_5table_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3039
 *     cdef public:
 *         Int64HashTable table
 *         Int64Vector uniques             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, size_hint: int):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_7uniques_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_7uniques_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_7uniques___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __pyx_r = ((PyObject *)__pyx_v_self->uniques);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_7uniques_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector))))) __PYX_ERR(2, 3039, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64Factorizer.uniques.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_7uniques_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_7uniques_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_7uniques_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15Int64Factorizer_5__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_4__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64Factorizer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15Int64Factorizer_7__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_6__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int64Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int64Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3075
 * cdef class Complex64HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_complex64()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __pyx_t_5numpy_int64_t __pyx_v_size_hint;
  int __pyx_v_uses_mask;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,&__pyx_n_s_uses_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3075, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uses_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3075, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 3075, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_size_hint = __Pyx_PyInt_As_npy_int64(values[0]); if (unlikely((__pyx_v_size_hint == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 3075, __pyx_L3_error)
    } else {
      __pyx_v_size_hint = ((__pyx_t_5numpy_int64_t)1);
    }
    if (values[1]) {
      __pyx_v_uses_mask = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_uses_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 3075, __pyx_L3_error)
    } else {
      __pyx_v_uses_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 0, 2, __pyx_nargs); __PYX_ERR(2, 3075, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)__pyx_v_self), __pyx_v_size_hint, __pyx_v_uses_mask);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  khuint_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __pyx_t_5numpy_int64_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":3076
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_complex64()             # <<<<<<<<<<<<<<
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_complex64(self.table, size_hint)
 */
  __pyx_v_self->table = kh_init_complex64();

  /* "pandas/_libs/hashtable_class_helper.pxi":3077
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_complex64()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)             # <<<<<<<<<<<<<<
 *         kh_resize_complex64(self.table, size_hint)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3077, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = kh_needed_n_buckets(__pyx_v_size_hint);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3077, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_1, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3077, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(2, 3077, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_6) {
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_5 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3077, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_int64(__pyx_t_3); if (unlikely((__pyx_t_7 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 3077, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_size_hint = __pyx_t_7;

  /* "pandas/_libs/hashtable_class_helper.pxi":3078
 *         self.table = kh_init_complex64()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_complex64(self.table, size_hint)             # <<<<<<<<<<<<<<
 * 
 *         self.uses_mask = uses_mask
 */
  kh_resize_complex64(__pyx_v_self->table, __pyx_v_size_hint);

  /* "pandas/_libs/hashtable_class_helper.pxi":3080
 *         kh_resize_complex64(self.table, size_hint)
 * 
 *         self.uses_mask = uses_mask             # <<<<<<<<<<<<<<
 *         self.na_position = -1
 * 
 */
  __pyx_v_self->uses_mask = __pyx_v_uses_mask;

  /* "pandas/_libs/hashtable_class_helper.pxi":3081
 * 
 *         self.uses_mask = uses_mask
 *         self.na_position = -1             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
  __pyx_v_self->na_position = -1LL;

  /* "pandas/_libs/hashtable_class_helper.pxi":3075
 * cdef class Complex64HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_complex64()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3083
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_3__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_3__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_2__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  long __pyx_t_1;
  int __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":3084
 * 
 *     def __len__(self) -> int:
 *         return self.table.size + (0 if self.na_position == -1 else 1)             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_2 = (__pyx_v_self->na_position == -1LL);
  if (__pyx_t_2) {
    __pyx_t_1 = 0;
  } else {
    __pyx_t_1 = 1;
  }
  __pyx_r = (__pyx_v_self->table->size + __pyx_t_1);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3083
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3086
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_complex64(self.table)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_5__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_5__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_4__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":3087
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_complex64(self.table)
 *             self.table = NULL
 */
  __pyx_t_1 = (__pyx_v_self->table != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3088
 *     def __dealloc__(self):
 *         if self.table is not NULL:
 *             kh_destroy_complex64(self.table)             # <<<<<<<<<<<<<<
 *             self.table = NULL
 * 
 */
    kh_destroy_complex64(__pyx_v_self->table);

    /* "pandas/_libs/hashtable_class_helper.pxi":3089
 *         if self.table is not NULL:
 *             kh_destroy_complex64(self.table)
 *             self.table = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __contains__(self, object key) -> bool:
 */
    __pyx_v_self->table = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":3087
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_complex64(self.table)
 *             self.table = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3086
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_complex64(self.table)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":3091
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__contains__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_6__contains__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)__pyx_v_self), ((PyObject *)__pyx_v_key));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, PyObject *__pyx_v_key) {
  khiter_t __pyx_v_k;
  khcomplex64_t __pyx_v_ckey;
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  __pyx_t_float_complex __pyx_t_3;
  khcomplex64_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3098
 *             khcomplex64_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_1 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_7missing_checknull(__pyx_v_key, 0, NULL); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3098, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3099
 * 
 *         if self.uses_mask and checknull(key):
 *             return -1 != self.na_position             # <<<<<<<<<<<<<<
 * 
 *         ckey = to_khcomplex64_t(key)
 */
    __pyx_r = (-1LL != __pyx_v_self->na_position);
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":3098
 *             khcomplex64_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3101
 *             return -1 != self.na_position
 * 
 *         ckey = to_khcomplex64_t(key)             # <<<<<<<<<<<<<<
 *         k = kh_get_complex64(self.table, ckey)
 *         return k != self.table.n_buckets
 */
  __pyx_t_3 = __Pyx_PyComplex_As___pyx_t_float_complex(__pyx_v_key); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3101, __pyx_L1_error)
  __pyx_t_4 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex64_t(__pyx_t_3); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3101, __pyx_L1_error)
  __pyx_v_ckey = __pyx_t_4;

  /* "pandas/_libs/hashtable_class_helper.pxi":3102
 * 
 *         ckey = to_khcomplex64_t(key)
 *         k = kh_get_complex64(self.table, ckey)             # <<<<<<<<<<<<<<
 *         return k != self.table.n_buckets
 * 
 */
  __pyx_v_k = kh_get_complex64(__pyx_v_self->table, __pyx_v_ckey);

  /* "pandas/_libs/hashtable_class_helper.pxi":3103
 *         ckey = to_khcomplex64_t(key)
 *         k = kh_get_complex64(self.table, ckey)
 *         return k != self.table.n_buckets             # <<<<<<<<<<<<<<
 * 
 *     def sizeof(self, deep: bool = False) -> int:
 */
  __pyx_r = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3091
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3105
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_18Complex64HashTable_8sizeof, " return the size of my table in bytes ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_9sizeof = {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_18Complex64HashTable_8sizeof};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_deep = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sizeof (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_deep,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_deep);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3105, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "sizeof") < 0)) __PYX_ERR(2, 3105, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_deep = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sizeof", 0, 0, 1, __pyx_nargs); __PYX_ERR(2, 3105, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_8sizeof(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)__pyx_v_self), __pyx_v_deep);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep) {
  PyObject *__pyx_v_overhead = NULL;
  PyObject *__pyx_v_for_flags = NULL;
  PyObject *__pyx_v_for_pairs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  long __pyx_t_2;
  long __pyx_t_3;
  long __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sizeof", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":3107
 *     def sizeof(self, deep: bool = False) -> int:
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)             # <<<<<<<<<<<<<<
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(complex64_t) + # keys
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(((4 * (sizeof(__pyx_t_5numpy_uint32_t))) + (3 * (sizeof(__pyx_t_5numpy_uint32_t *))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3107, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_overhead = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3108
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)             # <<<<<<<<<<<<<<
 *         for_pairs =  self.table.n_buckets * (sizeof(complex64_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 */
  __pyx_t_2 = (__pyx_v_self->table->n_buckets >> 5);
  __pyx_t_3 = 1;
  __pyx_t_5 = (__pyx_t_2 > __pyx_t_3);
  if (__pyx_t_5) {
    __pyx_t_4 = __pyx_t_2;
  } else {
    __pyx_t_4 = __pyx_t_3;
  }
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_t_4 * (sizeof(__pyx_t_5numpy_uint32_t)))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3108, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_flags = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3109
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(complex64_t) + # keys             # <<<<<<<<<<<<<<
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->n_buckets * ((sizeof(__pyx_t_float_complex)) + (sizeof(Py_ssize_t))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3109, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_pairs = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3111
 *         for_pairs =  self.table.n_buckets * (sizeof(complex64_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs             # <<<<<<<<<<<<<<
 * 
 *     def get_state(self) -> dict[str, int]:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Add(__pyx_v_overhead, __pyx_v_for_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyNumber_Add(__pyx_t_1, __pyx_v_for_pairs); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3111, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(__Pyx_Py3Int_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None) || __Pyx_RaiseUnexpectedTypeError("int", __pyx_t_6))) __PYX_ERR(2, 3111, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3105
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_overhead);
  __Pyx_XDECREF(__pyx_v_for_flags);
  __Pyx_XDECREF(__pyx_v_for_pairs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3113
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_18Complex64HashTable_10get_state, " returns infos about the state of the hashtable");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_11get_state = {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_18Complex64HashTable_10get_state};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_state (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_state", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_state", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_10get_state(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_state", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":3115
 *     def get_state(self) -> dict[str, int]:
 *         """ returns infos about the state of the hashtable"""
 *         return {             # <<<<<<<<<<<<<<
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 */
  __Pyx_XDECREF(__pyx_r);

  /* "pandas/_libs/hashtable_class_helper.pxi":3116
 *         """ returns infos about the state of the hashtable"""
 *         return {
 *             'n_buckets' : self.table.n_buckets,             # <<<<<<<<<<<<<<
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_buckets); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_buckets, __pyx_t_2) < 0) __PYX_ERR(2, 3116, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3117
 *         return {
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,             # <<<<<<<<<<<<<<
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->size); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3117, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_size, __pyx_t_2) < 0) __PYX_ERR(2, 3116, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3118
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,             # <<<<<<<<<<<<<<
 *             'upper_bound' : self.table.upper_bound,
 *         }
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_occupied); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_occupied, __pyx_t_2) < 0) __PYX_ERR(2, 3116, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3119
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,             # <<<<<<<<<<<<<<
 *         }
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->upper_bound); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_upper_bound, __pyx_t_2) < 0) __PYX_ERR(2, 3116, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3113
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.get_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3122
 *         }
 * 
 *     cpdef get_item(self, complex64_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_18Complex64HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, __pyx_t_float_complex __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  khcomplex64_t __pyx_v_cval;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  khcomplex64_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3122, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_13get_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __pyx_PyComplex_FromComplex(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3122, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3122, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3141
 *             khcomplex64_t cval
 * 
 *         cval = to_khcomplex64_t(val)             # <<<<<<<<<<<<<<
 *         k = kh_get_complex64(self.table, cval)
 *         if k != self.table.n_buckets:
 */
  __pyx_t_7 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex64_t(__pyx_v_val); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3141, __pyx_L1_error)
  __pyx_v_cval = __pyx_t_7;

  /* "pandas/_libs/hashtable_class_helper.pxi":3142
 * 
 *         cval = to_khcomplex64_t(val)
 *         k = kh_get_complex64(self.table, cval)             # <<<<<<<<<<<<<<
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]
 */
  __pyx_v_k = kh_get_complex64(__pyx_v_self->table, __pyx_v_cval);

  /* "pandas/_libs/hashtable_class_helper.pxi":3143
 *         cval = to_khcomplex64_t(val)
 *         k = kh_get_complex64(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  __pyx_t_8 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  if (likely(__pyx_t_8)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3144
 *         k = kh_get_complex64(self.table, cval)
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(val)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->vals[__pyx_v_k])); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3144, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":3143
 *         cval = to_khcomplex64_t(val)
 *         k = kh_get_complex64(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3146
 *             return self.table.vals[k]
 *         else:
 *             raise KeyError(val)             # <<<<<<<<<<<<<<
 * 
 *     cpdef get_na(self):
 */
  /*else*/ {
    __pyx_t_1 = __pyx_PyComplex_FromComplex(__pyx_v_val); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3146, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3146, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 3146, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3122
 *         }
 * 
 *     cpdef get_item(self, complex64_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_18Complex64HashTable_12get_item, "Extracts the position of val from the hashtable.\n\n        Parameters\n        ----------\n        val : Scalar\n            The value that is looked up in the hashtable\n\n        Returns\n        -------\n        The position of the requested integer.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_13get_item = {"get_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_13get_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_18Complex64HashTable_12get_item};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_float_complex __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3122, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_item") < 0)) __PYX_ERR(2, 3122, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __Pyx_PyComplex_As___pyx_t_float_complex(values[0]); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3122, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_item", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 3122, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_12get_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, __pyx_t_float_complex __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_18Complex64HashTable_get_item(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3148
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_18Complex64HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3148, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_15get_na)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3148, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3156
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_6 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3157
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         if self.na_position == -1:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 3157, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":3156
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3159
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  __pyx_t_6 = (__pyx_v_self->na_position == -1LL);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3160
 * 
 *         if self.na_position == -1:
 *             raise KeyError("NA")             # <<<<<<<<<<<<<<
 *         return self.na_position
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_KeyError, __pyx_tuple__13, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3160, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(2, 3160, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":3159
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3161
 *         if self.na_position == -1:
 *             raise KeyError("NA")
 *         return self.na_position             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_item(self, complex64_t key, Py_ssize_t val):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->na_position); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3161, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3148
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_18Complex64HashTable_14get_na, "Extracts the position of na_value from the hashtable.\n\n        Returns\n        -------\n        The position of the last na value.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_15get_na = {"get_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_15get_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_18Complex64HashTable_14get_na};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_na", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_na", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_14get_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_18Complex64HashTable_get_na(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3163
 *         return self.na_position
 * 
 *     cpdef set_item(self, complex64_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_18Complex64HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, __pyx_t_float_complex __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  khcomplex64_t __pyx_v_ckey;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  khcomplex64_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3163, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_17set_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __pyx_PyComplex_FromComplex(__pyx_v_key); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3163, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3163, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_5 = __pyx_t_1; __pyx_t_6 = NULL;
        __pyx_t_7 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_7 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_3, __pyx_t_4};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3163, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3168
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             khcomplex64_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3171
 *             khcomplex64_t ckey
 * 
 *         ckey = to_khcomplex64_t(key)             # <<<<<<<<<<<<<<
 *         k = kh_put_complex64(self.table, ckey, &ret)
 *         if kh_exist_complex64(self.table, k):
 */
  __pyx_t_8 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex64_t(__pyx_v_key); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3171, __pyx_L1_error)
  __pyx_v_ckey = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":3172
 * 
 *         ckey = to_khcomplex64_t(key)
 *         k = kh_put_complex64(self.table, ckey, &ret)             # <<<<<<<<<<<<<<
 *         if kh_exist_complex64(self.table, k):
 *             self.table.vals[k] = val
 */
  __pyx_v_k = kh_put_complex64(__pyx_v_self->table, __pyx_v_ckey, (&__pyx_v_ret));

  /* "pandas/_libs/hashtable_class_helper.pxi":3173
 *         ckey = to_khcomplex64_t(key)
 *         k = kh_put_complex64(self.table, ckey, &ret)
 *         if kh_exist_complex64(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
  __pyx_t_9 = kh_exist_complex64(__pyx_v_self->table, __pyx_v_k);
  if (likely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3174
 *         k = kh_put_complex64(self.table, ckey, &ret)
 *         if kh_exist_complex64(self.table, k):
 *             self.table.vals[k] = val             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(key)
 */
    (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_val;

    /* "pandas/_libs/hashtable_class_helper.pxi":3173
 *         ckey = to_khcomplex64_t(key)
 *         k = kh_put_complex64(self.table, ckey, &ret)
 *         if kh_exist_complex64(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3176
 *             self.table.vals[k] = val
 *         else:
 *             raise KeyError(key)             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_na(self, Py_ssize_t val):
 */
  /*else*/ {
    __pyx_t_1 = __pyx_PyComplex_FromComplex(__pyx_v_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3176, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3176, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 3176, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "pandas/_libs/hashtable_class_helper.pxi":3163
 *         return self.na_position
 * 
 *     cpdef set_item(self, complex64_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_17set_item = {"set_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_17set_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_float_complex __pyx_v_key;
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key,&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3163, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3163, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, 1); __PYX_ERR(2, 3163, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_item") < 0)) __PYX_ERR(2, 3163, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_key = __Pyx_PyComplex_As___pyx_t_float_complex(values[0]); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3163, __pyx_L3_error)
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 3163, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, __pyx_nargs); __PYX_ERR(2, 3163, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_16set_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)__pyx_v_self), __pyx_v_key, __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, __pyx_t_float_complex __pyx_v_key, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_18Complex64HashTable_set_item(__pyx_v_self, __pyx_v_key, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3178
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_18Complex64HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  CYTHON_UNUSED int __pyx_v_ret;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3178, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_19set_na)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3178, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3178, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3182
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             khcomplex64_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3185
 *             khcomplex64_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_7 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_7)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3186
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         self.na_position = val
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 3186, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":3185
 *             khcomplex64_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3188
 *             raise NotImplementedError
 * 
 *         self.na_position = val             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->na_position = __pyx_v_val;

  /* "pandas/_libs/hashtable_class_helper.pxi":3178
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_19set_na = {"set_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_19set_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3178, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_na") < 0)) __PYX_ERR(2, 3178, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[0]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 3178, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_na", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 3178, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_18set_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_18Complex64HashTable_set_na(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3191
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const complex64_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_21map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_21map_locations = {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_21map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_21map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("map_locations (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3191, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3191, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "map_locations") < 0)) __PYX_ERR(2, 3191, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_float_complex__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 3192, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 3192, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__24;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("map_locations", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 3191, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_20map_locations(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_20map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  int __pyx_v_ret;
  khcomplex64_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  __pyx_t_5numpy_int64_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  khcomplex64_t __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("map_locations", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":3195
 *         # Used in libindex, safe_sort
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             khcomplex64_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":3196
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             khcomplex64_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3199
 *             khcomplex64_t val
 *             khiter_t k
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_2 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":3201
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_3 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_3)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3202
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 3202, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":3201
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3204
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":3205
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
        if (__pyx_v_self->uses_mask) {

          /* "pandas/_libs/hashtable_class_helper.pxi":3206
 *         with nogil:
 *             if self.uses_mask:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     if mask[i]:
 *                         na_position = i
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":3207
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_mask.shape[0];
            __pyx_t_3 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) ))) != 0);
            if (__pyx_t_3) {

              /* "pandas/_libs/hashtable_class_helper.pxi":3208
 *                 for i in range(n):
 *                     if mask[i]:
 *                         na_position = i             # <<<<<<<<<<<<<<
 *                     else:
 *                         val= to_khcomplex64_t(values[i])
 */
              __pyx_v_na_position = __pyx_v_i;

              /* "pandas/_libs/hashtable_class_helper.pxi":3207
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
              goto __pyx_L12;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":3210
 *                         na_position = i
 *                     else:
 *                         val= to_khcomplex64_t(values[i])             # <<<<<<<<<<<<<<
 *                         k = kh_put_complex64(self.table, val, &ret)
 *                         self.table.vals[k] = i
 */
            /*else*/ {
              __pyx_t_7 = __pyx_v_i;
              if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
              __pyx_t_8 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex64_t((*((__pyx_t_float_complex const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )))); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 3210, __pyx_L7_error)
              __pyx_v_val = __pyx_t_8;

              /* "pandas/_libs/hashtable_class_helper.pxi":3211
 *                     else:
 *                         val= to_khcomplex64_t(values[i])
 *                         k = kh_put_complex64(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = i
 *             else:
 */
              __pyx_v_k = kh_put_complex64(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

              /* "pandas/_libs/hashtable_class_helper.pxi":3212
 *                         val= to_khcomplex64_t(values[i])
 *                         k = kh_put_complex64(self.table, val, &ret)
 *                         self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *             else:
 *                 for i in range(n):
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
            }
            __pyx_L12:;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":3205
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
          goto __pyx_L9;
        }

        /* "pandas/_libs/hashtable_class_helper.pxi":3214
 *                         self.table.vals[k] = i
 *             else:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     val= to_khcomplex64_t(values[i])
 *                     k = kh_put_complex64(self.table, val, &ret)
 */
        /*else*/ {
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":3215
 *             else:
 *                 for i in range(n):
 *                     val= to_khcomplex64_t(values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_put_complex64(self.table, val, &ret)
 *                     self.table.vals[k] = i
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
            __pyx_t_8 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex64_t((*((__pyx_t_float_complex const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )))); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 3215, __pyx_L7_error)
            __pyx_v_val = __pyx_t_8;

            /* "pandas/_libs/hashtable_class_helper.pxi":3216
 *                 for i in range(n):
 *                     val= to_khcomplex64_t(values[i])
 *                     k = kh_put_complex64(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                     self.table.vals[k] = i
 *         self.na_position = na_position
 */
            __pyx_v_k = kh_put_complex64(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":3217
 *                     val= to_khcomplex64_t(values[i])
 *                     k = kh_put_complex64(self.table, val, &ret)
 *                     self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *         self.na_position = na_position
 * 
 */
            (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
          }
        }
        __pyx_L9:;
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":3204
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L7_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3218
 *                     k = kh_put_complex64(self.table, val, &ret)
 *                     self.table.vals[k] = i
 *         self.na_position = na_position             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __pyx_v_self->na_position = __pyx_v_na_position;

  /* "pandas/_libs/hashtable_class_helper.pxi":3191
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const complex64_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3220
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const complex64_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

/* Python wrapper */
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_23lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_23lookup = {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_23lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_23lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyArrayObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lookup (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3220, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3220, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lookup") < 0)) __PYX_ERR(2, 3220, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_float_complex__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 3221, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 3221, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__25;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lookup", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 3220, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_22lookup(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_22lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  CYTHON_UNUSED int __pyx_v_ret;
  khcomplex64_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __Pyx_memviewslice __pyx_v_locs = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  khcomplex64_t __pyx_t_14;
  int __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lookup", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":3225
 *         # Used in safe_sort, IndexEngine.get_indexer
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             khcomplex64_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":3226
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             khcomplex64_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3229
 *             khcomplex64_t val
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *             int8_t na_position = self.na_position
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 3229, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 3229, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3229, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 3229, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_locs = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":3230
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_8 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":3232
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_9 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_10 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_9 = __pyx_t_10;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3233
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 3233, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":3232
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3235
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":3236
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_11 = __pyx_t_1;
        for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
          __pyx_v_i = __pyx_t_12;

          /* "pandas/_libs/hashtable_class_helper.pxi":3237
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
          if (__pyx_v_self->uses_mask) {
          } else {
            __pyx_t_9 = __pyx_v_self->uses_mask;
            goto __pyx_L12_bool_binop_done;
          }
          __pyx_t_13 = __pyx_v_i;
          if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_mask.shape[0];
          __pyx_t_10 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_13 * __pyx_v_mask.strides[0]) ))) != 0);
          __pyx_t_9 = __pyx_t_10;
          __pyx_L12_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":3238
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position             # <<<<<<<<<<<<<<
 *                 else:
 *                     val = to_khcomplex64_t(values[i])
 */
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = __pyx_v_na_position;

            /* "pandas/_libs/hashtable_class_helper.pxi":3237
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
            goto __pyx_L11;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":3240
 *                     locs[i] = na_position
 *                 else:
 *                     val = to_khcomplex64_t(values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_complex64(self.table, val)
 *                     if k != self.table.n_buckets:
 */
          /*else*/ {
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_values.shape[0];
            __pyx_t_14 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex64_t((*((__pyx_t_float_complex const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_13 * __pyx_v_values.strides[0]) )))); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 3240, __pyx_L7_error)
            __pyx_v_val = __pyx_t_14;

            /* "pandas/_libs/hashtable_class_helper.pxi":3241
 *                 else:
 *                     val = to_khcomplex64_t(values[i])
 *                     k = kh_get_complex64(self.table, val)             # <<<<<<<<<<<<<<
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]
 */
            __pyx_v_k = kh_get_complex64(__pyx_v_self->table, __pyx_v_val);

            /* "pandas/_libs/hashtable_class_helper.pxi":3242
 *                     val = to_khcomplex64_t(values[i])
 *                     k = kh_get_complex64(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
            __pyx_t_9 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":3243
 *                     k = kh_get_complex64(self.table, val)
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     else:
 *                         locs[i] = -1
 */
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = (__pyx_v_self->table->vals[__pyx_v_k]);

              /* "pandas/_libs/hashtable_class_helper.pxi":3242
 *                     val = to_khcomplex64_t(values[i])
 *                     k = kh_get_complex64(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
              goto __pyx_L14;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":3245
 *                         locs[i] = self.table.vals[k]
 *                     else:
 *                         locs[i] = -1             # <<<<<<<<<<<<<<
 * 
 *         return np.asarray(locs)
 */
            /*else*/ {
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = -1;
            }
            __pyx_L14:;
          }
          __pyx_L11:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":3235
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L7_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3247
 *                         locs[i] = -1
 * 
 *         return np.asarray(locs)             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_locs, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_15 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_15 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_15, 1+__pyx_t_15);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3247, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 3247, __pyx_L1_error)
  __pyx_r = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3220
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const complex64_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_locs, 1);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3249
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const complex64_t[:] values, Complex64Vector uniques,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_25_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_18Complex64HashTable_24_unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[complex64]\n            Array of values of which unique will be calculated\n        uniques : Complex64Vector\n            Vector into which uniques will be written\n        count_prior : Py_ssize_t, default 0\n            Number of existing entries in uniques\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        ignore_na : bool, default False\n            Whether NA-values should be ignored for calculating the uniques. If\n            True, the labels corresponding to missing values will be set to\n            na_sentinel.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        use_result_mask: bool, default False\n            Whether to create a result mask for the unique values. Not supported\n            with return_inverse=True.\n\n        Returns\n        -------\n        uniques : ndarray[complex64]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse=True)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if use_result_mask is true\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_25_unique = {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_25_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_18Complex64HashTable_24_unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_25_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  int __pyx_v_ignore_na;
  PyObject *__pyx_v_mask = 0;
  int __pyx_v_return_inverse;
  int __pyx_v_use_result_mask;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[9] = {0,0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_ignore_na,&__pyx_n_s_mask,&__pyx_n_s_return_inverse,&__pyx_n_s_use_result_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":3253
 *     def _unique(self, const complex64_t[:] values, Complex64Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));

    /* "pandas/_libs/hashtable_class_helper.pxi":3254
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[6] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3249, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3249, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, 1); __PYX_ERR(2, 3249, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3249, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3249, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3249, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3249, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[6] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3249, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[7] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3249, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_use_result_mask);
          if (value) { values[8] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3249, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_unique") < 0)) __PYX_ERR(2, 3249, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_float_complex__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 3251, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 3252, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 3252, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    if (values[5]) {
      __pyx_v_ignore_na = __Pyx_PyObject_IsTrue(values[5]); if (unlikely((__pyx_v_ignore_na == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 3253, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":3253
 *     def _unique(self, const complex64_t[:] values, Complex64Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
      __pyx_v_ignore_na = ((int)0);
    }
    __pyx_v_mask = values[6];
    if (values[7]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[7]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 3254, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":3254
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
      __pyx_v_return_inverse = ((int)0);
    }
    if (values[8]) {
      __pyx_v_use_result_mask = __Pyx_PyObject_IsTrue(values[8]); if (unlikely((__pyx_v_use_result_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 3254, __pyx_L3_error)
    } else {
      __pyx_v_use_result_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, __pyx_nargs); __PYX_ERR(2, 3249, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector, 1, "uniques", 0))) __PYX_ERR(2, 3251, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_24_unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_ignore_na, __pyx_v_mask, __pyx_v_return_inverse, __pyx_v_use_result_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":3249
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const complex64_t[:] values, Complex64Vector uniques,
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_24_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_idx;
  Py_ssize_t __pyx_v_count;
  Py_ssize_t __pyx_v_n;
  __Pyx_memviewslice __pyx_v_labels = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_ret;
  khcomplex64_t __pyx_v_val;
  khcomplex64_t __pyx_v_na_value2;
  khiter_t __pyx_v_k;
  __pyx_t_6pandas_5_libs_9hashtable_Complex64VectorData *__pyx_v_ud;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_result_mask = 0;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_v_rmd;
  int __pyx_v_use_na_value;
  int __pyx_v_use_mask;
  int __pyx_v_seen_na;
  __Pyx_memviewslice __pyx_v_mask_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_6pandas_5_libs_9hashtable_Complex64VectorData *__pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_t_11;
  int __pyx_t_12;
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_float_complex __pyx_t_14;
  khcomplex64_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  Py_ssize_t __pyx_t_18;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":3298
 *         """
 *         cdef:
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)             # <<<<<<<<<<<<<<
 *             intp_t[::1] labels
 *             int ret = 0
 */
  __pyx_v_count = __pyx_v_count_prior;
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":3300
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)
 *             intp_t[::1] labels
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             khcomplex64_t val, na_value2
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3306
 *             UInt8Vector result_mask
 *             UInt8VectorData *rmd
 *             bint use_na_value, use_mask, seen_na = False             # <<<<<<<<<<<<<<
 *             uint8_t[:] mask_values
 * 
 */
  __pyx_v_seen_na = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3309
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3310
 * 
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 3310, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 3310, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3310, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 3310, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_labels = __pyx_t_7;
    __pyx_t_7.memview = NULL;
    __pyx_t_7.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":3309
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3311
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data             # <<<<<<<<<<<<<<
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 */
  __pyx_t_8 = __pyx_v_uniques->data;
  __pyx_v_ud = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":3312
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 *         use_na_value = na_value is not None             # <<<<<<<<<<<<<<
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 */
  __pyx_t_9 = (__pyx_v_na_value != Py_None);
  __pyx_v_use_na_value = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":3313
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None             # <<<<<<<<<<<<<<
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover
 */
  __pyx_t_9 = (__pyx_v_mask != Py_None);
  __pyx_v_use_mask = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":3314
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  __pyx_t_10 = (!__pyx_v_use_mask);
  if (__pyx_t_10) {
  } else {
    __pyx_t_9 = __pyx_t_10;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_use_result_mask;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3315
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         if use_result_mask and return_inverse:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 3315, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":3314
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3317
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_use_result_mask) {
  } else {
    __pyx_t_9 = __pyx_v_use_result_mask;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_return_inverse;
  __pyx_L8_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3318
 * 
 *         if use_result_mask and return_inverse:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         result_mask = UInt8Vector()
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 3318, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":3317
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3320
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         result_mask = UInt8Vector()             # <<<<<<<<<<<<<<
 *         rmd = result_mask.data
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_v_result_mask = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3321
 * 
 *         result_mask = UInt8Vector()
 *         rmd = result_mask.data             # <<<<<<<<<<<<<<
 * 
 *         if use_mask:
 */
  __pyx_t_11 = __pyx_v_result_mask->data;
  __pyx_v_rmd = __pyx_t_11;

  /* "pandas/_libs/hashtable_class_helper.pxi":3323
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  if (__pyx_v_use_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3324
 * 
 *         if use_mask:
 *             mask_values = mask.view("uint8")             # <<<<<<<<<<<<<<
 * 
 *         if use_na_value:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_mask, __pyx_n_s_view); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3324, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    __pyx_t_12 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_12 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_uint8};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_12, 1+__pyx_t_12);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3324, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(2, 3324, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_mask_values = __pyx_t_13;
    __pyx_t_13.memview = NULL;
    __pyx_t_13.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":3323
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3326
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
  if (__pyx_v_use_na_value) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3332
 *             # for the parameter. To please the compiler, we use na_value2,
 *             # which is only used if it's *specified*.
 *             na_value2 = to_khcomplex64_t(na_value)             # <<<<<<<<<<<<<<
 *         else:
 *             na_value2 = to_khcomplex64_t(0)
 */
    __pyx_t_14 = __Pyx_PyComplex_As___pyx_t_float_complex(__pyx_v_na_value); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3332, __pyx_L1_error)
    __pyx_t_15 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex64_t(__pyx_t_14); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3332, __pyx_L1_error)
    __pyx_v_na_value2 = __pyx_t_15;

    /* "pandas/_libs/hashtable_class_helper.pxi":3326
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
    goto __pyx_L11;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3334
 *             na_value2 = to_khcomplex64_t(na_value)
 *         else:
 *             na_value2 = to_khcomplex64_t(0)             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
  /*else*/ {
    __pyx_t_15 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex64_t(__pyx_t_float_complex_from_parts(0, 0)); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3334, __pyx_L1_error)
    __pyx_v_na_value2 = __pyx_t_15;
  }
  __pyx_L11:;

  /* "pandas/_libs/hashtable_class_helper.pxi":3336
 *             na_value2 = to_khcomplex64_t(0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = to_khcomplex64_t(values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":3337
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 val = to_khcomplex64_t(values[i])
 * 
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_16 = __pyx_t_1;
        for (__pyx_t_17 = 0; __pyx_t_17 < __pyx_t_16; __pyx_t_17+=1) {
          __pyx_v_i = __pyx_t_17;

          /* "pandas/_libs/hashtable_class_helper.pxi":3338
 *         with nogil:
 *             for i in range(n):
 *                 val = to_khcomplex64_t(values[i])             # <<<<<<<<<<<<<<
 * 
 *                 if ignore_na and use_mask:
 */
          __pyx_t_18 = __pyx_v_i;
          __pyx_t_15 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex64_t((*((__pyx_t_float_complex const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_18 * __pyx_v_values.strides[0]) )))); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 3338, __pyx_L13_error)
          __pyx_v_val = __pyx_t_15;

          /* "pandas/_libs/hashtable_class_helper.pxi":3340
 *                 val = to_khcomplex64_t(values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L18_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_mask;
          __pyx_L18_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":3341
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 3341, __pyx_L13_error) }
            __pyx_t_18 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_18 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":3342
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                         continue
 *                 elif ignore_na and (
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 3342, __pyx_L13_error) }
              __pyx_t_18 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_18)) )) = __pyx_v_na_sentinel;

              /* "pandas/_libs/hashtable_class_helper.pxi":3343
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 *                         continue             # <<<<<<<<<<<<<<
 *                 elif ignore_na and (
 *                    is_nan_khcomplex64_t(val) or
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":3341
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":3340
 *                 val = to_khcomplex64_t(values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
            goto __pyx_L17;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":3344
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_khcomplex64_t(val) or
 *                    (use_na_value and are_equivalent_khcomplex64_t(val, na_value2))
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":3345
 *                         continue
 *                 elif ignore_na and (
 *                    is_nan_khcomplex64_t(val) or             # <<<<<<<<<<<<<<
 *                    (use_na_value and are_equivalent_khcomplex64_t(val, na_value2))
 *                 ):
 */
          __pyx_t_10 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_khcomplex64_t(__pyx_v_val); if (unlikely(__pyx_t_10 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 3345, __pyx_L13_error)
          if (!__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":3346
 *                 elif ignore_na and (
 *                    is_nan_khcomplex64_t(val) or
 *                    (use_na_value and are_equivalent_khcomplex64_t(val, na_value2))             # <<<<<<<<<<<<<<
 *                 ):
 *                     # if missing values do not count as unique values (i.e. if
 */
          if (__pyx_v_use_na_value) {
          } else {
            __pyx_t_9 = __pyx_v_use_na_value;
            goto __pyx_L21_bool_binop_done;
          }
          __pyx_t_10 = kh_complex_hash_equal(__pyx_v_val, __pyx_v_na_value2);
          __pyx_t_9 = __pyx_t_10;
          __pyx_L21_bool_binop_done:;

          /* "pandas/_libs/hashtable_class_helper.pxi":3344
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_khcomplex64_t(val) or
 *                    (use_na_value and are_equivalent_khcomplex64_t(val, na_value2))
 */
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":3351
 *                     # ignore_na is True), skip the hashtable entry for them,
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 3351, __pyx_L13_error) }
            __pyx_t_18 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_18)) )) = __pyx_v_na_sentinel;

            /* "pandas/_libs/hashtable_class_helper.pxi":3352
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel
 *                     continue             # <<<<<<<<<<<<<<
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 */
            goto __pyx_L15_continue;

            /* "pandas/_libs/hashtable_class_helper.pxi":3344
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_khcomplex64_t(val) or
 *                    (use_na_value and are_equivalent_khcomplex64_t(val, na_value2))
 */
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":3353
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          __pyx_t_10 = (!__pyx_v_ignore_na);
          if (__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L25_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_result_mask;
          __pyx_L25_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":3354
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 3354, __pyx_L13_error) }
            __pyx_t_18 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_18 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":3355
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_class_helper.pxi":3356
 *                     if mask_values[i]:
 *                         if seen_na:
 *                             continue             # <<<<<<<<<<<<<<
 * 
 *                         seen_na = True
 */
                goto __pyx_L15_continue;

                /* "pandas/_libs/hashtable_class_helper.pxi":3355
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":3358
 *                             continue
 * 
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         if needs_resize(ud):
 *                             with gil:
 */
              __pyx_v_seen_na = 1;

              /* "pandas/_libs/hashtable_class_helper.pxi":3359
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              __pyx_t_9 = __pyx_fuse_11__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 3359, __pyx_L13_error)
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_class_helper.pxi":3360
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                {
                    #ifdef WITH_THREAD
                    PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                    #endif
                    /*try:*/ {

                      /* "pandas/_libs/hashtable_class_helper.pxi":3361
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":3362
 *                             with gil:
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3362, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 3362, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":3361
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":3365
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex64Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3365, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":3366
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":3367
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3367, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 3367, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":3366
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":3370
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                         append_data_complex64(ud, val)
 *                         append_data_uint8(rmd, 1)
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3370, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":3360
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    /*finally:*/ {
                      /*normal exit:*/{
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L34;
                      }
                      __pyx_L33_error: {
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L13_error;
                      }
                      __pyx_L34:;
                    }
                }

                /* "pandas/_libs/hashtable_class_helper.pxi":3359
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":3371
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                         append_data_complex64(ud, val)             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 1)
 *                         continue
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_complex64(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 3371, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":3372
 *                                 result_mask.resize()
 *                         append_data_complex64(ud, val)
 *                         append_data_uint8(rmd, 1)             # <<<<<<<<<<<<<<
 *                         continue
 * 
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 1); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 3372, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":3373
 *                         append_data_complex64(ud, val)
 *                         append_data_uint8(rmd, 1)
 *                         continue             # <<<<<<<<<<<<<<
 * 
 *                 k = kh_get_complex64(self.table, val)
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":3354
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":3353
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          }
          __pyx_L17:;

          /* "pandas/_libs/hashtable_class_helper.pxi":3375
 *                         continue
 * 
 *                 k = kh_get_complex64(self.table, val)             # <<<<<<<<<<<<<<
 * 
 *                 if k == self.table.n_buckets:
 */
          __pyx_v_k = kh_get_complex64(__pyx_v_self->table, __pyx_v_val);

          /* "pandas/_libs/hashtable_class_helper.pxi":3377
 *                 k = kh_get_complex64(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_complex64(self.table, val, &ret)
 */
          __pyx_t_9 = (__pyx_v_k == __pyx_v_self->table->n_buckets);
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":3379
 *                 if k == self.table.n_buckets:
 *                     # k hasn't been seen yet
 *                     k = kh_put_complex64(self.table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *                     if needs_resize(ud):
 */
            __pyx_v_k = kh_put_complex64(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":3381
 *                     k = kh_put_complex64(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            __pyx_t_9 = __pyx_fuse_11__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 3381, __pyx_L13_error)
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":3382
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
              {
                  #ifdef WITH_THREAD
                  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                  #endif
                  /*try:*/ {

                    /* "pandas/_libs/hashtable_class_helper.pxi":3383
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":3384
 *                         with gil:
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 */
                      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3384, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                      __PYX_ERR(2, 3384, __pyx_L42_error)

                      /* "pandas/_libs/hashtable_class_helper.pxi":3383
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":3387
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()             # <<<<<<<<<<<<<<
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 */
                    __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex64Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3387, __pyx_L42_error)
                    __Pyx_GOTREF(__pyx_t_6);
                    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                    /* "pandas/_libs/hashtable_class_helper.pxi":3388
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    if (__pyx_v_use_result_mask) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":3389
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":3390
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3390, __pyx_L42_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 3390, __pyx_L42_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":3389
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":3393
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                     append_data_complex64(ud, val)
 *                     if use_result_mask:
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3393, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":3388
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    }
                  }

                  /* "pandas/_libs/hashtable_class_helper.pxi":3382
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
                  /*finally:*/ {
                    /*normal exit:*/{
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L43;
                    }
                    __pyx_L42_error: {
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L13_error;
                    }
                    __pyx_L43:;
                  }
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":3381
 *                     k = kh_put_complex64(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":3394
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                     append_data_complex64(ud, val)             # <<<<<<<<<<<<<<
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)
 */
            __pyx_f_6pandas_5_libs_9hashtable_append_data_complex64(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 3394, __pyx_L13_error)

            /* "pandas/_libs/hashtable_class_helper.pxi":3395
 *                                 result_mask.resize()
 *                     append_data_complex64(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            if (__pyx_v_use_result_mask) {

              /* "pandas/_libs/hashtable_class_helper.pxi":3396
 *                     append_data_complex64(ud, val)
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)             # <<<<<<<<<<<<<<
 * 
 *                     if return_inverse:
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 0); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 3396, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":3395
 *                                 result_mask.resize()
 *                     append_data_complex64(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":3398
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            if (__pyx_v_return_inverse) {

              /* "pandas/_libs/hashtable_class_helper.pxi":3399
 * 
 *                     if return_inverse:
 *                         self.table.vals[k] = count             # <<<<<<<<<<<<<<
 *                         labels[i] = count
 *                         count += 1
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":3400
 *                     if return_inverse:
 *                         self.table.vals[k] = count
 *                         labels[i] = count             # <<<<<<<<<<<<<<
 *                         count += 1
 *                 elif return_inverse:
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 3400, __pyx_L13_error) }
              __pyx_t_18 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_18)) )) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":3401
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 *                         count += 1             # <<<<<<<<<<<<<<
 *                 elif return_inverse:
 *                     # k falls into a previous bucket
 */
              __pyx_v_count = (__pyx_v_count + 1);

              /* "pandas/_libs/hashtable_class_helper.pxi":3398
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":3377
 *                 k = kh_get_complex64(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_complex64(self.table, val, &ret)
 */
            goto __pyx_L37;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":3402
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          if (__pyx_v_return_inverse) {

            /* "pandas/_libs/hashtable_class_helper.pxi":3405
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     labels[i] = idx
 * 
 */
            __pyx_v_idx = (__pyx_v_self->table->vals[__pyx_v_k]);

            /* "pandas/_libs/hashtable_class_helper.pxi":3406
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]
 *                     labels[i] = idx             # <<<<<<<<<<<<<<
 * 
 *         if return_inverse:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 3406, __pyx_L13_error) }
            __pyx_t_18 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_18)) )) = __pyx_v_idx;

            /* "pandas/_libs/hashtable_class_helper.pxi":3402
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          }
          __pyx_L37:;
          __pyx_L15_continue:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":3336
 *             na_value2 = to_khcomplex64_t(0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = to_khcomplex64_t(values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L14;
        }
        __pyx_L13_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L14:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3408
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3409
 * 
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray             # <<<<<<<<<<<<<<
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex64Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3409, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundLocalError("labels"); __PYX_ERR(2, 3409, __pyx_L1_error) }
    __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_labels, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3409, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_base); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3409, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3409, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_6);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_6)) __PYX_ERR(2, 3409, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4)) __PYX_ERR(2, 3409, __pyx_L1_error);
    __pyx_t_6 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":3408
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3410
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  if (__pyx_v_use_result_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3411
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()             # <<<<<<<<<<<<<<
 *         return uniques.to_array()
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex64Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->to_array(__pyx_v_result_mask, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3411, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2)) __PYX_ERR(2, 3411, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4)) __PYX_ERR(2, 3411, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":3410
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3412
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()             # <<<<<<<<<<<<<<
 * 
 *     def unique(self, const complex64_t[:] values, bint return_inverse=False, object mask=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex64Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3412, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3249
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const complex64_t[:] values, Complex64Vector uniques,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_13, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_labels, 1);
  __Pyx_XDECREF((PyObject *)__pyx_v_result_mask);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask_values, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3414
 *         return uniques.to_array()
 * 
 *     def unique(self, const complex64_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_27unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_18Complex64HashTable_26unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[complex64]\n            Array of values of which unique will be calculated\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n\n        Returns\n        -------\n        uniques : ndarray[complex64]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if mask is given as input\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_27unique = {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_27unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_18Complex64HashTable_26unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_27unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_return_inverse;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_return_inverse,&__pyx_n_s_mask,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3414, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3414, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3414, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "unique") < 0)) __PYX_ERR(2, 3414, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_float_complex__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 3414, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 3414, __pyx_L3_error)
    } else {
      __pyx_v_return_inverse = ((int)0);
    }
    __pyx_v_mask = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("unique", 0, 1, 3, __pyx_nargs); __PYX_ERR(2, 3414, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_26unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_return_inverse, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_26unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_uniques = NULL;
  int __pyx_v_use_result_mask;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":3438
 *             The mask for the result values.
 *         """
 *         uniques = Complex64Vector()             # <<<<<<<<<<<<<<
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3438, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3439
 *         """
 *         uniques = Complex64Vector()
 *         use_result_mask = True if mask is not None else False             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 */
  __pyx_t_3 = (__pyx_v_mask != Py_None);
  if (__pyx_t_3) {
    __pyx_t_2 = 1;
  } else {
    __pyx_t_2 = 0;
  }
  __pyx_v_use_result_mask = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":3440
 *         uniques = Complex64Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get___pyx_t_float_complex__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4)) __PYX_ERR(2, 3440, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 3440, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ignore_na, Py_False) < 0) __PYX_ERR(2, 3440, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3441
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const complex64_t[:] values, Py_ssize_t na_sentinel=-1,
 */
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_return_inverse); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3441, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return_inverse, __pyx_t_6) < 0) __PYX_ERR(2, 3440, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 3440, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_use_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3441, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_use_result_mask, __pyx_t_6) < 0) __PYX_ERR(2, 3440, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3440
 *         uniques = Complex64Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3414
 *         return uniques.to_array()
 * 
 *     def unique(self, const complex64_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3443
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const complex64_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_29factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_18Complex64HashTable_28factorize, "\n        Calculate unique values and labels (no sorting!)\n\n        Missing values are not included in the \"uniques\" for this method.\n        The labels for any missing values will be set to \"na_sentinel\"\n\n        Parameters\n        ----------\n        values : ndarray[complex64]\n            Array of values of which unique will be calculated\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n\n        Returns\n        -------\n        uniques : ndarray[complex64]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t]\n            The labels from values to uniques\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_29factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_29factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_18Complex64HashTable_28factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_29factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  PyObject *__pyx_v_ignore_na = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,&__pyx_n_s_ignore_na,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":3444
 * 
 *     def factorize(self, const complex64_t[:] values, Py_ssize_t na_sentinel=-1,
 *                   object na_value=None, object mask=None, ignore_na=True):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_True));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3443, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3443, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3443, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3443, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3443, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 3443, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_float_complex__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 3443, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 3443, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
    __pyx_v_ignore_na = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 5, __pyx_nargs); __PYX_ERR(2, 3443, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_28factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask, __pyx_v_ignore_na);

  /* "pandas/_libs/hashtable_class_helper.pxi":3443
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const complex64_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_28factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_uniques_vector = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":3474
 *             The labels from values to uniques
 *         """
 *         uniques_vector = Complex64Vector()             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3474, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques_vector = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3475
 *         """
 *         uniques_vector = Complex64Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get___pyx_t_float_complex__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 3475, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques_vector);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques_vector))) __PYX_ERR(2, 3475, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 3475, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3476
 *         uniques_vector = Complex64Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,             # <<<<<<<<<<<<<<
 *                             return_inverse=True)
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 3475, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, __pyx_v_ignore_na) < 0) __PYX_ERR(2, 3475, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 3475, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3477
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)             # <<<<<<<<<<<<<<
 * 
 *     def get_labels(self, const complex64_t[:] values, Complex64Vector uniques,
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 3475, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3475
 *         """
 *         uniques_vector = Complex64Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3443
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const complex64_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3479
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const complex64_t[:] values, Complex64Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_31get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_31get_labels = {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_31get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_31get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_labels (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":3481
 *     def get_labels(self, const complex64_t[:] values, Complex64Vector uniques,
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3479, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3479, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, 1); __PYX_ERR(2, 3479, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3479, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3479, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3479, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3479, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_labels") < 0)) __PYX_ERR(2, 3479, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_float_complex__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 3479, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 3480, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 3480, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    __pyx_v_mask = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, __pyx_nargs); __PYX_ERR(2, 3479, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector, 1, "uniques", 0))) __PYX_ERR(2, 3479, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_30get_labels(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":3479
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const complex64_t[:] values, Complex64Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_30get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_v_labels = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_labels", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":3483
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get___pyx_t_float_complex__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 3483, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 3483, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_count_prior); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_count_prior, __pyx_t_4) < 0) __PYX_ERR(2, 3483, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3484
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,             # <<<<<<<<<<<<<<
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 3483, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 3483, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3485
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, Py_True) < 0) __PYX_ERR(2, 3483, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 3483, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 3483, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3483
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3483, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
    PyObject* sequence = __pyx_t_4;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(2, 3483, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3483, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3483, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3483, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
    index = 0; __pyx_t_2 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_1), 2) < 0) __PYX_ERR(2, 3483, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(2, 3483, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v__ = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_labels = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3486
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_labels);
  __pyx_r = __pyx_v_labels;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3479
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const complex64_t[:] values, Complex64Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XDECREF(__pyx_v_labels);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_33__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_33__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_33__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_33__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_32__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_32__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_35__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_35__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_35__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_35__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_34__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18Complex64HashTable_34__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3495
 *         Complex64Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = Complex64HashTable(size_hint)
 *         self.uniques = Complex64Vector()
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_size_hint = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3495, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 3495, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_size_hint = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 3495, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_size_hint), (&PyInt_Type), 0, "size_hint", 1))) __PYX_ERR(2, 3495, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *)__pyx_v_self), __pyx_v_size_hint);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":3496
 * 
 *     def __cinit__(self, size_hint: int):
 *         self.table = Complex64HashTable(size_hint)             # <<<<<<<<<<<<<<
 *         self.uniques = Complex64Vector()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable), __pyx_v_size_hint); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3496, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3497
 *     def __cinit__(self, size_hint: int):
 *         self.table = Complex64HashTable(size_hint)
 *         self.uniques = Complex64Vector()             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const khcomplex64_t[:] values,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3497, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3495
 *         Complex64Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = Complex64HashTable(size_hint)
 *         self.uniques = Complex64Vector()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3499
 *         self.uniques = Complex64Vector()
 * 
 *     def factorize(self, const khcomplex64_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_19Complex64Factorizer_2factorize, "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = Complex64Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"complex64\"), na_sentinel=20)\n        array([0, 1, 2])\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_19Complex64Factorizer_3factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_19Complex64Factorizer_2factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_v_na_sentinel = 0;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_neg_1));

    /* "pandas/_libs/hashtable_class_helper.pxi":3500
 * 
 *     def factorize(self, const khcomplex64_t[:] values,
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:             # <<<<<<<<<<<<<<
 *         """
 *         Returns
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3499, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3499, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3499, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3499, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 3499, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn_khcomplex64_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 3499, __pyx_L3_error)
    __pyx_v_na_sentinel = values[1];
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 4, __pyx_nargs); __PYX_ERR(2, 3499, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_2factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":3499
 *         self.uniques = Complex64Vector()
 * 
 *     def factorize(self, const khcomplex64_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  PyArrayObject *__pyx_v_labels = 0;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_uniques = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_labels;
  __Pyx_Buffer __pyx_pybuffer_labels;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);
  __pyx_pybuffer_labels.pybuffer.buf = NULL;
  __pyx_pybuffer_labels.refcount = 0;
  __pyx_pybuffernd_labels.data = NULL;
  __pyx_pybuffernd_labels.rcbuffer = &__pyx_pybuffer_labels;

  /* "pandas/_libs/hashtable_class_helper.pxi":3517
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = Complex64Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  if (__pyx_v_self->uniques->__pyx_base.external_view_exists) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3518
 * 
 *         if self.uniques.external_view_exists:
 *             uniques = Complex64Vector()             # <<<<<<<<<<<<<<
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 */
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3518, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":3519
 *         if self.uniques.external_view_exists:
 *             uniques = Complex64Vector()
 *             uniques.extend(self.uniques.to_array())             # <<<<<<<<<<<<<<
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 */
    __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex64Vector *)__pyx_v_self->uniques->__pyx_vtab)->to_array(__pyx_v_self->uniques, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3519, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn_khcomplex64_t__const__(__pyx_t_1, 0); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(2, 3519, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex64Vector *)__pyx_v_uniques->__pyx_vtab)->extend(__pyx_v_uniques, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3519, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
    __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":3520
 *             uniques = Complex64Vector()
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques             # <<<<<<<<<<<<<<
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 */
    __Pyx_INCREF((PyObject *)__pyx_v_uniques);
    __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
    __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
    __pyx_v_self->uniques = __pyx_v_uniques;

    /* "pandas/_libs/hashtable_class_helper.pxi":3517
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = Complex64Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3521
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->table), __pyx_n_s_get_labels); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn_khcomplex64_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "pandas/_libs/hashtable_class_helper.pxi":3522
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,             # <<<<<<<<<<<<<<
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_self->__pyx_base.count); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3522, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "pandas/_libs/hashtable_class_helper.pxi":3521
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_5 = PyTuple_New(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3)) __PYX_ERR(2, 3521, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self->uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_self->uniques))) __PYX_ERR(2, 3521, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_4)) __PYX_ERR(2, 3521, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_na_sentinel);
  __Pyx_GIVEREF(__pyx_v_na_sentinel);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_v_na_sentinel)) __PYX_ERR(2, 3521, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3523
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)             # <<<<<<<<<<<<<<
 *         self.count = len(self.uniques)
 *         return labels
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 3523, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 3523, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3521
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3521, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 3521, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
    __pyx_t_7 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_7 < 0)) {
      PyErr_Fetch(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_v_labels, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      }
      __pyx_t_8 = __pyx_t_9 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_labels.diminfo[0].strides = __pyx_pybuffernd_labels.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_labels.diminfo[0].shape = __pyx_pybuffernd_labels.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(2, 3521, __pyx_L1_error)
  }
  __pyx_t_6 = 0;
  __pyx_v_labels = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3524
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  __pyx_t_3 = ((PyObject *)__pyx_v_self->uniques);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_11 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(2, 3524, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_self->__pyx_base.count = __pyx_t_11;

  /* "pandas/_libs/hashtable_class_helper.pxi":3525
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * cdef class Float32HashTable(HashTable):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_labels);
  __pyx_r = ((PyObject *)__pyx_v_labels);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3499
 *         self.uniques = Complex64Vector()
 * 
 *     def factorize(self, const khcomplex64_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_labels);
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3492
 * cdef class Complex64Factorizer(Factorizer):
 *     cdef public:
 *         Complex64HashTable table             # <<<<<<<<<<<<<<
 *         Complex64Vector uniques
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_5table_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_5table_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_5table___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->table);
  __pyx_r = ((PyObject *)__pyx_v_self->table);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_5table_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable))))) __PYX_ERR(2, 3492, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64Factorizer.table.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_5table_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_5table_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_5table_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3493
 *     cdef public:
 *         Complex64HashTable table
 *         Complex64Vector uniques             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, size_hint: int):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_7uniques_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_7uniques_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_7uniques___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __pyx_r = ((PyObject *)__pyx_v_self->uniques);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_7uniques_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector))))) __PYX_ERR(2, 3493, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64Factorizer.uniques.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_7uniques_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_7uniques_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_7uniques_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_19Complex64Factorizer_5__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_4__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64Factorizer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_19Complex64Factorizer_7__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_6__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_19Complex64Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Complex64Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3529
 * cdef class Float32HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_float32()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __pyx_t_5numpy_int64_t __pyx_v_size_hint;
  int __pyx_v_uses_mask;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,&__pyx_n_s_uses_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3529, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uses_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3529, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 3529, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_size_hint = __Pyx_PyInt_As_npy_int64(values[0]); if (unlikely((__pyx_v_size_hint == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 3529, __pyx_L3_error)
    } else {
      __pyx_v_size_hint = ((__pyx_t_5numpy_int64_t)1);
    }
    if (values[1]) {
      __pyx_v_uses_mask = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_uses_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 3529, __pyx_L3_error)
    } else {
      __pyx_v_uses_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 0, 2, __pyx_nargs); __PYX_ERR(2, 3529, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)__pyx_v_self), __pyx_v_size_hint, __pyx_v_uses_mask);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  khuint_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __pyx_t_5numpy_int64_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":3530
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_float32()             # <<<<<<<<<<<<<<
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_float32(self.table, size_hint)
 */
  __pyx_v_self->table = kh_init_float32();

  /* "pandas/_libs/hashtable_class_helper.pxi":3531
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_float32()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)             # <<<<<<<<<<<<<<
 *         kh_resize_float32(self.table, size_hint)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = kh_needed_n_buckets(__pyx_v_size_hint);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_1, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3531, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(2, 3531, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_6) {
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_5 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3531, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_int64(__pyx_t_3); if (unlikely((__pyx_t_7 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 3531, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_size_hint = __pyx_t_7;

  /* "pandas/_libs/hashtable_class_helper.pxi":3532
 *         self.table = kh_init_float32()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_float32(self.table, size_hint)             # <<<<<<<<<<<<<<
 * 
 *         self.uses_mask = uses_mask
 */
  kh_resize_float32(__pyx_v_self->table, __pyx_v_size_hint);

  /* "pandas/_libs/hashtable_class_helper.pxi":3534
 *         kh_resize_float32(self.table, size_hint)
 * 
 *         self.uses_mask = uses_mask             # <<<<<<<<<<<<<<
 *         self.na_position = -1
 * 
 */
  __pyx_v_self->uses_mask = __pyx_v_uses_mask;

  /* "pandas/_libs/hashtable_class_helper.pxi":3535
 * 
 *         self.uses_mask = uses_mask
 *         self.na_position = -1             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
  __pyx_v_self->na_position = -1LL;

  /* "pandas/_libs/hashtable_class_helper.pxi":3529
 * cdef class Float32HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_float32()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3537
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_3__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_3__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_2__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  long __pyx_t_1;
  int __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":3538
 * 
 *     def __len__(self) -> int:
 *         return self.table.size + (0 if self.na_position == -1 else 1)             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_2 = (__pyx_v_self->na_position == -1LL);
  if (__pyx_t_2) {
    __pyx_t_1 = 0;
  } else {
    __pyx_t_1 = 1;
  }
  __pyx_r = (__pyx_v_self->table->size + __pyx_t_1);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3537
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3540
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_float32(self.table)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_5__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_5__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_4__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":3541
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_float32(self.table)
 *             self.table = NULL
 */
  __pyx_t_1 = (__pyx_v_self->table != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3542
 *     def __dealloc__(self):
 *         if self.table is not NULL:
 *             kh_destroy_float32(self.table)             # <<<<<<<<<<<<<<
 *             self.table = NULL
 * 
 */
    kh_destroy_float32(__pyx_v_self->table);

    /* "pandas/_libs/hashtable_class_helper.pxi":3543
 *         if self.table is not NULL:
 *             kh_destroy_float32(self.table)
 *             self.table = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __contains__(self, object key) -> bool:
 */
    __pyx_v_self->table = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":3541
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_float32(self.table)
 *             self.table = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3540
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_float32(self.table)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":3545
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__contains__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_6__contains__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)__pyx_v_self), ((PyObject *)__pyx_v_key));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, PyObject *__pyx_v_key) {
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_float32_t __pyx_v_ckey;
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  __pyx_t_5numpy_float32_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3552
 *             float32_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_1 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_7missing_checknull(__pyx_v_key, 0, NULL); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3552, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3553
 * 
 *         if self.uses_mask and checknull(key):
 *             return -1 != self.na_position             # <<<<<<<<<<<<<<
 * 
 *         ckey = (key)
 */
    __pyx_r = (-1LL != __pyx_v_self->na_position);
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":3552
 *             float32_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3555
 *             return -1 != self.na_position
 * 
 *         ckey = (key)             # <<<<<<<<<<<<<<
 *         k = kh_get_float32(self.table, ckey)
 *         return k != self.table.n_buckets
 */
  __pyx_t_3 = __pyx_PyFloat_AsFloat(__pyx_v_key); if (unlikely((__pyx_t_3 == ((npy_float32)-1)) && PyErr_Occurred())) __PYX_ERR(2, 3555, __pyx_L1_error)
  __pyx_v_ckey = __pyx_t_3;

  /* "pandas/_libs/hashtable_class_helper.pxi":3556
 * 
 *         ckey = (key)
 *         k = kh_get_float32(self.table, ckey)             # <<<<<<<<<<<<<<
 *         return k != self.table.n_buckets
 * 
 */
  __pyx_v_k = kh_get_float32(__pyx_v_self->table, __pyx_v_ckey);

  /* "pandas/_libs/hashtable_class_helper.pxi":3557
 *         ckey = (key)
 *         k = kh_get_float32(self.table, ckey)
 *         return k != self.table.n_buckets             # <<<<<<<<<<<<<<
 * 
 *     def sizeof(self, deep: bool = False) -> int:
 */
  __pyx_r = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3545
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3559
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_16Float32HashTable_8sizeof, " return the size of my table in bytes ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_9sizeof = {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float32HashTable_8sizeof};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_deep = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sizeof (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_deep,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_deep);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3559, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "sizeof") < 0)) __PYX_ERR(2, 3559, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_deep = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sizeof", 0, 0, 1, __pyx_nargs); __PYX_ERR(2, 3559, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_8sizeof(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)__pyx_v_self), __pyx_v_deep);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep) {
  PyObject *__pyx_v_overhead = NULL;
  PyObject *__pyx_v_for_flags = NULL;
  PyObject *__pyx_v_for_pairs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  long __pyx_t_2;
  long __pyx_t_3;
  long __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sizeof", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":3561
 *     def sizeof(self, deep: bool = False) -> int:
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)             # <<<<<<<<<<<<<<
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(float32_t) + # keys
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(((4 * (sizeof(__pyx_t_5numpy_uint32_t))) + (3 * (sizeof(__pyx_t_5numpy_uint32_t *))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3561, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_overhead = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3562
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)             # <<<<<<<<<<<<<<
 *         for_pairs =  self.table.n_buckets * (sizeof(float32_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 */
  __pyx_t_2 = (__pyx_v_self->table->n_buckets >> 5);
  __pyx_t_3 = 1;
  __pyx_t_5 = (__pyx_t_2 > __pyx_t_3);
  if (__pyx_t_5) {
    __pyx_t_4 = __pyx_t_2;
  } else {
    __pyx_t_4 = __pyx_t_3;
  }
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_t_4 * (sizeof(__pyx_t_5numpy_uint32_t)))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_flags = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3563
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(float32_t) + # keys             # <<<<<<<<<<<<<<
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->n_buckets * ((sizeof(__pyx_t_5numpy_float32_t)) + (sizeof(Py_ssize_t))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3563, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_pairs = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3565
 *         for_pairs =  self.table.n_buckets * (sizeof(float32_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs             # <<<<<<<<<<<<<<
 * 
 *     def get_state(self) -> dict[str, int]:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Add(__pyx_v_overhead, __pyx_v_for_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyNumber_Add(__pyx_t_1, __pyx_v_for_pairs); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(__Pyx_Py3Int_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None) || __Pyx_RaiseUnexpectedTypeError("int", __pyx_t_6))) __PYX_ERR(2, 3565, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3559
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_overhead);
  __Pyx_XDECREF(__pyx_v_for_flags);
  __Pyx_XDECREF(__pyx_v_for_pairs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3567
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_16Float32HashTable_10get_state, " returns infos about the state of the hashtable");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_11get_state = {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float32HashTable_10get_state};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_state (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_state", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_state", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_10get_state(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_state", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":3569
 *     def get_state(self) -> dict[str, int]:
 *         """ returns infos about the state of the hashtable"""
 *         return {             # <<<<<<<<<<<<<<
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 */
  __Pyx_XDECREF(__pyx_r);

  /* "pandas/_libs/hashtable_class_helper.pxi":3570
 *         """ returns infos about the state of the hashtable"""
 *         return {
 *             'n_buckets' : self.table.n_buckets,             # <<<<<<<<<<<<<<
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_buckets); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_buckets, __pyx_t_2) < 0) __PYX_ERR(2, 3570, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3571
 *         return {
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,             # <<<<<<<<<<<<<<
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->size); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3571, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_size, __pyx_t_2) < 0) __PYX_ERR(2, 3570, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3572
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,             # <<<<<<<<<<<<<<
 *             'upper_bound' : self.table.upper_bound,
 *         }
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_occupied); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3572, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_occupied, __pyx_t_2) < 0) __PYX_ERR(2, 3570, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3573
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,             # <<<<<<<<<<<<<<
 *         }
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->upper_bound); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_upper_bound, __pyx_t_2) < 0) __PYX_ERR(2, 3570, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3567
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.get_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3576
 *         }
 * 
 *     cpdef get_item(self, float32_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_16Float32HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, __pyx_t_5numpy_float32_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_float32_t __pyx_v_cval;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3576, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_13get_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = PyFloat_FromDouble(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3576, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3576, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3595
 *             float32_t cval
 * 
 *         cval = (val)             # <<<<<<<<<<<<<<
 *         k = kh_get_float32(self.table, cval)
 *         if k != self.table.n_buckets:
 */
  __pyx_v_cval = __pyx_v_val;

  /* "pandas/_libs/hashtable_class_helper.pxi":3596
 * 
 *         cval = (val)
 *         k = kh_get_float32(self.table, cval)             # <<<<<<<<<<<<<<
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]
 */
  __pyx_v_k = kh_get_float32(__pyx_v_self->table, __pyx_v_cval);

  /* "pandas/_libs/hashtable_class_helper.pxi":3597
 *         cval = (val)
 *         k = kh_get_float32(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  __pyx_t_7 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  if (likely(__pyx_t_7)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3598
 *         k = kh_get_float32(self.table, cval)
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(val)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->vals[__pyx_v_k])); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3598, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":3597
 *         cval = (val)
 *         k = kh_get_float32(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3600
 *             return self.table.vals[k]
 *         else:
 *             raise KeyError(val)             # <<<<<<<<<<<<<<
 * 
 *     cpdef get_na(self):
 */
  /*else*/ {
    __pyx_t_1 = PyFloat_FromDouble(__pyx_v_val); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3600, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3600, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 3600, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3576
 *         }
 * 
 *     cpdef get_item(self, float32_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_16Float32HashTable_12get_item, "Extracts the position of val from the hashtable.\n\n        Parameters\n        ----------\n        val : Scalar\n            The value that is looked up in the hashtable\n\n        Returns\n        -------\n        The position of the requested integer.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_13get_item = {"get_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_13get_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float32HashTable_12get_item};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_5numpy_float32_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3576, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_item") < 0)) __PYX_ERR(2, 3576, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __pyx_PyFloat_AsFloat(values[0]); if (unlikely((__pyx_v_val == ((npy_float32)-1)) && PyErr_Occurred())) __PYX_ERR(2, 3576, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_item", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 3576, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_12get_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, __pyx_t_5numpy_float32_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_16Float32HashTable_get_item(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3602
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_16Float32HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3602, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_15get_na)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3602, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3610
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_6 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3611
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         if self.na_position == -1:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 3611, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":3610
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3613
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  __pyx_t_6 = (__pyx_v_self->na_position == -1LL);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3614
 * 
 *         if self.na_position == -1:
 *             raise KeyError("NA")             # <<<<<<<<<<<<<<
 *         return self.na_position
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_KeyError, __pyx_tuple__13, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3614, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(2, 3614, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":3613
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3615
 *         if self.na_position == -1:
 *             raise KeyError("NA")
 *         return self.na_position             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_item(self, float32_t key, Py_ssize_t val):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->na_position); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3615, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3602
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_16Float32HashTable_14get_na, "Extracts the position of na_value from the hashtable.\n\n        Returns\n        -------\n        The position of the last na value.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_15get_na = {"get_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_15get_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float32HashTable_14get_na};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_na", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_na", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_14get_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_16Float32HashTable_get_na(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3617
 *         return self.na_position
 * 
 *     cpdef set_item(self, float32_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_16Float32HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, __pyx_t_5numpy_float32_t __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  __pyx_t_5numpy_float32_t __pyx_v_ckey;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3617, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_17set_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = PyFloat_FromDouble(__pyx_v_key); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3617, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3617, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_5 = __pyx_t_1; __pyx_t_6 = NULL;
        __pyx_t_7 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_7 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_3, __pyx_t_4};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3617, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3622
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             float32_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3625
 *             float32_t ckey
 * 
 *         ckey = (key)             # <<<<<<<<<<<<<<
 *         k = kh_put_float32(self.table, ckey, &ret)
 *         if kh_exist_float32(self.table, k):
 */
  __pyx_v_ckey = __pyx_v_key;

  /* "pandas/_libs/hashtable_class_helper.pxi":3626
 * 
 *         ckey = (key)
 *         k = kh_put_float32(self.table, ckey, &ret)             # <<<<<<<<<<<<<<
 *         if kh_exist_float32(self.table, k):
 *             self.table.vals[k] = val
 */
  __pyx_v_k = kh_put_float32(__pyx_v_self->table, __pyx_v_ckey, (&__pyx_v_ret));

  /* "pandas/_libs/hashtable_class_helper.pxi":3627
 *         ckey = (key)
 *         k = kh_put_float32(self.table, ckey, &ret)
 *         if kh_exist_float32(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
  __pyx_t_8 = kh_exist_float32(__pyx_v_self->table, __pyx_v_k);
  if (likely(__pyx_t_8)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3628
 *         k = kh_put_float32(self.table, ckey, &ret)
 *         if kh_exist_float32(self.table, k):
 *             self.table.vals[k] = val             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(key)
 */
    (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_val;

    /* "pandas/_libs/hashtable_class_helper.pxi":3627
 *         ckey = (key)
 *         k = kh_put_float32(self.table, ckey, &ret)
 *         if kh_exist_float32(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3630
 *             self.table.vals[k] = val
 *         else:
 *             raise KeyError(key)             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_na(self, Py_ssize_t val):
 */
  /*else*/ {
    __pyx_t_1 = PyFloat_FromDouble(__pyx_v_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3630, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3630, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 3630, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "pandas/_libs/hashtable_class_helper.pxi":3617
 *         return self.na_position
 * 
 *     cpdef set_item(self, float32_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_17set_item = {"set_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_17set_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_5numpy_float32_t __pyx_v_key;
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key,&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3617, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3617, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, 1); __PYX_ERR(2, 3617, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_item") < 0)) __PYX_ERR(2, 3617, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_key = __pyx_PyFloat_AsFloat(values[0]); if (unlikely((__pyx_v_key == ((npy_float32)-1)) && PyErr_Occurred())) __PYX_ERR(2, 3617, __pyx_L3_error)
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 3617, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, __pyx_nargs); __PYX_ERR(2, 3617, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_16set_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)__pyx_v_self), __pyx_v_key, __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, __pyx_t_5numpy_float32_t __pyx_v_key, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_16Float32HashTable_set_item(__pyx_v_self, __pyx_v_key, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3632
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_16Float32HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  CYTHON_UNUSED int __pyx_v_ret;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3632, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_19set_na)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3632, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3632, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3636
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             float32_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3639
 *             float32_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_7 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_7)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3640
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         self.na_position = val
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 3640, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":3639
 *             float32_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3642
 *             raise NotImplementedError
 * 
 *         self.na_position = val             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->na_position = __pyx_v_val;

  /* "pandas/_libs/hashtable_class_helper.pxi":3632
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_19set_na = {"set_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_19set_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3632, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_na") < 0)) __PYX_ERR(2, 3632, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[0]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 3632, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_na", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 3632, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_18set_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_16Float32HashTable_set_na(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3645
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const float32_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_21map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_21map_locations = {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_21map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_21map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("map_locations (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3645, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3645, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "map_locations") < 0)) __PYX_ERR(2, 3645, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float32_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 3646, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 3646, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__26;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("map_locations", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 3645, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_20map_locations(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_20map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  int __pyx_v_ret;
  __pyx_t_5numpy_float32_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  __pyx_t_5numpy_int64_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("map_locations", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":3649
 *         # Used in libindex, safe_sort
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             float32_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":3650
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             float32_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3653
 *             float32_t val
 *             khiter_t k
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_2 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":3655
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_3 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_3)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3656
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 3656, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":3655
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3658
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":3659
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
        if (__pyx_v_self->uses_mask) {

          /* "pandas/_libs/hashtable_class_helper.pxi":3660
 *         with nogil:
 *             if self.uses_mask:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     if mask[i]:
 *                         na_position = i
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":3661
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_mask.shape[0];
            __pyx_t_3 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) ))) != 0);
            if (__pyx_t_3) {

              /* "pandas/_libs/hashtable_class_helper.pxi":3662
 *                 for i in range(n):
 *                     if mask[i]:
 *                         na_position = i             # <<<<<<<<<<<<<<
 *                     else:
 *                         val= (values[i])
 */
              __pyx_v_na_position = __pyx_v_i;

              /* "pandas/_libs/hashtable_class_helper.pxi":3661
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
              goto __pyx_L12;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":3664
 *                         na_position = i
 *                     else:
 *                         val= (values[i])             # <<<<<<<<<<<<<<
 *                         k = kh_put_float32(self.table, val, &ret)
 *                         self.table.vals[k] = i
 */
            /*else*/ {
              __pyx_t_7 = __pyx_v_i;
              if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
              __pyx_v_val = (*((__pyx_t_5numpy_float32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_class_helper.pxi":3665
 *                     else:
 *                         val= (values[i])
 *                         k = kh_put_float32(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = i
 *             else:
 */
              __pyx_v_k = kh_put_float32(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

              /* "pandas/_libs/hashtable_class_helper.pxi":3666
 *                         val= (values[i])
 *                         k = kh_put_float32(self.table, val, &ret)
 *                         self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *             else:
 *                 for i in range(n):
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
            }
            __pyx_L12:;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":3659
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
          goto __pyx_L9;
        }

        /* "pandas/_libs/hashtable_class_helper.pxi":3668
 *                         self.table.vals[k] = i
 *             else:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     val= (values[i])
 *                     k = kh_put_float32(self.table, val, &ret)
 */
        /*else*/ {
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":3669
 *             else:
 *                 for i in range(n):
 *                     val= (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_put_float32(self.table, val, &ret)
 *                     self.table.vals[k] = i
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
            __pyx_v_val = (*((__pyx_t_5numpy_float32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

            /* "pandas/_libs/hashtable_class_helper.pxi":3670
 *                 for i in range(n):
 *                     val= (values[i])
 *                     k = kh_put_float32(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                     self.table.vals[k] = i
 *         self.na_position = na_position
 */
            __pyx_v_k = kh_put_float32(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":3671
 *                     val= (values[i])
 *                     k = kh_put_float32(self.table, val, &ret)
 *                     self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *         self.na_position = na_position
 * 
 */
            (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
          }
        }
        __pyx_L9:;
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":3658
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3672
 *                     k = kh_put_float32(self.table, val, &ret)
 *                     self.table.vals[k] = i
 *         self.na_position = na_position             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __pyx_v_self->na_position = __pyx_v_na_position;

  /* "pandas/_libs/hashtable_class_helper.pxi":3645
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const float32_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3674
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const float32_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

/* Python wrapper */
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_23lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_23lookup = {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_23lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_23lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyArrayObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lookup (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3674, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3674, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lookup") < 0)) __PYX_ERR(2, 3674, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float32_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 3675, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 3675, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__27;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lookup", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 3674, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_22lookup(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_22lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  CYTHON_UNUSED int __pyx_v_ret;
  __pyx_t_5numpy_float32_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __Pyx_memviewslice __pyx_v_locs = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lookup", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":3679
 *         # Used in safe_sort, IndexEngine.get_indexer
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             float32_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":3680
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             float32_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3683
 *             float32_t val
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *             int8_t na_position = self.na_position
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 3683, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 3683, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3683, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 3683, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_locs = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":3684
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_8 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":3686
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_9 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_10 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_9 = __pyx_t_10;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3687
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 3687, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":3686
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3689
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":3690
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_11 = __pyx_t_1;
        for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
          __pyx_v_i = __pyx_t_12;

          /* "pandas/_libs/hashtable_class_helper.pxi":3691
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
          if (__pyx_v_self->uses_mask) {
          } else {
            __pyx_t_9 = __pyx_v_self->uses_mask;
            goto __pyx_L12_bool_binop_done;
          }
          __pyx_t_13 = __pyx_v_i;
          if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_mask.shape[0];
          __pyx_t_10 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_13 * __pyx_v_mask.strides[0]) ))) != 0);
          __pyx_t_9 = __pyx_t_10;
          __pyx_L12_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":3692
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position             # <<<<<<<<<<<<<<
 *                 else:
 *                     val = (values[i])
 */
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = __pyx_v_na_position;

            /* "pandas/_libs/hashtable_class_helper.pxi":3691
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
            goto __pyx_L11;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":3694
 *                     locs[i] = na_position
 *                 else:
 *                     val = (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_float32(self.table, val)
 *                     if k != self.table.n_buckets:
 */
          /*else*/ {
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_values.shape[0];
            __pyx_v_val = (*((__pyx_t_5numpy_float32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_13 * __pyx_v_values.strides[0]) )));

            /* "pandas/_libs/hashtable_class_helper.pxi":3695
 *                 else:
 *                     val = (values[i])
 *                     k = kh_get_float32(self.table, val)             # <<<<<<<<<<<<<<
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]
 */
            __pyx_v_k = kh_get_float32(__pyx_v_self->table, __pyx_v_val);

            /* "pandas/_libs/hashtable_class_helper.pxi":3696
 *                     val = (values[i])
 *                     k = kh_get_float32(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
            __pyx_t_9 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":3697
 *                     k = kh_get_float32(self.table, val)
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     else:
 *                         locs[i] = -1
 */
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = (__pyx_v_self->table->vals[__pyx_v_k]);

              /* "pandas/_libs/hashtable_class_helper.pxi":3696
 *                     val = (values[i])
 *                     k = kh_get_float32(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
              goto __pyx_L14;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":3699
 *                         locs[i] = self.table.vals[k]
 *                     else:
 *                         locs[i] = -1             # <<<<<<<<<<<<<<
 * 
 *         return np.asarray(locs)
 */
            /*else*/ {
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = -1;
            }
            __pyx_L14:;
          }
          __pyx_L11:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":3689
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3701
 *                         locs[i] = -1
 * 
 *         return np.asarray(locs)             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_locs, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_14 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_14 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3701, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 3701, __pyx_L1_error)
  __pyx_r = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3674
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const float32_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_locs, 1);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3703
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const float32_t[:] values, Float32Vector uniques,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_25_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_16Float32HashTable_24_unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[float32]\n            Array of values of which unique will be calculated\n        uniques : Float32Vector\n            Vector into which uniques will be written\n        count_prior : Py_ssize_t, default 0\n            Number of existing entries in uniques\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        ignore_na : bool, default False\n            Whether NA-values should be ignored for calculating the uniques. If\n            True, the labels corresponding to missing values will be set to\n            na_sentinel.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        use_result_mask: bool, default False\n            Whether to create a result mask for the unique values. Not supported\n            with return_inverse=True.\n\n        Returns\n        -------\n        uniques : ndarray[float32]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse=True)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if use_result_mask is true\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_25_unique = {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_25_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float32HashTable_24_unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_25_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  int __pyx_v_ignore_na;
  PyObject *__pyx_v_mask = 0;
  int __pyx_v_return_inverse;
  int __pyx_v_use_result_mask;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[9] = {0,0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_ignore_na,&__pyx_n_s_mask,&__pyx_n_s_return_inverse,&__pyx_n_s_use_result_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":3707
 *     def _unique(self, const float32_t[:] values, Float32Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));

    /* "pandas/_libs/hashtable_class_helper.pxi":3708
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[6] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3703, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3703, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, 1); __PYX_ERR(2, 3703, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3703, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3703, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3703, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3703, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[6] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3703, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[7] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3703, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_use_result_mask);
          if (value) { values[8] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3703, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_unique") < 0)) __PYX_ERR(2, 3703, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float32_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 3705, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 3706, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 3706, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    if (values[5]) {
      __pyx_v_ignore_na = __Pyx_PyObject_IsTrue(values[5]); if (unlikely((__pyx_v_ignore_na == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 3707, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":3707
 *     def _unique(self, const float32_t[:] values, Float32Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
      __pyx_v_ignore_na = ((int)0);
    }
    __pyx_v_mask = values[6];
    if (values[7]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[7]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 3708, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":3708
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
      __pyx_v_return_inverse = ((int)0);
    }
    if (values[8]) {
      __pyx_v_use_result_mask = __Pyx_PyObject_IsTrue(values[8]); if (unlikely((__pyx_v_use_result_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 3708, __pyx_L3_error)
    } else {
      __pyx_v_use_result_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, __pyx_nargs); __PYX_ERR(2, 3703, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector, 1, "uniques", 0))) __PYX_ERR(2, 3705, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_24_unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_ignore_na, __pyx_v_mask, __pyx_v_return_inverse, __pyx_v_use_result_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":3703
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const float32_t[:] values, Float32Vector uniques,
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_24_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_idx;
  Py_ssize_t __pyx_v_count;
  Py_ssize_t __pyx_v_n;
  __Pyx_memviewslice __pyx_v_labels = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_ret;
  __pyx_t_5numpy_float32_t __pyx_v_val;
  __pyx_t_5numpy_float32_t __pyx_v_na_value2;
  khiter_t __pyx_v_k;
  __pyx_t_6pandas_5_libs_9hashtable_Float32VectorData *__pyx_v_ud;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_result_mask = 0;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_v_rmd;
  int __pyx_v_use_na_value;
  int __pyx_v_use_mask;
  int __pyx_v_seen_na;
  __Pyx_memviewslice __pyx_v_mask_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_6pandas_5_libs_9hashtable_Float32VectorData *__pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_t_11;
  int __pyx_t_12;
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_float32_t __pyx_t_14;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":3752
 *         """
 *         cdef:
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)             # <<<<<<<<<<<<<<
 *             intp_t[::1] labels
 *             int ret = 0
 */
  __pyx_v_count = __pyx_v_count_prior;
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":3754
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)
 *             intp_t[::1] labels
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             float32_t val, na_value2
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3760
 *             UInt8Vector result_mask
 *             UInt8VectorData *rmd
 *             bint use_na_value, use_mask, seen_na = False             # <<<<<<<<<<<<<<
 *             uint8_t[:] mask_values
 * 
 */
  __pyx_v_seen_na = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3763
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3764
 * 
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 3764, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 3764, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3764, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 3764, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_labels = __pyx_t_7;
    __pyx_t_7.memview = NULL;
    __pyx_t_7.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":3763
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3765
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data             # <<<<<<<<<<<<<<
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 */
  __pyx_t_8 = __pyx_v_uniques->data;
  __pyx_v_ud = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":3766
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 *         use_na_value = na_value is not None             # <<<<<<<<<<<<<<
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 */
  __pyx_t_9 = (__pyx_v_na_value != Py_None);
  __pyx_v_use_na_value = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":3767
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None             # <<<<<<<<<<<<<<
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover
 */
  __pyx_t_9 = (__pyx_v_mask != Py_None);
  __pyx_v_use_mask = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":3768
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  __pyx_t_10 = (!__pyx_v_use_mask);
  if (__pyx_t_10) {
  } else {
    __pyx_t_9 = __pyx_t_10;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_use_result_mask;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3769
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         if use_result_mask and return_inverse:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 3769, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":3768
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3771
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_use_result_mask) {
  } else {
    __pyx_t_9 = __pyx_v_use_result_mask;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_return_inverse;
  __pyx_L8_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3772
 * 
 *         if use_result_mask and return_inverse:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         result_mask = UInt8Vector()
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 3772, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":3771
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3774
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         result_mask = UInt8Vector()             # <<<<<<<<<<<<<<
 *         rmd = result_mask.data
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_v_result_mask = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3775
 * 
 *         result_mask = UInt8Vector()
 *         rmd = result_mask.data             # <<<<<<<<<<<<<<
 * 
 *         if use_mask:
 */
  __pyx_t_11 = __pyx_v_result_mask->data;
  __pyx_v_rmd = __pyx_t_11;

  /* "pandas/_libs/hashtable_class_helper.pxi":3777
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  if (__pyx_v_use_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3778
 * 
 *         if use_mask:
 *             mask_values = mask.view("uint8")             # <<<<<<<<<<<<<<
 * 
 *         if use_na_value:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_mask, __pyx_n_s_view); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3778, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    __pyx_t_12 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_12 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_uint8};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_12, 1+__pyx_t_12);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3778, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(2, 3778, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_mask_values = __pyx_t_13;
    __pyx_t_13.memview = NULL;
    __pyx_t_13.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":3777
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3780
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
  if (__pyx_v_use_na_value) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3786
 *             # for the parameter. To please the compiler, we use na_value2,
 *             # which is only used if it's *specified*.
 *             na_value2 = (na_value)             # <<<<<<<<<<<<<<
 *         else:
 *             na_value2 = (0)
 */
    __pyx_t_14 = __pyx_PyFloat_AsFloat(__pyx_v_na_value); if (unlikely((__pyx_t_14 == ((npy_float32)-1)) && PyErr_Occurred())) __PYX_ERR(2, 3786, __pyx_L1_error)
    __pyx_v_na_value2 = __pyx_t_14;

    /* "pandas/_libs/hashtable_class_helper.pxi":3780
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
    goto __pyx_L11;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3788
 *             na_value2 = (na_value)
 *         else:
 *             na_value2 = (0)             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
  /*else*/ {
    __pyx_v_na_value2 = 0.0;
  }
  __pyx_L11:;

  /* "pandas/_libs/hashtable_class_helper.pxi":3790
 *             na_value2 = (0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = (values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":3791
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 val = (values[i])
 * 
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_15 = __pyx_t_1;
        for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
          __pyx_v_i = __pyx_t_16;

          /* "pandas/_libs/hashtable_class_helper.pxi":3792
 *         with nogil:
 *             for i in range(n):
 *                 val = (values[i])             # <<<<<<<<<<<<<<
 * 
 *                 if ignore_na and use_mask:
 */
          __pyx_t_17 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_float32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_17 * __pyx_v_values.strides[0]) )));

          /* "pandas/_libs/hashtable_class_helper.pxi":3794
 *                 val = (values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L18_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_mask;
          __pyx_L18_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":3795
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 3795, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_17 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":3796
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                         continue
 *                 elif ignore_na and (
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 3796, __pyx_L13_error) }
              __pyx_t_17 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_na_sentinel;

              /* "pandas/_libs/hashtable_class_helper.pxi":3797
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 *                         continue             # <<<<<<<<<<<<<<
 *                 elif ignore_na and (
 *                    is_nan_float32_t(val) or
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":3795
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":3794
 *                 val = (values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
            goto __pyx_L17;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":3798
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_float32_t(val) or
 *                    (use_na_value and are_equivalent_float32_t(val, na_value2))
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":3799
 *                         continue
 *                 elif ignore_na and (
 *                    is_nan_float32_t(val) or             # <<<<<<<<<<<<<<
 *                    (use_na_value and are_equivalent_float32_t(val, na_value2))
 *                 ):
 */
          __pyx_t_10 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_float32_t(__pyx_v_val); if (unlikely(__pyx_t_10 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 3799, __pyx_L13_error)
          if (!__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":3800
 *                 elif ignore_na and (
 *                    is_nan_float32_t(val) or
 *                    (use_na_value and are_equivalent_float32_t(val, na_value2))             # <<<<<<<<<<<<<<
 *                 ):
 *                     # if missing values do not count as unique values (i.e. if
 */
          if (__pyx_v_use_na_value) {
          } else {
            __pyx_t_9 = __pyx_v_use_na_value;
            goto __pyx_L21_bool_binop_done;
          }
          __pyx_t_10 = kh_floats_hash_equal(__pyx_v_val, __pyx_v_na_value2);
          __pyx_t_9 = __pyx_t_10;
          __pyx_L21_bool_binop_done:;

          /* "pandas/_libs/hashtable_class_helper.pxi":3798
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_float32_t(val) or
 *                    (use_na_value and are_equivalent_float32_t(val, na_value2))
 */
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":3805
 *                     # ignore_na is True), skip the hashtable entry for them,
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 3805, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_na_sentinel;

            /* "pandas/_libs/hashtable_class_helper.pxi":3806
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel
 *                     continue             # <<<<<<<<<<<<<<
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 */
            goto __pyx_L15_continue;

            /* "pandas/_libs/hashtable_class_helper.pxi":3798
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_float32_t(val) or
 *                    (use_na_value and are_equivalent_float32_t(val, na_value2))
 */
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":3807
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          __pyx_t_10 = (!__pyx_v_ignore_na);
          if (__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L25_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_result_mask;
          __pyx_L25_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":3808
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 3808, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_17 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":3809
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_class_helper.pxi":3810
 *                     if mask_values[i]:
 *                         if seen_na:
 *                             continue             # <<<<<<<<<<<<<<
 * 
 *                         seen_na = True
 */
                goto __pyx_L15_continue;

                /* "pandas/_libs/hashtable_class_helper.pxi":3809
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":3812
 *                             continue
 * 
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         if needs_resize(ud):
 *                             with gil:
 */
              __pyx_v_seen_na = 1;

              /* "pandas/_libs/hashtable_class_helper.pxi":3813
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              __pyx_t_9 = __pyx_fuse_9__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 3813, __pyx_L13_error)
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_class_helper.pxi":3814
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                {
                    #ifdef WITH_THREAD
                    PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                    #endif
                    /*try:*/ {

                      /* "pandas/_libs/hashtable_class_helper.pxi":3815
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":3816
 *                             with gil:
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3816, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 3816, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":3815
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":3819
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float32Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3819, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":3820
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":3821
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3821, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 3821, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":3820
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":3824
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                         append_data_float32(ud, val)
 *                         append_data_uint8(rmd, 1)
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3824, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":3814
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    /*finally:*/ {
                      /*normal exit:*/{
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L34;
                      }
                      __pyx_L33_error: {
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L13_error;
                      }
                      __pyx_L34:;
                    }
                }

                /* "pandas/_libs/hashtable_class_helper.pxi":3813
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":3825
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                         append_data_float32(ud, val)             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 1)
 *                         continue
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_float32(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 3825, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":3826
 *                                 result_mask.resize()
 *                         append_data_float32(ud, val)
 *                         append_data_uint8(rmd, 1)             # <<<<<<<<<<<<<<
 *                         continue
 * 
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 1); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 3826, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":3827
 *                         append_data_float32(ud, val)
 *                         append_data_uint8(rmd, 1)
 *                         continue             # <<<<<<<<<<<<<<
 * 
 *                 k = kh_get_float32(self.table, val)
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":3808
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":3807
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          }
          __pyx_L17:;

          /* "pandas/_libs/hashtable_class_helper.pxi":3829
 *                         continue
 * 
 *                 k = kh_get_float32(self.table, val)             # <<<<<<<<<<<<<<
 * 
 *                 if k == self.table.n_buckets:
 */
          __pyx_v_k = kh_get_float32(__pyx_v_self->table, __pyx_v_val);

          /* "pandas/_libs/hashtable_class_helper.pxi":3831
 *                 k = kh_get_float32(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_float32(self.table, val, &ret)
 */
          __pyx_t_9 = (__pyx_v_k == __pyx_v_self->table->n_buckets);
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":3833
 *                 if k == self.table.n_buckets:
 *                     # k hasn't been seen yet
 *                     k = kh_put_float32(self.table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *                     if needs_resize(ud):
 */
            __pyx_v_k = kh_put_float32(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":3835
 *                     k = kh_put_float32(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            __pyx_t_9 = __pyx_fuse_9__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 3835, __pyx_L13_error)
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":3836
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
              {
                  #ifdef WITH_THREAD
                  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                  #endif
                  /*try:*/ {

                    /* "pandas/_libs/hashtable_class_helper.pxi":3837
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":3838
 *                         with gil:
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 */
                      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3838, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                      __PYX_ERR(2, 3838, __pyx_L42_error)

                      /* "pandas/_libs/hashtable_class_helper.pxi":3837
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":3841
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()             # <<<<<<<<<<<<<<
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 */
                    __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float32Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3841, __pyx_L42_error)
                    __Pyx_GOTREF(__pyx_t_6);
                    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                    /* "pandas/_libs/hashtable_class_helper.pxi":3842
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    if (__pyx_v_use_result_mask) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":3843
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":3844
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3844, __pyx_L42_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 3844, __pyx_L42_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":3843
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":3847
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                     append_data_float32(ud, val)
 *                     if use_result_mask:
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3847, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":3842
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    }
                  }

                  /* "pandas/_libs/hashtable_class_helper.pxi":3836
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
                  /*finally:*/ {
                    /*normal exit:*/{
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L43;
                    }
                    __pyx_L42_error: {
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L13_error;
                    }
                    __pyx_L43:;
                  }
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":3835
 *                     k = kh_put_float32(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":3848
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                     append_data_float32(ud, val)             # <<<<<<<<<<<<<<
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)
 */
            __pyx_f_6pandas_5_libs_9hashtable_append_data_float32(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 3848, __pyx_L13_error)

            /* "pandas/_libs/hashtable_class_helper.pxi":3849
 *                                 result_mask.resize()
 *                     append_data_float32(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            if (__pyx_v_use_result_mask) {

              /* "pandas/_libs/hashtable_class_helper.pxi":3850
 *                     append_data_float32(ud, val)
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)             # <<<<<<<<<<<<<<
 * 
 *                     if return_inverse:
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 0); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 3850, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":3849
 *                                 result_mask.resize()
 *                     append_data_float32(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":3852
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            if (__pyx_v_return_inverse) {

              /* "pandas/_libs/hashtable_class_helper.pxi":3853
 * 
 *                     if return_inverse:
 *                         self.table.vals[k] = count             # <<<<<<<<<<<<<<
 *                         labels[i] = count
 *                         count += 1
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":3854
 *                     if return_inverse:
 *                         self.table.vals[k] = count
 *                         labels[i] = count             # <<<<<<<<<<<<<<
 *                         count += 1
 *                 elif return_inverse:
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 3854, __pyx_L13_error) }
              __pyx_t_17 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":3855
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 *                         count += 1             # <<<<<<<<<<<<<<
 *                 elif return_inverse:
 *                     # k falls into a previous bucket
 */
              __pyx_v_count = (__pyx_v_count + 1);

              /* "pandas/_libs/hashtable_class_helper.pxi":3852
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":3831
 *                 k = kh_get_float32(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_float32(self.table, val, &ret)
 */
            goto __pyx_L37;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":3856
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          if (__pyx_v_return_inverse) {

            /* "pandas/_libs/hashtable_class_helper.pxi":3859
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     labels[i] = idx
 * 
 */
            __pyx_v_idx = (__pyx_v_self->table->vals[__pyx_v_k]);

            /* "pandas/_libs/hashtable_class_helper.pxi":3860
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]
 *                     labels[i] = idx             # <<<<<<<<<<<<<<
 * 
 *         if return_inverse:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 3860, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_idx;

            /* "pandas/_libs/hashtable_class_helper.pxi":3856
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          }
          __pyx_L37:;
          __pyx_L15_continue:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":3790
 *             na_value2 = (0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = (values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L14;
        }
        __pyx_L13_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L14:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3862
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3863
 * 
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray             # <<<<<<<<<<<<<<
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float32Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3863, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundLocalError("labels"); __PYX_ERR(2, 3863, __pyx_L1_error) }
    __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_labels, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3863, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_base); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3863, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3863, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_6);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_6)) __PYX_ERR(2, 3863, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4)) __PYX_ERR(2, 3863, __pyx_L1_error);
    __pyx_t_6 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":3862
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3864
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  if (__pyx_v_use_result_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3865
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()             # <<<<<<<<<<<<<<
 *         return uniques.to_array()
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float32Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3865, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->to_array(__pyx_v_result_mask, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3865, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3865, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2)) __PYX_ERR(2, 3865, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4)) __PYX_ERR(2, 3865, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":3864
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3866
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()             # <<<<<<<<<<<<<<
 * 
 *     def unique(self, const float32_t[:] values, bint return_inverse=False, object mask=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float32Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3866, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3703
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const float32_t[:] values, Float32Vector uniques,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_13, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_labels, 1);
  __Pyx_XDECREF((PyObject *)__pyx_v_result_mask);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask_values, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3868
 *         return uniques.to_array()
 * 
 *     def unique(self, const float32_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_27unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_16Float32HashTable_26unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[float32]\n            Array of values of which unique will be calculated\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n\n        Returns\n        -------\n        uniques : ndarray[float32]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if mask is given as input\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_27unique = {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_27unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float32HashTable_26unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_27unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_return_inverse;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_return_inverse,&__pyx_n_s_mask,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3868, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3868, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3868, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "unique") < 0)) __PYX_ERR(2, 3868, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float32_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 3868, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 3868, __pyx_L3_error)
    } else {
      __pyx_v_return_inverse = ((int)0);
    }
    __pyx_v_mask = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("unique", 0, 1, 3, __pyx_nargs); __PYX_ERR(2, 3868, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_26unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_return_inverse, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_26unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_uniques = NULL;
  int __pyx_v_use_result_mask;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":3892
 *             The mask for the result values.
 *         """
 *         uniques = Float32Vector()             # <<<<<<<<<<<<<<
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3892, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3893
 *         """
 *         uniques = Float32Vector()
 *         use_result_mask = True if mask is not None else False             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 */
  __pyx_t_3 = (__pyx_v_mask != Py_None);
  if (__pyx_t_3) {
    __pyx_t_2 = 1;
  } else {
    __pyx_t_2 = 0;
  }
  __pyx_v_use_result_mask = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":3894
 *         uniques = Float32Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_float32_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4)) __PYX_ERR(2, 3894, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 3894, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ignore_na, Py_False) < 0) __PYX_ERR(2, 3894, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3895
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const float32_t[:] values, Py_ssize_t na_sentinel=-1,
 */
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_return_inverse); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return_inverse, __pyx_t_6) < 0) __PYX_ERR(2, 3894, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 3894, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_use_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3895, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_use_result_mask, __pyx_t_6) < 0) __PYX_ERR(2, 3894, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3894
 *         uniques = Float32Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 3894, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3868
 *         return uniques.to_array()
 * 
 *     def unique(self, const float32_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3897
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const float32_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_29factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_16Float32HashTable_28factorize, "\n        Calculate unique values and labels (no sorting!)\n\n        Missing values are not included in the \"uniques\" for this method.\n        The labels for any missing values will be set to \"na_sentinel\"\n\n        Parameters\n        ----------\n        values : ndarray[float32]\n            Array of values of which unique will be calculated\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n\n        Returns\n        -------\n        uniques : ndarray[float32]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t]\n            The labels from values to uniques\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_29factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_29factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float32HashTable_28factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_29factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  PyObject *__pyx_v_ignore_na = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,&__pyx_n_s_ignore_na,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":3898
 * 
 *     def factorize(self, const float32_t[:] values, Py_ssize_t na_sentinel=-1,
 *                   object na_value=None, object mask=None, ignore_na=True):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_True));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3897, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3897, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3897, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3897, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3897, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 3897, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float32_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 3897, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 3897, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
    __pyx_v_ignore_na = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 5, __pyx_nargs); __PYX_ERR(2, 3897, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_28factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask, __pyx_v_ignore_na);

  /* "pandas/_libs/hashtable_class_helper.pxi":3897
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const float32_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_28factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_uniques_vector = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":3928
 *             The labels from values to uniques
 *         """
 *         uniques_vector = Float32Vector()             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques_vector = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3929
 *         """
 *         uniques_vector = Float32Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3929, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_float32_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3929, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3929, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 3929, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques_vector);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques_vector))) __PYX_ERR(2, 3929, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3929, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3929, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 3929, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3930
 *         uniques_vector = Float32Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,             # <<<<<<<<<<<<<<
 *                             return_inverse=True)
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 3929, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, __pyx_v_ignore_na) < 0) __PYX_ERR(2, 3929, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 3929, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3931
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)             # <<<<<<<<<<<<<<
 * 
 *     def get_labels(self, const float32_t[:] values, Float32Vector uniques,
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 3929, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3929
 *         """
 *         uniques_vector = Float32Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3929, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3897
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const float32_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3933
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const float32_t[:] values, Float32Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_31get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_31get_labels = {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_31get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_31get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_labels (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":3935
 *     def get_labels(self, const float32_t[:] values, Float32Vector uniques,
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3933, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3933, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, 1); __PYX_ERR(2, 3933, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3933, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3933, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3933, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3933, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_labels") < 0)) __PYX_ERR(2, 3933, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float32_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 3933, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 3934, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 3934, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    __pyx_v_mask = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, __pyx_nargs); __PYX_ERR(2, 3933, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector, 1, "uniques", 0))) __PYX_ERR(2, 3933, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_30get_labels(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":3933
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const float32_t[:] values, Float32Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_30get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_v_labels = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_labels", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":3937
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3937, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_float32_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3937, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3937, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 3937, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 3937, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3937, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_count_prior); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3937, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_count_prior, __pyx_t_4) < 0) __PYX_ERR(2, 3937, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3938
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,             # <<<<<<<<<<<<<<
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 3937, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 3937, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3939
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, Py_True) < 0) __PYX_ERR(2, 3937, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 3937, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 3937, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3937
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3937, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
    PyObject* sequence = __pyx_t_4;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(2, 3937, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 3937, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3937, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3937, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
    index = 0; __pyx_t_2 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_1), 2) < 0) __PYX_ERR(2, 3937, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(2, 3937, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v__ = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_labels = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3940
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_labels);
  __pyx_r = __pyx_v_labels;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3933
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const float32_t[:] values, Float32Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XDECREF(__pyx_v_labels);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_33__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_33__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_33__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_33__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_32__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_32__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_35__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_35__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_35__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_35__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_34__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16Float32HashTable_34__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3949
 *         Float32Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = Float32HashTable(size_hint)
 *         self.uniques = Float32Vector()
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_size_hint = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3949, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 3949, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_size_hint = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 3949, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_size_hint), (&PyInt_Type), 0, "size_hint", 1))) __PYX_ERR(2, 3949, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *)__pyx_v_self), __pyx_v_size_hint);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":3950
 * 
 *     def __cinit__(self, size_hint: int):
 *         self.table = Float32HashTable(size_hint)             # <<<<<<<<<<<<<<
 *         self.uniques = Float32Vector()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable), __pyx_v_size_hint); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3950, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3951
 *     def __cinit__(self, size_hint: int):
 *         self.table = Float32HashTable(size_hint)
 *         self.uniques = Float32Vector()             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const float32_t[:] values,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3951, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3949
 *         Float32Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = Float32HashTable(size_hint)
 *         self.uniques = Float32Vector()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3953
 *         self.uniques = Float32Vector()
 * 
 *     def factorize(self, const float32_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_17Float32Factorizer_2factorize, "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = Float32Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"float32\"), na_sentinel=20)\n        array([0, 1, 2])\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_17Float32Factorizer_3factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_17Float32Factorizer_2factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_v_na_sentinel = 0;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_neg_1));

    /* "pandas/_libs/hashtable_class_helper.pxi":3954
 * 
 *     def factorize(self, const float32_t[:] values,
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:             # <<<<<<<<<<<<<<
 *         """
 *         Returns
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3953, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3953, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3953, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3953, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 3953, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float32_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 3953, __pyx_L3_error)
    __pyx_v_na_sentinel = values[1];
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 4, __pyx_nargs); __PYX_ERR(2, 3953, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_2factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":3953
 *         self.uniques = Float32Vector()
 * 
 *     def factorize(self, const float32_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  PyArrayObject *__pyx_v_labels = 0;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_uniques = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_labels;
  __Pyx_Buffer __pyx_pybuffer_labels;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);
  __pyx_pybuffer_labels.pybuffer.buf = NULL;
  __pyx_pybuffer_labels.refcount = 0;
  __pyx_pybuffernd_labels.data = NULL;
  __pyx_pybuffernd_labels.rcbuffer = &__pyx_pybuffer_labels;

  /* "pandas/_libs/hashtable_class_helper.pxi":3971
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = Float32Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  if (__pyx_v_self->uniques->__pyx_base.external_view_exists) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3972
 * 
 *         if self.uniques.external_view_exists:
 *             uniques = Float32Vector()             # <<<<<<<<<<<<<<
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 */
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3972, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":3973
 *         if self.uniques.external_view_exists:
 *             uniques = Float32Vector()
 *             uniques.extend(self.uniques.to_array())             # <<<<<<<<<<<<<<
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 */
    __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float32Vector *)__pyx_v_self->uniques->__pyx_vtab)->to_array(__pyx_v_self->uniques, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3973, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float32_t__const__(__pyx_t_1, 0); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(2, 3973, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float32Vector *)__pyx_v_uniques->__pyx_vtab)->extend(__pyx_v_uniques, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3973, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
    __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":3974
 *             uniques = Float32Vector()
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques             # <<<<<<<<<<<<<<
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 */
    __Pyx_INCREF((PyObject *)__pyx_v_uniques);
    __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
    __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
    __pyx_v_self->uniques = __pyx_v_uniques;

    /* "pandas/_libs/hashtable_class_helper.pxi":3971
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = Float32Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3975
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->table), __pyx_n_s_get_labels); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_float32_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "pandas/_libs/hashtable_class_helper.pxi":3976
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,             # <<<<<<<<<<<<<<
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_self->__pyx_base.count); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3976, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "pandas/_libs/hashtable_class_helper.pxi":3975
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_5 = PyTuple_New(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3)) __PYX_ERR(2, 3975, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self->uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_self->uniques))) __PYX_ERR(2, 3975, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_4)) __PYX_ERR(2, 3975, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_na_sentinel);
  __Pyx_GIVEREF(__pyx_v_na_sentinel);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_v_na_sentinel)) __PYX_ERR(2, 3975, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3977
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)             # <<<<<<<<<<<<<<
 *         self.count = len(self.uniques)
 *         return labels
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 3977, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 3977, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3975
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 3975, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 3975, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
    __pyx_t_7 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_7 < 0)) {
      PyErr_Fetch(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_v_labels, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      }
      __pyx_t_8 = __pyx_t_9 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_labels.diminfo[0].strides = __pyx_pybuffernd_labels.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_labels.diminfo[0].shape = __pyx_pybuffernd_labels.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(2, 3975, __pyx_L1_error)
  }
  __pyx_t_6 = 0;
  __pyx_v_labels = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3978
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  __pyx_t_3 = ((PyObject *)__pyx_v_self->uniques);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_11 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(2, 3978, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_self->__pyx_base.count = __pyx_t_11;

  /* "pandas/_libs/hashtable_class_helper.pxi":3979
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * cdef class UInt32HashTable(HashTable):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_labels);
  __pyx_r = ((PyObject *)__pyx_v_labels);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3953
 *         self.uniques = Float32Vector()
 * 
 *     def factorize(self, const float32_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_labels);
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3946
 * cdef class Float32Factorizer(Factorizer):
 *     cdef public:
 *         Float32HashTable table             # <<<<<<<<<<<<<<
 *         Float32Vector uniques
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_5table_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_5table_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_5table___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->table);
  __pyx_r = ((PyObject *)__pyx_v_self->table);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_5table_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable))))) __PYX_ERR(2, 3946, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32Factorizer.table.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_5table_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_5table_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_5table_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3947
 *     cdef public:
 *         Float32HashTable table
 *         Float32Vector uniques             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, size_hint: int):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_7uniques_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_7uniques_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_7uniques___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __pyx_r = ((PyObject *)__pyx_v_self->uniques);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_7uniques_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector))))) __PYX_ERR(2, 3947, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32Factorizer.uniques.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_7uniques_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_7uniques_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_7uniques_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_17Float32Factorizer_5__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_4__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32Factorizer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_17Float32Factorizer_7__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_6__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17Float32Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Float32Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3983
 * cdef class UInt32HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_uint32()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __pyx_t_5numpy_int64_t __pyx_v_size_hint;
  int __pyx_v_uses_mask;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,&__pyx_n_s_uses_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3983, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uses_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 3983, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 3983, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_size_hint = __Pyx_PyInt_As_npy_int64(values[0]); if (unlikely((__pyx_v_size_hint == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 3983, __pyx_L3_error)
    } else {
      __pyx_v_size_hint = ((__pyx_t_5numpy_int64_t)1);
    }
    if (values[1]) {
      __pyx_v_uses_mask = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_uses_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 3983, __pyx_L3_error)
    } else {
      __pyx_v_uses_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 0, 2, __pyx_nargs); __PYX_ERR(2, 3983, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)__pyx_v_self), __pyx_v_size_hint, __pyx_v_uses_mask);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  khuint_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __pyx_t_5numpy_int64_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":3984
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_uint32()             # <<<<<<<<<<<<<<
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_uint32(self.table, size_hint)
 */
  __pyx_v_self->table = kh_init_uint32();

  /* "pandas/_libs/hashtable_class_helper.pxi":3985
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_uint32()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)             # <<<<<<<<<<<<<<
 *         kh_resize_uint32(self.table, size_hint)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = kh_needed_n_buckets(__pyx_v_size_hint);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3985, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_1, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3985, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(2, 3985, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_6) {
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_5 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3985, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_int64(__pyx_t_3); if (unlikely((__pyx_t_7 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 3985, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_size_hint = __pyx_t_7;

  /* "pandas/_libs/hashtable_class_helper.pxi":3986
 *         self.table = kh_init_uint32()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_uint32(self.table, size_hint)             # <<<<<<<<<<<<<<
 * 
 *         self.uses_mask = uses_mask
 */
  kh_resize_uint32(__pyx_v_self->table, __pyx_v_size_hint);

  /* "pandas/_libs/hashtable_class_helper.pxi":3988
 *         kh_resize_uint32(self.table, size_hint)
 * 
 *         self.uses_mask = uses_mask             # <<<<<<<<<<<<<<
 *         self.na_position = -1
 * 
 */
  __pyx_v_self->uses_mask = __pyx_v_uses_mask;

  /* "pandas/_libs/hashtable_class_helper.pxi":3989
 * 
 *         self.uses_mask = uses_mask
 *         self.na_position = -1             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
  __pyx_v_self->na_position = -1LL;

  /* "pandas/_libs/hashtable_class_helper.pxi":3983
 * cdef class UInt32HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_uint32()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3991
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_3__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_3__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_2__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  long __pyx_t_1;
  int __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":3992
 * 
 *     def __len__(self) -> int:
 *         return self.table.size + (0 if self.na_position == -1 else 1)             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_2 = (__pyx_v_self->na_position == -1LL);
  if (__pyx_t_2) {
    __pyx_t_1 = 0;
  } else {
    __pyx_t_1 = 1;
  }
  __pyx_r = (__pyx_v_self->table->size + __pyx_t_1);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3991
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":3994
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_uint32(self.table)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_5__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_5__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_4__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":3995
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_uint32(self.table)
 *             self.table = NULL
 */
  __pyx_t_1 = (__pyx_v_self->table != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":3996
 *     def __dealloc__(self):
 *         if self.table is not NULL:
 *             kh_destroy_uint32(self.table)             # <<<<<<<<<<<<<<
 *             self.table = NULL
 * 
 */
    kh_destroy_uint32(__pyx_v_self->table);

    /* "pandas/_libs/hashtable_class_helper.pxi":3997
 *         if self.table is not NULL:
 *             kh_destroy_uint32(self.table)
 *             self.table = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __contains__(self, object key) -> bool:
 */
    __pyx_v_self->table = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":3995
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_uint32(self.table)
 *             self.table = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":3994
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_uint32(self.table)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":3999
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__contains__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_6__contains__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)__pyx_v_self), ((PyObject *)__pyx_v_key));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, PyObject *__pyx_v_key) {
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_uint32_t __pyx_v_ckey;
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  __pyx_t_5numpy_uint32_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4006
 *             uint32_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_1 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_7missing_checknull(__pyx_v_key, 0, NULL); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4006, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4007
 * 
 *         if self.uses_mask and checknull(key):
 *             return -1 != self.na_position             # <<<<<<<<<<<<<<
 * 
 *         ckey = (key)
 */
    __pyx_r = (-1LL != __pyx_v_self->na_position);
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":4006
 *             uint32_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4009
 *             return -1 != self.na_position
 * 
 *         ckey = (key)             # <<<<<<<<<<<<<<
 *         k = kh_get_uint32(self.table, ckey)
 *         return k != self.table.n_buckets
 */
  __pyx_t_3 = __Pyx_PyInt_As_npy_uint32(__pyx_v_key); if (unlikely((__pyx_t_3 == ((npy_uint32)-1)) && PyErr_Occurred())) __PYX_ERR(2, 4009, __pyx_L1_error)
  __pyx_v_ckey = __pyx_t_3;

  /* "pandas/_libs/hashtable_class_helper.pxi":4010
 * 
 *         ckey = (key)
 *         k = kh_get_uint32(self.table, ckey)             # <<<<<<<<<<<<<<
 *         return k != self.table.n_buckets
 * 
 */
  __pyx_v_k = kh_get_uint32(__pyx_v_self->table, __pyx_v_ckey);

  /* "pandas/_libs/hashtable_class_helper.pxi":4011
 *         ckey = (key)
 *         k = kh_get_uint32(self.table, ckey)
 *         return k != self.table.n_buckets             # <<<<<<<<<<<<<<
 * 
 *     def sizeof(self, deep: bool = False) -> int:
 */
  __pyx_r = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3999
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4013
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15UInt32HashTable_8sizeof, " return the size of my table in bytes ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_9sizeof = {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt32HashTable_8sizeof};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_deep = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sizeof (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_deep,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_deep);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4013, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "sizeof") < 0)) __PYX_ERR(2, 4013, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_deep = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sizeof", 0, 0, 1, __pyx_nargs); __PYX_ERR(2, 4013, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_8sizeof(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)__pyx_v_self), __pyx_v_deep);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep) {
  PyObject *__pyx_v_overhead = NULL;
  PyObject *__pyx_v_for_flags = NULL;
  PyObject *__pyx_v_for_pairs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  long __pyx_t_2;
  long __pyx_t_3;
  long __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sizeof", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":4015
 *     def sizeof(self, deep: bool = False) -> int:
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)             # <<<<<<<<<<<<<<
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(uint32_t) + # keys
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(((4 * (sizeof(__pyx_t_5numpy_uint32_t))) + (3 * (sizeof(__pyx_t_5numpy_uint32_t *))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4015, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_overhead = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4016
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)             # <<<<<<<<<<<<<<
 *         for_pairs =  self.table.n_buckets * (sizeof(uint32_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 */
  __pyx_t_2 = (__pyx_v_self->table->n_buckets >> 5);
  __pyx_t_3 = 1;
  __pyx_t_5 = (__pyx_t_2 > __pyx_t_3);
  if (__pyx_t_5) {
    __pyx_t_4 = __pyx_t_2;
  } else {
    __pyx_t_4 = __pyx_t_3;
  }
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_t_4 * (sizeof(__pyx_t_5numpy_uint32_t)))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4016, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_flags = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4017
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(uint32_t) + # keys             # <<<<<<<<<<<<<<
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->n_buckets * ((sizeof(__pyx_t_5numpy_uint32_t)) + (sizeof(Py_ssize_t))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4017, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_pairs = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4019
 *         for_pairs =  self.table.n_buckets * (sizeof(uint32_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs             # <<<<<<<<<<<<<<
 * 
 *     def get_state(self) -> dict[str, int]:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Add(__pyx_v_overhead, __pyx_v_for_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyNumber_Add(__pyx_t_1, __pyx_v_for_pairs); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(__Pyx_Py3Int_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None) || __Pyx_RaiseUnexpectedTypeError("int", __pyx_t_6))) __PYX_ERR(2, 4019, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4013
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_overhead);
  __Pyx_XDECREF(__pyx_v_for_flags);
  __Pyx_XDECREF(__pyx_v_for_pairs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4021
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15UInt32HashTable_10get_state, " returns infos about the state of the hashtable");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_11get_state = {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt32HashTable_10get_state};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_state (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_state", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_state", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_10get_state(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_state", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":4023
 *     def get_state(self) -> dict[str, int]:
 *         """ returns infos about the state of the hashtable"""
 *         return {             # <<<<<<<<<<<<<<
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 */
  __Pyx_XDECREF(__pyx_r);

  /* "pandas/_libs/hashtable_class_helper.pxi":4024
 *         """ returns infos about the state of the hashtable"""
 *         return {
 *             'n_buckets' : self.table.n_buckets,             # <<<<<<<<<<<<<<
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_buckets); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4024, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_buckets, __pyx_t_2) < 0) __PYX_ERR(2, 4024, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4025
 *         return {
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,             # <<<<<<<<<<<<<<
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->size); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4025, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_size, __pyx_t_2) < 0) __PYX_ERR(2, 4024, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4026
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,             # <<<<<<<<<<<<<<
 *             'upper_bound' : self.table.upper_bound,
 *         }
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_occupied); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4026, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_occupied, __pyx_t_2) < 0) __PYX_ERR(2, 4024, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4027
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,             # <<<<<<<<<<<<<<
 *         }
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->upper_bound); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_upper_bound, __pyx_t_2) < 0) __PYX_ERR(2, 4024, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4021
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.get_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4030
 *         }
 * 
 *     cpdef get_item(self, uint32_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt32HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, __pyx_t_5numpy_uint32_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_uint32_t __pyx_v_cval;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4030, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_13get_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyInt_From_npy_uint32(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4030, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4030, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4049
 *             uint32_t cval
 * 
 *         cval = (val)             # <<<<<<<<<<<<<<
 *         k = kh_get_uint32(self.table, cval)
 *         if k != self.table.n_buckets:
 */
  __pyx_v_cval = __pyx_v_val;

  /* "pandas/_libs/hashtable_class_helper.pxi":4050
 * 
 *         cval = (val)
 *         k = kh_get_uint32(self.table, cval)             # <<<<<<<<<<<<<<
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]
 */
  __pyx_v_k = kh_get_uint32(__pyx_v_self->table, __pyx_v_cval);

  /* "pandas/_libs/hashtable_class_helper.pxi":4051
 *         cval = (val)
 *         k = kh_get_uint32(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  __pyx_t_7 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  if (likely(__pyx_t_7)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4052
 *         k = kh_get_uint32(self.table, cval)
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(val)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->vals[__pyx_v_k])); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4052, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":4051
 *         cval = (val)
 *         k = kh_get_uint32(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4054
 *             return self.table.vals[k]
 *         else:
 *             raise KeyError(val)             # <<<<<<<<<<<<<<
 * 
 *     cpdef get_na(self):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyInt_From_npy_uint32(__pyx_v_val); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4054, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4054, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 4054, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4030
 *         }
 * 
 *     cpdef get_item(self, uint32_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15UInt32HashTable_12get_item, "Extracts the position of val from the hashtable.\n\n        Parameters\n        ----------\n        val : Scalar\n            The value that is looked up in the hashtable\n\n        Returns\n        -------\n        The position of the requested integer.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_13get_item = {"get_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_13get_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt32HashTable_12get_item};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_5numpy_uint32_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4030, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_item") < 0)) __PYX_ERR(2, 4030, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __Pyx_PyInt_As_npy_uint32(values[0]); if (unlikely((__pyx_v_val == ((npy_uint32)-1)) && PyErr_Occurred())) __PYX_ERR(2, 4030, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_item", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 4030, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_12get_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, __pyx_t_5numpy_uint32_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_15UInt32HashTable_get_item(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4030, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4056
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt32HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4056, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_15get_na)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4056, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4064
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_6 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4065
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         if self.na_position == -1:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 4065, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":4064
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4067
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  __pyx_t_6 = (__pyx_v_self->na_position == -1LL);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4068
 * 
 *         if self.na_position == -1:
 *             raise KeyError("NA")             # <<<<<<<<<<<<<<
 *         return self.na_position
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_KeyError, __pyx_tuple__13, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4068, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(2, 4068, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":4067
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4069
 *         if self.na_position == -1:
 *             raise KeyError("NA")
 *         return self.na_position             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_item(self, uint32_t key, Py_ssize_t val):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->na_position); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4069, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4056
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15UInt32HashTable_14get_na, "Extracts the position of na_value from the hashtable.\n\n        Returns\n        -------\n        The position of the last na value.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_15get_na = {"get_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_15get_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt32HashTable_14get_na};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_na", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_na", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_14get_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_15UInt32HashTable_get_na(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4071
 *         return self.na_position
 * 
 *     cpdef set_item(self, uint32_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt32HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, __pyx_t_5numpy_uint32_t __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  __pyx_t_5numpy_uint32_t __pyx_v_ckey;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4071, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_17set_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyInt_From_npy_uint32(__pyx_v_key); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4071, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4071, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_5 = __pyx_t_1; __pyx_t_6 = NULL;
        __pyx_t_7 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_7 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_3, __pyx_t_4};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4071, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4076
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             uint32_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4079
 *             uint32_t ckey
 * 
 *         ckey = (key)             # <<<<<<<<<<<<<<
 *         k = kh_put_uint32(self.table, ckey, &ret)
 *         if kh_exist_uint32(self.table, k):
 */
  __pyx_v_ckey = __pyx_v_key;

  /* "pandas/_libs/hashtable_class_helper.pxi":4080
 * 
 *         ckey = (key)
 *         k = kh_put_uint32(self.table, ckey, &ret)             # <<<<<<<<<<<<<<
 *         if kh_exist_uint32(self.table, k):
 *             self.table.vals[k] = val
 */
  __pyx_v_k = kh_put_uint32(__pyx_v_self->table, __pyx_v_ckey, (&__pyx_v_ret));

  /* "pandas/_libs/hashtable_class_helper.pxi":4081
 *         ckey = (key)
 *         k = kh_put_uint32(self.table, ckey, &ret)
 *         if kh_exist_uint32(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
  __pyx_t_8 = kh_exist_uint32(__pyx_v_self->table, __pyx_v_k);
  if (likely(__pyx_t_8)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4082
 *         k = kh_put_uint32(self.table, ckey, &ret)
 *         if kh_exist_uint32(self.table, k):
 *             self.table.vals[k] = val             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(key)
 */
    (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_val;

    /* "pandas/_libs/hashtable_class_helper.pxi":4081
 *         ckey = (key)
 *         k = kh_put_uint32(self.table, ckey, &ret)
 *         if kh_exist_uint32(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4084
 *             self.table.vals[k] = val
 *         else:
 *             raise KeyError(key)             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_na(self, Py_ssize_t val):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyInt_From_npy_uint32(__pyx_v_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4084, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4084, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 4084, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "pandas/_libs/hashtable_class_helper.pxi":4071
 *         return self.na_position
 * 
 *     cpdef set_item(self, uint32_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_17set_item = {"set_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_17set_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_5numpy_uint32_t __pyx_v_key;
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key,&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4071, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4071, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, 1); __PYX_ERR(2, 4071, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_item") < 0)) __PYX_ERR(2, 4071, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_key = __Pyx_PyInt_As_npy_uint32(values[0]); if (unlikely((__pyx_v_key == ((npy_uint32)-1)) && PyErr_Occurred())) __PYX_ERR(2, 4071, __pyx_L3_error)
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 4071, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, __pyx_nargs); __PYX_ERR(2, 4071, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_16set_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)__pyx_v_self), __pyx_v_key, __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, __pyx_t_5numpy_uint32_t __pyx_v_key, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_15UInt32HashTable_set_item(__pyx_v_self, __pyx_v_key, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4086
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt32HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  CYTHON_UNUSED int __pyx_v_ret;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4086, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_19set_na)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4086, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4086, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4090
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             uint32_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4093
 *             uint32_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_7 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_7)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4094
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         self.na_position = val
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 4094, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":4093
 *             uint32_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4096
 *             raise NotImplementedError
 * 
 *         self.na_position = val             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->na_position = __pyx_v_val;

  /* "pandas/_libs/hashtable_class_helper.pxi":4086
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_19set_na = {"set_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_19set_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4086, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_na") < 0)) __PYX_ERR(2, 4086, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[0]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 4086, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_na", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 4086, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_18set_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_15UInt32HashTable_set_na(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4099
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const uint32_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_21map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_21map_locations = {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_21map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_21map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("map_locations (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4099, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4099, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "map_locations") < 0)) __PYX_ERR(2, 4099, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint32_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 4100, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 4100, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__28;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("map_locations", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 4099, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_20map_locations(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_20map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  int __pyx_v_ret;
  __pyx_t_5numpy_uint32_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  __pyx_t_5numpy_int64_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("map_locations", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":4103
 *         # Used in libindex, safe_sort
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             uint32_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":4104
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             uint32_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4107
 *             uint32_t val
 *             khiter_t k
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_2 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":4109
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_3 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_3)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4110
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 4110, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":4109
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4112
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":4113
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
        if (__pyx_v_self->uses_mask) {

          /* "pandas/_libs/hashtable_class_helper.pxi":4114
 *         with nogil:
 *             if self.uses_mask:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     if mask[i]:
 *                         na_position = i
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":4115
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_mask.shape[0];
            __pyx_t_3 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) ))) != 0);
            if (__pyx_t_3) {

              /* "pandas/_libs/hashtable_class_helper.pxi":4116
 *                 for i in range(n):
 *                     if mask[i]:
 *                         na_position = i             # <<<<<<<<<<<<<<
 *                     else:
 *                         val= (values[i])
 */
              __pyx_v_na_position = __pyx_v_i;

              /* "pandas/_libs/hashtable_class_helper.pxi":4115
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
              goto __pyx_L12;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":4118
 *                         na_position = i
 *                     else:
 *                         val= (values[i])             # <<<<<<<<<<<<<<
 *                         k = kh_put_uint32(self.table, val, &ret)
 *                         self.table.vals[k] = i
 */
            /*else*/ {
              __pyx_t_7 = __pyx_v_i;
              if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
              __pyx_v_val = (*((__pyx_t_5numpy_uint32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_class_helper.pxi":4119
 *                     else:
 *                         val= (values[i])
 *                         k = kh_put_uint32(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = i
 *             else:
 */
              __pyx_v_k = kh_put_uint32(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

              /* "pandas/_libs/hashtable_class_helper.pxi":4120
 *                         val= (values[i])
 *                         k = kh_put_uint32(self.table, val, &ret)
 *                         self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *             else:
 *                 for i in range(n):
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
            }
            __pyx_L12:;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":4113
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
          goto __pyx_L9;
        }

        /* "pandas/_libs/hashtable_class_helper.pxi":4122
 *                         self.table.vals[k] = i
 *             else:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     val= (values[i])
 *                     k = kh_put_uint32(self.table, val, &ret)
 */
        /*else*/ {
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":4123
 *             else:
 *                 for i in range(n):
 *                     val= (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_put_uint32(self.table, val, &ret)
 *                     self.table.vals[k] = i
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
            __pyx_v_val = (*((__pyx_t_5numpy_uint32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

            /* "pandas/_libs/hashtable_class_helper.pxi":4124
 *                 for i in range(n):
 *                     val= (values[i])
 *                     k = kh_put_uint32(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                     self.table.vals[k] = i
 *         self.na_position = na_position
 */
            __pyx_v_k = kh_put_uint32(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":4125
 *                     val= (values[i])
 *                     k = kh_put_uint32(self.table, val, &ret)
 *                     self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *         self.na_position = na_position
 * 
 */
            (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
          }
        }
        __pyx_L9:;
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":4112
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4126
 *                     k = kh_put_uint32(self.table, val, &ret)
 *                     self.table.vals[k] = i
 *         self.na_position = na_position             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __pyx_v_self->na_position = __pyx_v_na_position;

  /* "pandas/_libs/hashtable_class_helper.pxi":4099
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const uint32_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4128
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const uint32_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

/* Python wrapper */
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_23lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_23lookup = {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_23lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_23lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyArrayObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lookup (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4128, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4128, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lookup") < 0)) __PYX_ERR(2, 4128, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint32_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 4129, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 4129, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__29;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lookup", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 4128, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_22lookup(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_22lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  CYTHON_UNUSED int __pyx_v_ret;
  __pyx_t_5numpy_uint32_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __Pyx_memviewslice __pyx_v_locs = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lookup", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":4133
 *         # Used in safe_sort, IndexEngine.get_indexer
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             uint32_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":4134
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             uint32_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4137
 *             uint32_t val
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *             int8_t na_position = self.na_position
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 4137, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 4137, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4137, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 4137, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_locs = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":4138
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_8 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":4140
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_9 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_10 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_9 = __pyx_t_10;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4141
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 4141, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":4140
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4143
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":4144
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_11 = __pyx_t_1;
        for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
          __pyx_v_i = __pyx_t_12;

          /* "pandas/_libs/hashtable_class_helper.pxi":4145
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
          if (__pyx_v_self->uses_mask) {
          } else {
            __pyx_t_9 = __pyx_v_self->uses_mask;
            goto __pyx_L12_bool_binop_done;
          }
          __pyx_t_13 = __pyx_v_i;
          if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_mask.shape[0];
          __pyx_t_10 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_13 * __pyx_v_mask.strides[0]) ))) != 0);
          __pyx_t_9 = __pyx_t_10;
          __pyx_L12_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":4146
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position             # <<<<<<<<<<<<<<
 *                 else:
 *                     val = (values[i])
 */
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = __pyx_v_na_position;

            /* "pandas/_libs/hashtable_class_helper.pxi":4145
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
            goto __pyx_L11;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":4148
 *                     locs[i] = na_position
 *                 else:
 *                     val = (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_uint32(self.table, val)
 *                     if k != self.table.n_buckets:
 */
          /*else*/ {
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_values.shape[0];
            __pyx_v_val = (*((__pyx_t_5numpy_uint32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_13 * __pyx_v_values.strides[0]) )));

            /* "pandas/_libs/hashtable_class_helper.pxi":4149
 *                 else:
 *                     val = (values[i])
 *                     k = kh_get_uint32(self.table, val)             # <<<<<<<<<<<<<<
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]
 */
            __pyx_v_k = kh_get_uint32(__pyx_v_self->table, __pyx_v_val);

            /* "pandas/_libs/hashtable_class_helper.pxi":4150
 *                     val = (values[i])
 *                     k = kh_get_uint32(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
            __pyx_t_9 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":4151
 *                     k = kh_get_uint32(self.table, val)
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     else:
 *                         locs[i] = -1
 */
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = (__pyx_v_self->table->vals[__pyx_v_k]);

              /* "pandas/_libs/hashtable_class_helper.pxi":4150
 *                     val = (values[i])
 *                     k = kh_get_uint32(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
              goto __pyx_L14;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":4153
 *                         locs[i] = self.table.vals[k]
 *                     else:
 *                         locs[i] = -1             # <<<<<<<<<<<<<<
 * 
 *         return np.asarray(locs)
 */
            /*else*/ {
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = -1;
            }
            __pyx_L14:;
          }
          __pyx_L11:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":4143
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4155
 *                         locs[i] = -1
 * 
 *         return np.asarray(locs)             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_locs, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4155, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_14 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_14 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4155, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 4155, __pyx_L1_error)
  __pyx_r = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4128
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const uint32_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_locs, 1);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4157
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const uint32_t[:] values, UInt32Vector uniques,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_25_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15UInt32HashTable_24_unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[uint32]\n            Array of values of which unique will be calculated\n        uniques : UInt32Vector\n            Vector into which uniques will be written\n        count_prior : Py_ssize_t, default 0\n            Number of existing entries in uniques\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        ignore_na : bool, default False\n            Whether NA-values should be ignored for calculating the uniques. If\n            True, the labels corresponding to missing values will be set to\n            na_sentinel.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        use_result_mask: bool, default False\n            Whether to create a result mask for the unique values. Not supported\n            with return_inverse=True.\n\n        Returns\n        -------\n        uniques : ndarray[uint32]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse=True)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if use_result_mask is true\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_25_unique = {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_25_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt32HashTable_24_unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_25_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  int __pyx_v_ignore_na;
  PyObject *__pyx_v_mask = 0;
  int __pyx_v_return_inverse;
  int __pyx_v_use_result_mask;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[9] = {0,0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_ignore_na,&__pyx_n_s_mask,&__pyx_n_s_return_inverse,&__pyx_n_s_use_result_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":4161
 *     def _unique(self, const uint32_t[:] values, UInt32Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));

    /* "pandas/_libs/hashtable_class_helper.pxi":4162
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[6] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4157, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4157, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, 1); __PYX_ERR(2, 4157, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4157, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4157, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4157, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4157, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[6] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4157, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[7] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4157, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_use_result_mask);
          if (value) { values[8] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4157, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_unique") < 0)) __PYX_ERR(2, 4157, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint32_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 4159, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 4160, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 4160, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    if (values[5]) {
      __pyx_v_ignore_na = __Pyx_PyObject_IsTrue(values[5]); if (unlikely((__pyx_v_ignore_na == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 4161, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":4161
 *     def _unique(self, const uint32_t[:] values, UInt32Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
      __pyx_v_ignore_na = ((int)0);
    }
    __pyx_v_mask = values[6];
    if (values[7]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[7]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 4162, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":4162
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
      __pyx_v_return_inverse = ((int)0);
    }
    if (values[8]) {
      __pyx_v_use_result_mask = __Pyx_PyObject_IsTrue(values[8]); if (unlikely((__pyx_v_use_result_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 4162, __pyx_L3_error)
    } else {
      __pyx_v_use_result_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, __pyx_nargs); __PYX_ERR(2, 4157, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector, 1, "uniques", 0))) __PYX_ERR(2, 4159, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_24_unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_ignore_na, __pyx_v_mask, __pyx_v_return_inverse, __pyx_v_use_result_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":4157
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const uint32_t[:] values, UInt32Vector uniques,
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_24_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_idx;
  Py_ssize_t __pyx_v_count;
  Py_ssize_t __pyx_v_n;
  __Pyx_memviewslice __pyx_v_labels = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_ret;
  __pyx_t_5numpy_uint32_t __pyx_v_val;
  __pyx_t_5numpy_uint32_t __pyx_v_na_value2;
  khiter_t __pyx_v_k;
  __pyx_t_6pandas_5_libs_9hashtable_UInt32VectorData *__pyx_v_ud;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_result_mask = 0;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_v_rmd;
  int __pyx_v_use_na_value;
  int __pyx_v_use_mask;
  int __pyx_v_seen_na;
  __Pyx_memviewslice __pyx_v_mask_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_6pandas_5_libs_9hashtable_UInt32VectorData *__pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_t_11;
  int __pyx_t_12;
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_uint32_t __pyx_t_14;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":4206
 *         """
 *         cdef:
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)             # <<<<<<<<<<<<<<
 *             intp_t[::1] labels
 *             int ret = 0
 */
  __pyx_v_count = __pyx_v_count_prior;
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":4208
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)
 *             intp_t[::1] labels
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             uint32_t val, na_value2
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4214
 *             UInt8Vector result_mask
 *             UInt8VectorData *rmd
 *             bint use_na_value, use_mask, seen_na = False             # <<<<<<<<<<<<<<
 *             uint8_t[:] mask_values
 * 
 */
  __pyx_v_seen_na = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4217
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4218
 * 
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 4218, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 4218, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4218, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 4218, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_labels = __pyx_t_7;
    __pyx_t_7.memview = NULL;
    __pyx_t_7.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":4217
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4219
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data             # <<<<<<<<<<<<<<
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 */
  __pyx_t_8 = __pyx_v_uniques->data;
  __pyx_v_ud = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":4220
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 *         use_na_value = na_value is not None             # <<<<<<<<<<<<<<
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 */
  __pyx_t_9 = (__pyx_v_na_value != Py_None);
  __pyx_v_use_na_value = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":4221
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None             # <<<<<<<<<<<<<<
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover
 */
  __pyx_t_9 = (__pyx_v_mask != Py_None);
  __pyx_v_use_mask = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":4222
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  __pyx_t_10 = (!__pyx_v_use_mask);
  if (__pyx_t_10) {
  } else {
    __pyx_t_9 = __pyx_t_10;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_use_result_mask;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4223
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         if use_result_mask and return_inverse:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 4223, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":4222
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4225
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_use_result_mask) {
  } else {
    __pyx_t_9 = __pyx_v_use_result_mask;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_return_inverse;
  __pyx_L8_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4226
 * 
 *         if use_result_mask and return_inverse:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         result_mask = UInt8Vector()
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 4226, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":4225
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4228
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         result_mask = UInt8Vector()             # <<<<<<<<<<<<<<
 *         rmd = result_mask.data
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_v_result_mask = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4229
 * 
 *         result_mask = UInt8Vector()
 *         rmd = result_mask.data             # <<<<<<<<<<<<<<
 * 
 *         if use_mask:
 */
  __pyx_t_11 = __pyx_v_result_mask->data;
  __pyx_v_rmd = __pyx_t_11;

  /* "pandas/_libs/hashtable_class_helper.pxi":4231
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  if (__pyx_v_use_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4232
 * 
 *         if use_mask:
 *             mask_values = mask.view("uint8")             # <<<<<<<<<<<<<<
 * 
 *         if use_na_value:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_mask, __pyx_n_s_view); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4232, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    __pyx_t_12 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_12 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_uint8};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_12, 1+__pyx_t_12);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4232, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(2, 4232, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_mask_values = __pyx_t_13;
    __pyx_t_13.memview = NULL;
    __pyx_t_13.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":4231
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4234
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
  if (__pyx_v_use_na_value) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4240
 *             # for the parameter. To please the compiler, we use na_value2,
 *             # which is only used if it's *specified*.
 *             na_value2 = (na_value)             # <<<<<<<<<<<<<<
 *         else:
 *             na_value2 = (0)
 */
    __pyx_t_14 = __Pyx_PyInt_As_npy_uint32(__pyx_v_na_value); if (unlikely((__pyx_t_14 == ((npy_uint32)-1)) && PyErr_Occurred())) __PYX_ERR(2, 4240, __pyx_L1_error)
    __pyx_v_na_value2 = __pyx_t_14;

    /* "pandas/_libs/hashtable_class_helper.pxi":4234
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
    goto __pyx_L11;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4242
 *             na_value2 = (na_value)
 *         else:
 *             na_value2 = (0)             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
  /*else*/ {
    __pyx_v_na_value2 = 0;
  }
  __pyx_L11:;

  /* "pandas/_libs/hashtable_class_helper.pxi":4244
 *             na_value2 = (0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = (values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":4245
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 val = (values[i])
 * 
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_15 = __pyx_t_1;
        for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
          __pyx_v_i = __pyx_t_16;

          /* "pandas/_libs/hashtable_class_helper.pxi":4246
 *         with nogil:
 *             for i in range(n):
 *                 val = (values[i])             # <<<<<<<<<<<<<<
 * 
 *                 if ignore_na and use_mask:
 */
          __pyx_t_17 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_uint32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_17 * __pyx_v_values.strides[0]) )));

          /* "pandas/_libs/hashtable_class_helper.pxi":4248
 *                 val = (values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L18_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_mask;
          __pyx_L18_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":4249
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 4249, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_17 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":4250
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                         continue
 *                 elif ignore_na and (
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 4250, __pyx_L13_error) }
              __pyx_t_17 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_na_sentinel;

              /* "pandas/_libs/hashtable_class_helper.pxi":4251
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 *                         continue             # <<<<<<<<<<<<<<
 *                 elif ignore_na and (
 *                    is_nan_uint32_t(val) or
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":4249
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":4248
 *                 val = (values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
            goto __pyx_L17;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":4252
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_uint32_t(val) or
 *                    (use_na_value and are_equivalent_uint32_t(val, na_value2))
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":4253
 *                         continue
 *                 elif ignore_na and (
 *                    is_nan_uint32_t(val) or             # <<<<<<<<<<<<<<
 *                    (use_na_value and are_equivalent_uint32_t(val, na_value2))
 *                 ):
 */
          __pyx_t_10 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_uint32_t(__pyx_v_val); if (unlikely(__pyx_t_10 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 4253, __pyx_L13_error)
          if (!__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":4254
 *                 elif ignore_na and (
 *                    is_nan_uint32_t(val) or
 *                    (use_na_value and are_equivalent_uint32_t(val, na_value2))             # <<<<<<<<<<<<<<
 *                 ):
 *                     # if missing values do not count as unique values (i.e. if
 */
          if (__pyx_v_use_na_value) {
          } else {
            __pyx_t_9 = __pyx_v_use_na_value;
            goto __pyx_L21_bool_binop_done;
          }
          __pyx_t_10 = __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_uint32_t(__pyx_v_val, __pyx_v_na_value2); if (unlikely(__pyx_t_10 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 4254, __pyx_L13_error)
          __pyx_t_9 = __pyx_t_10;
          __pyx_L21_bool_binop_done:;

          /* "pandas/_libs/hashtable_class_helper.pxi":4252
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_uint32_t(val) or
 *                    (use_na_value and are_equivalent_uint32_t(val, na_value2))
 */
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":4259
 *                     # ignore_na is True), skip the hashtable entry for them,
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 4259, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_na_sentinel;

            /* "pandas/_libs/hashtable_class_helper.pxi":4260
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel
 *                     continue             # <<<<<<<<<<<<<<
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 */
            goto __pyx_L15_continue;

            /* "pandas/_libs/hashtable_class_helper.pxi":4252
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_uint32_t(val) or
 *                    (use_na_value and are_equivalent_uint32_t(val, na_value2))
 */
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":4261
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          __pyx_t_10 = (!__pyx_v_ignore_na);
          if (__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L25_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_result_mask;
          __pyx_L25_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":4262
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 4262, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_17 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":4263
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_class_helper.pxi":4264
 *                     if mask_values[i]:
 *                         if seen_na:
 *                             continue             # <<<<<<<<<<<<<<
 * 
 *                         seen_na = True
 */
                goto __pyx_L15_continue;

                /* "pandas/_libs/hashtable_class_helper.pxi":4263
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":4266
 *                             continue
 * 
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         if needs_resize(ud):
 *                             with gil:
 */
              __pyx_v_seen_na = 1;

              /* "pandas/_libs/hashtable_class_helper.pxi":4267
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              __pyx_t_9 = __pyx_fuse_5__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 4267, __pyx_L13_error)
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_class_helper.pxi":4268
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                {
                    #ifdef WITH_THREAD
                    PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                    #endif
                    /*try:*/ {

                      /* "pandas/_libs/hashtable_class_helper.pxi":4269
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":4270
 *                             with gil:
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4270, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 4270, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":4269
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":4273
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt32Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4273, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":4274
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":4275
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4275, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 4275, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":4274
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":4278
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                         append_data_uint32(ud, val)
 *                         append_data_uint8(rmd, 1)
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4278, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":4268
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    /*finally:*/ {
                      /*normal exit:*/{
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L34;
                      }
                      __pyx_L33_error: {
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L13_error;
                      }
                      __pyx_L34:;
                    }
                }

                /* "pandas/_libs/hashtable_class_helper.pxi":4267
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":4279
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                         append_data_uint32(ud, val)             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 1)
 *                         continue
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint32(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 4279, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":4280
 *                                 result_mask.resize()
 *                         append_data_uint32(ud, val)
 *                         append_data_uint8(rmd, 1)             # <<<<<<<<<<<<<<
 *                         continue
 * 
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 1); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 4280, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":4281
 *                         append_data_uint32(ud, val)
 *                         append_data_uint8(rmd, 1)
 *                         continue             # <<<<<<<<<<<<<<
 * 
 *                 k = kh_get_uint32(self.table, val)
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":4262
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":4261
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          }
          __pyx_L17:;

          /* "pandas/_libs/hashtable_class_helper.pxi":4283
 *                         continue
 * 
 *                 k = kh_get_uint32(self.table, val)             # <<<<<<<<<<<<<<
 * 
 *                 if k == self.table.n_buckets:
 */
          __pyx_v_k = kh_get_uint32(__pyx_v_self->table, __pyx_v_val);

          /* "pandas/_libs/hashtable_class_helper.pxi":4285
 *                 k = kh_get_uint32(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_uint32(self.table, val, &ret)
 */
          __pyx_t_9 = (__pyx_v_k == __pyx_v_self->table->n_buckets);
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":4287
 *                 if k == self.table.n_buckets:
 *                     # k hasn't been seen yet
 *                     k = kh_put_uint32(self.table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *                     if needs_resize(ud):
 */
            __pyx_v_k = kh_put_uint32(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":4289
 *                     k = kh_put_uint32(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            __pyx_t_9 = __pyx_fuse_5__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 4289, __pyx_L13_error)
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":4290
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
              {
                  #ifdef WITH_THREAD
                  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                  #endif
                  /*try:*/ {

                    /* "pandas/_libs/hashtable_class_helper.pxi":4291
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":4292
 *                         with gil:
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 */
                      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4292, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                      __PYX_ERR(2, 4292, __pyx_L42_error)

                      /* "pandas/_libs/hashtable_class_helper.pxi":4291
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":4295
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()             # <<<<<<<<<<<<<<
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 */
                    __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt32Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4295, __pyx_L42_error)
                    __Pyx_GOTREF(__pyx_t_6);
                    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                    /* "pandas/_libs/hashtable_class_helper.pxi":4296
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    if (__pyx_v_use_result_mask) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":4297
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":4298
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4298, __pyx_L42_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 4298, __pyx_L42_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":4297
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":4301
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                     append_data_uint32(ud, val)
 *                     if use_result_mask:
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4301, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":4296
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    }
                  }

                  /* "pandas/_libs/hashtable_class_helper.pxi":4290
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
                  /*finally:*/ {
                    /*normal exit:*/{
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L43;
                    }
                    __pyx_L42_error: {
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L13_error;
                    }
                    __pyx_L43:;
                  }
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":4289
 *                     k = kh_put_uint32(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":4302
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                     append_data_uint32(ud, val)             # <<<<<<<<<<<<<<
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)
 */
            __pyx_f_6pandas_5_libs_9hashtable_append_data_uint32(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 4302, __pyx_L13_error)

            /* "pandas/_libs/hashtable_class_helper.pxi":4303
 *                                 result_mask.resize()
 *                     append_data_uint32(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            if (__pyx_v_use_result_mask) {

              /* "pandas/_libs/hashtable_class_helper.pxi":4304
 *                     append_data_uint32(ud, val)
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)             # <<<<<<<<<<<<<<
 * 
 *                     if return_inverse:
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 0); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 4304, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":4303
 *                                 result_mask.resize()
 *                     append_data_uint32(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":4306
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            if (__pyx_v_return_inverse) {

              /* "pandas/_libs/hashtable_class_helper.pxi":4307
 * 
 *                     if return_inverse:
 *                         self.table.vals[k] = count             # <<<<<<<<<<<<<<
 *                         labels[i] = count
 *                         count += 1
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":4308
 *                     if return_inverse:
 *                         self.table.vals[k] = count
 *                         labels[i] = count             # <<<<<<<<<<<<<<
 *                         count += 1
 *                 elif return_inverse:
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 4308, __pyx_L13_error) }
              __pyx_t_17 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":4309
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 *                         count += 1             # <<<<<<<<<<<<<<
 *                 elif return_inverse:
 *                     # k falls into a previous bucket
 */
              __pyx_v_count = (__pyx_v_count + 1);

              /* "pandas/_libs/hashtable_class_helper.pxi":4306
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":4285
 *                 k = kh_get_uint32(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_uint32(self.table, val, &ret)
 */
            goto __pyx_L37;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":4310
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          if (__pyx_v_return_inverse) {

            /* "pandas/_libs/hashtable_class_helper.pxi":4313
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     labels[i] = idx
 * 
 */
            __pyx_v_idx = (__pyx_v_self->table->vals[__pyx_v_k]);

            /* "pandas/_libs/hashtable_class_helper.pxi":4314
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]
 *                     labels[i] = idx             # <<<<<<<<<<<<<<
 * 
 *         if return_inverse:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 4314, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_idx;

            /* "pandas/_libs/hashtable_class_helper.pxi":4310
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          }
          __pyx_L37:;
          __pyx_L15_continue:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":4244
 *             na_value2 = (0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = (values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L14;
        }
        __pyx_L13_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L14:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4316
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4317
 * 
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray             # <<<<<<<<<<<<<<
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt32Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4317, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundLocalError("labels"); __PYX_ERR(2, 4317, __pyx_L1_error) }
    __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_labels, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4317, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_base); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4317, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4317, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_6);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_6)) __PYX_ERR(2, 4317, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4)) __PYX_ERR(2, 4317, __pyx_L1_error);
    __pyx_t_6 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":4316
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4318
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  if (__pyx_v_use_result_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4319
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()             # <<<<<<<<<<<<<<
 *         return uniques.to_array()
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt32Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->to_array(__pyx_v_result_mask, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2)) __PYX_ERR(2, 4319, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4)) __PYX_ERR(2, 4319, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":4318
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4320
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()             # <<<<<<<<<<<<<<
 * 
 *     def unique(self, const uint32_t[:] values, bint return_inverse=False, object mask=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt32Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4320, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4157
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const uint32_t[:] values, UInt32Vector uniques,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_13, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_labels, 1);
  __Pyx_XDECREF((PyObject *)__pyx_v_result_mask);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask_values, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4322
 *         return uniques.to_array()
 * 
 *     def unique(self, const uint32_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_27unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15UInt32HashTable_26unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[uint32]\n            Array of values of which unique will be calculated\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n\n        Returns\n        -------\n        uniques : ndarray[uint32]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if mask is given as input\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_27unique = {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_27unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt32HashTable_26unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_27unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_return_inverse;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_return_inverse,&__pyx_n_s_mask,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4322, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4322, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4322, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "unique") < 0)) __PYX_ERR(2, 4322, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint32_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 4322, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 4322, __pyx_L3_error)
    } else {
      __pyx_v_return_inverse = ((int)0);
    }
    __pyx_v_mask = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("unique", 0, 1, 3, __pyx_nargs); __PYX_ERR(2, 4322, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_26unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_return_inverse, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_26unique(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_uniques = NULL;
  int __pyx_v_use_result_mask;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":4346
 *             The mask for the result values.
 *         """
 *         uniques = UInt32Vector()             # <<<<<<<<<<<<<<
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4346, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4347
 *         """
 *         uniques = UInt32Vector()
 *         use_result_mask = True if mask is not None else False             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 */
  __pyx_t_3 = (__pyx_v_mask != Py_None);
  if (__pyx_t_3) {
    __pyx_t_2 = 1;
  } else {
    __pyx_t_2 = 0;
  }
  __pyx_v_use_result_mask = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":4348
 *         uniques = UInt32Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint32_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4)) __PYX_ERR(2, 4348, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 4348, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ignore_na, Py_False) < 0) __PYX_ERR(2, 4348, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4349
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const uint32_t[:] values, Py_ssize_t na_sentinel=-1,
 */
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_return_inverse); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return_inverse, __pyx_t_6) < 0) __PYX_ERR(2, 4348, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 4348, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_use_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4349, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_use_result_mask, __pyx_t_6) < 0) __PYX_ERR(2, 4348, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4348
 *         uniques = UInt32Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4348, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4322
 *         return uniques.to_array()
 * 
 *     def unique(self, const uint32_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4351
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const uint32_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_29factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15UInt32HashTable_28factorize, "\n        Calculate unique values and labels (no sorting!)\n\n        Missing values are not included in the \"uniques\" for this method.\n        The labels for any missing values will be set to \"na_sentinel\"\n\n        Parameters\n        ----------\n        values : ndarray[uint32]\n            Array of values of which unique will be calculated\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n\n        Returns\n        -------\n        uniques : ndarray[uint32]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t]\n            The labels from values to uniques\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_29factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_29factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt32HashTable_28factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_29factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  PyObject *__pyx_v_ignore_na = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,&__pyx_n_s_ignore_na,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":4352
 * 
 *     def factorize(self, const uint32_t[:] values, Py_ssize_t na_sentinel=-1,
 *                   object na_value=None, object mask=None, ignore_na=True):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_True));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4351, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4351, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4351, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4351, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4351, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 4351, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint32_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 4351, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 4351, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
    __pyx_v_ignore_na = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 5, __pyx_nargs); __PYX_ERR(2, 4351, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_28factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask, __pyx_v_ignore_na);

  /* "pandas/_libs/hashtable_class_helper.pxi":4351
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const uint32_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_28factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_uniques_vector = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":4382
 *             The labels from values to uniques
 *         """
 *         uniques_vector = UInt32Vector()             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques_vector = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4383
 *         """
 *         uniques_vector = UInt32Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint32_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 4383, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques_vector);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques_vector))) __PYX_ERR(2, 4383, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 4383, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4384
 *         uniques_vector = UInt32Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,             # <<<<<<<<<<<<<<
 *                             return_inverse=True)
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 4383, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, __pyx_v_ignore_na) < 0) __PYX_ERR(2, 4383, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 4383, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4385
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)             # <<<<<<<<<<<<<<
 * 
 *     def get_labels(self, const uint32_t[:] values, UInt32Vector uniques,
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 4383, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4383
 *         """
 *         uniques_vector = UInt32Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4351
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const uint32_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4387
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const uint32_t[:] values, UInt32Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_31get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_31get_labels = {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_31get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_31get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_labels (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":4389
 *     def get_labels(self, const uint32_t[:] values, UInt32Vector uniques,
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4387, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4387, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, 1); __PYX_ERR(2, 4387, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4387, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4387, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4387, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4387, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_labels") < 0)) __PYX_ERR(2, 4387, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint32_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 4387, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 4388, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 4388, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    __pyx_v_mask = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, __pyx_nargs); __PYX_ERR(2, 4387, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector, 1, "uniques", 0))) __PYX_ERR(2, 4387, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_30get_labels(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":4387
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const uint32_t[:] values, UInt32Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_30get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_v_labels = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_labels", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":4391
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint32_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 4391, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 4391, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_count_prior); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_count_prior, __pyx_t_4) < 0) __PYX_ERR(2, 4391, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4392
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,             # <<<<<<<<<<<<<<
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 4391, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 4391, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4393
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, Py_True) < 0) __PYX_ERR(2, 4391, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 4391, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 4391, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4391
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
    PyObject* sequence = __pyx_t_4;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(2, 4391, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4391, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4391, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4391, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
    index = 0; __pyx_t_2 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_1), 2) < 0) __PYX_ERR(2, 4391, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(2, 4391, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v__ = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_labels = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4394
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_labels);
  __pyx_r = __pyx_v_labels;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4387
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const uint32_t[:] values, UInt32Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XDECREF(__pyx_v_labels);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_33__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_33__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_33__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_33__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_32__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_32__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_35__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_35__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_35__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_35__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_34__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt32HashTable_34__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4403
 *         UInt32Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = UInt32HashTable(size_hint)
 *         self.uniques = UInt32Vector()
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_size_hint = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4403, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 4403, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_size_hint = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 4403, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_size_hint), (&PyInt_Type), 0, "size_hint", 1))) __PYX_ERR(2, 4403, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *)__pyx_v_self), __pyx_v_size_hint);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":4404
 * 
 *     def __cinit__(self, size_hint: int):
 *         self.table = UInt32HashTable(size_hint)             # <<<<<<<<<<<<<<
 *         self.uniques = UInt32Vector()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable), __pyx_v_size_hint); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4404, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4405
 *     def __cinit__(self, size_hint: int):
 *         self.table = UInt32HashTable(size_hint)
 *         self.uniques = UInt32Vector()             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const uint32_t[:] values,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4405, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4403
 *         UInt32Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = UInt32HashTable(size_hint)
 *         self.uniques = UInt32Vector()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4407
 *         self.uniques = UInt32Vector()
 * 
 *     def factorize(self, const uint32_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_16UInt32Factorizer_2factorize, "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = UInt32Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"uint32\"), na_sentinel=20)\n        array([0, 1, 2])\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16UInt32Factorizer_3factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16UInt32Factorizer_2factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_v_na_sentinel = 0;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_neg_1));

    /* "pandas/_libs/hashtable_class_helper.pxi":4408
 * 
 *     def factorize(self, const uint32_t[:] values,
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:             # <<<<<<<<<<<<<<
 *         """
 *         Returns
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4407, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4407, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4407, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4407, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 4407, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint32_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 4407, __pyx_L3_error)
    __pyx_v_na_sentinel = values[1];
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 4, __pyx_nargs); __PYX_ERR(2, 4407, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_2factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":4407
 *         self.uniques = UInt32Vector()
 * 
 *     def factorize(self, const uint32_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  PyArrayObject *__pyx_v_labels = 0;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_uniques = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_labels;
  __Pyx_Buffer __pyx_pybuffer_labels;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);
  __pyx_pybuffer_labels.pybuffer.buf = NULL;
  __pyx_pybuffer_labels.refcount = 0;
  __pyx_pybuffernd_labels.data = NULL;
  __pyx_pybuffernd_labels.rcbuffer = &__pyx_pybuffer_labels;

  /* "pandas/_libs/hashtable_class_helper.pxi":4425
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = UInt32Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  if (__pyx_v_self->uniques->__pyx_base.external_view_exists) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4426
 * 
 *         if self.uniques.external_view_exists:
 *             uniques = UInt32Vector()             # <<<<<<<<<<<<<<
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 */
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4426, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":4427
 *         if self.uniques.external_view_exists:
 *             uniques = UInt32Vector()
 *             uniques.extend(self.uniques.to_array())             # <<<<<<<<<<<<<<
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 */
    __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt32Vector *)__pyx_v_self->uniques->__pyx_vtab)->to_array(__pyx_v_self->uniques, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4427, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint32_t__const__(__pyx_t_1, 0); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(2, 4427, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt32Vector *)__pyx_v_uniques->__pyx_vtab)->extend(__pyx_v_uniques, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4427, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
    __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":4428
 *             uniques = UInt32Vector()
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques             # <<<<<<<<<<<<<<
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 */
    __Pyx_INCREF((PyObject *)__pyx_v_uniques);
    __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
    __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
    __pyx_v_self->uniques = __pyx_v_uniques;

    /* "pandas/_libs/hashtable_class_helper.pxi":4425
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = UInt32Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4429
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->table), __pyx_n_s_get_labels); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint32_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "pandas/_libs/hashtable_class_helper.pxi":4430
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,             # <<<<<<<<<<<<<<
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_self->__pyx_base.count); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4430, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "pandas/_libs/hashtable_class_helper.pxi":4429
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_5 = PyTuple_New(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3)) __PYX_ERR(2, 4429, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self->uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_self->uniques))) __PYX_ERR(2, 4429, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_4)) __PYX_ERR(2, 4429, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_na_sentinel);
  __Pyx_GIVEREF(__pyx_v_na_sentinel);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_v_na_sentinel)) __PYX_ERR(2, 4429, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4431
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)             # <<<<<<<<<<<<<<
 *         self.count = len(self.uniques)
 *         return labels
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 4431, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 4431, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4429
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4429, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 4429, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
    __pyx_t_7 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_7 < 0)) {
      PyErr_Fetch(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_v_labels, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      }
      __pyx_t_8 = __pyx_t_9 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_labels.diminfo[0].strides = __pyx_pybuffernd_labels.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_labels.diminfo[0].shape = __pyx_pybuffernd_labels.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(2, 4429, __pyx_L1_error)
  }
  __pyx_t_6 = 0;
  __pyx_v_labels = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4432
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  __pyx_t_3 = ((PyObject *)__pyx_v_self->uniques);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_11 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(2, 4432, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_self->__pyx_base.count = __pyx_t_11;

  /* "pandas/_libs/hashtable_class_helper.pxi":4433
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * cdef class Int32HashTable(HashTable):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_labels);
  __pyx_r = ((PyObject *)__pyx_v_labels);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4407
 *         self.uniques = UInt32Vector()
 * 
 *     def factorize(self, const uint32_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_labels);
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4400
 * cdef class UInt32Factorizer(Factorizer):
 *     cdef public:
 *         UInt32HashTable table             # <<<<<<<<<<<<<<
 *         UInt32Vector uniques
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_5table_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_5table_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_5table___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->table);
  __pyx_r = ((PyObject *)__pyx_v_self->table);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_5table_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable))))) __PYX_ERR(2, 4400, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32Factorizer.table.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_5table_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_5table_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_5table_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4401
 *     cdef public:
 *         UInt32HashTable table
 *         UInt32Vector uniques             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, size_hint: int):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_7uniques_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_7uniques_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_7uniques___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __pyx_r = ((PyObject *)__pyx_v_self->uniques);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_7uniques_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector))))) __PYX_ERR(2, 4401, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32Factorizer.uniques.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_7uniques_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_7uniques_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_7uniques_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16UInt32Factorizer_5__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_4__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32Factorizer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16UInt32Factorizer_7__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_6__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt32Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt32Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4437
 * cdef class Int32HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_int32()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __pyx_t_5numpy_int64_t __pyx_v_size_hint;
  int __pyx_v_uses_mask;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,&__pyx_n_s_uses_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4437, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uses_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4437, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 4437, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_size_hint = __Pyx_PyInt_As_npy_int64(values[0]); if (unlikely((__pyx_v_size_hint == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 4437, __pyx_L3_error)
    } else {
      __pyx_v_size_hint = ((__pyx_t_5numpy_int64_t)1);
    }
    if (values[1]) {
      __pyx_v_uses_mask = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_uses_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 4437, __pyx_L3_error)
    } else {
      __pyx_v_uses_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 0, 2, __pyx_nargs); __PYX_ERR(2, 4437, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)__pyx_v_self), __pyx_v_size_hint, __pyx_v_uses_mask);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  khuint_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __pyx_t_5numpy_int64_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":4438
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_int32()             # <<<<<<<<<<<<<<
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_int32(self.table, size_hint)
 */
  __pyx_v_self->table = kh_init_int32();

  /* "pandas/_libs/hashtable_class_helper.pxi":4439
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_int32()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)             # <<<<<<<<<<<<<<
 *         kh_resize_int32(self.table, size_hint)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = kh_needed_n_buckets(__pyx_v_size_hint);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4439, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_1, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4439, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(2, 4439, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_6) {
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_5 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4439, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_int64(__pyx_t_3); if (unlikely((__pyx_t_7 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 4439, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_size_hint = __pyx_t_7;

  /* "pandas/_libs/hashtable_class_helper.pxi":4440
 *         self.table = kh_init_int32()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_int32(self.table, size_hint)             # <<<<<<<<<<<<<<
 * 
 *         self.uses_mask = uses_mask
 */
  kh_resize_int32(__pyx_v_self->table, __pyx_v_size_hint);

  /* "pandas/_libs/hashtable_class_helper.pxi":4442
 *         kh_resize_int32(self.table, size_hint)
 * 
 *         self.uses_mask = uses_mask             # <<<<<<<<<<<<<<
 *         self.na_position = -1
 * 
 */
  __pyx_v_self->uses_mask = __pyx_v_uses_mask;

  /* "pandas/_libs/hashtable_class_helper.pxi":4443
 * 
 *         self.uses_mask = uses_mask
 *         self.na_position = -1             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
  __pyx_v_self->na_position = -1LL;

  /* "pandas/_libs/hashtable_class_helper.pxi":4437
 * cdef class Int32HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_int32()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4445
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_3__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_3__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_2__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  long __pyx_t_1;
  int __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":4446
 * 
 *     def __len__(self) -> int:
 *         return self.table.size + (0 if self.na_position == -1 else 1)             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_2 = (__pyx_v_self->na_position == -1LL);
  if (__pyx_t_2) {
    __pyx_t_1 = 0;
  } else {
    __pyx_t_1 = 1;
  }
  __pyx_r = (__pyx_v_self->table->size + __pyx_t_1);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4445
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4448
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_int32(self.table)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_5__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_5__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_4__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":4449
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_int32(self.table)
 *             self.table = NULL
 */
  __pyx_t_1 = (__pyx_v_self->table != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4450
 *     def __dealloc__(self):
 *         if self.table is not NULL:
 *             kh_destroy_int32(self.table)             # <<<<<<<<<<<<<<
 *             self.table = NULL
 * 
 */
    kh_destroy_int32(__pyx_v_self->table);

    /* "pandas/_libs/hashtable_class_helper.pxi":4451
 *         if self.table is not NULL:
 *             kh_destroy_int32(self.table)
 *             self.table = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __contains__(self, object key) -> bool:
 */
    __pyx_v_self->table = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":4449
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_int32(self.table)
 *             self.table = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4448
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_int32(self.table)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":4453
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__contains__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_6__contains__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)__pyx_v_self), ((PyObject *)__pyx_v_key));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, PyObject *__pyx_v_key) {
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int32_t __pyx_v_ckey;
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  __pyx_t_5numpy_int32_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4460
 *             int32_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_1 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_7missing_checknull(__pyx_v_key, 0, NULL); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4460, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4461
 * 
 *         if self.uses_mask and checknull(key):
 *             return -1 != self.na_position             # <<<<<<<<<<<<<<
 * 
 *         ckey = (key)
 */
    __pyx_r = (-1LL != __pyx_v_self->na_position);
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":4460
 *             int32_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4463
 *             return -1 != self.na_position
 * 
 *         ckey = (key)             # <<<<<<<<<<<<<<
 *         k = kh_get_int32(self.table, ckey)
 *         return k != self.table.n_buckets
 */
  __pyx_t_3 = __Pyx_PyInt_As_npy_int32(__pyx_v_key); if (unlikely((__pyx_t_3 == ((npy_int32)-1)) && PyErr_Occurred())) __PYX_ERR(2, 4463, __pyx_L1_error)
  __pyx_v_ckey = __pyx_t_3;

  /* "pandas/_libs/hashtable_class_helper.pxi":4464
 * 
 *         ckey = (key)
 *         k = kh_get_int32(self.table, ckey)             # <<<<<<<<<<<<<<
 *         return k != self.table.n_buckets
 * 
 */
  __pyx_v_k = kh_get_int32(__pyx_v_self->table, __pyx_v_ckey);

  /* "pandas/_libs/hashtable_class_helper.pxi":4465
 *         ckey = (key)
 *         k = kh_get_int32(self.table, ckey)
 *         return k != self.table.n_buckets             # <<<<<<<<<<<<<<
 * 
 *     def sizeof(self, deep: bool = False) -> int:
 */
  __pyx_r = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4453
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4467
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14Int32HashTable_8sizeof, " return the size of my table in bytes ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_9sizeof = {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int32HashTable_8sizeof};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_deep = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sizeof (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_deep,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_deep);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4467, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "sizeof") < 0)) __PYX_ERR(2, 4467, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_deep = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sizeof", 0, 0, 1, __pyx_nargs); __PYX_ERR(2, 4467, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_8sizeof(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)__pyx_v_self), __pyx_v_deep);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep) {
  PyObject *__pyx_v_overhead = NULL;
  PyObject *__pyx_v_for_flags = NULL;
  PyObject *__pyx_v_for_pairs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  long __pyx_t_2;
  long __pyx_t_3;
  long __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sizeof", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":4469
 *     def sizeof(self, deep: bool = False) -> int:
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)             # <<<<<<<<<<<<<<
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(int32_t) + # keys
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(((4 * (sizeof(__pyx_t_5numpy_uint32_t))) + (3 * (sizeof(__pyx_t_5numpy_uint32_t *))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4469, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_overhead = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4470
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)             # <<<<<<<<<<<<<<
 *         for_pairs =  self.table.n_buckets * (sizeof(int32_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 */
  __pyx_t_2 = (__pyx_v_self->table->n_buckets >> 5);
  __pyx_t_3 = 1;
  __pyx_t_5 = (__pyx_t_2 > __pyx_t_3);
  if (__pyx_t_5) {
    __pyx_t_4 = __pyx_t_2;
  } else {
    __pyx_t_4 = __pyx_t_3;
  }
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_t_4 * (sizeof(__pyx_t_5numpy_uint32_t)))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_flags = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4471
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(int32_t) + # keys             # <<<<<<<<<<<<<<
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->n_buckets * ((sizeof(__pyx_t_5numpy_int32_t)) + (sizeof(Py_ssize_t))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4471, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_pairs = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4473
 *         for_pairs =  self.table.n_buckets * (sizeof(int32_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs             # <<<<<<<<<<<<<<
 * 
 *     def get_state(self) -> dict[str, int]:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Add(__pyx_v_overhead, __pyx_v_for_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyNumber_Add(__pyx_t_1, __pyx_v_for_pairs); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(__Pyx_Py3Int_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None) || __Pyx_RaiseUnexpectedTypeError("int", __pyx_t_6))) __PYX_ERR(2, 4473, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4467
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_overhead);
  __Pyx_XDECREF(__pyx_v_for_flags);
  __Pyx_XDECREF(__pyx_v_for_pairs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4475
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14Int32HashTable_10get_state, " returns infos about the state of the hashtable");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_11get_state = {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int32HashTable_10get_state};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_state (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_state", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_state", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_10get_state(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_state", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":4477
 *     def get_state(self) -> dict[str, int]:
 *         """ returns infos about the state of the hashtable"""
 *         return {             # <<<<<<<<<<<<<<
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 */
  __Pyx_XDECREF(__pyx_r);

  /* "pandas/_libs/hashtable_class_helper.pxi":4478
 *         """ returns infos about the state of the hashtable"""
 *         return {
 *             'n_buckets' : self.table.n_buckets,             # <<<<<<<<<<<<<<
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_buckets); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4478, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_buckets, __pyx_t_2) < 0) __PYX_ERR(2, 4478, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4479
 *         return {
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,             # <<<<<<<<<<<<<<
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->size); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_size, __pyx_t_2) < 0) __PYX_ERR(2, 4478, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4480
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,             # <<<<<<<<<<<<<<
 *             'upper_bound' : self.table.upper_bound,
 *         }
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_occupied); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4480, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_occupied, __pyx_t_2) < 0) __PYX_ERR(2, 4478, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4481
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,             # <<<<<<<<<<<<<<
 *         }
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->upper_bound); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4481, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_upper_bound, __pyx_t_2) < 0) __PYX_ERR(2, 4478, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4475
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.get_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4484
 *         }
 * 
 *     cpdef get_item(self, int32_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int32HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, __pyx_t_5numpy_int32_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int32_t __pyx_v_cval;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4484, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_13get_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyInt_From_npy_int32(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4484, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4484, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4503
 *             int32_t cval
 * 
 *         cval = (val)             # <<<<<<<<<<<<<<
 *         k = kh_get_int32(self.table, cval)
 *         if k != self.table.n_buckets:
 */
  __pyx_v_cval = __pyx_v_val;

  /* "pandas/_libs/hashtable_class_helper.pxi":4504
 * 
 *         cval = (val)
 *         k = kh_get_int32(self.table, cval)             # <<<<<<<<<<<<<<
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]
 */
  __pyx_v_k = kh_get_int32(__pyx_v_self->table, __pyx_v_cval);

  /* "pandas/_libs/hashtable_class_helper.pxi":4505
 *         cval = (val)
 *         k = kh_get_int32(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  __pyx_t_7 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  if (likely(__pyx_t_7)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4506
 *         k = kh_get_int32(self.table, cval)
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(val)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->vals[__pyx_v_k])); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4506, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":4505
 *         cval = (val)
 *         k = kh_get_int32(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4508
 *             return self.table.vals[k]
 *         else:
 *             raise KeyError(val)             # <<<<<<<<<<<<<<
 * 
 *     cpdef get_na(self):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyInt_From_npy_int32(__pyx_v_val); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4508, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4508, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 4508, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4484
 *         }
 * 
 *     cpdef get_item(self, int32_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14Int32HashTable_12get_item, "Extracts the position of val from the hashtable.\n\n        Parameters\n        ----------\n        val : Scalar\n            The value that is looked up in the hashtable\n\n        Returns\n        -------\n        The position of the requested integer.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_13get_item = {"get_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_13get_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int32HashTable_12get_item};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_5numpy_int32_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4484, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_item") < 0)) __PYX_ERR(2, 4484, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __Pyx_PyInt_As_npy_int32(values[0]); if (unlikely((__pyx_v_val == ((npy_int32)-1)) && PyErr_Occurred())) __PYX_ERR(2, 4484, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_item", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 4484, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_12get_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, __pyx_t_5numpy_int32_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_14Int32HashTable_get_item(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4510
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int32HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4510, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_15get_na)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4510, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4518
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_6 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4519
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         if self.na_position == -1:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 4519, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":4518
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4521
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  __pyx_t_6 = (__pyx_v_self->na_position == -1LL);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4522
 * 
 *         if self.na_position == -1:
 *             raise KeyError("NA")             # <<<<<<<<<<<<<<
 *         return self.na_position
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_KeyError, __pyx_tuple__13, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4522, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(2, 4522, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":4521
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4523
 *         if self.na_position == -1:
 *             raise KeyError("NA")
 *         return self.na_position             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_item(self, int32_t key, Py_ssize_t val):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->na_position); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4523, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4510
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14Int32HashTable_14get_na, "Extracts the position of na_value from the hashtable.\n\n        Returns\n        -------\n        The position of the last na value.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_15get_na = {"get_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_15get_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int32HashTable_14get_na};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_na", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_na", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_14get_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_14Int32HashTable_get_na(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4525
 *         return self.na_position
 * 
 *     cpdef set_item(self, int32_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int32HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, __pyx_t_5numpy_int32_t __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  __pyx_t_5numpy_int32_t __pyx_v_ckey;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4525, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_17set_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyInt_From_npy_int32(__pyx_v_key); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4525, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4525, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_5 = __pyx_t_1; __pyx_t_6 = NULL;
        __pyx_t_7 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_7 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_3, __pyx_t_4};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4525, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4530
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             int32_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4533
 *             int32_t ckey
 * 
 *         ckey = (key)             # <<<<<<<<<<<<<<
 *         k = kh_put_int32(self.table, ckey, &ret)
 *         if kh_exist_int32(self.table, k):
 */
  __pyx_v_ckey = __pyx_v_key;

  /* "pandas/_libs/hashtable_class_helper.pxi":4534
 * 
 *         ckey = (key)
 *         k = kh_put_int32(self.table, ckey, &ret)             # <<<<<<<<<<<<<<
 *         if kh_exist_int32(self.table, k):
 *             self.table.vals[k] = val
 */
  __pyx_v_k = kh_put_int32(__pyx_v_self->table, __pyx_v_ckey, (&__pyx_v_ret));

  /* "pandas/_libs/hashtable_class_helper.pxi":4535
 *         ckey = (key)
 *         k = kh_put_int32(self.table, ckey, &ret)
 *         if kh_exist_int32(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
  __pyx_t_8 = kh_exist_int32(__pyx_v_self->table, __pyx_v_k);
  if (likely(__pyx_t_8)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4536
 *         k = kh_put_int32(self.table, ckey, &ret)
 *         if kh_exist_int32(self.table, k):
 *             self.table.vals[k] = val             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(key)
 */
    (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_val;

    /* "pandas/_libs/hashtable_class_helper.pxi":4535
 *         ckey = (key)
 *         k = kh_put_int32(self.table, ckey, &ret)
 *         if kh_exist_int32(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4538
 *             self.table.vals[k] = val
 *         else:
 *             raise KeyError(key)             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_na(self, Py_ssize_t val):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyInt_From_npy_int32(__pyx_v_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4538, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4538, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 4538, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "pandas/_libs/hashtable_class_helper.pxi":4525
 *         return self.na_position
 * 
 *     cpdef set_item(self, int32_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_17set_item = {"set_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_17set_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_5numpy_int32_t __pyx_v_key;
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key,&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4525, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4525, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, 1); __PYX_ERR(2, 4525, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_item") < 0)) __PYX_ERR(2, 4525, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_key = __Pyx_PyInt_As_npy_int32(values[0]); if (unlikely((__pyx_v_key == ((npy_int32)-1)) && PyErr_Occurred())) __PYX_ERR(2, 4525, __pyx_L3_error)
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 4525, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, __pyx_nargs); __PYX_ERR(2, 4525, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_16set_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)__pyx_v_self), __pyx_v_key, __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, __pyx_t_5numpy_int32_t __pyx_v_key, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_14Int32HashTable_set_item(__pyx_v_self, __pyx_v_key, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4540
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int32HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  CYTHON_UNUSED int __pyx_v_ret;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4540, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_19set_na)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4540, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4540, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4544
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             int32_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4547
 *             int32_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_7 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_7)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4548
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         self.na_position = val
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 4548, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":4547
 *             int32_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4550
 *             raise NotImplementedError
 * 
 *         self.na_position = val             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->na_position = __pyx_v_val;

  /* "pandas/_libs/hashtable_class_helper.pxi":4540
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_19set_na = {"set_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_19set_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4540, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_na") < 0)) __PYX_ERR(2, 4540, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[0]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 4540, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_na", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 4540, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_18set_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_14Int32HashTable_set_na(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4553
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const int32_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_21map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_21map_locations = {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_21map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_21map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("map_locations (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4553, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4553, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "map_locations") < 0)) __PYX_ERR(2, 4553, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int32_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 4554, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 4554, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__30;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("map_locations", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 4553, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_20map_locations(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_20map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  int __pyx_v_ret;
  __pyx_t_5numpy_int32_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  __pyx_t_5numpy_int64_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("map_locations", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":4557
 *         # Used in libindex, safe_sort
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             int32_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":4558
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             int32_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4561
 *             int32_t val
 *             khiter_t k
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_2 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":4563
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_3 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_3)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4564
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 4564, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":4563
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4566
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":4567
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
        if (__pyx_v_self->uses_mask) {

          /* "pandas/_libs/hashtable_class_helper.pxi":4568
 *         with nogil:
 *             if self.uses_mask:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     if mask[i]:
 *                         na_position = i
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":4569
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_mask.shape[0];
            __pyx_t_3 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) ))) != 0);
            if (__pyx_t_3) {

              /* "pandas/_libs/hashtable_class_helper.pxi":4570
 *                 for i in range(n):
 *                     if mask[i]:
 *                         na_position = i             # <<<<<<<<<<<<<<
 *                     else:
 *                         val= (values[i])
 */
              __pyx_v_na_position = __pyx_v_i;

              /* "pandas/_libs/hashtable_class_helper.pxi":4569
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
              goto __pyx_L12;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":4572
 *                         na_position = i
 *                     else:
 *                         val= (values[i])             # <<<<<<<<<<<<<<
 *                         k = kh_put_int32(self.table, val, &ret)
 *                         self.table.vals[k] = i
 */
            /*else*/ {
              __pyx_t_7 = __pyx_v_i;
              if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
              __pyx_v_val = (*((__pyx_t_5numpy_int32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_class_helper.pxi":4573
 *                     else:
 *                         val= (values[i])
 *                         k = kh_put_int32(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = i
 *             else:
 */
              __pyx_v_k = kh_put_int32(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

              /* "pandas/_libs/hashtable_class_helper.pxi":4574
 *                         val= (values[i])
 *                         k = kh_put_int32(self.table, val, &ret)
 *                         self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *             else:
 *                 for i in range(n):
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
            }
            __pyx_L12:;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":4567
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
          goto __pyx_L9;
        }

        /* "pandas/_libs/hashtable_class_helper.pxi":4576
 *                         self.table.vals[k] = i
 *             else:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     val= (values[i])
 *                     k = kh_put_int32(self.table, val, &ret)
 */
        /*else*/ {
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":4577
 *             else:
 *                 for i in range(n):
 *                     val= (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_put_int32(self.table, val, &ret)
 *                     self.table.vals[k] = i
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
            __pyx_v_val = (*((__pyx_t_5numpy_int32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

            /* "pandas/_libs/hashtable_class_helper.pxi":4578
 *                 for i in range(n):
 *                     val= (values[i])
 *                     k = kh_put_int32(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                     self.table.vals[k] = i
 *         self.na_position = na_position
 */
            __pyx_v_k = kh_put_int32(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":4579
 *                     val= (values[i])
 *                     k = kh_put_int32(self.table, val, &ret)
 *                     self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *         self.na_position = na_position
 * 
 */
            (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
          }
        }
        __pyx_L9:;
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":4566
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4580
 *                     k = kh_put_int32(self.table, val, &ret)
 *                     self.table.vals[k] = i
 *         self.na_position = na_position             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __pyx_v_self->na_position = __pyx_v_na_position;

  /* "pandas/_libs/hashtable_class_helper.pxi":4553
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const int32_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4582
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const int32_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

/* Python wrapper */
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_23lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_23lookup = {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_23lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_23lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyArrayObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lookup (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4582, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4582, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lookup") < 0)) __PYX_ERR(2, 4582, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int32_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 4583, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 4583, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__31;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lookup", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 4582, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_22lookup(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_22lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  CYTHON_UNUSED int __pyx_v_ret;
  __pyx_t_5numpy_int32_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __Pyx_memviewslice __pyx_v_locs = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lookup", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":4587
 *         # Used in safe_sort, IndexEngine.get_indexer
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             int32_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":4588
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             int32_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4591
 *             int32_t val
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *             int8_t na_position = self.na_position
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 4591, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 4591, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 4591, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_locs = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":4592
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_8 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":4594
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_9 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_10 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_9 = __pyx_t_10;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4595
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 4595, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":4594
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4597
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":4598
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_11 = __pyx_t_1;
        for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
          __pyx_v_i = __pyx_t_12;

          /* "pandas/_libs/hashtable_class_helper.pxi":4599
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
          if (__pyx_v_self->uses_mask) {
          } else {
            __pyx_t_9 = __pyx_v_self->uses_mask;
            goto __pyx_L12_bool_binop_done;
          }
          __pyx_t_13 = __pyx_v_i;
          if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_mask.shape[0];
          __pyx_t_10 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_13 * __pyx_v_mask.strides[0]) ))) != 0);
          __pyx_t_9 = __pyx_t_10;
          __pyx_L12_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":4600
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position             # <<<<<<<<<<<<<<
 *                 else:
 *                     val = (values[i])
 */
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = __pyx_v_na_position;

            /* "pandas/_libs/hashtable_class_helper.pxi":4599
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
            goto __pyx_L11;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":4602
 *                     locs[i] = na_position
 *                 else:
 *                     val = (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_int32(self.table, val)
 *                     if k != self.table.n_buckets:
 */
          /*else*/ {
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_values.shape[0];
            __pyx_v_val = (*((__pyx_t_5numpy_int32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_13 * __pyx_v_values.strides[0]) )));

            /* "pandas/_libs/hashtable_class_helper.pxi":4603
 *                 else:
 *                     val = (values[i])
 *                     k = kh_get_int32(self.table, val)             # <<<<<<<<<<<<<<
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]
 */
            __pyx_v_k = kh_get_int32(__pyx_v_self->table, __pyx_v_val);

            /* "pandas/_libs/hashtable_class_helper.pxi":4604
 *                     val = (values[i])
 *                     k = kh_get_int32(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
            __pyx_t_9 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":4605
 *                     k = kh_get_int32(self.table, val)
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     else:
 *                         locs[i] = -1
 */
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = (__pyx_v_self->table->vals[__pyx_v_k]);

              /* "pandas/_libs/hashtable_class_helper.pxi":4604
 *                     val = (values[i])
 *                     k = kh_get_int32(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
              goto __pyx_L14;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":4607
 *                         locs[i] = self.table.vals[k]
 *                     else:
 *                         locs[i] = -1             # <<<<<<<<<<<<<<
 * 
 *         return np.asarray(locs)
 */
            /*else*/ {
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = -1;
            }
            __pyx_L14:;
          }
          __pyx_L11:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":4597
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4609
 *                         locs[i] = -1
 * 
 *         return np.asarray(locs)             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_locs, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_14 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_14 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4609, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 4609, __pyx_L1_error)
  __pyx_r = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4582
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const int32_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_locs, 1);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4611
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const int32_t[:] values, Int32Vector uniques,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_25_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14Int32HashTable_24_unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[int32]\n            Array of values of which unique will be calculated\n        uniques : Int32Vector\n            Vector into which uniques will be written\n        count_prior : Py_ssize_t, default 0\n            Number of existing entries in uniques\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        ignore_na : bool, default False\n            Whether NA-values should be ignored for calculating the uniques. If\n            True, the labels corresponding to missing values will be set to\n            na_sentinel.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        use_result_mask: bool, default False\n            Whether to create a result mask for the unique values. Not supported\n            with return_inverse=True.\n\n        Returns\n        -------\n        uniques : ndarray[int32]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse=True)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if use_result_mask is true\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_25_unique = {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_25_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int32HashTable_24_unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_25_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  int __pyx_v_ignore_na;
  PyObject *__pyx_v_mask = 0;
  int __pyx_v_return_inverse;
  int __pyx_v_use_result_mask;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[9] = {0,0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_ignore_na,&__pyx_n_s_mask,&__pyx_n_s_return_inverse,&__pyx_n_s_use_result_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":4615
 *     def _unique(self, const int32_t[:] values, Int32Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));

    /* "pandas/_libs/hashtable_class_helper.pxi":4616
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[6] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4611, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4611, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, 1); __PYX_ERR(2, 4611, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4611, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4611, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4611, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4611, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[6] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4611, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[7] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4611, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_use_result_mask);
          if (value) { values[8] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4611, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_unique") < 0)) __PYX_ERR(2, 4611, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int32_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 4613, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 4614, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 4614, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    if (values[5]) {
      __pyx_v_ignore_na = __Pyx_PyObject_IsTrue(values[5]); if (unlikely((__pyx_v_ignore_na == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 4615, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":4615
 *     def _unique(self, const int32_t[:] values, Int32Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
      __pyx_v_ignore_na = ((int)0);
    }
    __pyx_v_mask = values[6];
    if (values[7]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[7]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 4616, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":4616
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
      __pyx_v_return_inverse = ((int)0);
    }
    if (values[8]) {
      __pyx_v_use_result_mask = __Pyx_PyObject_IsTrue(values[8]); if (unlikely((__pyx_v_use_result_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 4616, __pyx_L3_error)
    } else {
      __pyx_v_use_result_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, __pyx_nargs); __PYX_ERR(2, 4611, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector, 1, "uniques", 0))) __PYX_ERR(2, 4613, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_24_unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_ignore_na, __pyx_v_mask, __pyx_v_return_inverse, __pyx_v_use_result_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":4611
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const int32_t[:] values, Int32Vector uniques,
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_24_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_idx;
  Py_ssize_t __pyx_v_count;
  Py_ssize_t __pyx_v_n;
  __Pyx_memviewslice __pyx_v_labels = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_ret;
  __pyx_t_5numpy_int32_t __pyx_v_val;
  __pyx_t_5numpy_int32_t __pyx_v_na_value2;
  khiter_t __pyx_v_k;
  __pyx_t_6pandas_5_libs_9hashtable_Int32VectorData *__pyx_v_ud;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_result_mask = 0;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_v_rmd;
  int __pyx_v_use_na_value;
  int __pyx_v_use_mask;
  int __pyx_v_seen_na;
  __Pyx_memviewslice __pyx_v_mask_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_6pandas_5_libs_9hashtable_Int32VectorData *__pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_t_11;
  int __pyx_t_12;
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int32_t __pyx_t_14;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":4660
 *         """
 *         cdef:
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)             # <<<<<<<<<<<<<<
 *             intp_t[::1] labels
 *             int ret = 0
 */
  __pyx_v_count = __pyx_v_count_prior;
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":4662
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)
 *             intp_t[::1] labels
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             int32_t val, na_value2
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4668
 *             UInt8Vector result_mask
 *             UInt8VectorData *rmd
 *             bint use_na_value, use_mask, seen_na = False             # <<<<<<<<<<<<<<
 *             uint8_t[:] mask_values
 * 
 */
  __pyx_v_seen_na = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4671
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4672
 * 
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4672, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4672, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4672, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4672, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 4672, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4672, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4672, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4672, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 4672, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4672, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 4672, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_labels = __pyx_t_7;
    __pyx_t_7.memview = NULL;
    __pyx_t_7.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":4671
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4673
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data             # <<<<<<<<<<<<<<
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 */
  __pyx_t_8 = __pyx_v_uniques->data;
  __pyx_v_ud = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":4674
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 *         use_na_value = na_value is not None             # <<<<<<<<<<<<<<
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 */
  __pyx_t_9 = (__pyx_v_na_value != Py_None);
  __pyx_v_use_na_value = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":4675
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None             # <<<<<<<<<<<<<<
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover
 */
  __pyx_t_9 = (__pyx_v_mask != Py_None);
  __pyx_v_use_mask = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":4676
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  __pyx_t_10 = (!__pyx_v_use_mask);
  if (__pyx_t_10) {
  } else {
    __pyx_t_9 = __pyx_t_10;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_use_result_mask;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4677
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         if use_result_mask and return_inverse:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 4677, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":4676
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4679
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_use_result_mask) {
  } else {
    __pyx_t_9 = __pyx_v_use_result_mask;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_return_inverse;
  __pyx_L8_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4680
 * 
 *         if use_result_mask and return_inverse:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         result_mask = UInt8Vector()
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 4680, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":4679
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4682
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         result_mask = UInt8Vector()             # <<<<<<<<<<<<<<
 *         rmd = result_mask.data
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_v_result_mask = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4683
 * 
 *         result_mask = UInt8Vector()
 *         rmd = result_mask.data             # <<<<<<<<<<<<<<
 * 
 *         if use_mask:
 */
  __pyx_t_11 = __pyx_v_result_mask->data;
  __pyx_v_rmd = __pyx_t_11;

  /* "pandas/_libs/hashtable_class_helper.pxi":4685
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  if (__pyx_v_use_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4686
 * 
 *         if use_mask:
 *             mask_values = mask.view("uint8")             # <<<<<<<<<<<<<<
 * 
 *         if use_na_value:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_mask, __pyx_n_s_view); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4686, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    __pyx_t_12 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_12 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_uint8};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_12, 1+__pyx_t_12);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4686, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(2, 4686, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_mask_values = __pyx_t_13;
    __pyx_t_13.memview = NULL;
    __pyx_t_13.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":4685
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4688
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
  if (__pyx_v_use_na_value) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4694
 *             # for the parameter. To please the compiler, we use na_value2,
 *             # which is only used if it's *specified*.
 *             na_value2 = (na_value)             # <<<<<<<<<<<<<<
 *         else:
 *             na_value2 = (0)
 */
    __pyx_t_14 = __Pyx_PyInt_As_npy_int32(__pyx_v_na_value); if (unlikely((__pyx_t_14 == ((npy_int32)-1)) && PyErr_Occurred())) __PYX_ERR(2, 4694, __pyx_L1_error)
    __pyx_v_na_value2 = __pyx_t_14;

    /* "pandas/_libs/hashtable_class_helper.pxi":4688
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
    goto __pyx_L11;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4696
 *             na_value2 = (na_value)
 *         else:
 *             na_value2 = (0)             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
  /*else*/ {
    __pyx_v_na_value2 = 0;
  }
  __pyx_L11:;

  /* "pandas/_libs/hashtable_class_helper.pxi":4698
 *             na_value2 = (0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = (values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":4699
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 val = (values[i])
 * 
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_15 = __pyx_t_1;
        for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
          __pyx_v_i = __pyx_t_16;

          /* "pandas/_libs/hashtable_class_helper.pxi":4700
 *         with nogil:
 *             for i in range(n):
 *                 val = (values[i])             # <<<<<<<<<<<<<<
 * 
 *                 if ignore_na and use_mask:
 */
          __pyx_t_17 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_int32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_17 * __pyx_v_values.strides[0]) )));

          /* "pandas/_libs/hashtable_class_helper.pxi":4702
 *                 val = (values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L18_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_mask;
          __pyx_L18_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":4703
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 4703, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_17 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":4704
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                         continue
 *                 elif ignore_na and (
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 4704, __pyx_L13_error) }
              __pyx_t_17 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_na_sentinel;

              /* "pandas/_libs/hashtable_class_helper.pxi":4705
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 *                         continue             # <<<<<<<<<<<<<<
 *                 elif ignore_na and (
 *                    is_nan_int32_t(val) or
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":4703
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":4702
 *                 val = (values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
            goto __pyx_L17;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":4706
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_int32_t(val) or
 *                    (use_na_value and are_equivalent_int32_t(val, na_value2))
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":4707
 *                         continue
 *                 elif ignore_na and (
 *                    is_nan_int32_t(val) or             # <<<<<<<<<<<<<<
 *                    (use_na_value and are_equivalent_int32_t(val, na_value2))
 *                 ):
 */
          __pyx_t_10 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_int32_t(__pyx_v_val); if (unlikely(__pyx_t_10 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 4707, __pyx_L13_error)
          if (!__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":4708
 *                 elif ignore_na and (
 *                    is_nan_int32_t(val) or
 *                    (use_na_value and are_equivalent_int32_t(val, na_value2))             # <<<<<<<<<<<<<<
 *                 ):
 *                     # if missing values do not count as unique values (i.e. if
 */
          if (__pyx_v_use_na_value) {
          } else {
            __pyx_t_9 = __pyx_v_use_na_value;
            goto __pyx_L21_bool_binop_done;
          }
          __pyx_t_10 = __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_int32_t(__pyx_v_val, __pyx_v_na_value2); if (unlikely(__pyx_t_10 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 4708, __pyx_L13_error)
          __pyx_t_9 = __pyx_t_10;
          __pyx_L21_bool_binop_done:;

          /* "pandas/_libs/hashtable_class_helper.pxi":4706
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_int32_t(val) or
 *                    (use_na_value and are_equivalent_int32_t(val, na_value2))
 */
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":4713
 *                     # ignore_na is True), skip the hashtable entry for them,
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 4713, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_na_sentinel;

            /* "pandas/_libs/hashtable_class_helper.pxi":4714
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel
 *                     continue             # <<<<<<<<<<<<<<
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 */
            goto __pyx_L15_continue;

            /* "pandas/_libs/hashtable_class_helper.pxi":4706
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_int32_t(val) or
 *                    (use_na_value and are_equivalent_int32_t(val, na_value2))
 */
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":4715
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          __pyx_t_10 = (!__pyx_v_ignore_na);
          if (__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L25_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_result_mask;
          __pyx_L25_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":4716
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 4716, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_17 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":4717
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_class_helper.pxi":4718
 *                     if mask_values[i]:
 *                         if seen_na:
 *                             continue             # <<<<<<<<<<<<<<
 * 
 *                         seen_na = True
 */
                goto __pyx_L15_continue;

                /* "pandas/_libs/hashtable_class_helper.pxi":4717
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":4720
 *                             continue
 * 
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         if needs_resize(ud):
 *                             with gil:
 */
              __pyx_v_seen_na = 1;

              /* "pandas/_libs/hashtable_class_helper.pxi":4721
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              __pyx_t_9 = __pyx_fuse_1__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 4721, __pyx_L13_error)
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_class_helper.pxi":4722
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                {
                    #ifdef WITH_THREAD
                    PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                    #endif
                    /*try:*/ {

                      /* "pandas/_libs/hashtable_class_helper.pxi":4723
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":4724
 *                             with gil:
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4724, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 4724, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":4723
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":4727
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4727, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":4728
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":4729
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4729, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 4729, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":4728
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":4732
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                         append_data_int32(ud, val)
 *                         append_data_uint8(rmd, 1)
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4732, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":4722
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    /*finally:*/ {
                      /*normal exit:*/{
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L34;
                      }
                      __pyx_L33_error: {
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L13_error;
                      }
                      __pyx_L34:;
                    }
                }

                /* "pandas/_libs/hashtable_class_helper.pxi":4721
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":4733
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                         append_data_int32(ud, val)             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 1)
 *                         continue
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_int32(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 4733, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":4734
 *                                 result_mask.resize()
 *                         append_data_int32(ud, val)
 *                         append_data_uint8(rmd, 1)             # <<<<<<<<<<<<<<
 *                         continue
 * 
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 1); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 4734, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":4735
 *                         append_data_int32(ud, val)
 *                         append_data_uint8(rmd, 1)
 *                         continue             # <<<<<<<<<<<<<<
 * 
 *                 k = kh_get_int32(self.table, val)
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":4716
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":4715
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          }
          __pyx_L17:;

          /* "pandas/_libs/hashtable_class_helper.pxi":4737
 *                         continue
 * 
 *                 k = kh_get_int32(self.table, val)             # <<<<<<<<<<<<<<
 * 
 *                 if k == self.table.n_buckets:
 */
          __pyx_v_k = kh_get_int32(__pyx_v_self->table, __pyx_v_val);

          /* "pandas/_libs/hashtable_class_helper.pxi":4739
 *                 k = kh_get_int32(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_int32(self.table, val, &ret)
 */
          __pyx_t_9 = (__pyx_v_k == __pyx_v_self->table->n_buckets);
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":4741
 *                 if k == self.table.n_buckets:
 *                     # k hasn't been seen yet
 *                     k = kh_put_int32(self.table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *                     if needs_resize(ud):
 */
            __pyx_v_k = kh_put_int32(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":4743
 *                     k = kh_put_int32(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            __pyx_t_9 = __pyx_fuse_1__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 4743, __pyx_L13_error)
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":4744
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
              {
                  #ifdef WITH_THREAD
                  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                  #endif
                  /*try:*/ {

                    /* "pandas/_libs/hashtable_class_helper.pxi":4745
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":4746
 *                         with gil:
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 */
                      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4746, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                      __PYX_ERR(2, 4746, __pyx_L42_error)

                      /* "pandas/_libs/hashtable_class_helper.pxi":4745
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":4749
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()             # <<<<<<<<<<<<<<
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 */
                    __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4749, __pyx_L42_error)
                    __Pyx_GOTREF(__pyx_t_6);
                    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                    /* "pandas/_libs/hashtable_class_helper.pxi":4750
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    if (__pyx_v_use_result_mask) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":4751
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":4752
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4752, __pyx_L42_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 4752, __pyx_L42_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":4751
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":4755
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                     append_data_int32(ud, val)
 *                     if use_result_mask:
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4755, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":4750
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    }
                  }

                  /* "pandas/_libs/hashtable_class_helper.pxi":4744
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
                  /*finally:*/ {
                    /*normal exit:*/{
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L43;
                    }
                    __pyx_L42_error: {
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L13_error;
                    }
                    __pyx_L43:;
                  }
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":4743
 *                     k = kh_put_int32(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":4756
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                     append_data_int32(ud, val)             # <<<<<<<<<<<<<<
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)
 */
            __pyx_f_6pandas_5_libs_9hashtable_append_data_int32(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 4756, __pyx_L13_error)

            /* "pandas/_libs/hashtable_class_helper.pxi":4757
 *                                 result_mask.resize()
 *                     append_data_int32(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            if (__pyx_v_use_result_mask) {

              /* "pandas/_libs/hashtable_class_helper.pxi":4758
 *                     append_data_int32(ud, val)
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)             # <<<<<<<<<<<<<<
 * 
 *                     if return_inverse:
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 0); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 4758, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":4757
 *                                 result_mask.resize()
 *                     append_data_int32(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":4760
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            if (__pyx_v_return_inverse) {

              /* "pandas/_libs/hashtable_class_helper.pxi":4761
 * 
 *                     if return_inverse:
 *                         self.table.vals[k] = count             # <<<<<<<<<<<<<<
 *                         labels[i] = count
 *                         count += 1
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":4762
 *                     if return_inverse:
 *                         self.table.vals[k] = count
 *                         labels[i] = count             # <<<<<<<<<<<<<<
 *                         count += 1
 *                 elif return_inverse:
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 4762, __pyx_L13_error) }
              __pyx_t_17 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":4763
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 *                         count += 1             # <<<<<<<<<<<<<<
 *                 elif return_inverse:
 *                     # k falls into a previous bucket
 */
              __pyx_v_count = (__pyx_v_count + 1);

              /* "pandas/_libs/hashtable_class_helper.pxi":4760
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":4739
 *                 k = kh_get_int32(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_int32(self.table, val, &ret)
 */
            goto __pyx_L37;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":4764
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          if (__pyx_v_return_inverse) {

            /* "pandas/_libs/hashtable_class_helper.pxi":4767
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     labels[i] = idx
 * 
 */
            __pyx_v_idx = (__pyx_v_self->table->vals[__pyx_v_k]);

            /* "pandas/_libs/hashtable_class_helper.pxi":4768
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]
 *                     labels[i] = idx             # <<<<<<<<<<<<<<
 * 
 *         if return_inverse:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 4768, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_idx;

            /* "pandas/_libs/hashtable_class_helper.pxi":4764
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          }
          __pyx_L37:;
          __pyx_L15_continue:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":4698
 *             na_value2 = (0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = (values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L14;
        }
        __pyx_L13_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L14:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4770
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4771
 * 
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray             # <<<<<<<<<<<<<<
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4771, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundLocalError("labels"); __PYX_ERR(2, 4771, __pyx_L1_error) }
    __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_labels, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4771, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_base); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4771, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4771, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_6);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_6)) __PYX_ERR(2, 4771, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4)) __PYX_ERR(2, 4771, __pyx_L1_error);
    __pyx_t_6 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":4770
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4772
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  if (__pyx_v_use_result_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4773
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()             # <<<<<<<<<<<<<<
 *         return uniques.to_array()
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4773, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->to_array(__pyx_v_result_mask, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4773, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4773, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2)) __PYX_ERR(2, 4773, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4)) __PYX_ERR(2, 4773, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":4772
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4774
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()             # <<<<<<<<<<<<<<
 * 
 *     def unique(self, const int32_t[:] values, bint return_inverse=False, object mask=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4774, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4611
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const int32_t[:] values, Int32Vector uniques,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_13, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_labels, 1);
  __Pyx_XDECREF((PyObject *)__pyx_v_result_mask);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask_values, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4776
 *         return uniques.to_array()
 * 
 *     def unique(self, const int32_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_27unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14Int32HashTable_26unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[int32]\n            Array of values of which unique will be calculated\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n\n        Returns\n        -------\n        uniques : ndarray[int32]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if mask is given as input\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_27unique = {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_27unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int32HashTable_26unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_27unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_return_inverse;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_return_inverse,&__pyx_n_s_mask,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4776, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4776, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4776, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "unique") < 0)) __PYX_ERR(2, 4776, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int32_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 4776, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 4776, __pyx_L3_error)
    } else {
      __pyx_v_return_inverse = ((int)0);
    }
    __pyx_v_mask = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("unique", 0, 1, 3, __pyx_nargs); __PYX_ERR(2, 4776, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_26unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_return_inverse, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_26unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_uniques = NULL;
  int __pyx_v_use_result_mask;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":4800
 *             The mask for the result values.
 *         """
 *         uniques = Int32Vector()             # <<<<<<<<<<<<<<
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4801
 *         """
 *         uniques = Int32Vector()
 *         use_result_mask = True if mask is not None else False             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 */
  __pyx_t_3 = (__pyx_v_mask != Py_None);
  if (__pyx_t_3) {
    __pyx_t_2 = 1;
  } else {
    __pyx_t_2 = 0;
  }
  __pyx_v_use_result_mask = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":4802
 *         uniques = Int32Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int32_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4)) __PYX_ERR(2, 4802, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 4802, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ignore_na, Py_False) < 0) __PYX_ERR(2, 4802, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4803
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const int32_t[:] values, Py_ssize_t na_sentinel=-1,
 */
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_return_inverse); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return_inverse, __pyx_t_6) < 0) __PYX_ERR(2, 4802, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 4802, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_use_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_use_result_mask, __pyx_t_6) < 0) __PYX_ERR(2, 4802, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4802
 *         uniques = Int32Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4776
 *         return uniques.to_array()
 * 
 *     def unique(self, const int32_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4805
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const int32_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_29factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14Int32HashTable_28factorize, "\n        Calculate unique values and labels (no sorting!)\n\n        Missing values are not included in the \"uniques\" for this method.\n        The labels for any missing values will be set to \"na_sentinel\"\n\n        Parameters\n        ----------\n        values : ndarray[int32]\n            Array of values of which unique will be calculated\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n\n        Returns\n        -------\n        uniques : ndarray[int32]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t]\n            The labels from values to uniques\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_29factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_29factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int32HashTable_28factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_29factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  PyObject *__pyx_v_ignore_na = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,&__pyx_n_s_ignore_na,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":4806
 * 
 *     def factorize(self, const int32_t[:] values, Py_ssize_t na_sentinel=-1,
 *                   object na_value=None, object mask=None, ignore_na=True):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_True));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4805, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4805, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4805, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4805, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4805, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 4805, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int32_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 4805, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 4805, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
    __pyx_v_ignore_na = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 5, __pyx_nargs); __PYX_ERR(2, 4805, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_28factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask, __pyx_v_ignore_na);

  /* "pandas/_libs/hashtable_class_helper.pxi":4805
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const int32_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_28factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_uniques_vector = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":4836
 *             The labels from values to uniques
 *         """
 *         uniques_vector = Int32Vector()             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4836, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques_vector = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4837
 *         """
 *         uniques_vector = Int32Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int32_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 4837, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques_vector);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques_vector))) __PYX_ERR(2, 4837, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 4837, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4838
 *         uniques_vector = Int32Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,             # <<<<<<<<<<<<<<
 *                             return_inverse=True)
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 4837, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, __pyx_v_ignore_na) < 0) __PYX_ERR(2, 4837, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 4837, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4839
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)             # <<<<<<<<<<<<<<
 * 
 *     def get_labels(self, const int32_t[:] values, Int32Vector uniques,
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 4837, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4837
 *         """
 *         uniques_vector = Int32Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4805
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const int32_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4841
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const int32_t[:] values, Int32Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_31get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_31get_labels = {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_31get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_31get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_labels (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":4843
 *     def get_labels(self, const int32_t[:] values, Int32Vector uniques,
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4841, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4841, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, 1); __PYX_ERR(2, 4841, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4841, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4841, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4841, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4841, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_labels") < 0)) __PYX_ERR(2, 4841, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int32_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 4841, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 4842, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 4842, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    __pyx_v_mask = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, __pyx_nargs); __PYX_ERR(2, 4841, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector, 1, "uniques", 0))) __PYX_ERR(2, 4841, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_30get_labels(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":4841
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const int32_t[:] values, Int32Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_30get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_v_labels = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_labels", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":4845
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4845, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int32_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4845, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4845, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 4845, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 4845, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4845, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_count_prior); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4845, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_count_prior, __pyx_t_4) < 0) __PYX_ERR(2, 4845, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4846
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,             # <<<<<<<<<<<<<<
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 4845, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 4845, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4847
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, Py_True) < 0) __PYX_ERR(2, 4845, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 4845, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 4845, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4845
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4845, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
    PyObject* sequence = __pyx_t_4;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(2, 4845, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4845, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
    index = 0; __pyx_t_2 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_1), 2) < 0) __PYX_ERR(2, 4845, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(2, 4845, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v__ = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_labels = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4848
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_labels);
  __pyx_r = __pyx_v_labels;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4841
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const int32_t[:] values, Int32Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XDECREF(__pyx_v_labels);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_33__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_33__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_33__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_33__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_32__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_32__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_35__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_35__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_35__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_35__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_34__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int32HashTable_34__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4857
 *         Int32Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = Int32HashTable(size_hint)
 *         self.uniques = Int32Vector()
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_size_hint = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4857, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 4857, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_size_hint = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 4857, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_size_hint), (&PyInt_Type), 0, "size_hint", 1))) __PYX_ERR(2, 4857, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *)__pyx_v_self), __pyx_v_size_hint);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":4858
 * 
 *     def __cinit__(self, size_hint: int):
 *         self.table = Int32HashTable(size_hint)             # <<<<<<<<<<<<<<
 *         self.uniques = Int32Vector()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable), __pyx_v_size_hint); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4859
 *     def __cinit__(self, size_hint: int):
 *         self.table = Int32HashTable(size_hint)
 *         self.uniques = Int32Vector()             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const int32_t[:] values,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4859, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4857
 *         Int32Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = Int32HashTable(size_hint)
 *         self.uniques = Int32Vector()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4861
 *         self.uniques = Int32Vector()
 * 
 *     def factorize(self, const int32_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15Int32Factorizer_2factorize, "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = Int32Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"int32\"), na_sentinel=20)\n        array([0, 1, 2])\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15Int32Factorizer_3factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15Int32Factorizer_2factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_v_na_sentinel = 0;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_neg_1));

    /* "pandas/_libs/hashtable_class_helper.pxi":4862
 * 
 *     def factorize(self, const int32_t[:] values,
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:             # <<<<<<<<<<<<<<
 *         """
 *         Returns
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4861, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4861, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4861, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4861, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 4861, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int32_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 4861, __pyx_L3_error)
    __pyx_v_na_sentinel = values[1];
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 4, __pyx_nargs); __PYX_ERR(2, 4861, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_2factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":4861
 *         self.uniques = Int32Vector()
 * 
 *     def factorize(self, const int32_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  PyArrayObject *__pyx_v_labels = 0;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_uniques = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_labels;
  __Pyx_Buffer __pyx_pybuffer_labels;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);
  __pyx_pybuffer_labels.pybuffer.buf = NULL;
  __pyx_pybuffer_labels.refcount = 0;
  __pyx_pybuffernd_labels.data = NULL;
  __pyx_pybuffernd_labels.rcbuffer = &__pyx_pybuffer_labels;

  /* "pandas/_libs/hashtable_class_helper.pxi":4879
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = Int32Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  if (__pyx_v_self->uniques->__pyx_base.external_view_exists) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4880
 * 
 *         if self.uniques.external_view_exists:
 *             uniques = Int32Vector()             # <<<<<<<<<<<<<<
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 */
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4880, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":4881
 *         if self.uniques.external_view_exists:
 *             uniques = Int32Vector()
 *             uniques.extend(self.uniques.to_array())             # <<<<<<<<<<<<<<
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 */
    __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_v_self->uniques->__pyx_vtab)->to_array(__pyx_v_self->uniques, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4881, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int32_t__const__(__pyx_t_1, 0); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(2, 4881, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_v_uniques->__pyx_vtab)->extend(__pyx_v_uniques, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4881, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
    __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":4882
 *             uniques = Int32Vector()
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques             # <<<<<<<<<<<<<<
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 */
    __Pyx_INCREF((PyObject *)__pyx_v_uniques);
    __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
    __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
    __pyx_v_self->uniques = __pyx_v_uniques;

    /* "pandas/_libs/hashtable_class_helper.pxi":4879
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = Int32Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4883
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->table), __pyx_n_s_get_labels); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int32_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "pandas/_libs/hashtable_class_helper.pxi":4884
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,             # <<<<<<<<<<<<<<
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_self->__pyx_base.count); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4884, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "pandas/_libs/hashtable_class_helper.pxi":4883
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_5 = PyTuple_New(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3)) __PYX_ERR(2, 4883, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self->uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_self->uniques))) __PYX_ERR(2, 4883, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_4)) __PYX_ERR(2, 4883, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_na_sentinel);
  __Pyx_GIVEREF(__pyx_v_na_sentinel);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_v_na_sentinel)) __PYX_ERR(2, 4883, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4885
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)             # <<<<<<<<<<<<<<
 *         self.count = len(self.uniques)
 *         return labels
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 4885, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 4885, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4883
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4883, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 4883, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
    __pyx_t_7 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_7 < 0)) {
      PyErr_Fetch(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_v_labels, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      }
      __pyx_t_8 = __pyx_t_9 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_labels.diminfo[0].strides = __pyx_pybuffernd_labels.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_labels.diminfo[0].shape = __pyx_pybuffernd_labels.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(2, 4883, __pyx_L1_error)
  }
  __pyx_t_6 = 0;
  __pyx_v_labels = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4886
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  __pyx_t_3 = ((PyObject *)__pyx_v_self->uniques);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_11 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(2, 4886, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_self->__pyx_base.count = __pyx_t_11;

  /* "pandas/_libs/hashtable_class_helper.pxi":4887
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * cdef class UInt16HashTable(HashTable):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_labels);
  __pyx_r = ((PyObject *)__pyx_v_labels);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4861
 *         self.uniques = Int32Vector()
 * 
 *     def factorize(self, const int32_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_labels);
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4854
 * cdef class Int32Factorizer(Factorizer):
 *     cdef public:
 *         Int32HashTable table             # <<<<<<<<<<<<<<
 *         Int32Vector uniques
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_5table_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_5table_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_5table___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->table);
  __pyx_r = ((PyObject *)__pyx_v_self->table);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_5table_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable))))) __PYX_ERR(2, 4854, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32Factorizer.table.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_5table_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_5table_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_5table_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4855
 *     cdef public:
 *         Int32HashTable table
 *         Int32Vector uniques             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, size_hint: int):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_7uniques_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_7uniques_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_7uniques___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __pyx_r = ((PyObject *)__pyx_v_self->uniques);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_7uniques_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector))))) __PYX_ERR(2, 4855, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32Factorizer.uniques.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_7uniques_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_7uniques_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_7uniques_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15Int32Factorizer_5__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_4__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32Factorizer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15Int32Factorizer_7__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_6__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int32Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int32Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4891
 * cdef class UInt16HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_uint16()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __pyx_t_5numpy_int64_t __pyx_v_size_hint;
  int __pyx_v_uses_mask;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,&__pyx_n_s_uses_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4891, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uses_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4891, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 4891, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_size_hint = __Pyx_PyInt_As_npy_int64(values[0]); if (unlikely((__pyx_v_size_hint == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 4891, __pyx_L3_error)
    } else {
      __pyx_v_size_hint = ((__pyx_t_5numpy_int64_t)1);
    }
    if (values[1]) {
      __pyx_v_uses_mask = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_uses_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 4891, __pyx_L3_error)
    } else {
      __pyx_v_uses_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 0, 2, __pyx_nargs); __PYX_ERR(2, 4891, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)__pyx_v_self), __pyx_v_size_hint, __pyx_v_uses_mask);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  khuint_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __pyx_t_5numpy_int64_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":4892
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_uint16()             # <<<<<<<<<<<<<<
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_uint16(self.table, size_hint)
 */
  __pyx_v_self->table = kh_init_uint16();

  /* "pandas/_libs/hashtable_class_helper.pxi":4893
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_uint16()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)             # <<<<<<<<<<<<<<
 *         kh_resize_uint16(self.table, size_hint)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = kh_needed_n_buckets(__pyx_v_size_hint);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4893, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_1, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4893, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(2, 4893, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_6) {
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_5 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4893, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_int64(__pyx_t_3); if (unlikely((__pyx_t_7 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 4893, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_size_hint = __pyx_t_7;

  /* "pandas/_libs/hashtable_class_helper.pxi":4894
 *         self.table = kh_init_uint16()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_uint16(self.table, size_hint)             # <<<<<<<<<<<<<<
 * 
 *         self.uses_mask = uses_mask
 */
  kh_resize_uint16(__pyx_v_self->table, __pyx_v_size_hint);

  /* "pandas/_libs/hashtable_class_helper.pxi":4896
 *         kh_resize_uint16(self.table, size_hint)
 * 
 *         self.uses_mask = uses_mask             # <<<<<<<<<<<<<<
 *         self.na_position = -1
 * 
 */
  __pyx_v_self->uses_mask = __pyx_v_uses_mask;

  /* "pandas/_libs/hashtable_class_helper.pxi":4897
 * 
 *         self.uses_mask = uses_mask
 *         self.na_position = -1             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
  __pyx_v_self->na_position = -1LL;

  /* "pandas/_libs/hashtable_class_helper.pxi":4891
 * cdef class UInt16HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_uint16()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4899
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_3__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_3__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_2__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  long __pyx_t_1;
  int __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":4900
 * 
 *     def __len__(self) -> int:
 *         return self.table.size + (0 if self.na_position == -1 else 1)             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_2 = (__pyx_v_self->na_position == -1LL);
  if (__pyx_t_2) {
    __pyx_t_1 = 0;
  } else {
    __pyx_t_1 = 1;
  }
  __pyx_r = (__pyx_v_self->table->size + __pyx_t_1);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4899
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4902
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_uint16(self.table)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_5__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_5__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_4__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":4903
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_uint16(self.table)
 *             self.table = NULL
 */
  __pyx_t_1 = (__pyx_v_self->table != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4904
 *     def __dealloc__(self):
 *         if self.table is not NULL:
 *             kh_destroy_uint16(self.table)             # <<<<<<<<<<<<<<
 *             self.table = NULL
 * 
 */
    kh_destroy_uint16(__pyx_v_self->table);

    /* "pandas/_libs/hashtable_class_helper.pxi":4905
 *         if self.table is not NULL:
 *             kh_destroy_uint16(self.table)
 *             self.table = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __contains__(self, object key) -> bool:
 */
    __pyx_v_self->table = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":4903
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_uint16(self.table)
 *             self.table = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4902
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_uint16(self.table)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":4907
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__contains__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_6__contains__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)__pyx_v_self), ((PyObject *)__pyx_v_key));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, PyObject *__pyx_v_key) {
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_uint16_t __pyx_v_ckey;
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  __pyx_t_5numpy_uint16_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4914
 *             uint16_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_1 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_7missing_checknull(__pyx_v_key, 0, NULL); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4914, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4915
 * 
 *         if self.uses_mask and checknull(key):
 *             return -1 != self.na_position             # <<<<<<<<<<<<<<
 * 
 *         ckey = (key)
 */
    __pyx_r = (-1LL != __pyx_v_self->na_position);
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":4914
 *             uint16_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4917
 *             return -1 != self.na_position
 * 
 *         ckey = (key)             # <<<<<<<<<<<<<<
 *         k = kh_get_uint16(self.table, ckey)
 *         return k != self.table.n_buckets
 */
  __pyx_t_3 = __Pyx_PyInt_As_npy_uint16(__pyx_v_key); if (unlikely((__pyx_t_3 == ((npy_uint16)-1)) && PyErr_Occurred())) __PYX_ERR(2, 4917, __pyx_L1_error)
  __pyx_v_ckey = __pyx_t_3;

  /* "pandas/_libs/hashtable_class_helper.pxi":4918
 * 
 *         ckey = (key)
 *         k = kh_get_uint16(self.table, ckey)             # <<<<<<<<<<<<<<
 *         return k != self.table.n_buckets
 * 
 */
  __pyx_v_k = kh_get_uint16(__pyx_v_self->table, __pyx_v_ckey);

  /* "pandas/_libs/hashtable_class_helper.pxi":4919
 *         ckey = (key)
 *         k = kh_get_uint16(self.table, ckey)
 *         return k != self.table.n_buckets             # <<<<<<<<<<<<<<
 * 
 *     def sizeof(self, deep: bool = False) -> int:
 */
  __pyx_r = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4907
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4921
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15UInt16HashTable_8sizeof, " return the size of my table in bytes ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_9sizeof = {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt16HashTable_8sizeof};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_deep = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sizeof (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_deep,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_deep);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4921, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "sizeof") < 0)) __PYX_ERR(2, 4921, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_deep = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sizeof", 0, 0, 1, __pyx_nargs); __PYX_ERR(2, 4921, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_8sizeof(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)__pyx_v_self), __pyx_v_deep);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep) {
  PyObject *__pyx_v_overhead = NULL;
  PyObject *__pyx_v_for_flags = NULL;
  PyObject *__pyx_v_for_pairs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  long __pyx_t_2;
  long __pyx_t_3;
  long __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sizeof", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":4923
 *     def sizeof(self, deep: bool = False) -> int:
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)             # <<<<<<<<<<<<<<
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(uint16_t) + # keys
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(((4 * (sizeof(__pyx_t_5numpy_uint32_t))) + (3 * (sizeof(__pyx_t_5numpy_uint32_t *))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4923, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_overhead = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4924
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)             # <<<<<<<<<<<<<<
 *         for_pairs =  self.table.n_buckets * (sizeof(uint16_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 */
  __pyx_t_2 = (__pyx_v_self->table->n_buckets >> 5);
  __pyx_t_3 = 1;
  __pyx_t_5 = (__pyx_t_2 > __pyx_t_3);
  if (__pyx_t_5) {
    __pyx_t_4 = __pyx_t_2;
  } else {
    __pyx_t_4 = __pyx_t_3;
  }
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_t_4 * (sizeof(__pyx_t_5numpy_uint32_t)))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4924, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_flags = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4925
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(uint16_t) + # keys             # <<<<<<<<<<<<<<
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->n_buckets * ((sizeof(__pyx_t_5numpy_uint16_t)) + (sizeof(Py_ssize_t))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4925, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_pairs = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4927
 *         for_pairs =  self.table.n_buckets * (sizeof(uint16_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs             # <<<<<<<<<<<<<<
 * 
 *     def get_state(self) -> dict[str, int]:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Add(__pyx_v_overhead, __pyx_v_for_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4927, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyNumber_Add(__pyx_t_1, __pyx_v_for_pairs); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 4927, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(__Pyx_Py3Int_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None) || __Pyx_RaiseUnexpectedTypeError("int", __pyx_t_6))) __PYX_ERR(2, 4927, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4921
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_overhead);
  __Pyx_XDECREF(__pyx_v_for_flags);
  __Pyx_XDECREF(__pyx_v_for_pairs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4929
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15UInt16HashTable_10get_state, " returns infos about the state of the hashtable");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_11get_state = {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt16HashTable_10get_state};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_state (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_state", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_state", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_10get_state(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_state", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":4931
 *     def get_state(self) -> dict[str, int]:
 *         """ returns infos about the state of the hashtable"""
 *         return {             # <<<<<<<<<<<<<<
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 */
  __Pyx_XDECREF(__pyx_r);

  /* "pandas/_libs/hashtable_class_helper.pxi":4932
 *         """ returns infos about the state of the hashtable"""
 *         return {
 *             'n_buckets' : self.table.n_buckets,             # <<<<<<<<<<<<<<
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_buckets); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4932, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_buckets, __pyx_t_2) < 0) __PYX_ERR(2, 4932, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4933
 *         return {
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,             # <<<<<<<<<<<<<<
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->size); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_size, __pyx_t_2) < 0) __PYX_ERR(2, 4932, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4934
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,             # <<<<<<<<<<<<<<
 *             'upper_bound' : self.table.upper_bound,
 *         }
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_occupied); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4934, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_occupied, __pyx_t_2) < 0) __PYX_ERR(2, 4932, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4935
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,             # <<<<<<<<<<<<<<
 *         }
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->upper_bound); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4935, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_upper_bound, __pyx_t_2) < 0) __PYX_ERR(2, 4932, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4929
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.get_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4938
 *         }
 * 
 *     cpdef get_item(self, uint16_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt16HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, __pyx_t_5numpy_uint16_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_uint16_t __pyx_v_cval;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4938, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_13get_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyInt_From_npy_uint16(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4938, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4938, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4957
 *             uint16_t cval
 * 
 *         cval = (val)             # <<<<<<<<<<<<<<
 *         k = kh_get_uint16(self.table, cval)
 *         if k != self.table.n_buckets:
 */
  __pyx_v_cval = __pyx_v_val;

  /* "pandas/_libs/hashtable_class_helper.pxi":4958
 * 
 *         cval = (val)
 *         k = kh_get_uint16(self.table, cval)             # <<<<<<<<<<<<<<
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]
 */
  __pyx_v_k = kh_get_uint16(__pyx_v_self->table, __pyx_v_cval);

  /* "pandas/_libs/hashtable_class_helper.pxi":4959
 *         cval = (val)
 *         k = kh_get_uint16(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  __pyx_t_7 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  if (likely(__pyx_t_7)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4960
 *         k = kh_get_uint16(self.table, cval)
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(val)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->vals[__pyx_v_k])); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4960, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":4959
 *         cval = (val)
 *         k = kh_get_uint16(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4962
 *             return self.table.vals[k]
 *         else:
 *             raise KeyError(val)             # <<<<<<<<<<<<<<
 * 
 *     cpdef get_na(self):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyInt_From_npy_uint16(__pyx_v_val); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4962, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4962, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 4962, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4938
 *         }
 * 
 *     cpdef get_item(self, uint16_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15UInt16HashTable_12get_item, "Extracts the position of val from the hashtable.\n\n        Parameters\n        ----------\n        val : Scalar\n            The value that is looked up in the hashtable\n\n        Returns\n        -------\n        The position of the requested integer.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_13get_item = {"get_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_13get_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt16HashTable_12get_item};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_5numpy_uint16_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4938, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_item") < 0)) __PYX_ERR(2, 4938, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __Pyx_PyInt_As_npy_uint16(values[0]); if (unlikely((__pyx_v_val == ((npy_uint16)-1)) && PyErr_Occurred())) __PYX_ERR(2, 4938, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_item", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 4938, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_12get_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, __pyx_t_5numpy_uint16_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_15UInt16HashTable_get_item(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4964
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt16HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4964, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_15get_na)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4964, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4972
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_6 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4973
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         if self.na_position == -1:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 4973, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":4972
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4975
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  __pyx_t_6 = (__pyx_v_self->na_position == -1LL);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4976
 * 
 *         if self.na_position == -1:
 *             raise KeyError("NA")             # <<<<<<<<<<<<<<
 *         return self.na_position
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_KeyError, __pyx_tuple__13, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4976, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(2, 4976, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":4975
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4977
 *         if self.na_position == -1:
 *             raise KeyError("NA")
 *         return self.na_position             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_item(self, uint16_t key, Py_ssize_t val):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->na_position); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4977, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4964
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15UInt16HashTable_14get_na, "Extracts the position of na_value from the hashtable.\n\n        Returns\n        -------\n        The position of the last na value.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_15get_na = {"get_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_15get_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt16HashTable_14get_na};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_na", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_na", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_14get_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_15UInt16HashTable_get_na(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4979
 *         return self.na_position
 * 
 *     cpdef set_item(self, uint16_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt16HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, __pyx_t_5numpy_uint16_t __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  __pyx_t_5numpy_uint16_t __pyx_v_ckey;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4979, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_17set_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyInt_From_npy_uint16(__pyx_v_key); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4979, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4979, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_5 = __pyx_t_1; __pyx_t_6 = NULL;
        __pyx_t_7 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_7 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_3, __pyx_t_4};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4979, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4984
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             uint16_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4987
 *             uint16_t ckey
 * 
 *         ckey = (key)             # <<<<<<<<<<<<<<
 *         k = kh_put_uint16(self.table, ckey, &ret)
 *         if kh_exist_uint16(self.table, k):
 */
  __pyx_v_ckey = __pyx_v_key;

  /* "pandas/_libs/hashtable_class_helper.pxi":4988
 * 
 *         ckey = (key)
 *         k = kh_put_uint16(self.table, ckey, &ret)             # <<<<<<<<<<<<<<
 *         if kh_exist_uint16(self.table, k):
 *             self.table.vals[k] = val
 */
  __pyx_v_k = kh_put_uint16(__pyx_v_self->table, __pyx_v_ckey, (&__pyx_v_ret));

  /* "pandas/_libs/hashtable_class_helper.pxi":4989
 *         ckey = (key)
 *         k = kh_put_uint16(self.table, ckey, &ret)
 *         if kh_exist_uint16(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
  __pyx_t_8 = kh_exist_uint16(__pyx_v_self->table, __pyx_v_k);
  if (likely(__pyx_t_8)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":4990
 *         k = kh_put_uint16(self.table, ckey, &ret)
 *         if kh_exist_uint16(self.table, k):
 *             self.table.vals[k] = val             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(key)
 */
    (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_val;

    /* "pandas/_libs/hashtable_class_helper.pxi":4989
 *         ckey = (key)
 *         k = kh_put_uint16(self.table, ckey, &ret)
 *         if kh_exist_uint16(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4992
 *             self.table.vals[k] = val
 *         else:
 *             raise KeyError(key)             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_na(self, Py_ssize_t val):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyInt_From_npy_uint16(__pyx_v_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4992, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4992, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 4992, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "pandas/_libs/hashtable_class_helper.pxi":4979
 *         return self.na_position
 * 
 *     cpdef set_item(self, uint16_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_17set_item = {"set_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_17set_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_5numpy_uint16_t __pyx_v_key;
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key,&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4979, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4979, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, 1); __PYX_ERR(2, 4979, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_item") < 0)) __PYX_ERR(2, 4979, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_key = __Pyx_PyInt_As_npy_uint16(values[0]); if (unlikely((__pyx_v_key == ((npy_uint16)-1)) && PyErr_Occurred())) __PYX_ERR(2, 4979, __pyx_L3_error)
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 4979, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, __pyx_nargs); __PYX_ERR(2, 4979, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_16set_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)__pyx_v_self), __pyx_v_key, __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, __pyx_t_5numpy_uint16_t __pyx_v_key, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_15UInt16HashTable_set_item(__pyx_v_self, __pyx_v_key, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":4994
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15UInt16HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  CYTHON_UNUSED int __pyx_v_ret;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4994, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_19set_na)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 4994, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 4994, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":4998
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             uint16_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5001
 *             uint16_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_7 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_7)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5002
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         self.na_position = val
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 5002, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":5001
 *             uint16_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5004
 *             raise NotImplementedError
 * 
 *         self.na_position = val             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->na_position = __pyx_v_val;

  /* "pandas/_libs/hashtable_class_helper.pxi":4994
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_19set_na = {"set_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_19set_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 4994, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_na") < 0)) __PYX_ERR(2, 4994, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[0]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 4994, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_na", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 4994, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_18set_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_15UInt16HashTable_set_na(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5007
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const uint16_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_21map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_21map_locations = {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_21map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_21map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("map_locations (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5007, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5007, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "map_locations") < 0)) __PYX_ERR(2, 5007, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint16_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 5008, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 5008, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__32;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("map_locations", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 5007, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_20map_locations(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_20map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  int __pyx_v_ret;
  __pyx_t_5numpy_uint16_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  __pyx_t_5numpy_int64_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("map_locations", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":5011
 *         # Used in libindex, safe_sort
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             uint16_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":5012
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             uint16_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5015
 *             uint16_t val
 *             khiter_t k
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_2 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":5017
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_3 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_3)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5018
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 5018, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":5017
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5020
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":5021
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
        if (__pyx_v_self->uses_mask) {

          /* "pandas/_libs/hashtable_class_helper.pxi":5022
 *         with nogil:
 *             if self.uses_mask:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     if mask[i]:
 *                         na_position = i
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":5023
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_mask.shape[0];
            __pyx_t_3 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) ))) != 0);
            if (__pyx_t_3) {

              /* "pandas/_libs/hashtable_class_helper.pxi":5024
 *                 for i in range(n):
 *                     if mask[i]:
 *                         na_position = i             # <<<<<<<<<<<<<<
 *                     else:
 *                         val= (values[i])
 */
              __pyx_v_na_position = __pyx_v_i;

              /* "pandas/_libs/hashtable_class_helper.pxi":5023
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
              goto __pyx_L12;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":5026
 *                         na_position = i
 *                     else:
 *                         val= (values[i])             # <<<<<<<<<<<<<<
 *                         k = kh_put_uint16(self.table, val, &ret)
 *                         self.table.vals[k] = i
 */
            /*else*/ {
              __pyx_t_7 = __pyx_v_i;
              if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
              __pyx_v_val = (*((__pyx_t_5numpy_uint16_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_class_helper.pxi":5027
 *                     else:
 *                         val= (values[i])
 *                         k = kh_put_uint16(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = i
 *             else:
 */
              __pyx_v_k = kh_put_uint16(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

              /* "pandas/_libs/hashtable_class_helper.pxi":5028
 *                         val= (values[i])
 *                         k = kh_put_uint16(self.table, val, &ret)
 *                         self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *             else:
 *                 for i in range(n):
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
            }
            __pyx_L12:;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":5021
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
          goto __pyx_L9;
        }

        /* "pandas/_libs/hashtable_class_helper.pxi":5030
 *                         self.table.vals[k] = i
 *             else:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     val= (values[i])
 *                     k = kh_put_uint16(self.table, val, &ret)
 */
        /*else*/ {
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":5031
 *             else:
 *                 for i in range(n):
 *                     val= (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_put_uint16(self.table, val, &ret)
 *                     self.table.vals[k] = i
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
            __pyx_v_val = (*((__pyx_t_5numpy_uint16_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

            /* "pandas/_libs/hashtable_class_helper.pxi":5032
 *                 for i in range(n):
 *                     val= (values[i])
 *                     k = kh_put_uint16(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                     self.table.vals[k] = i
 *         self.na_position = na_position
 */
            __pyx_v_k = kh_put_uint16(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":5033
 *                     val= (values[i])
 *                     k = kh_put_uint16(self.table, val, &ret)
 *                     self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *         self.na_position = na_position
 * 
 */
            (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
          }
        }
        __pyx_L9:;
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":5020
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5034
 *                     k = kh_put_uint16(self.table, val, &ret)
 *                     self.table.vals[k] = i
 *         self.na_position = na_position             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __pyx_v_self->na_position = __pyx_v_na_position;

  /* "pandas/_libs/hashtable_class_helper.pxi":5007
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const uint16_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5036
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const uint16_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

/* Python wrapper */
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_23lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_23lookup = {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_23lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_23lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyArrayObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lookup (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5036, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5036, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lookup") < 0)) __PYX_ERR(2, 5036, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint16_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 5037, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 5037, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__33;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lookup", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 5036, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_22lookup(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_22lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  CYTHON_UNUSED int __pyx_v_ret;
  __pyx_t_5numpy_uint16_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __Pyx_memviewslice __pyx_v_locs = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lookup", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":5041
 *         # Used in safe_sort, IndexEngine.get_indexer
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             uint16_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":5042
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             uint16_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5045
 *             uint16_t val
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *             int8_t na_position = self.na_position
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 5045, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 5045, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 5045, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_locs = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":5046
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_8 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":5048
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_9 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_10 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_9 = __pyx_t_10;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5049
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 5049, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":5048
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5051
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":5052
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_11 = __pyx_t_1;
        for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
          __pyx_v_i = __pyx_t_12;

          /* "pandas/_libs/hashtable_class_helper.pxi":5053
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
          if (__pyx_v_self->uses_mask) {
          } else {
            __pyx_t_9 = __pyx_v_self->uses_mask;
            goto __pyx_L12_bool_binop_done;
          }
          __pyx_t_13 = __pyx_v_i;
          if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_mask.shape[0];
          __pyx_t_10 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_13 * __pyx_v_mask.strides[0]) ))) != 0);
          __pyx_t_9 = __pyx_t_10;
          __pyx_L12_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":5054
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position             # <<<<<<<<<<<<<<
 *                 else:
 *                     val = (values[i])
 */
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = __pyx_v_na_position;

            /* "pandas/_libs/hashtable_class_helper.pxi":5053
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
            goto __pyx_L11;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":5056
 *                     locs[i] = na_position
 *                 else:
 *                     val = (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_uint16(self.table, val)
 *                     if k != self.table.n_buckets:
 */
          /*else*/ {
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_values.shape[0];
            __pyx_v_val = (*((__pyx_t_5numpy_uint16_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_13 * __pyx_v_values.strides[0]) )));

            /* "pandas/_libs/hashtable_class_helper.pxi":5057
 *                 else:
 *                     val = (values[i])
 *                     k = kh_get_uint16(self.table, val)             # <<<<<<<<<<<<<<
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]
 */
            __pyx_v_k = kh_get_uint16(__pyx_v_self->table, __pyx_v_val);

            /* "pandas/_libs/hashtable_class_helper.pxi":5058
 *                     val = (values[i])
 *                     k = kh_get_uint16(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
            __pyx_t_9 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":5059
 *                     k = kh_get_uint16(self.table, val)
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     else:
 *                         locs[i] = -1
 */
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = (__pyx_v_self->table->vals[__pyx_v_k]);

              /* "pandas/_libs/hashtable_class_helper.pxi":5058
 *                     val = (values[i])
 *                     k = kh_get_uint16(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
              goto __pyx_L14;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":5061
 *                         locs[i] = self.table.vals[k]
 *                     else:
 *                         locs[i] = -1             # <<<<<<<<<<<<<<
 * 
 *         return np.asarray(locs)
 */
            /*else*/ {
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = -1;
            }
            __pyx_L14:;
          }
          __pyx_L11:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":5051
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5063
 *                         locs[i] = -1
 * 
 *         return np.asarray(locs)             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_locs, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_14 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_14 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5063, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 5063, __pyx_L1_error)
  __pyx_r = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5036
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const uint16_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_locs, 1);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5065
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const uint16_t[:] values, UInt16Vector uniques,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_25_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15UInt16HashTable_24_unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[uint16]\n            Array of values of which unique will be calculated\n        uniques : UInt16Vector\n            Vector into which uniques will be written\n        count_prior : Py_ssize_t, default 0\n            Number of existing entries in uniques\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        ignore_na : bool, default False\n            Whether NA-values should be ignored for calculating the uniques. If\n            True, the labels corresponding to missing values will be set to\n            na_sentinel.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        use_result_mask: bool, default False\n            Whether to create a result mask for the unique values. Not supported\n            with return_inverse=True.\n\n        Returns\n        -------\n        uniques : ndarray[uint16]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse=True)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if use_result_mask is true\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_25_unique = {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_25_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt16HashTable_24_unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_25_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  int __pyx_v_ignore_na;
  PyObject *__pyx_v_mask = 0;
  int __pyx_v_return_inverse;
  int __pyx_v_use_result_mask;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[9] = {0,0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_ignore_na,&__pyx_n_s_mask,&__pyx_n_s_return_inverse,&__pyx_n_s_use_result_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":5069
 *     def _unique(self, const uint16_t[:] values, UInt16Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));

    /* "pandas/_libs/hashtable_class_helper.pxi":5070
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[6] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5065, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5065, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, 1); __PYX_ERR(2, 5065, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5065, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5065, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5065, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5065, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[6] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5065, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[7] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5065, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_use_result_mask);
          if (value) { values[8] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5065, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_unique") < 0)) __PYX_ERR(2, 5065, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint16_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 5067, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 5068, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 5068, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    if (values[5]) {
      __pyx_v_ignore_na = __Pyx_PyObject_IsTrue(values[5]); if (unlikely((__pyx_v_ignore_na == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 5069, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":5069
 *     def _unique(self, const uint16_t[:] values, UInt16Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
      __pyx_v_ignore_na = ((int)0);
    }
    __pyx_v_mask = values[6];
    if (values[7]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[7]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 5070, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":5070
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
      __pyx_v_return_inverse = ((int)0);
    }
    if (values[8]) {
      __pyx_v_use_result_mask = __Pyx_PyObject_IsTrue(values[8]); if (unlikely((__pyx_v_use_result_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 5070, __pyx_L3_error)
    } else {
      __pyx_v_use_result_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, __pyx_nargs); __PYX_ERR(2, 5065, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector, 1, "uniques", 0))) __PYX_ERR(2, 5067, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_24_unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_ignore_na, __pyx_v_mask, __pyx_v_return_inverse, __pyx_v_use_result_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":5065
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const uint16_t[:] values, UInt16Vector uniques,
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_24_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_idx;
  Py_ssize_t __pyx_v_count;
  Py_ssize_t __pyx_v_n;
  __Pyx_memviewslice __pyx_v_labels = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_ret;
  __pyx_t_5numpy_uint16_t __pyx_v_val;
  __pyx_t_5numpy_uint16_t __pyx_v_na_value2;
  khiter_t __pyx_v_k;
  __pyx_t_6pandas_5_libs_9hashtable_UInt16VectorData *__pyx_v_ud;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_result_mask = 0;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_v_rmd;
  int __pyx_v_use_na_value;
  int __pyx_v_use_mask;
  int __pyx_v_seen_na;
  __Pyx_memviewslice __pyx_v_mask_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_6pandas_5_libs_9hashtable_UInt16VectorData *__pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_t_11;
  int __pyx_t_12;
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_uint16_t __pyx_t_14;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":5114
 *         """
 *         cdef:
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)             # <<<<<<<<<<<<<<
 *             intp_t[::1] labels
 *             int ret = 0
 */
  __pyx_v_count = __pyx_v_count_prior;
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":5116
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)
 *             intp_t[::1] labels
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             uint16_t val, na_value2
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5122
 *             UInt8Vector result_mask
 *             UInt8VectorData *rmd
 *             bint use_na_value, use_mask, seen_na = False             # <<<<<<<<<<<<<<
 *             uint8_t[:] mask_values
 * 
 */
  __pyx_v_seen_na = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5125
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5126
 * 
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 5126, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 5126, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5126, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 5126, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_labels = __pyx_t_7;
    __pyx_t_7.memview = NULL;
    __pyx_t_7.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":5125
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5127
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data             # <<<<<<<<<<<<<<
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 */
  __pyx_t_8 = __pyx_v_uniques->data;
  __pyx_v_ud = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":5128
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 *         use_na_value = na_value is not None             # <<<<<<<<<<<<<<
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 */
  __pyx_t_9 = (__pyx_v_na_value != Py_None);
  __pyx_v_use_na_value = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":5129
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None             # <<<<<<<<<<<<<<
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover
 */
  __pyx_t_9 = (__pyx_v_mask != Py_None);
  __pyx_v_use_mask = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":5130
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  __pyx_t_10 = (!__pyx_v_use_mask);
  if (__pyx_t_10) {
  } else {
    __pyx_t_9 = __pyx_t_10;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_use_result_mask;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5131
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         if use_result_mask and return_inverse:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 5131, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":5130
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5133
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_use_result_mask) {
  } else {
    __pyx_t_9 = __pyx_v_use_result_mask;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_return_inverse;
  __pyx_L8_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5134
 * 
 *         if use_result_mask and return_inverse:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         result_mask = UInt8Vector()
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 5134, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":5133
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5136
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         result_mask = UInt8Vector()             # <<<<<<<<<<<<<<
 *         rmd = result_mask.data
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_v_result_mask = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5137
 * 
 *         result_mask = UInt8Vector()
 *         rmd = result_mask.data             # <<<<<<<<<<<<<<
 * 
 *         if use_mask:
 */
  __pyx_t_11 = __pyx_v_result_mask->data;
  __pyx_v_rmd = __pyx_t_11;

  /* "pandas/_libs/hashtable_class_helper.pxi":5139
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  if (__pyx_v_use_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5140
 * 
 *         if use_mask:
 *             mask_values = mask.view("uint8")             # <<<<<<<<<<<<<<
 * 
 *         if use_na_value:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_mask, __pyx_n_s_view); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5140, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    __pyx_t_12 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_12 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_uint8};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_12, 1+__pyx_t_12);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5140, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(2, 5140, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_mask_values = __pyx_t_13;
    __pyx_t_13.memview = NULL;
    __pyx_t_13.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":5139
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5142
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
  if (__pyx_v_use_na_value) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5148
 *             # for the parameter. To please the compiler, we use na_value2,
 *             # which is only used if it's *specified*.
 *             na_value2 = (na_value)             # <<<<<<<<<<<<<<
 *         else:
 *             na_value2 = (0)
 */
    __pyx_t_14 = __Pyx_PyInt_As_npy_uint16(__pyx_v_na_value); if (unlikely((__pyx_t_14 == ((npy_uint16)-1)) && PyErr_Occurred())) __PYX_ERR(2, 5148, __pyx_L1_error)
    __pyx_v_na_value2 = __pyx_t_14;

    /* "pandas/_libs/hashtable_class_helper.pxi":5142
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
    goto __pyx_L11;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5150
 *             na_value2 = (na_value)
 *         else:
 *             na_value2 = (0)             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
  /*else*/ {
    __pyx_v_na_value2 = 0;
  }
  __pyx_L11:;

  /* "pandas/_libs/hashtable_class_helper.pxi":5152
 *             na_value2 = (0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = (values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":5153
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 val = (values[i])
 * 
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_15 = __pyx_t_1;
        for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
          __pyx_v_i = __pyx_t_16;

          /* "pandas/_libs/hashtable_class_helper.pxi":5154
 *         with nogil:
 *             for i in range(n):
 *                 val = (values[i])             # <<<<<<<<<<<<<<
 * 
 *                 if ignore_na and use_mask:
 */
          __pyx_t_17 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_uint16_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_17 * __pyx_v_values.strides[0]) )));

          /* "pandas/_libs/hashtable_class_helper.pxi":5156
 *                 val = (values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L18_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_mask;
          __pyx_L18_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":5157
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 5157, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_17 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":5158
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                         continue
 *                 elif ignore_na and (
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 5158, __pyx_L13_error) }
              __pyx_t_17 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_na_sentinel;

              /* "pandas/_libs/hashtable_class_helper.pxi":5159
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 *                         continue             # <<<<<<<<<<<<<<
 *                 elif ignore_na and (
 *                    is_nan_uint16_t(val) or
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":5157
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":5156
 *                 val = (values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
            goto __pyx_L17;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":5160
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_uint16_t(val) or
 *                    (use_na_value and are_equivalent_uint16_t(val, na_value2))
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":5161
 *                         continue
 *                 elif ignore_na and (
 *                    is_nan_uint16_t(val) or             # <<<<<<<<<<<<<<
 *                    (use_na_value and are_equivalent_uint16_t(val, na_value2))
 *                 ):
 */
          __pyx_t_10 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_uint16_t(__pyx_v_val); if (unlikely(__pyx_t_10 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 5161, __pyx_L13_error)
          if (!__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":5162
 *                 elif ignore_na and (
 *                    is_nan_uint16_t(val) or
 *                    (use_na_value and are_equivalent_uint16_t(val, na_value2))             # <<<<<<<<<<<<<<
 *                 ):
 *                     # if missing values do not count as unique values (i.e. if
 */
          if (__pyx_v_use_na_value) {
          } else {
            __pyx_t_9 = __pyx_v_use_na_value;
            goto __pyx_L21_bool_binop_done;
          }
          __pyx_t_10 = __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_uint16_t(__pyx_v_val, __pyx_v_na_value2); if (unlikely(__pyx_t_10 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 5162, __pyx_L13_error)
          __pyx_t_9 = __pyx_t_10;
          __pyx_L21_bool_binop_done:;

          /* "pandas/_libs/hashtable_class_helper.pxi":5160
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_uint16_t(val) or
 *                    (use_na_value and are_equivalent_uint16_t(val, na_value2))
 */
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":5167
 *                     # ignore_na is True), skip the hashtable entry for them,
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 5167, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_na_sentinel;

            /* "pandas/_libs/hashtable_class_helper.pxi":5168
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel
 *                     continue             # <<<<<<<<<<<<<<
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 */
            goto __pyx_L15_continue;

            /* "pandas/_libs/hashtable_class_helper.pxi":5160
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_uint16_t(val) or
 *                    (use_na_value and are_equivalent_uint16_t(val, na_value2))
 */
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":5169
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          __pyx_t_10 = (!__pyx_v_ignore_na);
          if (__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L25_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_result_mask;
          __pyx_L25_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":5170
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 5170, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_17 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":5171
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_class_helper.pxi":5172
 *                     if mask_values[i]:
 *                         if seen_na:
 *                             continue             # <<<<<<<<<<<<<<
 * 
 *                         seen_na = True
 */
                goto __pyx_L15_continue;

                /* "pandas/_libs/hashtable_class_helper.pxi":5171
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":5174
 *                             continue
 * 
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         if needs_resize(ud):
 *                             with gil:
 */
              __pyx_v_seen_na = 1;

              /* "pandas/_libs/hashtable_class_helper.pxi":5175
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              __pyx_t_9 = __pyx_fuse_6__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 5175, __pyx_L13_error)
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_class_helper.pxi":5176
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                {
                    #ifdef WITH_THREAD
                    PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                    #endif
                    /*try:*/ {

                      /* "pandas/_libs/hashtable_class_helper.pxi":5177
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":5178
 *                             with gil:
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5178, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 5178, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":5177
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":5181
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt16Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5181, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":5182
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":5183
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5183, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 5183, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":5182
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":5186
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                         append_data_uint16(ud, val)
 *                         append_data_uint8(rmd, 1)
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5186, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":5176
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    /*finally:*/ {
                      /*normal exit:*/{
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L34;
                      }
                      __pyx_L33_error: {
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L13_error;
                      }
                      __pyx_L34:;
                    }
                }

                /* "pandas/_libs/hashtable_class_helper.pxi":5175
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":5187
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                         append_data_uint16(ud, val)             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 1)
 *                         continue
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint16(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 5187, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":5188
 *                                 result_mask.resize()
 *                         append_data_uint16(ud, val)
 *                         append_data_uint8(rmd, 1)             # <<<<<<<<<<<<<<
 *                         continue
 * 
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 1); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 5188, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":5189
 *                         append_data_uint16(ud, val)
 *                         append_data_uint8(rmd, 1)
 *                         continue             # <<<<<<<<<<<<<<
 * 
 *                 k = kh_get_uint16(self.table, val)
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":5170
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":5169
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          }
          __pyx_L17:;

          /* "pandas/_libs/hashtable_class_helper.pxi":5191
 *                         continue
 * 
 *                 k = kh_get_uint16(self.table, val)             # <<<<<<<<<<<<<<
 * 
 *                 if k == self.table.n_buckets:
 */
          __pyx_v_k = kh_get_uint16(__pyx_v_self->table, __pyx_v_val);

          /* "pandas/_libs/hashtable_class_helper.pxi":5193
 *                 k = kh_get_uint16(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_uint16(self.table, val, &ret)
 */
          __pyx_t_9 = (__pyx_v_k == __pyx_v_self->table->n_buckets);
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":5195
 *                 if k == self.table.n_buckets:
 *                     # k hasn't been seen yet
 *                     k = kh_put_uint16(self.table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *                     if needs_resize(ud):
 */
            __pyx_v_k = kh_put_uint16(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":5197
 *                     k = kh_put_uint16(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            __pyx_t_9 = __pyx_fuse_6__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 5197, __pyx_L13_error)
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":5198
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
              {
                  #ifdef WITH_THREAD
                  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                  #endif
                  /*try:*/ {

                    /* "pandas/_libs/hashtable_class_helper.pxi":5199
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":5200
 *                         with gil:
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 */
                      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5200, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                      __PYX_ERR(2, 5200, __pyx_L42_error)

                      /* "pandas/_libs/hashtable_class_helper.pxi":5199
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":5203
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()             # <<<<<<<<<<<<<<
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 */
                    __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt16Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5203, __pyx_L42_error)
                    __Pyx_GOTREF(__pyx_t_6);
                    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                    /* "pandas/_libs/hashtable_class_helper.pxi":5204
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    if (__pyx_v_use_result_mask) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":5205
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":5206
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5206, __pyx_L42_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 5206, __pyx_L42_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":5205
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":5209
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                     append_data_uint16(ud, val)
 *                     if use_result_mask:
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5209, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":5204
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    }
                  }

                  /* "pandas/_libs/hashtable_class_helper.pxi":5198
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
                  /*finally:*/ {
                    /*normal exit:*/{
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L43;
                    }
                    __pyx_L42_error: {
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L13_error;
                    }
                    __pyx_L43:;
                  }
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":5197
 *                     k = kh_put_uint16(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":5210
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                     append_data_uint16(ud, val)             # <<<<<<<<<<<<<<
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)
 */
            __pyx_f_6pandas_5_libs_9hashtable_append_data_uint16(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 5210, __pyx_L13_error)

            /* "pandas/_libs/hashtable_class_helper.pxi":5211
 *                                 result_mask.resize()
 *                     append_data_uint16(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            if (__pyx_v_use_result_mask) {

              /* "pandas/_libs/hashtable_class_helper.pxi":5212
 *                     append_data_uint16(ud, val)
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)             # <<<<<<<<<<<<<<
 * 
 *                     if return_inverse:
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 0); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 5212, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":5211
 *                                 result_mask.resize()
 *                     append_data_uint16(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":5214
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            if (__pyx_v_return_inverse) {

              /* "pandas/_libs/hashtable_class_helper.pxi":5215
 * 
 *                     if return_inverse:
 *                         self.table.vals[k] = count             # <<<<<<<<<<<<<<
 *                         labels[i] = count
 *                         count += 1
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":5216
 *                     if return_inverse:
 *                         self.table.vals[k] = count
 *                         labels[i] = count             # <<<<<<<<<<<<<<
 *                         count += 1
 *                 elif return_inverse:
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 5216, __pyx_L13_error) }
              __pyx_t_17 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":5217
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 *                         count += 1             # <<<<<<<<<<<<<<
 *                 elif return_inverse:
 *                     # k falls into a previous bucket
 */
              __pyx_v_count = (__pyx_v_count + 1);

              /* "pandas/_libs/hashtable_class_helper.pxi":5214
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":5193
 *                 k = kh_get_uint16(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_uint16(self.table, val, &ret)
 */
            goto __pyx_L37;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":5218
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          if (__pyx_v_return_inverse) {

            /* "pandas/_libs/hashtable_class_helper.pxi":5221
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     labels[i] = idx
 * 
 */
            __pyx_v_idx = (__pyx_v_self->table->vals[__pyx_v_k]);

            /* "pandas/_libs/hashtable_class_helper.pxi":5222
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]
 *                     labels[i] = idx             # <<<<<<<<<<<<<<
 * 
 *         if return_inverse:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 5222, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_idx;

            /* "pandas/_libs/hashtable_class_helper.pxi":5218
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          }
          __pyx_L37:;
          __pyx_L15_continue:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":5152
 *             na_value2 = (0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = (values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L14;
        }
        __pyx_L13_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L14:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5224
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5225
 * 
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray             # <<<<<<<<<<<<<<
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt16Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5225, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundLocalError("labels"); __PYX_ERR(2, 5225, __pyx_L1_error) }
    __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_labels, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5225, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_base); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5225, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5225, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_6);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_6)) __PYX_ERR(2, 5225, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4)) __PYX_ERR(2, 5225, __pyx_L1_error);
    __pyx_t_6 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":5224
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5226
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  if (__pyx_v_use_result_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5227
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()             # <<<<<<<<<<<<<<
 *         return uniques.to_array()
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt16Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5227, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->to_array(__pyx_v_result_mask, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5227, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5227, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2)) __PYX_ERR(2, 5227, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4)) __PYX_ERR(2, 5227, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":5226
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5228
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()             # <<<<<<<<<<<<<<
 * 
 *     def unique(self, const uint16_t[:] values, bint return_inverse=False, object mask=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt16Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5228, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5065
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const uint16_t[:] values, UInt16Vector uniques,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_13, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_labels, 1);
  __Pyx_XDECREF((PyObject *)__pyx_v_result_mask);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask_values, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5230
 *         return uniques.to_array()
 * 
 *     def unique(self, const uint16_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_27unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15UInt16HashTable_26unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[uint16]\n            Array of values of which unique will be calculated\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n\n        Returns\n        -------\n        uniques : ndarray[uint16]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if mask is given as input\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_27unique = {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_27unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt16HashTable_26unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_27unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_return_inverse;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_return_inverse,&__pyx_n_s_mask,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5230, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5230, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5230, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "unique") < 0)) __PYX_ERR(2, 5230, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint16_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 5230, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 5230, __pyx_L3_error)
    } else {
      __pyx_v_return_inverse = ((int)0);
    }
    __pyx_v_mask = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("unique", 0, 1, 3, __pyx_nargs); __PYX_ERR(2, 5230, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_26unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_return_inverse, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_26unique(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_uniques = NULL;
  int __pyx_v_use_result_mask;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":5254
 *             The mask for the result values.
 *         """
 *         uniques = UInt16Vector()             # <<<<<<<<<<<<<<
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5254, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5255
 *         """
 *         uniques = UInt16Vector()
 *         use_result_mask = True if mask is not None else False             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 */
  __pyx_t_3 = (__pyx_v_mask != Py_None);
  if (__pyx_t_3) {
    __pyx_t_2 = 1;
  } else {
    __pyx_t_2 = 0;
  }
  __pyx_v_use_result_mask = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":5256
 *         uniques = UInt16Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint16_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4)) __PYX_ERR(2, 5256, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 5256, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ignore_na, Py_False) < 0) __PYX_ERR(2, 5256, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5257
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const uint16_t[:] values, Py_ssize_t na_sentinel=-1,
 */
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_return_inverse); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return_inverse, __pyx_t_6) < 0) __PYX_ERR(2, 5256, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 5256, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_use_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5257, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_use_result_mask, __pyx_t_6) < 0) __PYX_ERR(2, 5256, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5256
 *         uniques = UInt16Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5256, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5230
 *         return uniques.to_array()
 * 
 *     def unique(self, const uint16_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5259
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const uint16_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_29factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15UInt16HashTable_28factorize, "\n        Calculate unique values and labels (no sorting!)\n\n        Missing values are not included in the \"uniques\" for this method.\n        The labels for any missing values will be set to \"na_sentinel\"\n\n        Parameters\n        ----------\n        values : ndarray[uint16]\n            Array of values of which unique will be calculated\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n\n        Returns\n        -------\n        uniques : ndarray[uint16]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t]\n            The labels from values to uniques\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_29factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_29factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt16HashTable_28factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_29factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  PyObject *__pyx_v_ignore_na = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,&__pyx_n_s_ignore_na,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":5260
 * 
 *     def factorize(self, const uint16_t[:] values, Py_ssize_t na_sentinel=-1,
 *                   object na_value=None, object mask=None, ignore_na=True):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_True));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5259, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5259, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5259, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5259, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5259, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 5259, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint16_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 5259, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 5259, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
    __pyx_v_ignore_na = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 5, __pyx_nargs); __PYX_ERR(2, 5259, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_28factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask, __pyx_v_ignore_na);

  /* "pandas/_libs/hashtable_class_helper.pxi":5259
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const uint16_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_28factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_uniques_vector = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":5290
 *             The labels from values to uniques
 *         """
 *         uniques_vector = UInt16Vector()             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5290, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques_vector = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5291
 *         """
 *         uniques_vector = UInt16Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint16_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 5291, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques_vector);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques_vector))) __PYX_ERR(2, 5291, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 5291, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5292
 *         uniques_vector = UInt16Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,             # <<<<<<<<<<<<<<
 *                             return_inverse=True)
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 5291, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, __pyx_v_ignore_na) < 0) __PYX_ERR(2, 5291, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 5291, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5293
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)             # <<<<<<<<<<<<<<
 * 
 *     def get_labels(self, const uint16_t[:] values, UInt16Vector uniques,
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 5291, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5291
 *         """
 *         uniques_vector = UInt16Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5259
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const uint16_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5295
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const uint16_t[:] values, UInt16Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_31get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_31get_labels = {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_31get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_31get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_labels (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":5297
 *     def get_labels(self, const uint16_t[:] values, UInt16Vector uniques,
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5295, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5295, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, 1); __PYX_ERR(2, 5295, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5295, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5295, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5295, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5295, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_labels") < 0)) __PYX_ERR(2, 5295, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint16_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 5295, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 5296, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 5296, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    __pyx_v_mask = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, __pyx_nargs); __PYX_ERR(2, 5295, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector, 1, "uniques", 0))) __PYX_ERR(2, 5295, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_30get_labels(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":5295
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const uint16_t[:] values, UInt16Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_30get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_v_labels = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_labels", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":5299
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint16_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 5299, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 5299, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_count_prior); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_count_prior, __pyx_t_4) < 0) __PYX_ERR(2, 5299, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5300
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,             # <<<<<<<<<<<<<<
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 5299, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 5299, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5301
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, Py_True) < 0) __PYX_ERR(2, 5299, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 5299, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 5299, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5299
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5299, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
    PyObject* sequence = __pyx_t_4;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(2, 5299, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5299, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5299, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5299, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
    index = 0; __pyx_t_2 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_1), 2) < 0) __PYX_ERR(2, 5299, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(2, 5299, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v__ = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_labels = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5302
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_labels);
  __pyx_r = __pyx_v_labels;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5295
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const uint16_t[:] values, UInt16Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XDECREF(__pyx_v_labels);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_33__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_33__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_33__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_33__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_32__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_32__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_35__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_35__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_35__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_35__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_34__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt16HashTable_34__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5311
 *         UInt16Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = UInt16HashTable(size_hint)
 *         self.uniques = UInt16Vector()
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_size_hint = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5311, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 5311, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_size_hint = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 5311, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_size_hint), (&PyInt_Type), 0, "size_hint", 1))) __PYX_ERR(2, 5311, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *)__pyx_v_self), __pyx_v_size_hint);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":5312
 * 
 *     def __cinit__(self, size_hint: int):
 *         self.table = UInt16HashTable(size_hint)             # <<<<<<<<<<<<<<
 *         self.uniques = UInt16Vector()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable), __pyx_v_size_hint); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5313
 *     def __cinit__(self, size_hint: int):
 *         self.table = UInt16HashTable(size_hint)
 *         self.uniques = UInt16Vector()             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const uint16_t[:] values,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5311
 *         UInt16Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = UInt16HashTable(size_hint)
 *         self.uniques = UInt16Vector()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5315
 *         self.uniques = UInt16Vector()
 * 
 *     def factorize(self, const uint16_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_16UInt16Factorizer_2factorize, "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = UInt16Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"uint16\"), na_sentinel=20)\n        array([0, 1, 2])\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16UInt16Factorizer_3factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16UInt16Factorizer_2factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_v_na_sentinel = 0;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_neg_1));

    /* "pandas/_libs/hashtable_class_helper.pxi":5316
 * 
 *     def factorize(self, const uint16_t[:] values,
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:             # <<<<<<<<<<<<<<
 *         """
 *         Returns
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5315, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5315, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5315, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5315, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 5315, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint16_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 5315, __pyx_L3_error)
    __pyx_v_na_sentinel = values[1];
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 4, __pyx_nargs); __PYX_ERR(2, 5315, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_2factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":5315
 *         self.uniques = UInt16Vector()
 * 
 *     def factorize(self, const uint16_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  PyArrayObject *__pyx_v_labels = 0;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_uniques = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_labels;
  __Pyx_Buffer __pyx_pybuffer_labels;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);
  __pyx_pybuffer_labels.pybuffer.buf = NULL;
  __pyx_pybuffer_labels.refcount = 0;
  __pyx_pybuffernd_labels.data = NULL;
  __pyx_pybuffernd_labels.rcbuffer = &__pyx_pybuffer_labels;

  /* "pandas/_libs/hashtable_class_helper.pxi":5333
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = UInt16Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  if (__pyx_v_self->uniques->__pyx_base.external_view_exists) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5334
 * 
 *         if self.uniques.external_view_exists:
 *             uniques = UInt16Vector()             # <<<<<<<<<<<<<<
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 */
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5334, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":5335
 *         if self.uniques.external_view_exists:
 *             uniques = UInt16Vector()
 *             uniques.extend(self.uniques.to_array())             # <<<<<<<<<<<<<<
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 */
    __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt16Vector *)__pyx_v_self->uniques->__pyx_vtab)->to_array(__pyx_v_self->uniques, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5335, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint16_t__const__(__pyx_t_1, 0); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(2, 5335, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt16Vector *)__pyx_v_uniques->__pyx_vtab)->extend(__pyx_v_uniques, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5335, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
    __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":5336
 *             uniques = UInt16Vector()
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques             # <<<<<<<<<<<<<<
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 */
    __Pyx_INCREF((PyObject *)__pyx_v_uniques);
    __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
    __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
    __pyx_v_self->uniques = __pyx_v_uniques;

    /* "pandas/_libs/hashtable_class_helper.pxi":5333
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = UInt16Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5337
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->table), __pyx_n_s_get_labels); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint16_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "pandas/_libs/hashtable_class_helper.pxi":5338
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,             # <<<<<<<<<<<<<<
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_self->__pyx_base.count); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5338, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "pandas/_libs/hashtable_class_helper.pxi":5337
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_5 = PyTuple_New(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3)) __PYX_ERR(2, 5337, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self->uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_self->uniques))) __PYX_ERR(2, 5337, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_4)) __PYX_ERR(2, 5337, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_na_sentinel);
  __Pyx_GIVEREF(__pyx_v_na_sentinel);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_v_na_sentinel)) __PYX_ERR(2, 5337, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5339
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)             # <<<<<<<<<<<<<<
 *         self.count = len(self.uniques)
 *         return labels
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5339, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 5339, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 5339, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5337
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5337, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 5337, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
    __pyx_t_7 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_7 < 0)) {
      PyErr_Fetch(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_v_labels, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      }
      __pyx_t_8 = __pyx_t_9 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_labels.diminfo[0].strides = __pyx_pybuffernd_labels.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_labels.diminfo[0].shape = __pyx_pybuffernd_labels.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(2, 5337, __pyx_L1_error)
  }
  __pyx_t_6 = 0;
  __pyx_v_labels = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5340
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  __pyx_t_3 = ((PyObject *)__pyx_v_self->uniques);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_11 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(2, 5340, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_self->__pyx_base.count = __pyx_t_11;

  /* "pandas/_libs/hashtable_class_helper.pxi":5341
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * cdef class Int16HashTable(HashTable):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_labels);
  __pyx_r = ((PyObject *)__pyx_v_labels);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5315
 *         self.uniques = UInt16Vector()
 * 
 *     def factorize(self, const uint16_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_labels);
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5308
 * cdef class UInt16Factorizer(Factorizer):
 *     cdef public:
 *         UInt16HashTable table             # <<<<<<<<<<<<<<
 *         UInt16Vector uniques
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_5table_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_5table_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_5table___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->table);
  __pyx_r = ((PyObject *)__pyx_v_self->table);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_5table_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable))))) __PYX_ERR(2, 5308, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16Factorizer.table.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_5table_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_5table_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_5table_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5309
 *     cdef public:
 *         UInt16HashTable table
 *         UInt16Vector uniques             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, size_hint: int):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_7uniques_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_7uniques_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_7uniques___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __pyx_r = ((PyObject *)__pyx_v_self->uniques);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_7uniques_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector))))) __PYX_ERR(2, 5309, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16Factorizer.uniques.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_7uniques_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_7uniques_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_7uniques_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16UInt16Factorizer_5__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_4__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16Factorizer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16UInt16Factorizer_7__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_6__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16UInt16Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt16Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5345
 * cdef class Int16HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_int16()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __pyx_t_5numpy_int64_t __pyx_v_size_hint;
  int __pyx_v_uses_mask;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,&__pyx_n_s_uses_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5345, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uses_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5345, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 5345, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_size_hint = __Pyx_PyInt_As_npy_int64(values[0]); if (unlikely((__pyx_v_size_hint == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 5345, __pyx_L3_error)
    } else {
      __pyx_v_size_hint = ((__pyx_t_5numpy_int64_t)1);
    }
    if (values[1]) {
      __pyx_v_uses_mask = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_uses_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 5345, __pyx_L3_error)
    } else {
      __pyx_v_uses_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 0, 2, __pyx_nargs); __PYX_ERR(2, 5345, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)__pyx_v_self), __pyx_v_size_hint, __pyx_v_uses_mask);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  khuint_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __pyx_t_5numpy_int64_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":5346
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_int16()             # <<<<<<<<<<<<<<
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_int16(self.table, size_hint)
 */
  __pyx_v_self->table = kh_init_int16();

  /* "pandas/_libs/hashtable_class_helper.pxi":5347
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_int16()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)             # <<<<<<<<<<<<<<
 *         kh_resize_int16(self.table, size_hint)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = kh_needed_n_buckets(__pyx_v_size_hint);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5347, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_1, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5347, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(2, 5347, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_6) {
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_5 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5347, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_int64(__pyx_t_3); if (unlikely((__pyx_t_7 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 5347, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_size_hint = __pyx_t_7;

  /* "pandas/_libs/hashtable_class_helper.pxi":5348
 *         self.table = kh_init_int16()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_int16(self.table, size_hint)             # <<<<<<<<<<<<<<
 * 
 *         self.uses_mask = uses_mask
 */
  kh_resize_int16(__pyx_v_self->table, __pyx_v_size_hint);

  /* "pandas/_libs/hashtable_class_helper.pxi":5350
 *         kh_resize_int16(self.table, size_hint)
 * 
 *         self.uses_mask = uses_mask             # <<<<<<<<<<<<<<
 *         self.na_position = -1
 * 
 */
  __pyx_v_self->uses_mask = __pyx_v_uses_mask;

  /* "pandas/_libs/hashtable_class_helper.pxi":5351
 * 
 *         self.uses_mask = uses_mask
 *         self.na_position = -1             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
  __pyx_v_self->na_position = -1LL;

  /* "pandas/_libs/hashtable_class_helper.pxi":5345
 * cdef class Int16HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_int16()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5353
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_3__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_3__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_2__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  long __pyx_t_1;
  int __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":5354
 * 
 *     def __len__(self) -> int:
 *         return self.table.size + (0 if self.na_position == -1 else 1)             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_2 = (__pyx_v_self->na_position == -1LL);
  if (__pyx_t_2) {
    __pyx_t_1 = 0;
  } else {
    __pyx_t_1 = 1;
  }
  __pyx_r = (__pyx_v_self->table->size + __pyx_t_1);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5353
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5356
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_int16(self.table)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_5__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_5__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_4__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":5357
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_int16(self.table)
 *             self.table = NULL
 */
  __pyx_t_1 = (__pyx_v_self->table != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5358
 *     def __dealloc__(self):
 *         if self.table is not NULL:
 *             kh_destroy_int16(self.table)             # <<<<<<<<<<<<<<
 *             self.table = NULL
 * 
 */
    kh_destroy_int16(__pyx_v_self->table);

    /* "pandas/_libs/hashtable_class_helper.pxi":5359
 *         if self.table is not NULL:
 *             kh_destroy_int16(self.table)
 *             self.table = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __contains__(self, object key) -> bool:
 */
    __pyx_v_self->table = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":5357
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_int16(self.table)
 *             self.table = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5356
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_int16(self.table)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":5361
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__contains__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_6__contains__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)__pyx_v_self), ((PyObject *)__pyx_v_key));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, PyObject *__pyx_v_key) {
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int16_t __pyx_v_ckey;
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  __pyx_t_5numpy_int16_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5368
 *             int16_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_1 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_7missing_checknull(__pyx_v_key, 0, NULL); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5368, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5369
 * 
 *         if self.uses_mask and checknull(key):
 *             return -1 != self.na_position             # <<<<<<<<<<<<<<
 * 
 *         ckey = (key)
 */
    __pyx_r = (-1LL != __pyx_v_self->na_position);
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":5368
 *             int16_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5371
 *             return -1 != self.na_position
 * 
 *         ckey = (key)             # <<<<<<<<<<<<<<
 *         k = kh_get_int16(self.table, ckey)
 *         return k != self.table.n_buckets
 */
  __pyx_t_3 = __Pyx_PyInt_As_npy_int16(__pyx_v_key); if (unlikely((__pyx_t_3 == ((npy_int16)-1)) && PyErr_Occurred())) __PYX_ERR(2, 5371, __pyx_L1_error)
  __pyx_v_ckey = __pyx_t_3;

  /* "pandas/_libs/hashtable_class_helper.pxi":5372
 * 
 *         ckey = (key)
 *         k = kh_get_int16(self.table, ckey)             # <<<<<<<<<<<<<<
 *         return k != self.table.n_buckets
 * 
 */
  __pyx_v_k = kh_get_int16(__pyx_v_self->table, __pyx_v_ckey);

  /* "pandas/_libs/hashtable_class_helper.pxi":5373
 *         ckey = (key)
 *         k = kh_get_int16(self.table, ckey)
 *         return k != self.table.n_buckets             # <<<<<<<<<<<<<<
 * 
 *     def sizeof(self, deep: bool = False) -> int:
 */
  __pyx_r = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5361
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5375
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14Int16HashTable_8sizeof, " return the size of my table in bytes ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_9sizeof = {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int16HashTable_8sizeof};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_deep = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sizeof (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_deep,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_deep);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5375, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "sizeof") < 0)) __PYX_ERR(2, 5375, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_deep = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sizeof", 0, 0, 1, __pyx_nargs); __PYX_ERR(2, 5375, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_8sizeof(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)__pyx_v_self), __pyx_v_deep);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep) {
  PyObject *__pyx_v_overhead = NULL;
  PyObject *__pyx_v_for_flags = NULL;
  PyObject *__pyx_v_for_pairs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  long __pyx_t_2;
  long __pyx_t_3;
  long __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sizeof", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":5377
 *     def sizeof(self, deep: bool = False) -> int:
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)             # <<<<<<<<<<<<<<
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(int16_t) + # keys
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(((4 * (sizeof(__pyx_t_5numpy_uint32_t))) + (3 * (sizeof(__pyx_t_5numpy_uint32_t *))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5377, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_overhead = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5378
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)             # <<<<<<<<<<<<<<
 *         for_pairs =  self.table.n_buckets * (sizeof(int16_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 */
  __pyx_t_2 = (__pyx_v_self->table->n_buckets >> 5);
  __pyx_t_3 = 1;
  __pyx_t_5 = (__pyx_t_2 > __pyx_t_3);
  if (__pyx_t_5) {
    __pyx_t_4 = __pyx_t_2;
  } else {
    __pyx_t_4 = __pyx_t_3;
  }
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_t_4 * (sizeof(__pyx_t_5numpy_uint32_t)))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5378, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_flags = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5379
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(int16_t) + # keys             # <<<<<<<<<<<<<<
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->n_buckets * ((sizeof(__pyx_t_5numpy_int16_t)) + (sizeof(Py_ssize_t))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5379, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_pairs = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5381
 *         for_pairs =  self.table.n_buckets * (sizeof(int16_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs             # <<<<<<<<<<<<<<
 * 
 *     def get_state(self) -> dict[str, int]:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Add(__pyx_v_overhead, __pyx_v_for_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5381, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyNumber_Add(__pyx_t_1, __pyx_v_for_pairs); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5381, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(__Pyx_Py3Int_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None) || __Pyx_RaiseUnexpectedTypeError("int", __pyx_t_6))) __PYX_ERR(2, 5381, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5375
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_overhead);
  __Pyx_XDECREF(__pyx_v_for_flags);
  __Pyx_XDECREF(__pyx_v_for_pairs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5383
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14Int16HashTable_10get_state, " returns infos about the state of the hashtable");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_11get_state = {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int16HashTable_10get_state};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_state (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_state", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_state", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_10get_state(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_state", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":5385
 *     def get_state(self) -> dict[str, int]:
 *         """ returns infos about the state of the hashtable"""
 *         return {             # <<<<<<<<<<<<<<
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 */
  __Pyx_XDECREF(__pyx_r);

  /* "pandas/_libs/hashtable_class_helper.pxi":5386
 *         """ returns infos about the state of the hashtable"""
 *         return {
 *             'n_buckets' : self.table.n_buckets,             # <<<<<<<<<<<<<<
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_buckets); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5386, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_buckets, __pyx_t_2) < 0) __PYX_ERR(2, 5386, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5387
 *         return {
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,             # <<<<<<<<<<<<<<
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->size); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_size, __pyx_t_2) < 0) __PYX_ERR(2, 5386, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5388
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,             # <<<<<<<<<<<<<<
 *             'upper_bound' : self.table.upper_bound,
 *         }
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_occupied); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5388, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_occupied, __pyx_t_2) < 0) __PYX_ERR(2, 5386, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5389
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,             # <<<<<<<<<<<<<<
 *         }
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->upper_bound); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_upper_bound, __pyx_t_2) < 0) __PYX_ERR(2, 5386, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5383
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.get_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5392
 *         }
 * 
 *     cpdef get_item(self, int16_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int16HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, __pyx_t_5numpy_int16_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int16_t __pyx_v_cval;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5392, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_13get_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyInt_From_npy_int16(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5392, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5392, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5411
 *             int16_t cval
 * 
 *         cval = (val)             # <<<<<<<<<<<<<<
 *         k = kh_get_int16(self.table, cval)
 *         if k != self.table.n_buckets:
 */
  __pyx_v_cval = __pyx_v_val;

  /* "pandas/_libs/hashtable_class_helper.pxi":5412
 * 
 *         cval = (val)
 *         k = kh_get_int16(self.table, cval)             # <<<<<<<<<<<<<<
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]
 */
  __pyx_v_k = kh_get_int16(__pyx_v_self->table, __pyx_v_cval);

  /* "pandas/_libs/hashtable_class_helper.pxi":5413
 *         cval = (val)
 *         k = kh_get_int16(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  __pyx_t_7 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  if (likely(__pyx_t_7)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5414
 *         k = kh_get_int16(self.table, cval)
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(val)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->vals[__pyx_v_k])); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5414, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":5413
 *         cval = (val)
 *         k = kh_get_int16(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5416
 *             return self.table.vals[k]
 *         else:
 *             raise KeyError(val)             # <<<<<<<<<<<<<<
 * 
 *     cpdef get_na(self):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyInt_From_npy_int16(__pyx_v_val); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5416, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5416, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 5416, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5392
 *         }
 * 
 *     cpdef get_item(self, int16_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14Int16HashTable_12get_item, "Extracts the position of val from the hashtable.\n\n        Parameters\n        ----------\n        val : Scalar\n            The value that is looked up in the hashtable\n\n        Returns\n        -------\n        The position of the requested integer.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_13get_item = {"get_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_13get_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int16HashTable_12get_item};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_5numpy_int16_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5392, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_item") < 0)) __PYX_ERR(2, 5392, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __Pyx_PyInt_As_npy_int16(values[0]); if (unlikely((__pyx_v_val == ((npy_int16)-1)) && PyErr_Occurred())) __PYX_ERR(2, 5392, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_item", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 5392, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_12get_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, __pyx_t_5numpy_int16_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_14Int16HashTable_get_item(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5418
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int16HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5418, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_15get_na)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5418, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5426
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_6 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5427
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         if self.na_position == -1:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 5427, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":5426
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5429
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  __pyx_t_6 = (__pyx_v_self->na_position == -1LL);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5430
 * 
 *         if self.na_position == -1:
 *             raise KeyError("NA")             # <<<<<<<<<<<<<<
 *         return self.na_position
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_KeyError, __pyx_tuple__13, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5430, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(2, 5430, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":5429
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5431
 *         if self.na_position == -1:
 *             raise KeyError("NA")
 *         return self.na_position             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_item(self, int16_t key, Py_ssize_t val):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->na_position); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5431, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5418
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14Int16HashTable_14get_na, "Extracts the position of na_value from the hashtable.\n\n        Returns\n        -------\n        The position of the last na value.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_15get_na = {"get_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_15get_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int16HashTable_14get_na};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_na", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_na", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_14get_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_14Int16HashTable_get_na(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5433
 *         return self.na_position
 * 
 *     cpdef set_item(self, int16_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int16HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, __pyx_t_5numpy_int16_t __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  __pyx_t_5numpy_int16_t __pyx_v_ckey;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5433, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_17set_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyInt_From_npy_int16(__pyx_v_key); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5433, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5433, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_5 = __pyx_t_1; __pyx_t_6 = NULL;
        __pyx_t_7 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_7 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_3, __pyx_t_4};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5433, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5438
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             int16_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5441
 *             int16_t ckey
 * 
 *         ckey = (key)             # <<<<<<<<<<<<<<
 *         k = kh_put_int16(self.table, ckey, &ret)
 *         if kh_exist_int16(self.table, k):
 */
  __pyx_v_ckey = __pyx_v_key;

  /* "pandas/_libs/hashtable_class_helper.pxi":5442
 * 
 *         ckey = (key)
 *         k = kh_put_int16(self.table, ckey, &ret)             # <<<<<<<<<<<<<<
 *         if kh_exist_int16(self.table, k):
 *             self.table.vals[k] = val
 */
  __pyx_v_k = kh_put_int16(__pyx_v_self->table, __pyx_v_ckey, (&__pyx_v_ret));

  /* "pandas/_libs/hashtable_class_helper.pxi":5443
 *         ckey = (key)
 *         k = kh_put_int16(self.table, ckey, &ret)
 *         if kh_exist_int16(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
  __pyx_t_8 = kh_exist_int16(__pyx_v_self->table, __pyx_v_k);
  if (likely(__pyx_t_8)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5444
 *         k = kh_put_int16(self.table, ckey, &ret)
 *         if kh_exist_int16(self.table, k):
 *             self.table.vals[k] = val             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(key)
 */
    (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_val;

    /* "pandas/_libs/hashtable_class_helper.pxi":5443
 *         ckey = (key)
 *         k = kh_put_int16(self.table, ckey, &ret)
 *         if kh_exist_int16(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5446
 *             self.table.vals[k] = val
 *         else:
 *             raise KeyError(key)             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_na(self, Py_ssize_t val):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyInt_From_npy_int16(__pyx_v_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5446, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5446, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 5446, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "pandas/_libs/hashtable_class_helper.pxi":5433
 *         return self.na_position
 * 
 *     cpdef set_item(self, int16_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_17set_item = {"set_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_17set_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_5numpy_int16_t __pyx_v_key;
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key,&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5433, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5433, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, 1); __PYX_ERR(2, 5433, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_item") < 0)) __PYX_ERR(2, 5433, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_key = __Pyx_PyInt_As_npy_int16(values[0]); if (unlikely((__pyx_v_key == ((npy_int16)-1)) && PyErr_Occurred())) __PYX_ERR(2, 5433, __pyx_L3_error)
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 5433, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, __pyx_nargs); __PYX_ERR(2, 5433, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_16set_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)__pyx_v_self), __pyx_v_key, __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, __pyx_t_5numpy_int16_t __pyx_v_key, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_14Int16HashTable_set_item(__pyx_v_self, __pyx_v_key, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5448
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14Int16HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  CYTHON_UNUSED int __pyx_v_ret;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5448, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_19set_na)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5448, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5448, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5452
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             int16_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5455
 *             int16_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_7 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_7)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5456
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         self.na_position = val
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 5456, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":5455
 *             int16_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5458
 *             raise NotImplementedError
 * 
 *         self.na_position = val             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->na_position = __pyx_v_val;

  /* "pandas/_libs/hashtable_class_helper.pxi":5448
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_19set_na = {"set_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_19set_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5448, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_na") < 0)) __PYX_ERR(2, 5448, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[0]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 5448, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_na", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 5448, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_18set_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_14Int16HashTable_set_na(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5461
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const int16_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_21map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_21map_locations = {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_21map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_21map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("map_locations (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5461, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5461, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "map_locations") < 0)) __PYX_ERR(2, 5461, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int16_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 5462, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 5462, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__34;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("map_locations", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 5461, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_20map_locations(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_20map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  int __pyx_v_ret;
  __pyx_t_5numpy_int16_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  __pyx_t_5numpy_int64_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("map_locations", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":5465
 *         # Used in libindex, safe_sort
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             int16_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":5466
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             int16_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5469
 *             int16_t val
 *             khiter_t k
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_2 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":5471
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_3 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_3)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5472
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 5472, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":5471
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5474
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":5475
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
        if (__pyx_v_self->uses_mask) {

          /* "pandas/_libs/hashtable_class_helper.pxi":5476
 *         with nogil:
 *             if self.uses_mask:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     if mask[i]:
 *                         na_position = i
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":5477
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_mask.shape[0];
            __pyx_t_3 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) ))) != 0);
            if (__pyx_t_3) {

              /* "pandas/_libs/hashtable_class_helper.pxi":5478
 *                 for i in range(n):
 *                     if mask[i]:
 *                         na_position = i             # <<<<<<<<<<<<<<
 *                     else:
 *                         val= (values[i])
 */
              __pyx_v_na_position = __pyx_v_i;

              /* "pandas/_libs/hashtable_class_helper.pxi":5477
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
              goto __pyx_L12;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":5480
 *                         na_position = i
 *                     else:
 *                         val= (values[i])             # <<<<<<<<<<<<<<
 *                         k = kh_put_int16(self.table, val, &ret)
 *                         self.table.vals[k] = i
 */
            /*else*/ {
              __pyx_t_7 = __pyx_v_i;
              if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
              __pyx_v_val = (*((__pyx_t_5numpy_int16_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_class_helper.pxi":5481
 *                     else:
 *                         val= (values[i])
 *                         k = kh_put_int16(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = i
 *             else:
 */
              __pyx_v_k = kh_put_int16(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

              /* "pandas/_libs/hashtable_class_helper.pxi":5482
 *                         val= (values[i])
 *                         k = kh_put_int16(self.table, val, &ret)
 *                         self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *             else:
 *                 for i in range(n):
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
            }
            __pyx_L12:;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":5475
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
          goto __pyx_L9;
        }

        /* "pandas/_libs/hashtable_class_helper.pxi":5484
 *                         self.table.vals[k] = i
 *             else:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     val= (values[i])
 *                     k = kh_put_int16(self.table, val, &ret)
 */
        /*else*/ {
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":5485
 *             else:
 *                 for i in range(n):
 *                     val= (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_put_int16(self.table, val, &ret)
 *                     self.table.vals[k] = i
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
            __pyx_v_val = (*((__pyx_t_5numpy_int16_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

            /* "pandas/_libs/hashtable_class_helper.pxi":5486
 *                 for i in range(n):
 *                     val= (values[i])
 *                     k = kh_put_int16(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                     self.table.vals[k] = i
 *         self.na_position = na_position
 */
            __pyx_v_k = kh_put_int16(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":5487
 *                     val= (values[i])
 *                     k = kh_put_int16(self.table, val, &ret)
 *                     self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *         self.na_position = na_position
 * 
 */
            (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
          }
        }
        __pyx_L9:;
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":5474
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5488
 *                     k = kh_put_int16(self.table, val, &ret)
 *                     self.table.vals[k] = i
 *         self.na_position = na_position             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __pyx_v_self->na_position = __pyx_v_na_position;

  /* "pandas/_libs/hashtable_class_helper.pxi":5461
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const int16_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5490
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const int16_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

/* Python wrapper */
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_23lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_23lookup = {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_23lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_23lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyArrayObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lookup (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5490, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5490, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lookup") < 0)) __PYX_ERR(2, 5490, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int16_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 5491, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 5491, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__35;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lookup", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 5490, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_22lookup(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_22lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  CYTHON_UNUSED int __pyx_v_ret;
  __pyx_t_5numpy_int16_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __Pyx_memviewslice __pyx_v_locs = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lookup", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":5495
 *         # Used in safe_sort, IndexEngine.get_indexer
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             int16_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":5496
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             int16_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5499
 *             int16_t val
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *             int8_t na_position = self.na_position
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 5499, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 5499, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 5499, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_locs = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":5500
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_8 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":5502
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_9 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_10 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_9 = __pyx_t_10;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5503
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 5503, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":5502
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5505
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":5506
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_11 = __pyx_t_1;
        for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
          __pyx_v_i = __pyx_t_12;

          /* "pandas/_libs/hashtable_class_helper.pxi":5507
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
          if (__pyx_v_self->uses_mask) {
          } else {
            __pyx_t_9 = __pyx_v_self->uses_mask;
            goto __pyx_L12_bool_binop_done;
          }
          __pyx_t_13 = __pyx_v_i;
          if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_mask.shape[0];
          __pyx_t_10 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_13 * __pyx_v_mask.strides[0]) ))) != 0);
          __pyx_t_9 = __pyx_t_10;
          __pyx_L12_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":5508
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position             # <<<<<<<<<<<<<<
 *                 else:
 *                     val = (values[i])
 */
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = __pyx_v_na_position;

            /* "pandas/_libs/hashtable_class_helper.pxi":5507
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
            goto __pyx_L11;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":5510
 *                     locs[i] = na_position
 *                 else:
 *                     val = (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_int16(self.table, val)
 *                     if k != self.table.n_buckets:
 */
          /*else*/ {
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_values.shape[0];
            __pyx_v_val = (*((__pyx_t_5numpy_int16_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_13 * __pyx_v_values.strides[0]) )));

            /* "pandas/_libs/hashtable_class_helper.pxi":5511
 *                 else:
 *                     val = (values[i])
 *                     k = kh_get_int16(self.table, val)             # <<<<<<<<<<<<<<
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]
 */
            __pyx_v_k = kh_get_int16(__pyx_v_self->table, __pyx_v_val);

            /* "pandas/_libs/hashtable_class_helper.pxi":5512
 *                     val = (values[i])
 *                     k = kh_get_int16(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
            __pyx_t_9 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":5513
 *                     k = kh_get_int16(self.table, val)
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     else:
 *                         locs[i] = -1
 */
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = (__pyx_v_self->table->vals[__pyx_v_k]);

              /* "pandas/_libs/hashtable_class_helper.pxi":5512
 *                     val = (values[i])
 *                     k = kh_get_int16(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
              goto __pyx_L14;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":5515
 *                         locs[i] = self.table.vals[k]
 *                     else:
 *                         locs[i] = -1             # <<<<<<<<<<<<<<
 * 
 *         return np.asarray(locs)
 */
            /*else*/ {
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = -1;
            }
            __pyx_L14:;
          }
          __pyx_L11:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":5505
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5517
 *                         locs[i] = -1
 * 
 *         return np.asarray(locs)             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_locs, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5517, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_14 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_14 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5517, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 5517, __pyx_L1_error)
  __pyx_r = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5490
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const int16_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_locs, 1);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5519
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const int16_t[:] values, Int16Vector uniques,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_25_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14Int16HashTable_24_unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[int16]\n            Array of values of which unique will be calculated\n        uniques : Int16Vector\n            Vector into which uniques will be written\n        count_prior : Py_ssize_t, default 0\n            Number of existing entries in uniques\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        ignore_na : bool, default False\n            Whether NA-values should be ignored for calculating the uniques. If\n            True, the labels corresponding to missing values will be set to\n            na_sentinel.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        use_result_mask: bool, default False\n            Whether to create a result mask for the unique values. Not supported\n            with return_inverse=True.\n\n        Returns\n        -------\n        uniques : ndarray[int16]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse=True)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if use_result_mask is true\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_25_unique = {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_25_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int16HashTable_24_unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_25_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  int __pyx_v_ignore_na;
  PyObject *__pyx_v_mask = 0;
  int __pyx_v_return_inverse;
  int __pyx_v_use_result_mask;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[9] = {0,0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_ignore_na,&__pyx_n_s_mask,&__pyx_n_s_return_inverse,&__pyx_n_s_use_result_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":5523
 *     def _unique(self, const int16_t[:] values, Int16Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));

    /* "pandas/_libs/hashtable_class_helper.pxi":5524
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[6] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5519, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5519, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, 1); __PYX_ERR(2, 5519, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5519, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5519, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5519, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5519, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[6] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5519, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[7] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5519, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_use_result_mask);
          if (value) { values[8] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5519, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_unique") < 0)) __PYX_ERR(2, 5519, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int16_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 5521, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 5522, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 5522, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    if (values[5]) {
      __pyx_v_ignore_na = __Pyx_PyObject_IsTrue(values[5]); if (unlikely((__pyx_v_ignore_na == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 5523, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":5523
 *     def _unique(self, const int16_t[:] values, Int16Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
      __pyx_v_ignore_na = ((int)0);
    }
    __pyx_v_mask = values[6];
    if (values[7]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[7]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 5524, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":5524
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
      __pyx_v_return_inverse = ((int)0);
    }
    if (values[8]) {
      __pyx_v_use_result_mask = __Pyx_PyObject_IsTrue(values[8]); if (unlikely((__pyx_v_use_result_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 5524, __pyx_L3_error)
    } else {
      __pyx_v_use_result_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, __pyx_nargs); __PYX_ERR(2, 5519, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector, 1, "uniques", 0))) __PYX_ERR(2, 5521, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_24_unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_ignore_na, __pyx_v_mask, __pyx_v_return_inverse, __pyx_v_use_result_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":5519
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const int16_t[:] values, Int16Vector uniques,
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_24_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_idx;
  Py_ssize_t __pyx_v_count;
  Py_ssize_t __pyx_v_n;
  __Pyx_memviewslice __pyx_v_labels = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_ret;
  __pyx_t_5numpy_int16_t __pyx_v_val;
  __pyx_t_5numpy_int16_t __pyx_v_na_value2;
  khiter_t __pyx_v_k;
  __pyx_t_6pandas_5_libs_9hashtable_Int16VectorData *__pyx_v_ud;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_result_mask = 0;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_v_rmd;
  int __pyx_v_use_na_value;
  int __pyx_v_use_mask;
  int __pyx_v_seen_na;
  __Pyx_memviewslice __pyx_v_mask_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_6pandas_5_libs_9hashtable_Int16VectorData *__pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_t_11;
  int __pyx_t_12;
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int16_t __pyx_t_14;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":5568
 *         """
 *         cdef:
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)             # <<<<<<<<<<<<<<
 *             intp_t[::1] labels
 *             int ret = 0
 */
  __pyx_v_count = __pyx_v_count_prior;
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":5570
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)
 *             intp_t[::1] labels
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             int16_t val, na_value2
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5576
 *             UInt8Vector result_mask
 *             UInt8VectorData *rmd
 *             bint use_na_value, use_mask, seen_na = False             # <<<<<<<<<<<<<<
 *             uint8_t[:] mask_values
 * 
 */
  __pyx_v_seen_na = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5579
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5580
 * 
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5580, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5580, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5580, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5580, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 5580, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5580, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5580, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5580, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 5580, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5580, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 5580, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_labels = __pyx_t_7;
    __pyx_t_7.memview = NULL;
    __pyx_t_7.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":5579
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5581
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data             # <<<<<<<<<<<<<<
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 */
  __pyx_t_8 = __pyx_v_uniques->data;
  __pyx_v_ud = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":5582
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 *         use_na_value = na_value is not None             # <<<<<<<<<<<<<<
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 */
  __pyx_t_9 = (__pyx_v_na_value != Py_None);
  __pyx_v_use_na_value = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":5583
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None             # <<<<<<<<<<<<<<
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover
 */
  __pyx_t_9 = (__pyx_v_mask != Py_None);
  __pyx_v_use_mask = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":5584
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  __pyx_t_10 = (!__pyx_v_use_mask);
  if (__pyx_t_10) {
  } else {
    __pyx_t_9 = __pyx_t_10;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_use_result_mask;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5585
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         if use_result_mask and return_inverse:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 5585, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":5584
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5587
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_use_result_mask) {
  } else {
    __pyx_t_9 = __pyx_v_use_result_mask;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_return_inverse;
  __pyx_L8_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5588
 * 
 *         if use_result_mask and return_inverse:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         result_mask = UInt8Vector()
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 5588, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":5587
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5590
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         result_mask = UInt8Vector()             # <<<<<<<<<<<<<<
 *         rmd = result_mask.data
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_v_result_mask = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5591
 * 
 *         result_mask = UInt8Vector()
 *         rmd = result_mask.data             # <<<<<<<<<<<<<<
 * 
 *         if use_mask:
 */
  __pyx_t_11 = __pyx_v_result_mask->data;
  __pyx_v_rmd = __pyx_t_11;

  /* "pandas/_libs/hashtable_class_helper.pxi":5593
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  if (__pyx_v_use_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5594
 * 
 *         if use_mask:
 *             mask_values = mask.view("uint8")             # <<<<<<<<<<<<<<
 * 
 *         if use_na_value:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_mask, __pyx_n_s_view); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5594, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    __pyx_t_12 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_12 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_uint8};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_12, 1+__pyx_t_12);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5594, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(2, 5594, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_mask_values = __pyx_t_13;
    __pyx_t_13.memview = NULL;
    __pyx_t_13.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":5593
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5596
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
  if (__pyx_v_use_na_value) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5602
 *             # for the parameter. To please the compiler, we use na_value2,
 *             # which is only used if it's *specified*.
 *             na_value2 = (na_value)             # <<<<<<<<<<<<<<
 *         else:
 *             na_value2 = (0)
 */
    __pyx_t_14 = __Pyx_PyInt_As_npy_int16(__pyx_v_na_value); if (unlikely((__pyx_t_14 == ((npy_int16)-1)) && PyErr_Occurred())) __PYX_ERR(2, 5602, __pyx_L1_error)
    __pyx_v_na_value2 = __pyx_t_14;

    /* "pandas/_libs/hashtable_class_helper.pxi":5596
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
    goto __pyx_L11;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5604
 *             na_value2 = (na_value)
 *         else:
 *             na_value2 = (0)             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
  /*else*/ {
    __pyx_v_na_value2 = 0;
  }
  __pyx_L11:;

  /* "pandas/_libs/hashtable_class_helper.pxi":5606
 *             na_value2 = (0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = (values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":5607
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 val = (values[i])
 * 
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_15 = __pyx_t_1;
        for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
          __pyx_v_i = __pyx_t_16;

          /* "pandas/_libs/hashtable_class_helper.pxi":5608
 *         with nogil:
 *             for i in range(n):
 *                 val = (values[i])             # <<<<<<<<<<<<<<
 * 
 *                 if ignore_na and use_mask:
 */
          __pyx_t_17 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_int16_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_17 * __pyx_v_values.strides[0]) )));

          /* "pandas/_libs/hashtable_class_helper.pxi":5610
 *                 val = (values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L18_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_mask;
          __pyx_L18_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":5611
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 5611, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_17 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":5612
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                         continue
 *                 elif ignore_na and (
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 5612, __pyx_L13_error) }
              __pyx_t_17 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_na_sentinel;

              /* "pandas/_libs/hashtable_class_helper.pxi":5613
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 *                         continue             # <<<<<<<<<<<<<<
 *                 elif ignore_na and (
 *                    is_nan_int16_t(val) or
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":5611
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":5610
 *                 val = (values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
            goto __pyx_L17;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":5614
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_int16_t(val) or
 *                    (use_na_value and are_equivalent_int16_t(val, na_value2))
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":5615
 *                         continue
 *                 elif ignore_na and (
 *                    is_nan_int16_t(val) or             # <<<<<<<<<<<<<<
 *                    (use_na_value and are_equivalent_int16_t(val, na_value2))
 *                 ):
 */
          __pyx_t_10 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_int16_t(__pyx_v_val); if (unlikely(__pyx_t_10 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 5615, __pyx_L13_error)
          if (!__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":5616
 *                 elif ignore_na and (
 *                    is_nan_int16_t(val) or
 *                    (use_na_value and are_equivalent_int16_t(val, na_value2))             # <<<<<<<<<<<<<<
 *                 ):
 *                     # if missing values do not count as unique values (i.e. if
 */
          if (__pyx_v_use_na_value) {
          } else {
            __pyx_t_9 = __pyx_v_use_na_value;
            goto __pyx_L21_bool_binop_done;
          }
          __pyx_t_10 = __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_int16_t(__pyx_v_val, __pyx_v_na_value2); if (unlikely(__pyx_t_10 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 5616, __pyx_L13_error)
          __pyx_t_9 = __pyx_t_10;
          __pyx_L21_bool_binop_done:;

          /* "pandas/_libs/hashtable_class_helper.pxi":5614
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_int16_t(val) or
 *                    (use_na_value and are_equivalent_int16_t(val, na_value2))
 */
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":5621
 *                     # ignore_na is True), skip the hashtable entry for them,
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 5621, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_na_sentinel;

            /* "pandas/_libs/hashtable_class_helper.pxi":5622
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel
 *                     continue             # <<<<<<<<<<<<<<
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 */
            goto __pyx_L15_continue;

            /* "pandas/_libs/hashtable_class_helper.pxi":5614
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_int16_t(val) or
 *                    (use_na_value and are_equivalent_int16_t(val, na_value2))
 */
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":5623
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          __pyx_t_10 = (!__pyx_v_ignore_na);
          if (__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L25_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_result_mask;
          __pyx_L25_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":5624
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 5624, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_17 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":5625
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_class_helper.pxi":5626
 *                     if mask_values[i]:
 *                         if seen_na:
 *                             continue             # <<<<<<<<<<<<<<
 * 
 *                         seen_na = True
 */
                goto __pyx_L15_continue;

                /* "pandas/_libs/hashtable_class_helper.pxi":5625
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":5628
 *                             continue
 * 
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         if needs_resize(ud):
 *                             with gil:
 */
              __pyx_v_seen_na = 1;

              /* "pandas/_libs/hashtable_class_helper.pxi":5629
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              __pyx_t_9 = __pyx_fuse_2__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 5629, __pyx_L13_error)
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_class_helper.pxi":5630
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                {
                    #ifdef WITH_THREAD
                    PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                    #endif
                    /*try:*/ {

                      /* "pandas/_libs/hashtable_class_helper.pxi":5631
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":5632
 *                             with gil:
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5632, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 5632, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":5631
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":5635
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int16Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5635, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":5636
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":5637
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5637, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 5637, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":5636
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":5640
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                         append_data_int16(ud, val)
 *                         append_data_uint8(rmd, 1)
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5640, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":5630
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    /*finally:*/ {
                      /*normal exit:*/{
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L34;
                      }
                      __pyx_L33_error: {
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L13_error;
                      }
                      __pyx_L34:;
                    }
                }

                /* "pandas/_libs/hashtable_class_helper.pxi":5629
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":5641
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                         append_data_int16(ud, val)             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 1)
 *                         continue
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_int16(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 5641, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":5642
 *                                 result_mask.resize()
 *                         append_data_int16(ud, val)
 *                         append_data_uint8(rmd, 1)             # <<<<<<<<<<<<<<
 *                         continue
 * 
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 1); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 5642, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":5643
 *                         append_data_int16(ud, val)
 *                         append_data_uint8(rmd, 1)
 *                         continue             # <<<<<<<<<<<<<<
 * 
 *                 k = kh_get_int16(self.table, val)
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":5624
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":5623
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          }
          __pyx_L17:;

          /* "pandas/_libs/hashtable_class_helper.pxi":5645
 *                         continue
 * 
 *                 k = kh_get_int16(self.table, val)             # <<<<<<<<<<<<<<
 * 
 *                 if k == self.table.n_buckets:
 */
          __pyx_v_k = kh_get_int16(__pyx_v_self->table, __pyx_v_val);

          /* "pandas/_libs/hashtable_class_helper.pxi":5647
 *                 k = kh_get_int16(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_int16(self.table, val, &ret)
 */
          __pyx_t_9 = (__pyx_v_k == __pyx_v_self->table->n_buckets);
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":5649
 *                 if k == self.table.n_buckets:
 *                     # k hasn't been seen yet
 *                     k = kh_put_int16(self.table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *                     if needs_resize(ud):
 */
            __pyx_v_k = kh_put_int16(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":5651
 *                     k = kh_put_int16(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            __pyx_t_9 = __pyx_fuse_2__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 5651, __pyx_L13_error)
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":5652
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
              {
                  #ifdef WITH_THREAD
                  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                  #endif
                  /*try:*/ {

                    /* "pandas/_libs/hashtable_class_helper.pxi":5653
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":5654
 *                         with gil:
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 */
                      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5654, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                      __PYX_ERR(2, 5654, __pyx_L42_error)

                      /* "pandas/_libs/hashtable_class_helper.pxi":5653
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":5657
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()             # <<<<<<<<<<<<<<
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 */
                    __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int16Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5657, __pyx_L42_error)
                    __Pyx_GOTREF(__pyx_t_6);
                    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                    /* "pandas/_libs/hashtable_class_helper.pxi":5658
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    if (__pyx_v_use_result_mask) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":5659
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":5660
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5660, __pyx_L42_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 5660, __pyx_L42_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":5659
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":5663
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                     append_data_int16(ud, val)
 *                     if use_result_mask:
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5663, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":5658
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    }
                  }

                  /* "pandas/_libs/hashtable_class_helper.pxi":5652
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
                  /*finally:*/ {
                    /*normal exit:*/{
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L43;
                    }
                    __pyx_L42_error: {
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L13_error;
                    }
                    __pyx_L43:;
                  }
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":5651
 *                     k = kh_put_int16(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":5664
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                     append_data_int16(ud, val)             # <<<<<<<<<<<<<<
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)
 */
            __pyx_f_6pandas_5_libs_9hashtable_append_data_int16(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 5664, __pyx_L13_error)

            /* "pandas/_libs/hashtable_class_helper.pxi":5665
 *                                 result_mask.resize()
 *                     append_data_int16(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            if (__pyx_v_use_result_mask) {

              /* "pandas/_libs/hashtable_class_helper.pxi":5666
 *                     append_data_int16(ud, val)
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)             # <<<<<<<<<<<<<<
 * 
 *                     if return_inverse:
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 0); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 5666, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":5665
 *                                 result_mask.resize()
 *                     append_data_int16(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":5668
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            if (__pyx_v_return_inverse) {

              /* "pandas/_libs/hashtable_class_helper.pxi":5669
 * 
 *                     if return_inverse:
 *                         self.table.vals[k] = count             # <<<<<<<<<<<<<<
 *                         labels[i] = count
 *                         count += 1
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":5670
 *                     if return_inverse:
 *                         self.table.vals[k] = count
 *                         labels[i] = count             # <<<<<<<<<<<<<<
 *                         count += 1
 *                 elif return_inverse:
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 5670, __pyx_L13_error) }
              __pyx_t_17 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":5671
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 *                         count += 1             # <<<<<<<<<<<<<<
 *                 elif return_inverse:
 *                     # k falls into a previous bucket
 */
              __pyx_v_count = (__pyx_v_count + 1);

              /* "pandas/_libs/hashtable_class_helper.pxi":5668
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":5647
 *                 k = kh_get_int16(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_int16(self.table, val, &ret)
 */
            goto __pyx_L37;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":5672
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          if (__pyx_v_return_inverse) {

            /* "pandas/_libs/hashtable_class_helper.pxi":5675
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     labels[i] = idx
 * 
 */
            __pyx_v_idx = (__pyx_v_self->table->vals[__pyx_v_k]);

            /* "pandas/_libs/hashtable_class_helper.pxi":5676
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]
 *                     labels[i] = idx             # <<<<<<<<<<<<<<
 * 
 *         if return_inverse:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 5676, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_idx;

            /* "pandas/_libs/hashtable_class_helper.pxi":5672
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          }
          __pyx_L37:;
          __pyx_L15_continue:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":5606
 *             na_value2 = (0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = (values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L14;
        }
        __pyx_L13_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L14:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5678
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5679
 * 
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray             # <<<<<<<<<<<<<<
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int16Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5679, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundLocalError("labels"); __PYX_ERR(2, 5679, __pyx_L1_error) }
    __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_labels, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5679, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_base); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5679, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5679, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_6);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_6)) __PYX_ERR(2, 5679, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4)) __PYX_ERR(2, 5679, __pyx_L1_error);
    __pyx_t_6 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":5678
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5680
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  if (__pyx_v_use_result_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5681
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()             # <<<<<<<<<<<<<<
 *         return uniques.to_array()
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int16Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->to_array(__pyx_v_result_mask, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5681, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2)) __PYX_ERR(2, 5681, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4)) __PYX_ERR(2, 5681, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":5680
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5682
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()             # <<<<<<<<<<<<<<
 * 
 *     def unique(self, const int16_t[:] values, bint return_inverse=False, object mask=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int16Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5682, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5519
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const int16_t[:] values, Int16Vector uniques,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_13, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_labels, 1);
  __Pyx_XDECREF((PyObject *)__pyx_v_result_mask);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask_values, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5684
 *         return uniques.to_array()
 * 
 *     def unique(self, const int16_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_27unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14Int16HashTable_26unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[int16]\n            Array of values of which unique will be calculated\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n\n        Returns\n        -------\n        uniques : ndarray[int16]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if mask is given as input\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_27unique = {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_27unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int16HashTable_26unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_27unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_return_inverse;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_return_inverse,&__pyx_n_s_mask,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5684, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5684, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5684, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "unique") < 0)) __PYX_ERR(2, 5684, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int16_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 5684, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 5684, __pyx_L3_error)
    } else {
      __pyx_v_return_inverse = ((int)0);
    }
    __pyx_v_mask = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("unique", 0, 1, 3, __pyx_nargs); __PYX_ERR(2, 5684, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_26unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_return_inverse, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_26unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_uniques = NULL;
  int __pyx_v_use_result_mask;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":5708
 *             The mask for the result values.
 *         """
 *         uniques = Int16Vector()             # <<<<<<<<<<<<<<
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5708, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5709
 *         """
 *         uniques = Int16Vector()
 *         use_result_mask = True if mask is not None else False             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 */
  __pyx_t_3 = (__pyx_v_mask != Py_None);
  if (__pyx_t_3) {
    __pyx_t_2 = 1;
  } else {
    __pyx_t_2 = 0;
  }
  __pyx_v_use_result_mask = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":5710
 *         uniques = Int16Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int16_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4)) __PYX_ERR(2, 5710, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 5710, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ignore_na, Py_False) < 0) __PYX_ERR(2, 5710, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5711
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const int16_t[:] values, Py_ssize_t na_sentinel=-1,
 */
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_return_inverse); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return_inverse, __pyx_t_6) < 0) __PYX_ERR(2, 5710, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 5710, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_use_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5711, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_use_result_mask, __pyx_t_6) < 0) __PYX_ERR(2, 5710, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5710
 *         uniques = Int16Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5710, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5684
 *         return uniques.to_array()
 * 
 *     def unique(self, const int16_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5713
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const int16_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_29factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14Int16HashTable_28factorize, "\n        Calculate unique values and labels (no sorting!)\n\n        Missing values are not included in the \"uniques\" for this method.\n        The labels for any missing values will be set to \"na_sentinel\"\n\n        Parameters\n        ----------\n        values : ndarray[int16]\n            Array of values of which unique will be calculated\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n\n        Returns\n        -------\n        uniques : ndarray[int16]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t]\n            The labels from values to uniques\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_29factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_29factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int16HashTable_28factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_29factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  PyObject *__pyx_v_ignore_na = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,&__pyx_n_s_ignore_na,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":5714
 * 
 *     def factorize(self, const int16_t[:] values, Py_ssize_t na_sentinel=-1,
 *                   object na_value=None, object mask=None, ignore_na=True):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_True));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5713, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5713, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5713, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5713, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5713, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 5713, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int16_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 5713, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 5713, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
    __pyx_v_ignore_na = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 5, __pyx_nargs); __PYX_ERR(2, 5713, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_28factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask, __pyx_v_ignore_na);

  /* "pandas/_libs/hashtable_class_helper.pxi":5713
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const int16_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_28factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_uniques_vector = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":5744
 *             The labels from values to uniques
 *         """
 *         uniques_vector = Int16Vector()             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5744, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques_vector = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5745
 *         """
 *         uniques_vector = Int16Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int16_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 5745, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques_vector);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques_vector))) __PYX_ERR(2, 5745, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 5745, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5746
 *         uniques_vector = Int16Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,             # <<<<<<<<<<<<<<
 *                             return_inverse=True)
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 5745, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, __pyx_v_ignore_na) < 0) __PYX_ERR(2, 5745, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 5745, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5747
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)             # <<<<<<<<<<<<<<
 * 
 *     def get_labels(self, const int16_t[:] values, Int16Vector uniques,
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 5745, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5745
 *         """
 *         uniques_vector = Int16Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5745, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5713
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const int16_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5749
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const int16_t[:] values, Int16Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_31get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_31get_labels = {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_31get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_31get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_labels (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":5751
 *     def get_labels(self, const int16_t[:] values, Int16Vector uniques,
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5749, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5749, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, 1); __PYX_ERR(2, 5749, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5749, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5749, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5749, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5749, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_labels") < 0)) __PYX_ERR(2, 5749, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int16_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 5749, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 5750, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 5750, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    __pyx_v_mask = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, __pyx_nargs); __PYX_ERR(2, 5749, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector, 1, "uniques", 0))) __PYX_ERR(2, 5749, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_30get_labels(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":5749
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const int16_t[:] values, Int16Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_30get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_v_labels = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_labels", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":5753
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int16_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 5753, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 5753, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_count_prior); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_count_prior, __pyx_t_4) < 0) __PYX_ERR(2, 5753, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5754
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,             # <<<<<<<<<<<<<<
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 5753, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 5753, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5755
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, Py_True) < 0) __PYX_ERR(2, 5753, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 5753, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 5753, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5753
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
    PyObject* sequence = __pyx_t_4;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(2, 5753, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5753, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5753, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5753, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
    index = 0; __pyx_t_2 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_1), 2) < 0) __PYX_ERR(2, 5753, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(2, 5753, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v__ = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_labels = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5756
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_labels);
  __pyx_r = __pyx_v_labels;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5749
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const int16_t[:] values, Int16Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XDECREF(__pyx_v_labels);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_33__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_33__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_33__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_33__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_32__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_32__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_35__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_35__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_35__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_35__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_34__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int16HashTable_34__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5765
 *         Int16Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = Int16HashTable(size_hint)
 *         self.uniques = Int16Vector()
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_size_hint = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5765, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 5765, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_size_hint = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 5765, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_size_hint), (&PyInt_Type), 0, "size_hint", 1))) __PYX_ERR(2, 5765, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *)__pyx_v_self), __pyx_v_size_hint);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":5766
 * 
 *     def __cinit__(self, size_hint: int):
 *         self.table = Int16HashTable(size_hint)             # <<<<<<<<<<<<<<
 *         self.uniques = Int16Vector()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable), __pyx_v_size_hint); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5766, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5767
 *     def __cinit__(self, size_hint: int):
 *         self.table = Int16HashTable(size_hint)
 *         self.uniques = Int16Vector()             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const int16_t[:] values,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5765
 *         Int16Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = Int16HashTable(size_hint)
 *         self.uniques = Int16Vector()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5769
 *         self.uniques = Int16Vector()
 * 
 *     def factorize(self, const int16_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15Int16Factorizer_2factorize, "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = Int16Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"int16\"), na_sentinel=20)\n        array([0, 1, 2])\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15Int16Factorizer_3factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15Int16Factorizer_2factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_v_na_sentinel = 0;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_neg_1));

    /* "pandas/_libs/hashtable_class_helper.pxi":5770
 * 
 *     def factorize(self, const int16_t[:] values,
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:             # <<<<<<<<<<<<<<
 *         """
 *         Returns
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5769, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5769, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5769, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5769, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 5769, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int16_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 5769, __pyx_L3_error)
    __pyx_v_na_sentinel = values[1];
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 4, __pyx_nargs); __PYX_ERR(2, 5769, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_2factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":5769
 *         self.uniques = Int16Vector()
 * 
 *     def factorize(self, const int16_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  PyArrayObject *__pyx_v_labels = 0;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_uniques = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_labels;
  __Pyx_Buffer __pyx_pybuffer_labels;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);
  __pyx_pybuffer_labels.pybuffer.buf = NULL;
  __pyx_pybuffer_labels.refcount = 0;
  __pyx_pybuffernd_labels.data = NULL;
  __pyx_pybuffernd_labels.rcbuffer = &__pyx_pybuffer_labels;

  /* "pandas/_libs/hashtable_class_helper.pxi":5787
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = Int16Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  if (__pyx_v_self->uniques->__pyx_base.external_view_exists) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5788
 * 
 *         if self.uniques.external_view_exists:
 *             uniques = Int16Vector()             # <<<<<<<<<<<<<<
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 */
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5788, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":5789
 *         if self.uniques.external_view_exists:
 *             uniques = Int16Vector()
 *             uniques.extend(self.uniques.to_array())             # <<<<<<<<<<<<<<
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 */
    __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int16Vector *)__pyx_v_self->uniques->__pyx_vtab)->to_array(__pyx_v_self->uniques, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5789, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int16_t__const__(__pyx_t_1, 0); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(2, 5789, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int16Vector *)__pyx_v_uniques->__pyx_vtab)->extend(__pyx_v_uniques, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5789, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
    __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":5790
 *             uniques = Int16Vector()
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques             # <<<<<<<<<<<<<<
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 */
    __Pyx_INCREF((PyObject *)__pyx_v_uniques);
    __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
    __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
    __pyx_v_self->uniques = __pyx_v_uniques;

    /* "pandas/_libs/hashtable_class_helper.pxi":5787
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = Int16Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5791
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->table), __pyx_n_s_get_labels); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int16_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "pandas/_libs/hashtable_class_helper.pxi":5792
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,             # <<<<<<<<<<<<<<
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_self->__pyx_base.count); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "pandas/_libs/hashtable_class_helper.pxi":5791
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_5 = PyTuple_New(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3)) __PYX_ERR(2, 5791, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self->uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_self->uniques))) __PYX_ERR(2, 5791, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_4)) __PYX_ERR(2, 5791, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_na_sentinel);
  __Pyx_GIVEREF(__pyx_v_na_sentinel);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_v_na_sentinel)) __PYX_ERR(2, 5791, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5793
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)             # <<<<<<<<<<<<<<
 *         self.count = len(self.uniques)
 *         return labels
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5793, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 5793, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 5793, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5791
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5791, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 5791, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
    __pyx_t_7 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_7 < 0)) {
      PyErr_Fetch(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_v_labels, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      }
      __pyx_t_8 = __pyx_t_9 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_labels.diminfo[0].strides = __pyx_pybuffernd_labels.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_labels.diminfo[0].shape = __pyx_pybuffernd_labels.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(2, 5791, __pyx_L1_error)
  }
  __pyx_t_6 = 0;
  __pyx_v_labels = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5794
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  __pyx_t_3 = ((PyObject *)__pyx_v_self->uniques);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_11 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(2, 5794, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_self->__pyx_base.count = __pyx_t_11;

  /* "pandas/_libs/hashtable_class_helper.pxi":5795
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * cdef class UInt8HashTable(HashTable):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_labels);
  __pyx_r = ((PyObject *)__pyx_v_labels);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5769
 *         self.uniques = Int16Vector()
 * 
 *     def factorize(self, const int16_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_labels);
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5762
 * cdef class Int16Factorizer(Factorizer):
 *     cdef public:
 *         Int16HashTable table             # <<<<<<<<<<<<<<
 *         Int16Vector uniques
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_5table_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_5table_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_5table___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->table);
  __pyx_r = ((PyObject *)__pyx_v_self->table);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_5table_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable))))) __PYX_ERR(2, 5762, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16Factorizer.table.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_5table_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_5table_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_5table_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5763
 *     cdef public:
 *         Int16HashTable table
 *         Int16Vector uniques             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, size_hint: int):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_7uniques_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_7uniques_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_7uniques___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __pyx_r = ((PyObject *)__pyx_v_self->uniques);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_7uniques_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector))))) __PYX_ERR(2, 5763, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16Factorizer.uniques.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_7uniques_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_7uniques_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_7uniques_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15Int16Factorizer_5__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_4__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16Factorizer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15Int16Factorizer_7__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_6__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15Int16Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int16Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5799
 * cdef class UInt8HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_uint8()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __pyx_t_5numpy_int64_t __pyx_v_size_hint;
  int __pyx_v_uses_mask;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,&__pyx_n_s_uses_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5799, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uses_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5799, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 5799, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_size_hint = __Pyx_PyInt_As_npy_int64(values[0]); if (unlikely((__pyx_v_size_hint == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 5799, __pyx_L3_error)
    } else {
      __pyx_v_size_hint = ((__pyx_t_5numpy_int64_t)1);
    }
    if (values[1]) {
      __pyx_v_uses_mask = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_uses_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 5799, __pyx_L3_error)
    } else {
      __pyx_v_uses_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 0, 2, __pyx_nargs); __PYX_ERR(2, 5799, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)__pyx_v_self), __pyx_v_size_hint, __pyx_v_uses_mask);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  khuint_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __pyx_t_5numpy_int64_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":5800
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_uint8()             # <<<<<<<<<<<<<<
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_uint8(self.table, size_hint)
 */
  __pyx_v_self->table = kh_init_uint8();

  /* "pandas/_libs/hashtable_class_helper.pxi":5801
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_uint8()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)             # <<<<<<<<<<<<<<
 *         kh_resize_uint8(self.table, size_hint)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5801, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = kh_needed_n_buckets(__pyx_v_size_hint);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5801, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_1, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5801, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(2, 5801, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_6) {
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_5 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5801, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_int64(__pyx_t_3); if (unlikely((__pyx_t_7 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 5801, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_size_hint = __pyx_t_7;

  /* "pandas/_libs/hashtable_class_helper.pxi":5802
 *         self.table = kh_init_uint8()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_uint8(self.table, size_hint)             # <<<<<<<<<<<<<<
 * 
 *         self.uses_mask = uses_mask
 */
  kh_resize_uint8(__pyx_v_self->table, __pyx_v_size_hint);

  /* "pandas/_libs/hashtable_class_helper.pxi":5804
 *         kh_resize_uint8(self.table, size_hint)
 * 
 *         self.uses_mask = uses_mask             # <<<<<<<<<<<<<<
 *         self.na_position = -1
 * 
 */
  __pyx_v_self->uses_mask = __pyx_v_uses_mask;

  /* "pandas/_libs/hashtable_class_helper.pxi":5805
 * 
 *         self.uses_mask = uses_mask
 *         self.na_position = -1             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
  __pyx_v_self->na_position = -1LL;

  /* "pandas/_libs/hashtable_class_helper.pxi":5799
 * cdef class UInt8HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_uint8()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5807
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_3__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_3__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_2__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  long __pyx_t_1;
  int __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":5808
 * 
 *     def __len__(self) -> int:
 *         return self.table.size + (0 if self.na_position == -1 else 1)             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_2 = (__pyx_v_self->na_position == -1LL);
  if (__pyx_t_2) {
    __pyx_t_1 = 0;
  } else {
    __pyx_t_1 = 1;
  }
  __pyx_r = (__pyx_v_self->table->size + __pyx_t_1);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5807
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5810
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_uint8(self.table)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_5__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_5__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_4__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":5811
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_uint8(self.table)
 *             self.table = NULL
 */
  __pyx_t_1 = (__pyx_v_self->table != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5812
 *     def __dealloc__(self):
 *         if self.table is not NULL:
 *             kh_destroy_uint8(self.table)             # <<<<<<<<<<<<<<
 *             self.table = NULL
 * 
 */
    kh_destroy_uint8(__pyx_v_self->table);

    /* "pandas/_libs/hashtable_class_helper.pxi":5813
 *         if self.table is not NULL:
 *             kh_destroy_uint8(self.table)
 *             self.table = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __contains__(self, object key) -> bool:
 */
    __pyx_v_self->table = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":5811
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_uint8(self.table)
 *             self.table = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5810
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_uint8(self.table)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":5815
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__contains__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_6__contains__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)__pyx_v_self), ((PyObject *)__pyx_v_key));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, PyObject *__pyx_v_key) {
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_uint8_t __pyx_v_ckey;
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  __pyx_t_5numpy_uint8_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5822
 *             uint8_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_1 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_7missing_checknull(__pyx_v_key, 0, NULL); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5822, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5823
 * 
 *         if self.uses_mask and checknull(key):
 *             return -1 != self.na_position             # <<<<<<<<<<<<<<
 * 
 *         ckey = (key)
 */
    __pyx_r = (-1LL != __pyx_v_self->na_position);
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":5822
 *             uint8_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5825
 *             return -1 != self.na_position
 * 
 *         ckey = (key)             # <<<<<<<<<<<<<<
 *         k = kh_get_uint8(self.table, ckey)
 *         return k != self.table.n_buckets
 */
  __pyx_t_3 = __Pyx_PyInt_As_npy_uint8(__pyx_v_key); if (unlikely((__pyx_t_3 == ((npy_uint8)-1)) && PyErr_Occurred())) __PYX_ERR(2, 5825, __pyx_L1_error)
  __pyx_v_ckey = __pyx_t_3;

  /* "pandas/_libs/hashtable_class_helper.pxi":5826
 * 
 *         ckey = (key)
 *         k = kh_get_uint8(self.table, ckey)             # <<<<<<<<<<<<<<
 *         return k != self.table.n_buckets
 * 
 */
  __pyx_v_k = kh_get_uint8(__pyx_v_self->table, __pyx_v_ckey);

  /* "pandas/_libs/hashtable_class_helper.pxi":5827
 *         ckey = (key)
 *         k = kh_get_uint8(self.table, ckey)
 *         return k != self.table.n_buckets             # <<<<<<<<<<<<<<
 * 
 *     def sizeof(self, deep: bool = False) -> int:
 */
  __pyx_r = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5815
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5829
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14UInt8HashTable_8sizeof, " return the size of my table in bytes ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_9sizeof = {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14UInt8HashTable_8sizeof};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_deep = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sizeof (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_deep,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_deep);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5829, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "sizeof") < 0)) __PYX_ERR(2, 5829, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_deep = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sizeof", 0, 0, 1, __pyx_nargs); __PYX_ERR(2, 5829, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_8sizeof(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)__pyx_v_self), __pyx_v_deep);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep) {
  PyObject *__pyx_v_overhead = NULL;
  PyObject *__pyx_v_for_flags = NULL;
  PyObject *__pyx_v_for_pairs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  long __pyx_t_2;
  long __pyx_t_3;
  long __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sizeof", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":5831
 *     def sizeof(self, deep: bool = False) -> int:
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)             # <<<<<<<<<<<<<<
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(uint8_t) + # keys
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(((4 * (sizeof(__pyx_t_5numpy_uint32_t))) + (3 * (sizeof(__pyx_t_5numpy_uint32_t *))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5831, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_overhead = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5832
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)             # <<<<<<<<<<<<<<
 *         for_pairs =  self.table.n_buckets * (sizeof(uint8_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 */
  __pyx_t_2 = (__pyx_v_self->table->n_buckets >> 5);
  __pyx_t_3 = 1;
  __pyx_t_5 = (__pyx_t_2 > __pyx_t_3);
  if (__pyx_t_5) {
    __pyx_t_4 = __pyx_t_2;
  } else {
    __pyx_t_4 = __pyx_t_3;
  }
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_t_4 * (sizeof(__pyx_t_5numpy_uint32_t)))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5832, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_flags = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5833
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(uint8_t) + # keys             # <<<<<<<<<<<<<<
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->n_buckets * ((sizeof(__pyx_t_5numpy_uint8_t)) + (sizeof(Py_ssize_t))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5833, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_pairs = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5835
 *         for_pairs =  self.table.n_buckets * (sizeof(uint8_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs             # <<<<<<<<<<<<<<
 * 
 *     def get_state(self) -> dict[str, int]:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Add(__pyx_v_overhead, __pyx_v_for_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyNumber_Add(__pyx_t_1, __pyx_v_for_pairs); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5835, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(__Pyx_Py3Int_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None) || __Pyx_RaiseUnexpectedTypeError("int", __pyx_t_6))) __PYX_ERR(2, 5835, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5829
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_overhead);
  __Pyx_XDECREF(__pyx_v_for_flags);
  __Pyx_XDECREF(__pyx_v_for_pairs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5837
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14UInt8HashTable_10get_state, " returns infos about the state of the hashtable");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_11get_state = {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14UInt8HashTable_10get_state};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_state (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_state", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_state", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_10get_state(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_state", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":5839
 *     def get_state(self) -> dict[str, int]:
 *         """ returns infos about the state of the hashtable"""
 *         return {             # <<<<<<<<<<<<<<
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 */
  __Pyx_XDECREF(__pyx_r);

  /* "pandas/_libs/hashtable_class_helper.pxi":5840
 *         """ returns infos about the state of the hashtable"""
 *         return {
 *             'n_buckets' : self.table.n_buckets,             # <<<<<<<<<<<<<<
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_buckets); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5840, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_buckets, __pyx_t_2) < 0) __PYX_ERR(2, 5840, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5841
 *         return {
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,             # <<<<<<<<<<<<<<
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->size); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_size, __pyx_t_2) < 0) __PYX_ERR(2, 5840, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5842
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,             # <<<<<<<<<<<<<<
 *             'upper_bound' : self.table.upper_bound,
 *         }
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_occupied); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_occupied, __pyx_t_2) < 0) __PYX_ERR(2, 5840, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5843
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,             # <<<<<<<<<<<<<<
 *         }
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->upper_bound); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5843, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_upper_bound, __pyx_t_2) < 0) __PYX_ERR(2, 5840, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5837
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.get_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5846
 *         }
 * 
 *     cpdef get_item(self, uint8_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14UInt8HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, __pyx_t_5numpy_uint8_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_uint8_t __pyx_v_cval;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5846, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_13get_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyInt_From_npy_uint8(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5846, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5846, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5865
 *             uint8_t cval
 * 
 *         cval = (val)             # <<<<<<<<<<<<<<
 *         k = kh_get_uint8(self.table, cval)
 *         if k != self.table.n_buckets:
 */
  __pyx_v_cval = __pyx_v_val;

  /* "pandas/_libs/hashtable_class_helper.pxi":5866
 * 
 *         cval = (val)
 *         k = kh_get_uint8(self.table, cval)             # <<<<<<<<<<<<<<
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]
 */
  __pyx_v_k = kh_get_uint8(__pyx_v_self->table, __pyx_v_cval);

  /* "pandas/_libs/hashtable_class_helper.pxi":5867
 *         cval = (val)
 *         k = kh_get_uint8(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  __pyx_t_7 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  if (likely(__pyx_t_7)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5868
 *         k = kh_get_uint8(self.table, cval)
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(val)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->vals[__pyx_v_k])); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5868, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":5867
 *         cval = (val)
 *         k = kh_get_uint8(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5870
 *             return self.table.vals[k]
 *         else:
 *             raise KeyError(val)             # <<<<<<<<<<<<<<
 * 
 *     cpdef get_na(self):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyInt_From_npy_uint8(__pyx_v_val); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5870, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5870, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 5870, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5846
 *         }
 * 
 *     cpdef get_item(self, uint8_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14UInt8HashTable_12get_item, "Extracts the position of val from the hashtable.\n\n        Parameters\n        ----------\n        val : Scalar\n            The value that is looked up in the hashtable\n\n        Returns\n        -------\n        The position of the requested integer.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_13get_item = {"get_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_13get_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14UInt8HashTable_12get_item};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_5numpy_uint8_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5846, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_item") < 0)) __PYX_ERR(2, 5846, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __Pyx_PyInt_As_npy_uint8(values[0]); if (unlikely((__pyx_v_val == ((npy_uint8)-1)) && PyErr_Occurred())) __PYX_ERR(2, 5846, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_item", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 5846, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_12get_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, __pyx_t_5numpy_uint8_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_14UInt8HashTable_get_item(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5872
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14UInt8HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5872, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_15get_na)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5872, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5880
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_6 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5881
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         if self.na_position == -1:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 5881, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":5880
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5883
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  __pyx_t_6 = (__pyx_v_self->na_position == -1LL);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5884
 * 
 *         if self.na_position == -1:
 *             raise KeyError("NA")             # <<<<<<<<<<<<<<
 *         return self.na_position
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_KeyError, __pyx_tuple__13, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5884, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(2, 5884, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":5883
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5885
 *         if self.na_position == -1:
 *             raise KeyError("NA")
 *         return self.na_position             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_item(self, uint8_t key, Py_ssize_t val):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->na_position); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5885, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5872
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14UInt8HashTable_14get_na, "Extracts the position of na_value from the hashtable.\n\n        Returns\n        -------\n        The position of the last na value.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_15get_na = {"get_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_15get_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14UInt8HashTable_14get_na};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_na", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_na", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_14get_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_14UInt8HashTable_get_na(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5887
 *         return self.na_position
 * 
 *     cpdef set_item(self, uint8_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14UInt8HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, __pyx_t_5numpy_uint8_t __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  __pyx_t_5numpy_uint8_t __pyx_v_ckey;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5887, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_17set_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyInt_From_npy_uint8(__pyx_v_key); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5887, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5887, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_5 = __pyx_t_1; __pyx_t_6 = NULL;
        __pyx_t_7 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_7 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_3, __pyx_t_4};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5887, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5892
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             uint8_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5895
 *             uint8_t ckey
 * 
 *         ckey = (key)             # <<<<<<<<<<<<<<
 *         k = kh_put_uint8(self.table, ckey, &ret)
 *         if kh_exist_uint8(self.table, k):
 */
  __pyx_v_ckey = __pyx_v_key;

  /* "pandas/_libs/hashtable_class_helper.pxi":5896
 * 
 *         ckey = (key)
 *         k = kh_put_uint8(self.table, ckey, &ret)             # <<<<<<<<<<<<<<
 *         if kh_exist_uint8(self.table, k):
 *             self.table.vals[k] = val
 */
  __pyx_v_k = kh_put_uint8(__pyx_v_self->table, __pyx_v_ckey, (&__pyx_v_ret));

  /* "pandas/_libs/hashtable_class_helper.pxi":5897
 *         ckey = (key)
 *         k = kh_put_uint8(self.table, ckey, &ret)
 *         if kh_exist_uint8(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
  __pyx_t_8 = kh_exist_uint8(__pyx_v_self->table, __pyx_v_k);
  if (likely(__pyx_t_8)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5898
 *         k = kh_put_uint8(self.table, ckey, &ret)
 *         if kh_exist_uint8(self.table, k):
 *             self.table.vals[k] = val             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(key)
 */
    (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_val;

    /* "pandas/_libs/hashtable_class_helper.pxi":5897
 *         ckey = (key)
 *         k = kh_put_uint8(self.table, ckey, &ret)
 *         if kh_exist_uint8(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5900
 *             self.table.vals[k] = val
 *         else:
 *             raise KeyError(key)             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_na(self, Py_ssize_t val):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyInt_From_npy_uint8(__pyx_v_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5900, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5900, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 5900, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "pandas/_libs/hashtable_class_helper.pxi":5887
 *         return self.na_position
 * 
 *     cpdef set_item(self, uint8_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_17set_item = {"set_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_17set_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_5numpy_uint8_t __pyx_v_key;
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key,&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5887, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5887, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, 1); __PYX_ERR(2, 5887, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_item") < 0)) __PYX_ERR(2, 5887, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_key = __Pyx_PyInt_As_npy_uint8(values[0]); if (unlikely((__pyx_v_key == ((npy_uint8)-1)) && PyErr_Occurred())) __PYX_ERR(2, 5887, __pyx_L3_error)
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 5887, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, __pyx_nargs); __PYX_ERR(2, 5887, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_16set_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)__pyx_v_self), __pyx_v_key, __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, __pyx_t_5numpy_uint8_t __pyx_v_key, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_14UInt8HashTable_set_item(__pyx_v_self, __pyx_v_key, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5902
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_14UInt8HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  CYTHON_UNUSED int __pyx_v_ret;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5902, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_19set_na)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5902, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5902, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5906
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             uint8_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5909
 *             uint8_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_7 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_7)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5910
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         self.na_position = val
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 5910, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":5909
 *             uint8_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5912
 *             raise NotImplementedError
 * 
 *         self.na_position = val             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->na_position = __pyx_v_val;

  /* "pandas/_libs/hashtable_class_helper.pxi":5902
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_19set_na = {"set_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_19set_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5902, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_na") < 0)) __PYX_ERR(2, 5902, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[0]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 5902, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_na", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 5902, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_18set_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_14UInt8HashTable_set_na(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5915
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const uint8_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_21map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_21map_locations = {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_21map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_21map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("map_locations (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5915, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5915, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "map_locations") < 0)) __PYX_ERR(2, 5915, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 5916, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 5916, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__36;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("map_locations", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 5915, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_20map_locations(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_20map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  int __pyx_v_ret;
  __pyx_t_5numpy_uint8_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  __pyx_t_5numpy_int64_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("map_locations", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":5919
 *         # Used in libindex, safe_sort
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             uint8_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":5920
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             uint8_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5923
 *             uint8_t val
 *             khiter_t k
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_2 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":5925
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_3 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_3)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5926
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 5926, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":5925
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5928
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":5929
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
        if (__pyx_v_self->uses_mask) {

          /* "pandas/_libs/hashtable_class_helper.pxi":5930
 *         with nogil:
 *             if self.uses_mask:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     if mask[i]:
 *                         na_position = i
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":5931
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_mask.shape[0];
            __pyx_t_3 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) ))) != 0);
            if (__pyx_t_3) {

              /* "pandas/_libs/hashtable_class_helper.pxi":5932
 *                 for i in range(n):
 *                     if mask[i]:
 *                         na_position = i             # <<<<<<<<<<<<<<
 *                     else:
 *                         val= (values[i])
 */
              __pyx_v_na_position = __pyx_v_i;

              /* "pandas/_libs/hashtable_class_helper.pxi":5931
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
              goto __pyx_L12;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":5934
 *                         na_position = i
 *                     else:
 *                         val= (values[i])             # <<<<<<<<<<<<<<
 *                         k = kh_put_uint8(self.table, val, &ret)
 *                         self.table.vals[k] = i
 */
            /*else*/ {
              __pyx_t_7 = __pyx_v_i;
              if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
              __pyx_v_val = (*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_class_helper.pxi":5935
 *                     else:
 *                         val= (values[i])
 *                         k = kh_put_uint8(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = i
 *             else:
 */
              __pyx_v_k = kh_put_uint8(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

              /* "pandas/_libs/hashtable_class_helper.pxi":5936
 *                         val= (values[i])
 *                         k = kh_put_uint8(self.table, val, &ret)
 *                         self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *             else:
 *                 for i in range(n):
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
            }
            __pyx_L12:;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":5929
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
          goto __pyx_L9;
        }

        /* "pandas/_libs/hashtable_class_helper.pxi":5938
 *                         self.table.vals[k] = i
 *             else:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     val= (values[i])
 *                     k = kh_put_uint8(self.table, val, &ret)
 */
        /*else*/ {
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":5939
 *             else:
 *                 for i in range(n):
 *                     val= (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_put_uint8(self.table, val, &ret)
 *                     self.table.vals[k] = i
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
            __pyx_v_val = (*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

            /* "pandas/_libs/hashtable_class_helper.pxi":5940
 *                 for i in range(n):
 *                     val= (values[i])
 *                     k = kh_put_uint8(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                     self.table.vals[k] = i
 *         self.na_position = na_position
 */
            __pyx_v_k = kh_put_uint8(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":5941
 *                     val= (values[i])
 *                     k = kh_put_uint8(self.table, val, &ret)
 *                     self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *         self.na_position = na_position
 * 
 */
            (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
          }
        }
        __pyx_L9:;
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":5928
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5942
 *                     k = kh_put_uint8(self.table, val, &ret)
 *                     self.table.vals[k] = i
 *         self.na_position = na_position             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __pyx_v_self->na_position = __pyx_v_na_position;

  /* "pandas/_libs/hashtable_class_helper.pxi":5915
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const uint8_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5944
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const uint8_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

/* Python wrapper */
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_23lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_23lookup = {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_23lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_23lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyArrayObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lookup (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5944, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5944, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lookup") < 0)) __PYX_ERR(2, 5944, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 5945, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 5945, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__37;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lookup", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 5944, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_22lookup(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_22lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  CYTHON_UNUSED int __pyx_v_ret;
  __pyx_t_5numpy_uint8_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __Pyx_memviewslice __pyx_v_locs = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lookup", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":5949
 *         # Used in safe_sort, IndexEngine.get_indexer
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             uint8_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":5950
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             uint8_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5953
 *             uint8_t val
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *             int8_t na_position = self.na_position
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 5953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 5953, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 5953, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 5953, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_locs = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":5954
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_8 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":5956
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_9 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_10 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_9 = __pyx_t_10;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":5957
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 5957, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":5956
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5959
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":5960
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_11 = __pyx_t_1;
        for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
          __pyx_v_i = __pyx_t_12;

          /* "pandas/_libs/hashtable_class_helper.pxi":5961
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
          if (__pyx_v_self->uses_mask) {
          } else {
            __pyx_t_9 = __pyx_v_self->uses_mask;
            goto __pyx_L12_bool_binop_done;
          }
          __pyx_t_13 = __pyx_v_i;
          if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_mask.shape[0];
          __pyx_t_10 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_13 * __pyx_v_mask.strides[0]) ))) != 0);
          __pyx_t_9 = __pyx_t_10;
          __pyx_L12_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":5962
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position             # <<<<<<<<<<<<<<
 *                 else:
 *                     val = (values[i])
 */
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = __pyx_v_na_position;

            /* "pandas/_libs/hashtable_class_helper.pxi":5961
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
            goto __pyx_L11;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":5964
 *                     locs[i] = na_position
 *                 else:
 *                     val = (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_uint8(self.table, val)
 *                     if k != self.table.n_buckets:
 */
          /*else*/ {
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_values.shape[0];
            __pyx_v_val = (*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_13 * __pyx_v_values.strides[0]) )));

            /* "pandas/_libs/hashtable_class_helper.pxi":5965
 *                 else:
 *                     val = (values[i])
 *                     k = kh_get_uint8(self.table, val)             # <<<<<<<<<<<<<<
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]
 */
            __pyx_v_k = kh_get_uint8(__pyx_v_self->table, __pyx_v_val);

            /* "pandas/_libs/hashtable_class_helper.pxi":5966
 *                     val = (values[i])
 *                     k = kh_get_uint8(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
            __pyx_t_9 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":5967
 *                     k = kh_get_uint8(self.table, val)
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     else:
 *                         locs[i] = -1
 */
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = (__pyx_v_self->table->vals[__pyx_v_k]);

              /* "pandas/_libs/hashtable_class_helper.pxi":5966
 *                     val = (values[i])
 *                     k = kh_get_uint8(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
              goto __pyx_L14;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":5969
 *                         locs[i] = self.table.vals[k]
 *                     else:
 *                         locs[i] = -1             # <<<<<<<<<<<<<<
 * 
 *         return np.asarray(locs)
 */
            /*else*/ {
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = -1;
            }
            __pyx_L14:;
          }
          __pyx_L11:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":5959
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":5971
 *                         locs[i] = -1
 * 
 *         return np.asarray(locs)             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_locs, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 5971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_14 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_14 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 5971, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 5971, __pyx_L1_error)
  __pyx_r = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5944
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const uint8_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_locs, 1);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":5973
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const uint8_t[:] values, UInt8Vector uniques,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_25_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14UInt8HashTable_24_unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[uint8]\n            Array of values of which unique will be calculated\n        uniques : UInt8Vector\n            Vector into which uniques will be written\n        count_prior : Py_ssize_t, default 0\n            Number of existing entries in uniques\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        ignore_na : bool, default False\n            Whether NA-values should be ignored for calculating the uniques. If\n            True, the labels corresponding to missing values will be set to\n            na_sentinel.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        use_result_mask: bool, default False\n            Whether to create a result mask for the unique values. Not supported\n            with return_inverse=True.\n\n        Returns\n        -------\n        uniques : ndarray[uint8]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse=True)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if use_result_mask is true\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_25_unique = {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_25_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14UInt8HashTable_24_unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_25_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  int __pyx_v_ignore_na;
  PyObject *__pyx_v_mask = 0;
  int __pyx_v_return_inverse;
  int __pyx_v_use_result_mask;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[9] = {0,0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_ignore_na,&__pyx_n_s_mask,&__pyx_n_s_return_inverse,&__pyx_n_s_use_result_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":5977
 *     def _unique(self, const uint8_t[:] values, UInt8Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));

    /* "pandas/_libs/hashtable_class_helper.pxi":5978
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[6] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5973, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5973, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, 1); __PYX_ERR(2, 5973, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5973, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5973, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5973, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5973, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[6] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5973, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[7] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5973, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_use_result_mask);
          if (value) { values[8] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 5973, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_unique") < 0)) __PYX_ERR(2, 5973, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 5975, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 5976, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 5976, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    if (values[5]) {
      __pyx_v_ignore_na = __Pyx_PyObject_IsTrue(values[5]); if (unlikely((__pyx_v_ignore_na == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 5977, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":5977
 *     def _unique(self, const uint8_t[:] values, UInt8Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
      __pyx_v_ignore_na = ((int)0);
    }
    __pyx_v_mask = values[6];
    if (values[7]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[7]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 5978, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":5978
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
      __pyx_v_return_inverse = ((int)0);
    }
    if (values[8]) {
      __pyx_v_use_result_mask = __Pyx_PyObject_IsTrue(values[8]); if (unlikely((__pyx_v_use_result_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 5978, __pyx_L3_error)
    } else {
      __pyx_v_use_result_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, __pyx_nargs); __PYX_ERR(2, 5973, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector, 1, "uniques", 0))) __PYX_ERR(2, 5975, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_24_unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_ignore_na, __pyx_v_mask, __pyx_v_return_inverse, __pyx_v_use_result_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":5973
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const uint8_t[:] values, UInt8Vector uniques,
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_24_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_idx;
  Py_ssize_t __pyx_v_count;
  Py_ssize_t __pyx_v_n;
  __Pyx_memviewslice __pyx_v_labels = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_ret;
  __pyx_t_5numpy_uint8_t __pyx_v_val;
  __pyx_t_5numpy_uint8_t __pyx_v_na_value2;
  khiter_t __pyx_v_k;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_v_ud;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_result_mask = 0;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_v_rmd;
  int __pyx_v_use_na_value;
  int __pyx_v_use_mask;
  int __pyx_v_seen_na;
  __Pyx_memviewslice __pyx_v_mask_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  int __pyx_t_11;
  __Pyx_memviewslice __pyx_t_12 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_uint8_t __pyx_t_13;
  Py_ssize_t __pyx_t_14;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":6022
 *         """
 *         cdef:
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)             # <<<<<<<<<<<<<<
 *             intp_t[::1] labels
 *             int ret = 0
 */
  __pyx_v_count = __pyx_v_count_prior;
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":6024
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)
 *             intp_t[::1] labels
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             uint8_t val, na_value2
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6030
 *             UInt8Vector result_mask
 *             UInt8VectorData *rmd
 *             bint use_na_value, use_mask, seen_na = False             # <<<<<<<<<<<<<<
 *             uint8_t[:] mask_values
 * 
 */
  __pyx_v_seen_na = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6033
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6034
 * 
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6034, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6034, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6034, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6034, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 6034, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6034, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6034, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6034, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 6034, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6034, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 6034, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_labels = __pyx_t_7;
    __pyx_t_7.memview = NULL;
    __pyx_t_7.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":6033
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6035
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data             # <<<<<<<<<<<<<<
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 */
  __pyx_t_8 = __pyx_v_uniques->data;
  __pyx_v_ud = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":6036
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 *         use_na_value = na_value is not None             # <<<<<<<<<<<<<<
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 */
  __pyx_t_9 = (__pyx_v_na_value != Py_None);
  __pyx_v_use_na_value = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":6037
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None             # <<<<<<<<<<<<<<
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover
 */
  __pyx_t_9 = (__pyx_v_mask != Py_None);
  __pyx_v_use_mask = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":6038
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  __pyx_t_10 = (!__pyx_v_use_mask);
  if (__pyx_t_10) {
  } else {
    __pyx_t_9 = __pyx_t_10;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_use_result_mask;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6039
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         if use_result_mask and return_inverse:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 6039, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":6038
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6041
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_use_result_mask) {
  } else {
    __pyx_t_9 = __pyx_v_use_result_mask;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_return_inverse;
  __pyx_L8_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6042
 * 
 *         if use_result_mask and return_inverse:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         result_mask = UInt8Vector()
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 6042, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":6041
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6044
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         result_mask = UInt8Vector()             # <<<<<<<<<<<<<<
 *         rmd = result_mask.data
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6044, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_v_result_mask = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6045
 * 
 *         result_mask = UInt8Vector()
 *         rmd = result_mask.data             # <<<<<<<<<<<<<<
 * 
 *         if use_mask:
 */
  __pyx_t_8 = __pyx_v_result_mask->data;
  __pyx_v_rmd = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":6047
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  if (__pyx_v_use_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6048
 * 
 *         if use_mask:
 *             mask_values = mask.view("uint8")             # <<<<<<<<<<<<<<
 * 
 *         if use_na_value:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_mask, __pyx_n_s_view); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6048, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    __pyx_t_11 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_11 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_uint8};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_11, 1+__pyx_t_11);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6048, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_12.memview)) __PYX_ERR(2, 6048, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_mask_values = __pyx_t_12;
    __pyx_t_12.memview = NULL;
    __pyx_t_12.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":6047
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6050
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
  if (__pyx_v_use_na_value) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6056
 *             # for the parameter. To please the compiler, we use na_value2,
 *             # which is only used if it's *specified*.
 *             na_value2 = (na_value)             # <<<<<<<<<<<<<<
 *         else:
 *             na_value2 = (0)
 */
    __pyx_t_13 = __Pyx_PyInt_As_npy_uint8(__pyx_v_na_value); if (unlikely((__pyx_t_13 == ((npy_uint8)-1)) && PyErr_Occurred())) __PYX_ERR(2, 6056, __pyx_L1_error)
    __pyx_v_na_value2 = __pyx_t_13;

    /* "pandas/_libs/hashtable_class_helper.pxi":6050
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
    goto __pyx_L11;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6058
 *             na_value2 = (na_value)
 *         else:
 *             na_value2 = (0)             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
  /*else*/ {
    __pyx_v_na_value2 = 0;
  }
  __pyx_L11:;

  /* "pandas/_libs/hashtable_class_helper.pxi":6060
 *             na_value2 = (0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = (values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":6061
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 val = (values[i])
 * 
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_14 = __pyx_t_1;
        for (__pyx_t_15 = 0; __pyx_t_15 < __pyx_t_14; __pyx_t_15+=1) {
          __pyx_v_i = __pyx_t_15;

          /* "pandas/_libs/hashtable_class_helper.pxi":6062
 *         with nogil:
 *             for i in range(n):
 *                 val = (values[i])             # <<<<<<<<<<<<<<
 * 
 *                 if ignore_na and use_mask:
 */
          __pyx_t_16 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_16 * __pyx_v_values.strides[0]) )));

          /* "pandas/_libs/hashtable_class_helper.pxi":6064
 *                 val = (values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L18_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_mask;
          __pyx_L18_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":6065
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 6065, __pyx_L13_error) }
            __pyx_t_16 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_16 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":6066
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                         continue
 *                 elif ignore_na and (
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 6066, __pyx_L13_error) }
              __pyx_t_16 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_16)) )) = __pyx_v_na_sentinel;

              /* "pandas/_libs/hashtable_class_helper.pxi":6067
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 *                         continue             # <<<<<<<<<<<<<<
 *                 elif ignore_na and (
 *                    is_nan_uint8_t(val) or
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":6065
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":6064
 *                 val = (values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
            goto __pyx_L17;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":6068
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_uint8_t(val) or
 *                    (use_na_value and are_equivalent_uint8_t(val, na_value2))
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":6069
 *                         continue
 *                 elif ignore_na and (
 *                    is_nan_uint8_t(val) or             # <<<<<<<<<<<<<<
 *                    (use_na_value and are_equivalent_uint8_t(val, na_value2))
 *                 ):
 */
          __pyx_t_10 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_uint8_t(__pyx_v_val); if (unlikely(__pyx_t_10 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 6069, __pyx_L13_error)
          if (!__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":6070
 *                 elif ignore_na and (
 *                    is_nan_uint8_t(val) or
 *                    (use_na_value and are_equivalent_uint8_t(val, na_value2))             # <<<<<<<<<<<<<<
 *                 ):
 *                     # if missing values do not count as unique values (i.e. if
 */
          if (__pyx_v_use_na_value) {
          } else {
            __pyx_t_9 = __pyx_v_use_na_value;
            goto __pyx_L21_bool_binop_done;
          }
          __pyx_t_10 = __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_uint8_t(__pyx_v_val, __pyx_v_na_value2); if (unlikely(__pyx_t_10 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 6070, __pyx_L13_error)
          __pyx_t_9 = __pyx_t_10;
          __pyx_L21_bool_binop_done:;

          /* "pandas/_libs/hashtable_class_helper.pxi":6068
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_uint8_t(val) or
 *                    (use_na_value and are_equivalent_uint8_t(val, na_value2))
 */
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":6075
 *                     # ignore_na is True), skip the hashtable entry for them,
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 6075, __pyx_L13_error) }
            __pyx_t_16 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_16)) )) = __pyx_v_na_sentinel;

            /* "pandas/_libs/hashtable_class_helper.pxi":6076
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel
 *                     continue             # <<<<<<<<<<<<<<
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 */
            goto __pyx_L15_continue;

            /* "pandas/_libs/hashtable_class_helper.pxi":6068
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_uint8_t(val) or
 *                    (use_na_value and are_equivalent_uint8_t(val, na_value2))
 */
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":6077
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          __pyx_t_10 = (!__pyx_v_ignore_na);
          if (__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L25_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_result_mask;
          __pyx_L25_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":6078
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 6078, __pyx_L13_error) }
            __pyx_t_16 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_16 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":6079
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_class_helper.pxi":6080
 *                     if mask_values[i]:
 *                         if seen_na:
 *                             continue             # <<<<<<<<<<<<<<
 * 
 *                         seen_na = True
 */
                goto __pyx_L15_continue;

                /* "pandas/_libs/hashtable_class_helper.pxi":6079
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":6082
 *                             continue
 * 
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         if needs_resize(ud):
 *                             with gil:
 */
              __pyx_v_seen_na = 1;

              /* "pandas/_libs/hashtable_class_helper.pxi":6083
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              __pyx_t_9 = __pyx_fuse_7__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 6083, __pyx_L13_error)
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_class_helper.pxi":6084
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                {
                    #ifdef WITH_THREAD
                    PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                    #endif
                    /*try:*/ {

                      /* "pandas/_libs/hashtable_class_helper.pxi":6085
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":6086
 *                             with gil:
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6086, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 6086, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":6085
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":6089
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6089, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":6090
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":6091
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6091, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 6091, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":6090
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":6094
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                         append_data_uint8(ud, val)
 *                         append_data_uint8(rmd, 1)
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6094, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":6084
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    /*finally:*/ {
                      /*normal exit:*/{
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L34;
                      }
                      __pyx_L33_error: {
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L13_error;
                      }
                      __pyx_L34:;
                    }
                }

                /* "pandas/_libs/hashtable_class_helper.pxi":6083
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":6095
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                         append_data_uint8(ud, val)             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 1)
 *                         continue
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 6095, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":6096
 *                                 result_mask.resize()
 *                         append_data_uint8(ud, val)
 *                         append_data_uint8(rmd, 1)             # <<<<<<<<<<<<<<
 *                         continue
 * 
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 1); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 6096, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":6097
 *                         append_data_uint8(ud, val)
 *                         append_data_uint8(rmd, 1)
 *                         continue             # <<<<<<<<<<<<<<
 * 
 *                 k = kh_get_uint8(self.table, val)
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":6078
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":6077
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          }
          __pyx_L17:;

          /* "pandas/_libs/hashtable_class_helper.pxi":6099
 *                         continue
 * 
 *                 k = kh_get_uint8(self.table, val)             # <<<<<<<<<<<<<<
 * 
 *                 if k == self.table.n_buckets:
 */
          __pyx_v_k = kh_get_uint8(__pyx_v_self->table, __pyx_v_val);

          /* "pandas/_libs/hashtable_class_helper.pxi":6101
 *                 k = kh_get_uint8(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_uint8(self.table, val, &ret)
 */
          __pyx_t_9 = (__pyx_v_k == __pyx_v_self->table->n_buckets);
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":6103
 *                 if k == self.table.n_buckets:
 *                     # k hasn't been seen yet
 *                     k = kh_put_uint8(self.table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *                     if needs_resize(ud):
 */
            __pyx_v_k = kh_put_uint8(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":6105
 *                     k = kh_put_uint8(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            __pyx_t_9 = __pyx_fuse_7__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 6105, __pyx_L13_error)
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":6106
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
              {
                  #ifdef WITH_THREAD
                  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                  #endif
                  /*try:*/ {

                    /* "pandas/_libs/hashtable_class_helper.pxi":6107
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":6108
 *                         with gil:
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 */
                      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6108, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                      __PYX_ERR(2, 6108, __pyx_L42_error)

                      /* "pandas/_libs/hashtable_class_helper.pxi":6107
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":6111
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()             # <<<<<<<<<<<<<<
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 */
                    __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6111, __pyx_L42_error)
                    __Pyx_GOTREF(__pyx_t_6);
                    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                    /* "pandas/_libs/hashtable_class_helper.pxi":6112
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    if (__pyx_v_use_result_mask) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":6113
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":6114
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6114, __pyx_L42_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 6114, __pyx_L42_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":6113
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":6117
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                     append_data_uint8(ud, val)
 *                     if use_result_mask:
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6117, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":6112
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    }
                  }

                  /* "pandas/_libs/hashtable_class_helper.pxi":6106
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
                  /*finally:*/ {
                    /*normal exit:*/{
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L43;
                    }
                    __pyx_L42_error: {
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L13_error;
                    }
                    __pyx_L43:;
                  }
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":6105
 *                     k = kh_put_uint8(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":6118
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                     append_data_uint8(ud, val)             # <<<<<<<<<<<<<<
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)
 */
            __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 6118, __pyx_L13_error)

            /* "pandas/_libs/hashtable_class_helper.pxi":6119
 *                                 result_mask.resize()
 *                     append_data_uint8(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            if (__pyx_v_use_result_mask) {

              /* "pandas/_libs/hashtable_class_helper.pxi":6120
 *                     append_data_uint8(ud, val)
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)             # <<<<<<<<<<<<<<
 * 
 *                     if return_inverse:
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 0); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 6120, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":6119
 *                                 result_mask.resize()
 *                     append_data_uint8(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":6122
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            if (__pyx_v_return_inverse) {

              /* "pandas/_libs/hashtable_class_helper.pxi":6123
 * 
 *                     if return_inverse:
 *                         self.table.vals[k] = count             # <<<<<<<<<<<<<<
 *                         labels[i] = count
 *                         count += 1
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":6124
 *                     if return_inverse:
 *                         self.table.vals[k] = count
 *                         labels[i] = count             # <<<<<<<<<<<<<<
 *                         count += 1
 *                 elif return_inverse:
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 6124, __pyx_L13_error) }
              __pyx_t_16 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_16)) )) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":6125
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 *                         count += 1             # <<<<<<<<<<<<<<
 *                 elif return_inverse:
 *                     # k falls into a previous bucket
 */
              __pyx_v_count = (__pyx_v_count + 1);

              /* "pandas/_libs/hashtable_class_helper.pxi":6122
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":6101
 *                 k = kh_get_uint8(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_uint8(self.table, val, &ret)
 */
            goto __pyx_L37;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":6126
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          if (__pyx_v_return_inverse) {

            /* "pandas/_libs/hashtable_class_helper.pxi":6129
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     labels[i] = idx
 * 
 */
            __pyx_v_idx = (__pyx_v_self->table->vals[__pyx_v_k]);

            /* "pandas/_libs/hashtable_class_helper.pxi":6130
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]
 *                     labels[i] = idx             # <<<<<<<<<<<<<<
 * 
 *         if return_inverse:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 6130, __pyx_L13_error) }
            __pyx_t_16 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_16)) )) = __pyx_v_idx;

            /* "pandas/_libs/hashtable_class_helper.pxi":6126
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          }
          __pyx_L37:;
          __pyx_L15_continue:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":6060
 *             na_value2 = (0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = (values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L14;
        }
        __pyx_L13_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L14:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6132
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6133
 * 
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray             # <<<<<<<<<<<<<<
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundLocalError("labels"); __PYX_ERR(2, 6133, __pyx_L1_error) }
    __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_labels, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_base); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6133, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_6);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_6)) __PYX_ERR(2, 6133, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4)) __PYX_ERR(2, 6133, __pyx_L1_error);
    __pyx_t_6 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":6132
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6134
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  if (__pyx_v_use_result_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6135
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()             # <<<<<<<<<<<<<<
 *         return uniques.to_array()
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6135, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->to_array(__pyx_v_result_mask, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6135, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6135, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2)) __PYX_ERR(2, 6135, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4)) __PYX_ERR(2, 6135, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":6134
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6136
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()             # <<<<<<<<<<<<<<
 * 
 *     def unique(self, const uint8_t[:] values, bint return_inverse=False, object mask=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6136, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5973
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const uint8_t[:] values, UInt8Vector uniques,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_12, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_labels, 1);
  __Pyx_XDECREF((PyObject *)__pyx_v_result_mask);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask_values, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6138
 *         return uniques.to_array()
 * 
 *     def unique(self, const uint8_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_27unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14UInt8HashTable_26unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[uint8]\n            Array of values of which unique will be calculated\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n\n        Returns\n        -------\n        uniques : ndarray[uint8]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if mask is given as input\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_27unique = {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_27unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14UInt8HashTable_26unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_27unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_return_inverse;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_return_inverse,&__pyx_n_s_mask,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6138, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6138, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6138, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "unique") < 0)) __PYX_ERR(2, 6138, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 6138, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 6138, __pyx_L3_error)
    } else {
      __pyx_v_return_inverse = ((int)0);
    }
    __pyx_v_mask = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("unique", 0, 1, 3, __pyx_nargs); __PYX_ERR(2, 6138, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_26unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_return_inverse, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_26unique(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_uniques = NULL;
  int __pyx_v_use_result_mask;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":6162
 *             The mask for the result values.
 *         """
 *         uniques = UInt8Vector()             # <<<<<<<<<<<<<<
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6162, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6163
 *         """
 *         uniques = UInt8Vector()
 *         use_result_mask = True if mask is not None else False             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 */
  __pyx_t_3 = (__pyx_v_mask != Py_None);
  if (__pyx_t_3) {
    __pyx_t_2 = 1;
  } else {
    __pyx_t_2 = 0;
  }
  __pyx_v_use_result_mask = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":6164
 *         uniques = UInt8Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4)) __PYX_ERR(2, 6164, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 6164, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ignore_na, Py_False) < 0) __PYX_ERR(2, 6164, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6165
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const uint8_t[:] values, Py_ssize_t na_sentinel=-1,
 */
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_return_inverse); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return_inverse, __pyx_t_6) < 0) __PYX_ERR(2, 6164, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 6164, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_use_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_use_result_mask, __pyx_t_6) < 0) __PYX_ERR(2, 6164, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6164
 *         uniques = UInt8Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6164, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6138
 *         return uniques.to_array()
 * 
 *     def unique(self, const uint8_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6167
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const uint8_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_29factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14UInt8HashTable_28factorize, "\n        Calculate unique values and labels (no sorting!)\n\n        Missing values are not included in the \"uniques\" for this method.\n        The labels for any missing values will be set to \"na_sentinel\"\n\n        Parameters\n        ----------\n        values : ndarray[uint8]\n            Array of values of which unique will be calculated\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n\n        Returns\n        -------\n        uniques : ndarray[uint8]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t]\n            The labels from values to uniques\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_29factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_29factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14UInt8HashTable_28factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_29factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  PyObject *__pyx_v_ignore_na = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,&__pyx_n_s_ignore_na,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":6168
 * 
 *     def factorize(self, const uint8_t[:] values, Py_ssize_t na_sentinel=-1,
 *                   object na_value=None, object mask=None, ignore_na=True):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_True));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6167, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6167, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6167, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6167, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6167, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 6167, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 6167, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 6167, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
    __pyx_v_ignore_na = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 5, __pyx_nargs); __PYX_ERR(2, 6167, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_28factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask, __pyx_v_ignore_na);

  /* "pandas/_libs/hashtable_class_helper.pxi":6167
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const uint8_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_28factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_uniques_vector = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":6198
 *             The labels from values to uniques
 *         """
 *         uniques_vector = UInt8Vector()             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6198, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques_vector = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6199
 *         """
 *         uniques_vector = UInt8Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 6199, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques_vector);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques_vector))) __PYX_ERR(2, 6199, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 6199, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6200
 *         uniques_vector = UInt8Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,             # <<<<<<<<<<<<<<
 *                             return_inverse=True)
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 6199, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, __pyx_v_ignore_na) < 0) __PYX_ERR(2, 6199, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 6199, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6201
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)             # <<<<<<<<<<<<<<
 * 
 *     def get_labels(self, const uint8_t[:] values, UInt8Vector uniques,
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 6199, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6199
 *         """
 *         uniques_vector = UInt8Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6199, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6167
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const uint8_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6203
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const uint8_t[:] values, UInt8Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_31get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_31get_labels = {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_31get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_31get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_labels (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":6205
 *     def get_labels(self, const uint8_t[:] values, UInt8Vector uniques,
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6203, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6203, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, 1); __PYX_ERR(2, 6203, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6203, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6203, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6203, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6203, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_labels") < 0)) __PYX_ERR(2, 6203, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 6203, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 6204, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 6204, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    __pyx_v_mask = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, __pyx_nargs); __PYX_ERR(2, 6203, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector, 1, "uniques", 0))) __PYX_ERR(2, 6203, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_30get_labels(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":6203
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const uint8_t[:] values, UInt8Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_30get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_v_labels = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_labels", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":6207
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 6207, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 6207, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_count_prior); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_count_prior, __pyx_t_4) < 0) __PYX_ERR(2, 6207, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6208
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,             # <<<<<<<<<<<<<<
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 6207, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 6207, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6209
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, Py_True) < 0) __PYX_ERR(2, 6207, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 6207, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 6207, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6207
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6207, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
    PyObject* sequence = __pyx_t_4;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(2, 6207, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6207, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
    index = 0; __pyx_t_2 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_1), 2) < 0) __PYX_ERR(2, 6207, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(2, 6207, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v__ = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_labels = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6210
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_labels);
  __pyx_r = __pyx_v_labels;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6203
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const uint8_t[:] values, UInt8Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XDECREF(__pyx_v_labels);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_33__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_33__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_33__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_33__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_32__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_32__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_35__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_35__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_35__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_35__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_34__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14UInt8HashTable_34__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6219
 *         UInt8Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = UInt8HashTable(size_hint)
 *         self.uniques = UInt8Vector()
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_size_hint = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6219, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 6219, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_size_hint = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 6219, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_size_hint), (&PyInt_Type), 0, "size_hint", 1))) __PYX_ERR(2, 6219, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *)__pyx_v_self), __pyx_v_size_hint);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":6220
 * 
 *     def __cinit__(self, size_hint: int):
 *         self.table = UInt8HashTable(size_hint)             # <<<<<<<<<<<<<<
 *         self.uniques = UInt8Vector()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable), __pyx_v_size_hint); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6221
 *     def __cinit__(self, size_hint: int):
 *         self.table = UInt8HashTable(size_hint)
 *         self.uniques = UInt8Vector()             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const uint8_t[:] values,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6219
 *         UInt8Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = UInt8HashTable(size_hint)
 *         self.uniques = UInt8Vector()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6223
 *         self.uniques = UInt8Vector()
 * 
 *     def factorize(self, const uint8_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15UInt8Factorizer_2factorize, "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = UInt8Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"uint8\"), na_sentinel=20)\n        array([0, 1, 2])\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt8Factorizer_3factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt8Factorizer_2factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_v_na_sentinel = 0;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_neg_1));

    /* "pandas/_libs/hashtable_class_helper.pxi":6224
 * 
 *     def factorize(self, const uint8_t[:] values,
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:             # <<<<<<<<<<<<<<
 *         """
 *         Returns
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6223, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6223, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6223, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6223, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 6223, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 6223, __pyx_L3_error)
    __pyx_v_na_sentinel = values[1];
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 4, __pyx_nargs); __PYX_ERR(2, 6223, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_2factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":6223
 *         self.uniques = UInt8Vector()
 * 
 *     def factorize(self, const uint8_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  PyArrayObject *__pyx_v_labels = 0;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_uniques = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_labels;
  __Pyx_Buffer __pyx_pybuffer_labels;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);
  __pyx_pybuffer_labels.pybuffer.buf = NULL;
  __pyx_pybuffer_labels.refcount = 0;
  __pyx_pybuffernd_labels.data = NULL;
  __pyx_pybuffernd_labels.rcbuffer = &__pyx_pybuffer_labels;

  /* "pandas/_libs/hashtable_class_helper.pxi":6241
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = UInt8Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  if (__pyx_v_self->uniques->__pyx_base.external_view_exists) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6242
 * 
 *         if self.uniques.external_view_exists:
 *             uniques = UInt8Vector()             # <<<<<<<<<<<<<<
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 */
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6242, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":6243
 *         if self.uniques.external_view_exists:
 *             uniques = UInt8Vector()
 *             uniques.extend(self.uniques.to_array())             # <<<<<<<<<<<<<<
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 */
    __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_self->uniques->__pyx_vtab)->to_array(__pyx_v_self->uniques, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6243, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(__pyx_t_1, 0); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(2, 6243, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_uniques->__pyx_vtab)->extend(__pyx_v_uniques, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6243, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
    __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":6244
 *             uniques = UInt8Vector()
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques             # <<<<<<<<<<<<<<
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 */
    __Pyx_INCREF((PyObject *)__pyx_v_uniques);
    __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
    __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
    __pyx_v_self->uniques = __pyx_v_uniques;

    /* "pandas/_libs/hashtable_class_helper.pxi":6241
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = UInt8Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6245
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->table), __pyx_n_s_get_labels); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "pandas/_libs/hashtable_class_helper.pxi":6246
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,             # <<<<<<<<<<<<<<
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_self->__pyx_base.count); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "pandas/_libs/hashtable_class_helper.pxi":6245
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_5 = PyTuple_New(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3)) __PYX_ERR(2, 6245, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self->uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_self->uniques))) __PYX_ERR(2, 6245, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_4)) __PYX_ERR(2, 6245, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_na_sentinel);
  __Pyx_GIVEREF(__pyx_v_na_sentinel);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_v_na_sentinel)) __PYX_ERR(2, 6245, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6247
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)             # <<<<<<<<<<<<<<
 *         self.count = len(self.uniques)
 *         return labels
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 6247, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 6247, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6245
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 6245, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
    __pyx_t_7 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_7 < 0)) {
      PyErr_Fetch(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_v_labels, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      }
      __pyx_t_8 = __pyx_t_9 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_labels.diminfo[0].strides = __pyx_pybuffernd_labels.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_labels.diminfo[0].shape = __pyx_pybuffernd_labels.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(2, 6245, __pyx_L1_error)
  }
  __pyx_t_6 = 0;
  __pyx_v_labels = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6248
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  __pyx_t_3 = ((PyObject *)__pyx_v_self->uniques);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_11 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(2, 6248, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_self->__pyx_base.count = __pyx_t_11;

  /* "pandas/_libs/hashtable_class_helper.pxi":6249
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * cdef class Int8HashTable(HashTable):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_labels);
  __pyx_r = ((PyObject *)__pyx_v_labels);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6223
 *         self.uniques = UInt8Vector()
 * 
 *     def factorize(self, const uint8_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_labels);
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6216
 * cdef class UInt8Factorizer(Factorizer):
 *     cdef public:
 *         UInt8HashTable table             # <<<<<<<<<<<<<<
 *         UInt8Vector uniques
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_5table_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_5table_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_5table___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->table);
  __pyx_r = ((PyObject *)__pyx_v_self->table);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_5table_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable))))) __PYX_ERR(2, 6216, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8Factorizer.table.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_5table_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_5table_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_5table_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6217
 *     cdef public:
 *         UInt8HashTable table
 *         UInt8Vector uniques             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, size_hint: int):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_7uniques_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_7uniques_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_7uniques___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __pyx_r = ((PyObject *)__pyx_v_self->uniques);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_7uniques_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector))))) __PYX_ERR(2, 6217, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8Factorizer.uniques.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_7uniques_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_7uniques_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_7uniques_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt8Factorizer_5__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_4__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8Factorizer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15UInt8Factorizer_7__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_6__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15UInt8Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.UInt8Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6253
 * cdef class Int8HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_int8()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __pyx_t_5numpy_int64_t __pyx_v_size_hint;
  int __pyx_v_uses_mask;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,&__pyx_n_s_uses_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6253, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uses_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6253, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 6253, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_size_hint = __Pyx_PyInt_As_npy_int64(values[0]); if (unlikely((__pyx_v_size_hint == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 6253, __pyx_L3_error)
    } else {
      __pyx_v_size_hint = ((__pyx_t_5numpy_int64_t)1);
    }
    if (values[1]) {
      __pyx_v_uses_mask = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_uses_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 6253, __pyx_L3_error)
    } else {
      __pyx_v_uses_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 0, 2, __pyx_nargs); __PYX_ERR(2, 6253, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)__pyx_v_self), __pyx_v_size_hint, __pyx_v_uses_mask);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint, int __pyx_v_uses_mask) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  khuint_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __pyx_t_5numpy_int64_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":6254
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_int8()             # <<<<<<<<<<<<<<
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_int8(self.table, size_hint)
 */
  __pyx_v_self->table = kh_init_int8();

  /* "pandas/_libs/hashtable_class_helper.pxi":6255
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):
 *         self.table = kh_init_int8()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)             # <<<<<<<<<<<<<<
 *         kh_resize_int8(self.table, size_hint)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = kh_needed_n_buckets(__pyx_v_size_hint);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6255, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_1, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6255, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(2, 6255, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_6) {
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_5 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6255, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_int64(__pyx_t_3); if (unlikely((__pyx_t_7 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 6255, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_size_hint = __pyx_t_7;

  /* "pandas/_libs/hashtable_class_helper.pxi":6256
 *         self.table = kh_init_int8()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_int8(self.table, size_hint)             # <<<<<<<<<<<<<<
 * 
 *         self.uses_mask = uses_mask
 */
  kh_resize_int8(__pyx_v_self->table, __pyx_v_size_hint);

  /* "pandas/_libs/hashtable_class_helper.pxi":6258
 *         kh_resize_int8(self.table, size_hint)
 * 
 *         self.uses_mask = uses_mask             # <<<<<<<<<<<<<<
 *         self.na_position = -1
 * 
 */
  __pyx_v_self->uses_mask = __pyx_v_uses_mask;

  /* "pandas/_libs/hashtable_class_helper.pxi":6259
 * 
 *         self.uses_mask = uses_mask
 *         self.na_position = -1             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
  __pyx_v_self->na_position = -1LL;

  /* "pandas/_libs/hashtable_class_helper.pxi":6253
 * cdef class Int8HashTable(HashTable):
 * 
 *     def __cinit__(self, int64_t size_hint=1, bint uses_mask=False):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_int8()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6261
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_3__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_3__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_2__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_2__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self) {
  Py_ssize_t __pyx_r;
  long __pyx_t_1;
  int __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":6262
 * 
 *     def __len__(self) -> int:
 *         return self.table.size + (0 if self.na_position == -1 else 1)             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_t_2 = (__pyx_v_self->na_position == -1LL);
  if (__pyx_t_2) {
    __pyx_t_1 = 0;
  } else {
    __pyx_t_1 = 1;
  }
  __pyx_r = (__pyx_v_self->table->size + __pyx_t_1);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6261
 *         self.na_position = -1
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6264
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_int8(self.table)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_5__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_5__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_4__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_4__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":6265
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_int8(self.table)
 *             self.table = NULL
 */
  __pyx_t_1 = (__pyx_v_self->table != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6266
 *     def __dealloc__(self):
 *         if self.table is not NULL:
 *             kh_destroy_int8(self.table)             # <<<<<<<<<<<<<<
 *             self.table = NULL
 * 
 */
    kh_destroy_int8(__pyx_v_self->table);

    /* "pandas/_libs/hashtable_class_helper.pxi":6267
 *         if self.table is not NULL:
 *             kh_destroy_int8(self.table)
 *             self.table = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __contains__(self, object key) -> bool:
 */
    __pyx_v_self->table = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":6265
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_int8(self.table)
 *             self.table = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6264
 *         return self.table.size + (0 if self.na_position == -1 else 1)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_int8(self.table)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":6269
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__contains__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_6__contains__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)__pyx_v_self), ((PyObject *)__pyx_v_key));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, PyObject *__pyx_v_key) {
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int8_t __pyx_v_ckey;
  int __pyx_r;
  int __pyx_t_1;
  int __pyx_t_2;
  __pyx_t_5numpy_int8_t __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6276
 *             int8_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_1 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = __pyx_f_6pandas_5_libs_7missing_checknull(__pyx_v_key, 0, NULL); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6276, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6277
 * 
 *         if self.uses_mask and checknull(key):
 *             return -1 != self.na_position             # <<<<<<<<<<<<<<
 * 
 *         ckey = (key)
 */
    __pyx_r = (-1LL != __pyx_v_self->na_position);
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":6276
 *             int8_t ckey
 * 
 *         if self.uses_mask and checknull(key):             # <<<<<<<<<<<<<<
 *             return -1 != self.na_position
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6279
 *             return -1 != self.na_position
 * 
 *         ckey = (key)             # <<<<<<<<<<<<<<
 *         k = kh_get_int8(self.table, ckey)
 *         return k != self.table.n_buckets
 */
  __pyx_t_3 = __Pyx_PyInt_As_npy_int8(__pyx_v_key); if (unlikely((__pyx_t_3 == ((npy_int8)-1)) && PyErr_Occurred())) __PYX_ERR(2, 6279, __pyx_L1_error)
  __pyx_v_ckey = __pyx_t_3;

  /* "pandas/_libs/hashtable_class_helper.pxi":6280
 * 
 *         ckey = (key)
 *         k = kh_get_int8(self.table, ckey)             # <<<<<<<<<<<<<<
 *         return k != self.table.n_buckets
 * 
 */
  __pyx_v_k = kh_get_int8(__pyx_v_self->table, __pyx_v_ckey);

  /* "pandas/_libs/hashtable_class_helper.pxi":6281
 *         ckey = (key)
 *         k = kh_get_int8(self.table, ckey)
 *         return k != self.table.n_buckets             # <<<<<<<<<<<<<<
 * 
 *     def sizeof(self, deep: bool = False) -> int:
 */
  __pyx_r = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6269
 *             self.table = NULL
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         # The caller is responsible to check for compatible NA values in case
 *         # of masked arrays.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6283
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_13Int8HashTable_8sizeof, " return the size of my table in bytes ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_9sizeof = {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_13Int8HashTable_8sizeof};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_deep = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sizeof (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_deep,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_deep);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6283, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "sizeof") < 0)) __PYX_ERR(2, 6283, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_deep = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sizeof", 0, 0, 1, __pyx_nargs); __PYX_ERR(2, 6283, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_8sizeof(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)__pyx_v_self), __pyx_v_deep);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep) {
  PyObject *__pyx_v_overhead = NULL;
  PyObject *__pyx_v_for_flags = NULL;
  PyObject *__pyx_v_for_pairs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  long __pyx_t_2;
  long __pyx_t_3;
  long __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sizeof", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":6285
 *     def sizeof(self, deep: bool = False) -> int:
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)             # <<<<<<<<<<<<<<
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(int8_t) + # keys
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(((4 * (sizeof(__pyx_t_5numpy_uint32_t))) + (3 * (sizeof(__pyx_t_5numpy_uint32_t *))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_overhead = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6286
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)             # <<<<<<<<<<<<<<
 *         for_pairs =  self.table.n_buckets * (sizeof(int8_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 */
  __pyx_t_2 = (__pyx_v_self->table->n_buckets >> 5);
  __pyx_t_3 = 1;
  __pyx_t_5 = (__pyx_t_2 > __pyx_t_3);
  if (__pyx_t_5) {
    __pyx_t_4 = __pyx_t_2;
  } else {
    __pyx_t_4 = __pyx_t_3;
  }
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_t_4 * (sizeof(__pyx_t_5numpy_uint32_t)))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6286, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_flags = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6287
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(int8_t) + # keys             # <<<<<<<<<<<<<<
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->n_buckets * ((sizeof(__pyx_t_5numpy_int8_t)) + (sizeof(Py_ssize_t))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6287, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_pairs = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6289
 *         for_pairs =  self.table.n_buckets * (sizeof(int8_t) + # keys
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs             # <<<<<<<<<<<<<<
 * 
 *     def get_state(self) -> dict[str, int]:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Add(__pyx_v_overhead, __pyx_v_for_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyNumber_Add(__pyx_t_1, __pyx_v_for_pairs); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(__Pyx_Py3Int_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None) || __Pyx_RaiseUnexpectedTypeError("int", __pyx_t_6))) __PYX_ERR(2, 6289, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6283
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_overhead);
  __Pyx_XDECREF(__pyx_v_for_flags);
  __Pyx_XDECREF(__pyx_v_for_pairs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6291
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_13Int8HashTable_10get_state, " returns infos about the state of the hashtable");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_11get_state = {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_13Int8HashTable_10get_state};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_state (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_state", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_state", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_10get_state(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_state", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":6293
 *     def get_state(self) -> dict[str, int]:
 *         """ returns infos about the state of the hashtable"""
 *         return {             # <<<<<<<<<<<<<<
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 */
  __Pyx_XDECREF(__pyx_r);

  /* "pandas/_libs/hashtable_class_helper.pxi":6294
 *         """ returns infos about the state of the hashtable"""
 *         return {
 *             'n_buckets' : self.table.n_buckets,             # <<<<<<<<<<<<<<
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_buckets); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6294, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_buckets, __pyx_t_2) < 0) __PYX_ERR(2, 6294, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6295
 *         return {
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,             # <<<<<<<<<<<<<<
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->size); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_size, __pyx_t_2) < 0) __PYX_ERR(2, 6294, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6296
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,             # <<<<<<<<<<<<<<
 *             'upper_bound' : self.table.upper_bound,
 *         }
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_occupied); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6296, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_occupied, __pyx_t_2) < 0) __PYX_ERR(2, 6294, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6297
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,             # <<<<<<<<<<<<<<
 *         }
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->upper_bound); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6297, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_upper_bound, __pyx_t_2) < 0) __PYX_ERR(2, 6294, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6291
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.get_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6300
 *         }
 * 
 *     cpdef get_item(self, int8_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_13Int8HashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, __pyx_t_5numpy_int8_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int8_t __pyx_v_cval;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6300, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_13get_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyInt_From_npy_int8(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6300, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6300, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6319
 *             int8_t cval
 * 
 *         cval = (val)             # <<<<<<<<<<<<<<
 *         k = kh_get_int8(self.table, cval)
 *         if k != self.table.n_buckets:
 */
  __pyx_v_cval = __pyx_v_val;

  /* "pandas/_libs/hashtable_class_helper.pxi":6320
 * 
 *         cval = (val)
 *         k = kh_get_int8(self.table, cval)             # <<<<<<<<<<<<<<
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]
 */
  __pyx_v_k = kh_get_int8(__pyx_v_self->table, __pyx_v_cval);

  /* "pandas/_libs/hashtable_class_helper.pxi":6321
 *         cval = (val)
 *         k = kh_get_int8(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  __pyx_t_7 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  if (likely(__pyx_t_7)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6322
 *         k = kh_get_int8(self.table, cval)
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(val)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->vals[__pyx_v_k])); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6322, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":6321
 *         cval = (val)
 *         k = kh_get_int8(self.table, cval)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6324
 *             return self.table.vals[k]
 *         else:
 *             raise KeyError(val)             # <<<<<<<<<<<<<<
 * 
 *     cpdef get_na(self):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyInt_From_npy_int8(__pyx_v_val); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6324, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6324, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 6324, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6300
 *         }
 * 
 *     cpdef get_item(self, int8_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_13Int8HashTable_12get_item, "Extracts the position of val from the hashtable.\n\n        Parameters\n        ----------\n        val : Scalar\n            The value that is looked up in the hashtable\n\n        Returns\n        -------\n        The position of the requested integer.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_13get_item = {"get_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_13get_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_13Int8HashTable_12get_item};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_5numpy_int8_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6300, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_item") < 0)) __PYX_ERR(2, 6300, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __Pyx_PyInt_As_npy_int8(values[0]); if (unlikely((__pyx_v_val == ((npy_int8)-1)) && PyErr_Occurred())) __PYX_ERR(2, 6300, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_item", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 6300, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_12get_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, __pyx_t_5numpy_int8_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_13Int8HashTable_get_item(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6326
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_13Int8HashTable_get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6326, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_15get_na)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, NULL};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 0+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6326, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6334
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_6 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6335
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         if self.na_position == -1:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 6335, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":6334
 *         """
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6337
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  __pyx_t_6 = (__pyx_v_self->na_position == -1LL);
  if (unlikely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6338
 * 
 *         if self.na_position == -1:
 *             raise KeyError("NA")             # <<<<<<<<<<<<<<
 *         return self.na_position
 * 
 */
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_builtin_KeyError, __pyx_tuple__13, NULL); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6338, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(2, 6338, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":6337
 *             raise NotImplementedError
 * 
 *         if self.na_position == -1:             # <<<<<<<<<<<<<<
 *             raise KeyError("NA")
 *         return self.na_position
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6339
 *         if self.na_position == -1:
 *             raise KeyError("NA")
 *         return self.na_position             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_item(self, int8_t key, Py_ssize_t val):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_npy_int64(__pyx_v_self->na_position); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6339, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6326
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_13Int8HashTable_14get_na, "Extracts the position of na_value from the hashtable.\n\n        Returns\n        -------\n        The position of the last na value.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_15get_na = {"get_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_15get_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_13Int8HashTable_14get_na};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_15get_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_na", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_na", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_14get_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_14get_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_13Int8HashTable_get_na(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.get_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6341
 *         return self.na_position
 * 
 *     cpdef set_item(self, int8_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_13Int8HashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, __pyx_t_5numpy_int8_t __pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  __pyx_t_5numpy_int8_t __pyx_v_ckey;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6341, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_17set_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = __Pyx_PyInt_From_npy_int8(__pyx_v_key); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6341, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6341, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_5 = __pyx_t_1; __pyx_t_6 = NULL;
        __pyx_t_7 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_5))) {
          __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_5);
          if (likely(__pyx_t_6)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
            __Pyx_INCREF(__pyx_t_6);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_5, function);
            __pyx_t_7 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_6, __pyx_t_3, __pyx_t_4};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_7, 2+__pyx_t_7);
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6341, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6346
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             int8_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6349
 *             int8_t ckey
 * 
 *         ckey = (key)             # <<<<<<<<<<<<<<
 *         k = kh_put_int8(self.table, ckey, &ret)
 *         if kh_exist_int8(self.table, k):
 */
  __pyx_v_ckey = __pyx_v_key;

  /* "pandas/_libs/hashtable_class_helper.pxi":6350
 * 
 *         ckey = (key)
 *         k = kh_put_int8(self.table, ckey, &ret)             # <<<<<<<<<<<<<<
 *         if kh_exist_int8(self.table, k):
 *             self.table.vals[k] = val
 */
  __pyx_v_k = kh_put_int8(__pyx_v_self->table, __pyx_v_ckey, (&__pyx_v_ret));

  /* "pandas/_libs/hashtable_class_helper.pxi":6351
 *         ckey = (key)
 *         k = kh_put_int8(self.table, ckey, &ret)
 *         if kh_exist_int8(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
  __pyx_t_8 = kh_exist_int8(__pyx_v_self->table, __pyx_v_k);
  if (likely(__pyx_t_8)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6352
 *         k = kh_put_int8(self.table, ckey, &ret)
 *         if kh_exist_int8(self.table, k):
 *             self.table.vals[k] = val             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(key)
 */
    (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_val;

    /* "pandas/_libs/hashtable_class_helper.pxi":6351
 *         ckey = (key)
 *         k = kh_put_int8(self.table, ckey, &ret)
 *         if kh_exist_int8(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6354
 *             self.table.vals[k] = val
 *         else:
 *             raise KeyError(key)             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_na(self, Py_ssize_t val):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyInt_From_npy_int8(__pyx_v_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6354, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6354, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(2, 6354, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "pandas/_libs/hashtable_class_helper.pxi":6341
 *         return self.na_position
 * 
 *     cpdef set_item(self, int8_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_17set_item = {"set_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_17set_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_17set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __pyx_t_5numpy_int8_t __pyx_v_key;
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key,&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6341, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6341, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, 1); __PYX_ERR(2, 6341, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_item") < 0)) __PYX_ERR(2, 6341, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_key = __Pyx_PyInt_As_npy_int8(values[0]); if (unlikely((__pyx_v_key == ((npy_int8)-1)) && PyErr_Occurred())) __PYX_ERR(2, 6341, __pyx_L3_error)
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 6341, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, __pyx_nargs); __PYX_ERR(2, 6341, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_16set_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)__pyx_v_self), __pyx_v_key, __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_16set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, __pyx_t_5numpy_int8_t __pyx_v_key, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_13Int8HashTable_set_item(__pyx_v_self, __pyx_v_key, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6356
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_13Int8HashTable_set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  CYTHON_UNUSED int __pyx_v_ret;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_na); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6356, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_19set_na)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6356, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_5, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 1+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6356, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6360
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             int8_t ckey
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6363
 *             int8_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  __pyx_t_7 = (!__pyx_v_self->uses_mask);
  if (unlikely(__pyx_t_7)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6364
 * 
 *         if not self.uses_mask:
 *             raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 *         self.na_position = val
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 6364, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":6363
 *             int8_t ckey
 * 
 *         if not self.uses_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6366
 *             raise NotImplementedError
 * 
 *         self.na_position = val             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->na_position = __pyx_v_val;

  /* "pandas/_libs/hashtable_class_helper.pxi":6356
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_19set_na = {"set_na", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_19set_na, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_19set_na(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_na (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6356, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_na") < 0)) __PYX_ERR(2, 6356, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[0]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 6356, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_na", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 6356, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_18set_na(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_18set_na(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_na", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_13Int8HashTable_set_na(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.set_na", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6369
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const int8_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_21map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_21map_locations = {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_21map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_21map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("map_locations (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6369, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6369, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "map_locations") < 0)) __PYX_ERR(2, 6369, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int8_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 6370, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 6370, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__38;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("map_locations", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 6369, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_20map_locations(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_20map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  int __pyx_v_ret;
  __pyx_t_5numpy_int8_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  __pyx_t_5numpy_int64_t __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("map_locations", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":6373
 *         # Used in libindex, safe_sort
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             int8_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":6374
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             int8_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6377
 *             int8_t val
 *             khiter_t k
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_2 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":6379
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_3 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_4 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_3 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_3)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6380
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 6380, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":6379
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6382
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":6383
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
        if (__pyx_v_self->uses_mask) {

          /* "pandas/_libs/hashtable_class_helper.pxi":6384
 *         with nogil:
 *             if self.uses_mask:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     if mask[i]:
 *                         na_position = i
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":6385
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_mask.shape[0];
            __pyx_t_3 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) ))) != 0);
            if (__pyx_t_3) {

              /* "pandas/_libs/hashtable_class_helper.pxi":6386
 *                 for i in range(n):
 *                     if mask[i]:
 *                         na_position = i             # <<<<<<<<<<<<<<
 *                     else:
 *                         val= (values[i])
 */
              __pyx_v_na_position = __pyx_v_i;

              /* "pandas/_libs/hashtable_class_helper.pxi":6385
 *             if self.uses_mask:
 *                 for i in range(n):
 *                     if mask[i]:             # <<<<<<<<<<<<<<
 *                         na_position = i
 *                     else:
 */
              goto __pyx_L12;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":6388
 *                         na_position = i
 *                     else:
 *                         val= (values[i])             # <<<<<<<<<<<<<<
 *                         k = kh_put_int8(self.table, val, &ret)
 *                         self.table.vals[k] = i
 */
            /*else*/ {
              __pyx_t_7 = __pyx_v_i;
              if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
              __pyx_v_val = (*((__pyx_t_5numpy_int8_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_class_helper.pxi":6389
 *                     else:
 *                         val= (values[i])
 *                         k = kh_put_int8(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = i
 *             else:
 */
              __pyx_v_k = kh_put_int8(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

              /* "pandas/_libs/hashtable_class_helper.pxi":6390
 *                         val= (values[i])
 *                         k = kh_put_int8(self.table, val, &ret)
 *                         self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *             else:
 *                 for i in range(n):
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
            }
            __pyx_L12:;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":6383
 * 
 *         with nogil:
 *             if self.uses_mask:             # <<<<<<<<<<<<<<
 *                 for i in range(n):
 *                     if mask[i]:
 */
          goto __pyx_L9;
        }

        /* "pandas/_libs/hashtable_class_helper.pxi":6392
 *                         self.table.vals[k] = i
 *             else:
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     val= (values[i])
 *                     k = kh_put_int8(self.table, val, &ret)
 */
        /*else*/ {
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_5 = __pyx_t_1;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pandas/_libs/hashtable_class_helper.pxi":6393
 *             else:
 *                 for i in range(n):
 *                     val= (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_put_int8(self.table, val, &ret)
 *                     self.table.vals[k] = i
 */
            __pyx_t_7 = __pyx_v_i;
            if (__pyx_t_7 < 0) __pyx_t_7 += __pyx_v_values.shape[0];
            __pyx_v_val = (*((__pyx_t_5numpy_int8_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

            /* "pandas/_libs/hashtable_class_helper.pxi":6394
 *                 for i in range(n):
 *                     val= (values[i])
 *                     k = kh_put_int8(self.table, val, &ret)             # <<<<<<<<<<<<<<
 *                     self.table.vals[k] = i
 *         self.na_position = na_position
 */
            __pyx_v_k = kh_put_int8(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":6395
 *                     val= (values[i])
 *                     k = kh_put_int8(self.table, val, &ret)
 *                     self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *         self.na_position = na_position
 * 
 */
            (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
          }
        }
        __pyx_L9:;
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":6382
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             if self.uses_mask:
 *                 for i in range(n):
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6396
 *                     k = kh_put_int8(self.table, val, &ret)
 *                     self.table.vals[k] = i
 *         self.na_position = na_position             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __pyx_v_self->na_position = __pyx_v_na_position;

  /* "pandas/_libs/hashtable_class_helper.pxi":6369
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const int8_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6398
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const int8_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

/* Python wrapper */
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_23lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_23lookup = {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_23lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_23lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyArrayObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lookup (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6398, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6398, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lookup") < 0)) __PYX_ERR(2, 6398, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int8_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 6399, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[1], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(2, 6399, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__39;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lookup", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 6398, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_22lookup(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_22lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, __Pyx_memviewslice __pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  CYTHON_UNUSED int __pyx_v_ret;
  __pyx_t_5numpy_int8_t __pyx_v_val;
  khiter_t __pyx_v_k;
  __Pyx_memviewslice __pyx_v_locs = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int8_t __pyx_v_na_position;
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lookup", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":6403
 *         # Used in safe_sort, IndexEngine.get_indexer
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             int8_t val
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":6404
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             int8_t val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6407
 *             int8_t val
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *             int8_t na_position = self.na_position
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 6407, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 6407, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 6407, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_locs = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":6408
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)
 *             int8_t na_position = self.na_position             # <<<<<<<<<<<<<<
 * 
 *         if self.uses_mask and mask is None:
 */
  __pyx_t_8 = __pyx_v_self->na_position;
  __pyx_v_na_position = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":6410
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_self->uses_mask) {
  } else {
    __pyx_t_9 = __pyx_v_self->uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_10 = (((PyObject *) __pyx_v_mask.memview) == Py_None);
  __pyx_t_9 = __pyx_t_10;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6411
 * 
 *         if self.uses_mask and mask is None:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 6411, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":6410
 *             int8_t na_position = self.na_position
 * 
 *         if self.uses_mask and mask is None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6413
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":6414
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_11 = __pyx_t_1;
        for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
          __pyx_v_i = __pyx_t_12;

          /* "pandas/_libs/hashtable_class_helper.pxi":6415
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
          if (__pyx_v_self->uses_mask) {
          } else {
            __pyx_t_9 = __pyx_v_self->uses_mask;
            goto __pyx_L12_bool_binop_done;
          }
          __pyx_t_13 = __pyx_v_i;
          if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_mask.shape[0];
          __pyx_t_10 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_13 * __pyx_v_mask.strides[0]) ))) != 0);
          __pyx_t_9 = __pyx_t_10;
          __pyx_L12_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":6416
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 *                     locs[i] = na_position             # <<<<<<<<<<<<<<
 *                 else:
 *                     val = (values[i])
 */
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = __pyx_v_na_position;

            /* "pandas/_libs/hashtable_class_helper.pxi":6415
 *         with nogil:
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     locs[i] = na_position
 *                 else:
 */
            goto __pyx_L11;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":6418
 *                     locs[i] = na_position
 *                 else:
 *                     val = (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_int8(self.table, val)
 *                     if k != self.table.n_buckets:
 */
          /*else*/ {
            __pyx_t_13 = __pyx_v_i;
            if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_values.shape[0];
            __pyx_v_val = (*((__pyx_t_5numpy_int8_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_13 * __pyx_v_values.strides[0]) )));

            /* "pandas/_libs/hashtable_class_helper.pxi":6419
 *                 else:
 *                     val = (values[i])
 *                     k = kh_get_int8(self.table, val)             # <<<<<<<<<<<<<<
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]
 */
            __pyx_v_k = kh_get_int8(__pyx_v_self->table, __pyx_v_val);

            /* "pandas/_libs/hashtable_class_helper.pxi":6420
 *                     val = (values[i])
 *                     k = kh_get_int8(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
            __pyx_t_9 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":6421
 *                     k = kh_get_int8(self.table, val)
 *                     if k != self.table.n_buckets:
 *                         locs[i] = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     else:
 *                         locs[i] = -1
 */
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = (__pyx_v_self->table->vals[__pyx_v_k]);

              /* "pandas/_libs/hashtable_class_helper.pxi":6420
 *                     val = (values[i])
 *                     k = kh_get_int8(self.table, val)
 *                     if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                         locs[i] = self.table.vals[k]
 *                     else:
 */
              goto __pyx_L14;
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":6423
 *                         locs[i] = self.table.vals[k]
 *                     else:
 *                         locs[i] = -1             # <<<<<<<<<<<<<<
 * 
 *         return np.asarray(locs)
 */
            /*else*/ {
              __pyx_t_13 = __pyx_v_i;
              if (__pyx_t_13 < 0) __pyx_t_13 += __pyx_v_locs.shape[0];
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_13)) )) = -1;
            }
            __pyx_L14:;
          }
          __pyx_L11:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":6413
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if self.uses_mask and mask[i]:
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6425
 *                         locs[i] = -1
 * 
 *         return np.asarray(locs)             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_locs, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6425, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_14 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_14 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_14, 1+__pyx_t_14);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6425, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 6425, __pyx_L1_error)
  __pyx_r = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6398
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const int8_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_locs, 1);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6427
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const int8_t[:] values, Int8Vector uniques,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_25_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_13Int8HashTable_24_unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[int8]\n            Array of values of which unique will be calculated\n        uniques : Int8Vector\n            Vector into which uniques will be written\n        count_prior : Py_ssize_t, default 0\n            Number of existing entries in uniques\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        ignore_na : bool, default False\n            Whether NA-values should be ignored for calculating the uniques. If\n            True, the labels corresponding to missing values will be set to\n            na_sentinel.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        use_result_mask: bool, default False\n            Whether to create a result mask for the unique values. Not supported\n            with return_inverse=True.\n\n        Returns\n        -------\n        uniques : ndarray[int8]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse=True)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if use_result_mask is true\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_25_unique = {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_25_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_13Int8HashTable_24_unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_25_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  int __pyx_v_ignore_na;
  PyObject *__pyx_v_mask = 0;
  int __pyx_v_return_inverse;
  int __pyx_v_use_result_mask;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[9] = {0,0,0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_ignore_na,&__pyx_n_s_mask,&__pyx_n_s_return_inverse,&__pyx_n_s_use_result_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":6431
 *     def _unique(self, const int8_t[:] values, Int8Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));

    /* "pandas/_libs/hashtable_class_helper.pxi":6432
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[6] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6427, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6427, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, 1); __PYX_ERR(2, 6427, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6427, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6427, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6427, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6427, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[6] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6427, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  7:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[7] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6427, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  8:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_use_result_mask);
          if (value) { values[8] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6427, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_unique") < 0)) __PYX_ERR(2, 6427, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  9: values[8] = __Pyx_Arg_FASTCALL(__pyx_args, 8);
        CYTHON_FALLTHROUGH;
        case  8: values[7] = __Pyx_Arg_FASTCALL(__pyx_args, 7);
        CYTHON_FALLTHROUGH;
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int8_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 6429, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 6430, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 6430, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    if (values[5]) {
      __pyx_v_ignore_na = __Pyx_PyObject_IsTrue(values[5]); if (unlikely((__pyx_v_ignore_na == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 6431, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":6431
 *     def _unique(self, const int8_t[:] values, Int8Vector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):
 *         """
 */
      __pyx_v_ignore_na = ((int)0);
    }
    __pyx_v_mask = values[6];
    if (values[7]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[7]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 6432, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":6432
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 object mask=None, bint return_inverse=False, bint use_result_mask=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
      __pyx_v_return_inverse = ((int)0);
    }
    if (values[8]) {
      __pyx_v_use_result_mask = __Pyx_PyObject_IsTrue(values[8]); if (unlikely((__pyx_v_use_result_mask == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 6432, __pyx_L3_error)
    } else {
      __pyx_v_use_result_mask = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 9, __pyx_nargs); __PYX_ERR(2, 6427, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector, 1, "uniques", 0))) __PYX_ERR(2, 6429, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_24_unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_ignore_na, __pyx_v_mask, __pyx_v_return_inverse, __pyx_v_use_result_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":6427
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const int8_t[:] values, Int8Vector uniques,
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_24_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, PyObject *__pyx_v_mask, int __pyx_v_return_inverse, int __pyx_v_use_result_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_idx;
  Py_ssize_t __pyx_v_count;
  Py_ssize_t __pyx_v_n;
  __Pyx_memviewslice __pyx_v_labels = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_ret;
  __pyx_t_5numpy_int8_t __pyx_v_val;
  __pyx_t_5numpy_int8_t __pyx_v_na_value2;
  khiter_t __pyx_v_k;
  __pyx_t_6pandas_5_libs_9hashtable_Int8VectorData *__pyx_v_ud;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_result_mask = 0;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_v_rmd;
  int __pyx_v_use_na_value;
  int __pyx_v_use_mask;
  int __pyx_v_seen_na;
  __Pyx_memviewslice __pyx_v_mask_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_6pandas_5_libs_9hashtable_Int8VectorData *__pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  __pyx_t_6pandas_5_libs_9hashtable_UInt8VectorData *__pyx_t_11;
  int __pyx_t_12;
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int8_t __pyx_t_14;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":6476
 *         """
 *         cdef:
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)             # <<<<<<<<<<<<<<
 *             intp_t[::1] labels
 *             int ret = 0
 */
  __pyx_v_count = __pyx_v_count_prior;
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":6478
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)
 *             intp_t[::1] labels
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             int8_t val, na_value2
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6484
 *             UInt8Vector result_mask
 *             UInt8VectorData *rmd
 *             bint use_na_value, use_mask, seen_na = False             # <<<<<<<<<<<<<<
 *             uint8_t[:] mask_values
 * 
 */
  __pyx_v_seen_na = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6487
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6488
 * 
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6488, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6488, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6488, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6488, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 6488, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6488, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6488, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6488, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 6488, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6488, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 6488, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_labels = __pyx_t_7;
    __pyx_t_7.memview = NULL;
    __pyx_t_7.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":6487
 *             uint8_t[:] mask_values
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6489
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data             # <<<<<<<<<<<<<<
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 */
  __pyx_t_8 = __pyx_v_uniques->data;
  __pyx_v_ud = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":6490
 *             labels = np.empty(n, dtype=np.intp)
 *         ud = uniques.data
 *         use_na_value = na_value is not None             # <<<<<<<<<<<<<<
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 */
  __pyx_t_9 = (__pyx_v_na_value != Py_None);
  __pyx_v_use_na_value = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":6491
 *         ud = uniques.data
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None             # <<<<<<<<<<<<<<
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover
 */
  __pyx_t_9 = (__pyx_v_mask != Py_None);
  __pyx_v_use_mask = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":6492
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  __pyx_t_10 = (!__pyx_v_use_mask);
  if (__pyx_t_10) {
  } else {
    __pyx_t_9 = __pyx_t_10;
    goto __pyx_L5_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_use_result_mask;
  __pyx_L5_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6493
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         if use_result_mask and return_inverse:
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 6493, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":6492
 *         use_na_value = na_value is not None
 *         use_mask = mask is not None
 *         if not use_mask and use_result_mask:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6495
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  if (__pyx_v_use_result_mask) {
  } else {
    __pyx_t_9 = __pyx_v_use_result_mask;
    goto __pyx_L8_bool_binop_done;
  }
  __pyx_t_9 = __pyx_v_return_inverse;
  __pyx_L8_bool_binop_done:;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6496
 * 
 *         if use_result_mask and return_inverse:
 *             raise NotImplementedError  # pragma: no cover             # <<<<<<<<<<<<<<
 * 
 *         result_mask = UInt8Vector()
 */
    __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
    __PYX_ERR(2, 6496, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":6495
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         if use_result_mask and return_inverse:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError  # pragma: no cover
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6498
 *             raise NotImplementedError  # pragma: no cover
 * 
 *         result_mask = UInt8Vector()             # <<<<<<<<<<<<<<
 *         rmd = result_mask.data
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6498, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_v_result_mask = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6499
 * 
 *         result_mask = UInt8Vector()
 *         rmd = result_mask.data             # <<<<<<<<<<<<<<
 * 
 *         if use_mask:
 */
  __pyx_t_11 = __pyx_v_result_mask->data;
  __pyx_v_rmd = __pyx_t_11;

  /* "pandas/_libs/hashtable_class_helper.pxi":6501
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  if (__pyx_v_use_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6502
 * 
 *         if use_mask:
 *             mask_values = mask.view("uint8")             # <<<<<<<<<<<<<<
 * 
 *         if use_na_value:
 */
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_v_mask, __pyx_n_s_view); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6502, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = NULL;
    __pyx_t_12 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
        __pyx_t_12 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_n_u_uint8};
      __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_12, 1+__pyx_t_12);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6502, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(2, 6502, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_mask_values = __pyx_t_13;
    __pyx_t_13.memview = NULL;
    __pyx_t_13.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":6501
 *         rmd = result_mask.data
 * 
 *         if use_mask:             # <<<<<<<<<<<<<<
 *             mask_values = mask.view("uint8")
 * 
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6504
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
  if (__pyx_v_use_na_value) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6510
 *             # for the parameter. To please the compiler, we use na_value2,
 *             # which is only used if it's *specified*.
 *             na_value2 = (na_value)             # <<<<<<<<<<<<<<
 *         else:
 *             na_value2 = (0)
 */
    __pyx_t_14 = __Pyx_PyInt_As_npy_int8(__pyx_v_na_value); if (unlikely((__pyx_t_14 == ((npy_int8)-1)) && PyErr_Occurred())) __PYX_ERR(2, 6510, __pyx_L1_error)
    __pyx_v_na_value2 = __pyx_t_14;

    /* "pandas/_libs/hashtable_class_helper.pxi":6504
 *             mask_values = mask.view("uint8")
 * 
 *         if use_na_value:             # <<<<<<<<<<<<<<
 *             # We need this na_value2 because we want to allow users
 *             # to *optionally* specify an NA sentinel *of the correct* type.
 */
    goto __pyx_L11;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6512
 *             na_value2 = (na_value)
 *         else:
 *             na_value2 = (0)             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
  /*else*/ {
    __pyx_v_na_value2 = 0;
  }
  __pyx_L11:;

  /* "pandas/_libs/hashtable_class_helper.pxi":6514
 *             na_value2 = (0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = (values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":6515
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 val = (values[i])
 * 
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_15 = __pyx_t_1;
        for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
          __pyx_v_i = __pyx_t_16;

          /* "pandas/_libs/hashtable_class_helper.pxi":6516
 *         with nogil:
 *             for i in range(n):
 *                 val = (values[i])             # <<<<<<<<<<<<<<
 * 
 *                 if ignore_na and use_mask:
 */
          __pyx_t_17 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_int8_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_17 * __pyx_v_values.strides[0]) )));

          /* "pandas/_libs/hashtable_class_helper.pxi":6518
 *                 val = (values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L18_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_mask;
          __pyx_L18_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":6519
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 6519, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_17 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":6520
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                         continue
 *                 elif ignore_na and (
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 6520, __pyx_L13_error) }
              __pyx_t_17 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_na_sentinel;

              /* "pandas/_libs/hashtable_class_helper.pxi":6521
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 *                         continue             # <<<<<<<<<<<<<<
 *                 elif ignore_na and (
 *                    is_nan_int8_t(val) or
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":6519
 * 
 *                 if ignore_na and use_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         labels[i] = na_sentinel
 *                         continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":6518
 *                 val = (values[i])
 * 
 *                 if ignore_na and use_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         labels[i] = na_sentinel
 */
            goto __pyx_L17;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":6522
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_int8_t(val) or
 *                    (use_na_value and are_equivalent_int8_t(val, na_value2))
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":6523
 *                         continue
 *                 elif ignore_na and (
 *                    is_nan_int8_t(val) or             # <<<<<<<<<<<<<<
 *                    (use_na_value and are_equivalent_int8_t(val, na_value2))
 *                 ):
 */
          __pyx_t_10 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_int8_t(__pyx_v_val); if (unlikely(__pyx_t_10 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 6523, __pyx_L13_error)
          if (!__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L21_bool_binop_done;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":6524
 *                 elif ignore_na and (
 *                    is_nan_int8_t(val) or
 *                    (use_na_value and are_equivalent_int8_t(val, na_value2))             # <<<<<<<<<<<<<<
 *                 ):
 *                     # if missing values do not count as unique values (i.e. if
 */
          if (__pyx_v_use_na_value) {
          } else {
            __pyx_t_9 = __pyx_v_use_na_value;
            goto __pyx_L21_bool_binop_done;
          }
          __pyx_t_10 = __pyx_f_6pandas_5_libs_9hashtable_are_equivalent_int8_t(__pyx_v_val, __pyx_v_na_value2); if (unlikely(__pyx_t_10 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 6524, __pyx_L13_error)
          __pyx_t_9 = __pyx_t_10;
          __pyx_L21_bool_binop_done:;

          /* "pandas/_libs/hashtable_class_helper.pxi":6522
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_int8_t(val) or
 *                    (use_na_value and are_equivalent_int8_t(val, na_value2))
 */
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":6529
 *                     # ignore_na is True), skip the hashtable entry for them,
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 6529, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_na_sentinel;

            /* "pandas/_libs/hashtable_class_helper.pxi":6530
 *                     # and replace the corresponding label with na_sentinel
 *                     labels[i] = na_sentinel
 *                     continue             # <<<<<<<<<<<<<<
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 */
            goto __pyx_L15_continue;

            /* "pandas/_libs/hashtable_class_helper.pxi":6522
 *                         labels[i] = na_sentinel
 *                         continue
 *                 elif ignore_na and (             # <<<<<<<<<<<<<<
 *                    is_nan_int8_t(val) or
 *                    (use_na_value and are_equivalent_int8_t(val, na_value2))
 */
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":6531
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          __pyx_t_10 = (!__pyx_v_ignore_na);
          if (__pyx_t_10) {
          } else {
            __pyx_t_9 = __pyx_t_10;
            goto __pyx_L25_bool_binop_done;
          }
          __pyx_t_9 = __pyx_v_use_result_mask;
          __pyx_L25_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":6532
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            if (unlikely(!__pyx_v_mask_values.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("mask_values"); __PYX_ERR(2, 6532, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            __pyx_t_9 = ((*((__pyx_t_5numpy_uint8_t *) ( /* dim=0 */ (__pyx_v_mask_values.data + __pyx_t_17 * __pyx_v_mask_values.strides[0]) ))) != 0);
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":6533
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_class_helper.pxi":6534
 *                     if mask_values[i]:
 *                         if seen_na:
 *                             continue             # <<<<<<<<<<<<<<
 * 
 *                         seen_na = True
 */
                goto __pyx_L15_continue;

                /* "pandas/_libs/hashtable_class_helper.pxi":6533
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:
 *                         if seen_na:             # <<<<<<<<<<<<<<
 *                             continue
 * 
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":6536
 *                             continue
 * 
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         if needs_resize(ud):
 *                             with gil:
 */
              __pyx_v_seen_na = 1;

              /* "pandas/_libs/hashtable_class_helper.pxi":6537
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              __pyx_t_9 = __pyx_fuse_3__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 6537, __pyx_L13_error)
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_class_helper.pxi":6538
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                {
                    #ifdef WITH_THREAD
                    PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                    #endif
                    /*try:*/ {

                      /* "pandas/_libs/hashtable_class_helper.pxi":6539
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":6540
 *                             with gil:
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6540, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 6540, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":6539
 *                         if needs_resize(ud):
 *                             with gil:
 *                                 if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "uniques held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":6543
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int8Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6543, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":6544
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":6545
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6545, __pyx_L33_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 6545, __pyx_L33_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":6544
 *                                                      "Vector.resize() needed")
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":6548
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                         append_data_int8(ud, val)
 *                         append_data_uint8(rmd, 1)
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6548, __pyx_L33_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":6538
 *                         seen_na = True
 *                         if needs_resize(ud):
 *                             with gil:             # <<<<<<<<<<<<<<
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    /*finally:*/ {
                      /*normal exit:*/{
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L34;
                      }
                      __pyx_L33_error: {
                        #ifdef WITH_THREAD
                        __Pyx_PyGILState_Release(__pyx_gilstate_save);
                        #endif
                        goto __pyx_L13_error;
                      }
                      __pyx_L34:;
                    }
                }

                /* "pandas/_libs/hashtable_class_helper.pxi":6537
 * 
 *                         seen_na = True
 *                         if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                             with gil:
 *                                 if uniques.external_view_exists:
 */
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":6549
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                         append_data_int8(ud, val)             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 1)
 *                         continue
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_int8(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 6549, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":6550
 *                                 result_mask.resize()
 *                         append_data_int8(ud, val)
 *                         append_data_uint8(rmd, 1)             # <<<<<<<<<<<<<<
 *                         continue
 * 
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 1); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 6550, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":6551
 *                         append_data_int8(ud, val)
 *                         append_data_uint8(rmd, 1)
 *                         continue             # <<<<<<<<<<<<<<
 * 
 *                 k = kh_get_int8(self.table, val)
 */
              goto __pyx_L15_continue;

              /* "pandas/_libs/hashtable_class_helper.pxi":6532
 *                     continue
 *                 elif not ignore_na and use_result_mask:
 *                     if mask_values[i]:             # <<<<<<<<<<<<<<
 *                         if seen_na:
 *                             continue
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":6531
 *                     labels[i] = na_sentinel
 *                     continue
 *                 elif not ignore_na and use_result_mask:             # <<<<<<<<<<<<<<
 *                     if mask_values[i]:
 *                         if seen_na:
 */
          }
          __pyx_L17:;

          /* "pandas/_libs/hashtable_class_helper.pxi":6553
 *                         continue
 * 
 *                 k = kh_get_int8(self.table, val)             # <<<<<<<<<<<<<<
 * 
 *                 if k == self.table.n_buckets:
 */
          __pyx_v_k = kh_get_int8(__pyx_v_self->table, __pyx_v_val);

          /* "pandas/_libs/hashtable_class_helper.pxi":6555
 *                 k = kh_get_int8(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_int8(self.table, val, &ret)
 */
          __pyx_t_9 = (__pyx_v_k == __pyx_v_self->table->n_buckets);
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":6557
 *                 if k == self.table.n_buckets:
 *                     # k hasn't been seen yet
 *                     k = kh_put_int8(self.table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *                     if needs_resize(ud):
 */
            __pyx_v_k = kh_put_int8(__pyx_v_self->table, __pyx_v_val, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":6559
 *                     k = kh_put_int8(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            __pyx_t_9 = __pyx_fuse_3__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_9 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 6559, __pyx_L13_error)
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_class_helper.pxi":6560
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
              {
                  #ifdef WITH_THREAD
                  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                  #endif
                  /*try:*/ {

                    /* "pandas/_libs/hashtable_class_helper.pxi":6561
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    if (unlikely(__pyx_v_uniques->__pyx_base.external_view_exists)) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":6562
 *                         with gil:
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 */
                      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__16, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6562, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                      __PYX_ERR(2, 6562, __pyx_L42_error)

                      /* "pandas/_libs/hashtable_class_helper.pxi":6561
 *                     if needs_resize(ud):
 *                         with gil:
 *                             if uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *                                 raise ValueError("external reference to "
 *                                                  "uniques held, but "
 */
                    }

                    /* "pandas/_libs/hashtable_class_helper.pxi":6565
 *                                                  "uniques held, but "
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()             # <<<<<<<<<<<<<<
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 */
                    __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int8Vector *)__pyx_v_uniques->__pyx_vtab)->resize(__pyx_v_uniques); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6565, __pyx_L42_error)
                    __Pyx_GOTREF(__pyx_t_6);
                    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                    /* "pandas/_libs/hashtable_class_helper.pxi":6566
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    if (__pyx_v_use_result_mask) {

                      /* "pandas/_libs/hashtable_class_helper.pxi":6567
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      if (unlikely(__pyx_v_result_mask->__pyx_base.external_view_exists)) {

                        /* "pandas/_libs/hashtable_class_helper.pxi":6568
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
                        __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__17, NULL); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6568, __pyx_L42_error)
                        __Pyx_GOTREF(__pyx_t_6);
                        __Pyx_Raise(__pyx_t_6, 0, 0, 0);
                        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
                        __PYX_ERR(2, 6568, __pyx_L42_error)

                        /* "pandas/_libs/hashtable_class_helper.pxi":6567
 *                             uniques.resize()
 *                             if use_result_mask:
 *                                 if result_mask.external_view_exists:             # <<<<<<<<<<<<<<
 *                                     raise ValueError("external reference to "
 *                                                      "result_mask held, but "
 */
                      }

                      /* "pandas/_libs/hashtable_class_helper.pxi":6571
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()             # <<<<<<<<<<<<<<
 *                     append_data_int8(ud, val)
 *                     if use_result_mask:
 */
                      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->resize(__pyx_v_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6571, __pyx_L42_error)
                      __Pyx_GOTREF(__pyx_t_6);
                      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

                      /* "pandas/_libs/hashtable_class_helper.pxi":6566
 *                                                  "Vector.resize() needed")
 *                             uniques.resize()
 *                             if use_result_mask:             # <<<<<<<<<<<<<<
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "
 */
                    }
                  }

                  /* "pandas/_libs/hashtable_class_helper.pxi":6560
 * 
 *                     if needs_resize(ud):
 *                         with gil:             # <<<<<<<<<<<<<<
 *                             if uniques.external_view_exists:
 *                                 raise ValueError("external reference to "
 */
                  /*finally:*/ {
                    /*normal exit:*/{
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L43;
                    }
                    __pyx_L42_error: {
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L13_error;
                    }
                    __pyx_L43:;
                  }
              }

              /* "pandas/_libs/hashtable_class_helper.pxi":6559
 *                     k = kh_put_int8(self.table, val, &ret)
 * 
 *                     if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                         with gil:
 *                             if uniques.external_view_exists:
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":6572
 *                                                      "Vector.resize() needed")
 *                                 result_mask.resize()
 *                     append_data_int8(ud, val)             # <<<<<<<<<<<<<<
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)
 */
            __pyx_f_6pandas_5_libs_9hashtable_append_data_int8(__pyx_v_ud, __pyx_v_val); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 6572, __pyx_L13_error)

            /* "pandas/_libs/hashtable_class_helper.pxi":6573
 *                                 result_mask.resize()
 *                     append_data_int8(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            if (__pyx_v_use_result_mask) {

              /* "pandas/_libs/hashtable_class_helper.pxi":6574
 *                     append_data_int8(ud, val)
 *                     if use_result_mask:
 *                         append_data_uint8(rmd, 0)             # <<<<<<<<<<<<<<
 * 
 *                     if return_inverse:
 */
              __pyx_f_6pandas_5_libs_9hashtable_append_data_uint8(__pyx_v_rmd, 0); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(2, 6574, __pyx_L13_error)

              /* "pandas/_libs/hashtable_class_helper.pxi":6573
 *                                 result_mask.resize()
 *                     append_data_int8(ud, val)
 *                     if use_result_mask:             # <<<<<<<<<<<<<<
 *                         append_data_uint8(rmd, 0)
 * 
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":6576
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            if (__pyx_v_return_inverse) {

              /* "pandas/_libs/hashtable_class_helper.pxi":6577
 * 
 *                     if return_inverse:
 *                         self.table.vals[k] = count             # <<<<<<<<<<<<<<
 *                         labels[i] = count
 *                         count += 1
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":6578
 *                     if return_inverse:
 *                         self.table.vals[k] = count
 *                         labels[i] = count             # <<<<<<<<<<<<<<
 *                         count += 1
 *                 elif return_inverse:
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 6578, __pyx_L13_error) }
              __pyx_t_17 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":6579
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 *                         count += 1             # <<<<<<<<<<<<<<
 *                 elif return_inverse:
 *                     # k falls into a previous bucket
 */
              __pyx_v_count = (__pyx_v_count + 1);

              /* "pandas/_libs/hashtable_class_helper.pxi":6576
 *                         append_data_uint8(rmd, 0)
 * 
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":6555
 *                 k = kh_get_int8(self.table, val)
 * 
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_int8(self.table, val, &ret)
 */
            goto __pyx_L37;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":6580
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          if (__pyx_v_return_inverse) {

            /* "pandas/_libs/hashtable_class_helper.pxi":6583
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     labels[i] = idx
 * 
 */
            __pyx_v_idx = (__pyx_v_self->table->vals[__pyx_v_k]);

            /* "pandas/_libs/hashtable_class_helper.pxi":6584
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]
 *                     labels[i] = idx             # <<<<<<<<<<<<<<
 * 
 *         if return_inverse:
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 6584, __pyx_L13_error) }
            __pyx_t_17 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_17)) )) = __pyx_v_idx;

            /* "pandas/_libs/hashtable_class_helper.pxi":6580
 *                         labels[i] = count
 *                         count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          }
          __pyx_L37:;
          __pyx_L15_continue:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":6514
 *             na_value2 = (0)
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 val = (values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L14;
        }
        __pyx_L13_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L14:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6586
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6587
 * 
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray             # <<<<<<<<<<<<<<
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int8Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundLocalError("labels"); __PYX_ERR(2, 6587, __pyx_L1_error) }
    __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_labels, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_base); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6587, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_6);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_6)) __PYX_ERR(2, 6587, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4)) __PYX_ERR(2, 6587, __pyx_L1_error);
    __pyx_t_6 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":6586
 *                     labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6588
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  if (__pyx_v_use_result_mask) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6589
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()             # <<<<<<<<<<<<<<
 *         return uniques.to_array()
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int8Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_mask->__pyx_vtab)->to_array(__pyx_v_result_mask, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_6 = PyTuple_New(2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2)) __PYX_ERR(2, 6589, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4)) __PYX_ERR(2, 6589, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_6;
    __pyx_t_6 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":6588
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         if use_result_mask:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6590
 *         if use_result_mask:
 *             return uniques.to_array(), result_mask.to_array()
 *         return uniques.to_array()             # <<<<<<<<<<<<<<
 * 
 *     def unique(self, const int8_t[:] values, bint return_inverse=False, object mask=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int8Vector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6590, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6427
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const int8_t[:] values, Int8Vector uniques,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_13, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_labels, 1);
  __Pyx_XDECREF((PyObject *)__pyx_v_result_mask);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask_values, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6592
 *         return uniques.to_array()
 * 
 *     def unique(self, const int8_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_27unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_13Int8HashTable_26unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[int8]\n            Array of values of which unique will be calculated\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n\n        Returns\n        -------\n        uniques : ndarray[int8]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse)\n            The labels from values to uniques\n        result_mask: ndarray[bool], if mask is given as input\n            The mask for the result values.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_27unique = {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_27unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_13Int8HashTable_26unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_27unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_return_inverse;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_return_inverse,&__pyx_n_s_mask,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6592, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6592, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6592, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "unique") < 0)) __PYX_ERR(2, 6592, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int8_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 6592, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 6592, __pyx_L3_error)
    } else {
      __pyx_v_return_inverse = ((int)0);
    }
    __pyx_v_mask = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("unique", 0, 1, 3, __pyx_nargs); __PYX_ERR(2, 6592, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_26unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_return_inverse, __pyx_v_mask);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_26unique(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, int __pyx_v_return_inverse, PyObject *__pyx_v_mask) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_uniques = NULL;
  int __pyx_v_use_result_mask;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unique", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":6616
 *             The mask for the result values.
 *         """
 *         uniques = Int8Vector()             # <<<<<<<<<<<<<<
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6616, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6617
 *         """
 *         uniques = Int8Vector()
 *         use_result_mask = True if mask is not None else False             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 */
  __pyx_t_3 = (__pyx_v_mask != Py_None);
  if (__pyx_t_3) {
    __pyx_t_2 = 1;
  } else {
    __pyx_t_2 = 0;
  }
  __pyx_v_use_result_mask = __pyx_t_2;

  /* "pandas/_libs/hashtable_class_helper.pxi":6618
 *         uniques = Int8Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4)) __PYX_ERR(2, 6618, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 6618, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_ignore_na, Py_False) < 0) __PYX_ERR(2, 6618, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6619
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const int8_t[:] values, Py_ssize_t na_sentinel=-1,
 */
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_return_inverse); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return_inverse, __pyx_t_6) < 0) __PYX_ERR(2, 6618, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 6618, __pyx_L1_error)
  __pyx_t_6 = __Pyx_PyBool_FromLong(__pyx_v_use_result_mask); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6619, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_use_result_mask, __pyx_t_6) < 0) __PYX_ERR(2, 6618, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6618
 *         uniques = Int8Vector()
 *         use_result_mask = True if mask is not None else False
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 */
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_r = __pyx_t_6;
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6592
 *         return uniques.to_array()
 * 
 *     def unique(self, const int8_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6621
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const int8_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_29factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_13Int8HashTable_28factorize, "\n        Calculate unique values and labels (no sorting!)\n\n        Missing values are not included in the \"uniques\" for this method.\n        The labels for any missing values will be set to \"na_sentinel\"\n\n        Parameters\n        ----------\n        values : ndarray[int8]\n            Array of values of which unique will be calculated\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        mask : ndarray[bool], optional\n            If not None, the mask is used as indicator for missing values\n            (True = missing, False = valid) instead of `na_value` or\n            condition \"val != val\".\n\n        Returns\n        -------\n        uniques : ndarray[int8]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t]\n            The labels from values to uniques\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_29factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_29factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_13Int8HashTable_28factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_29factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  PyObject *__pyx_v_ignore_na = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,&__pyx_n_s_ignore_na,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":6622
 * 
 *     def factorize(self, const int8_t[:] values, Py_ssize_t na_sentinel=-1,
 *                   object na_value=None, object mask=None, ignore_na=True):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_True));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6621, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6621, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6621, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6621, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6621, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 6621, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int8_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 6621, __pyx_L3_error)
    if (values[1]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 6621, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
    __pyx_v_ignore_na = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 5, __pyx_nargs); __PYX_ERR(2, 6621, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_28factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask, __pyx_v_ignore_na);

  /* "pandas/_libs/hashtable_class_helper.pxi":6621
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const int8_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_28factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_uniques_vector = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":6652
 *             The labels from values to uniques
 *         """
 *         uniques_vector = Int8Vector()             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6652, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques_vector = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6653
 *         """
 *         uniques_vector = Int8Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 6653, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques_vector);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques_vector))) __PYX_ERR(2, 6653, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 6653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6654
 *         uniques_vector = Int8Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,             # <<<<<<<<<<<<<<
 *                             return_inverse=True)
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 6653, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, __pyx_v_ignore_na) < 0) __PYX_ERR(2, 6653, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 6653, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6655
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)             # <<<<<<<<<<<<<<
 * 
 *     def get_labels(self, const int8_t[:] values, Int8Vector uniques,
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 6653, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6653
 *         """
 *         uniques_vector = Int8Vector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na, mask=mask,
 *                             return_inverse=True)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6621
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const int8_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6657
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const int8_t[:] values, Int8Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_31get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_31get_labels = {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_31get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_31get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[6] = {0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_labels (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":6659
 *     def get_labels(self, const int8_t[:] values, Int8Vector uniques,
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[5] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6657, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6657, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, 1); __PYX_ERR(2, 6657, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6657, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6657, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6657, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6657, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_labels") < 0)) __PYX_ERR(2, 6657, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int8_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 6657, __pyx_L3_error)
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 6658, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 6658, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    __pyx_v_mask = values[5];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 6, __pyx_nargs); __PYX_ERR(2, 6657, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector, 1, "uniques", 0))) __PYX_ERR(2, 6657, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_30get_labels(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":6657
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const int8_t[:] values, Int8Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_30get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_v_labels = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_labels", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":6661
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2)) __PYX_ERR(2, 6661, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 6661, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(6); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_count_prior); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_count_prior, __pyx_t_4) < 0) __PYX_ERR(2, 6661, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6662
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,             # <<<<<<<<<<<<<<
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 6661, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 6661, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6663
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_ignore_na, Py_True) < 0) __PYX_ERR(2, 6661, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 6661, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 6661, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6661
 *                    object na_value=None, object mask=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6661, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
    PyObject* sequence = __pyx_t_4;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(2, 6661, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_2 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_2 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6661, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6661, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6661, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
    index = 0; __pyx_t_2 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    index = 1; __pyx_t_3 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_1), 2) < 0) __PYX_ERR(2, 6661, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(2, 6661, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v__ = __pyx_t_2;
  __pyx_t_2 = 0;
  __pyx_v_labels = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6664
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True, mask=mask)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_labels);
  __pyx_r = __pyx_v_labels;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6657
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const int8_t[:] values, Int8Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XDECREF(__pyx_v_labels);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_33__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_33__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_33__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_33__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_32__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_32__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_35__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_35__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_35__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_35__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_34__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_13Int8HashTable_34__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8HashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6673
 *         Int8Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = Int8HashTable(size_hint)
 *         self.uniques = Int8Vector()
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_size_hint = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6673, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(2, 6673, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_size_hint = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 6673, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_size_hint), (&PyInt_Type), 0, "size_hint", 1))) __PYX_ERR(2, 6673, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *)__pyx_v_self), __pyx_v_size_hint);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *__pyx_v_self, PyObject *__pyx_v_size_hint) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":6674
 * 
 *     def __cinit__(self, size_hint: int):
 *         self.table = Int8HashTable(size_hint)             # <<<<<<<<<<<<<<
 *         self.uniques = Int8Vector()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable), __pyx_v_size_hint); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6675
 *     def __cinit__(self, size_hint: int):
 *         self.table = Int8HashTable(size_hint)
 *         self.uniques = Int8Vector()             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, const int8_t[:] values,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6673
 *         Int8Vector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = Int8HashTable(size_hint)
 *         self.uniques = Int8Vector()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6677
 *         self.uniques = Int8Vector()
 * 
 *     def factorize(self, const int8_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14Int8Factorizer_2factorize, "\n        Returns\n        -------\n        ndarray[intp_t]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = Int8Factorizer(3)\n        >>> fac.factorize(np.array([1,2,3], dtype=\"int8\"), na_sentinel=20)\n        array([0, 1, 2])\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int8Factorizer_3factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int8Factorizer_2factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_values = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_v_na_sentinel = 0;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_neg_1));

    /* "pandas/_libs/hashtable_class_helper.pxi":6678
 * 
 *     def factorize(self, const int8_t[:] values,
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:             # <<<<<<<<<<<<<<
 *         """
 *         Returns
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6677, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6677, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6677, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6677, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 6677, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int8_t__const__(values[0], 0); if (unlikely(!__pyx_v_values.memview)) __PYX_ERR(2, 6677, __pyx_L3_error)
    __pyx_v_na_sentinel = values[1];
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 4, __pyx_nargs); __PYX_ERR(2, 6677, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_2factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":6677
 *         self.uniques = Int8Vector()
 * 
 *     def factorize(self, const int8_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_values, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *__pyx_v_self, __Pyx_memviewslice __pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  PyArrayObject *__pyx_v_labels = 0;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_uniques = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_labels;
  __Pyx_Buffer __pyx_pybuffer_labels;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);
  __pyx_pybuffer_labels.pybuffer.buf = NULL;
  __pyx_pybuffer_labels.refcount = 0;
  __pyx_pybuffernd_labels.data = NULL;
  __pyx_pybuffernd_labels.rcbuffer = &__pyx_pybuffer_labels;

  /* "pandas/_libs/hashtable_class_helper.pxi":6695
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = Int8Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  if (__pyx_v_self->uniques->__pyx_base.external_view_exists) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6696
 * 
 *         if self.uniques.external_view_exists:
 *             uniques = Int8Vector()             # <<<<<<<<<<<<<<
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 */
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6696, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *)__pyx_t_1);
    __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":6697
 *         if self.uniques.external_view_exists:
 *             uniques = Int8Vector()
 *             uniques.extend(self.uniques.to_array())             # <<<<<<<<<<<<<<
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 */
    __pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int8Vector *)__pyx_v_self->uniques->__pyx_vtab)->to_array(__pyx_v_self->uniques, 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6697, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int8_t__const__(__pyx_t_1, 0); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(2, 6697, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int8Vector *)__pyx_v_uniques->__pyx_vtab)->extend(__pyx_v_uniques, __pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6697, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
    __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":6698
 *             uniques = Int8Vector()
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques             # <<<<<<<<<<<<<<
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 */
    __Pyx_INCREF((PyObject *)__pyx_v_uniques);
    __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
    __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
    __pyx_v_self->uniques = __pyx_v_uniques;

    /* "pandas/_libs/hashtable_class_helper.pxi":6695
 *             ndarray[intp_t] labels
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = Int8Vector()
 *             uniques.extend(self.uniques.to_array())
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6699
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->table), __pyx_n_s_get_labels); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = __pyx_memoryview_fromslice(__pyx_v_values, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);

  /* "pandas/_libs/hashtable_class_helper.pxi":6700
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,             # <<<<<<<<<<<<<<
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_self->__pyx_base.count); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6700, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);

  /* "pandas/_libs/hashtable_class_helper.pxi":6699
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_5 = PyTuple_New(4); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3)) __PYX_ERR(2, 6699, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_self->uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 1, ((PyObject *)__pyx_v_self->uniques))) __PYX_ERR(2, 6699, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_t_4)) __PYX_ERR(2, 6699, __pyx_L1_error);
  __Pyx_INCREF(__pyx_v_na_sentinel);
  __Pyx_GIVEREF(__pyx_v_na_sentinel);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 3, __pyx_v_na_sentinel)) __PYX_ERR(2, 6699, __pyx_L1_error);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6701
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)             # <<<<<<<<<<<<<<
 *         self.count = len(self.uniques)
 *         return labels
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6701, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 6701, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_mask, __pyx_v_mask) < 0) __PYX_ERR(2, 6701, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6699
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 */
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6699, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 6699, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
    __pyx_t_7 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_7 < 0)) {
      PyErr_Fetch(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_v_labels, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      }
      __pyx_t_8 = __pyx_t_9 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_labels.diminfo[0].strides = __pyx_pybuffernd_labels.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_labels.diminfo[0].shape = __pyx_pybuffernd_labels.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_7 < 0))) __PYX_ERR(2, 6699, __pyx_L1_error)
  }
  __pyx_t_6 = 0;
  __pyx_v_labels = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6702
 *                                        self.count, na_sentinel,
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  __pyx_t_3 = ((PyObject *)__pyx_v_self->uniques);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_11 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(2, 6702, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_self->__pyx_base.count = __pyx_t_11;

  /* "pandas/_libs/hashtable_class_helper.pxi":6703
 *                                        na_value=na_value, mask=mask)
 *         self.count = len(self.uniques)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_labels);
  __pyx_r = ((PyObject *)__pyx_v_labels);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6677
 *         self.uniques = Int8Vector()
 * 
 *     def factorize(self, const int8_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_labels);
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6670
 * cdef class Int8Factorizer(Factorizer):
 *     cdef public:
 *         Int8HashTable table             # <<<<<<<<<<<<<<
 *         Int8Vector uniques
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_5table_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_5table_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_5table___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->table);
  __pyx_r = ((PyObject *)__pyx_v_self->table);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_5table_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable))))) __PYX_ERR(2, 6670, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8Factorizer.table.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_5table_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_5table_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_5table_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6671
 *     cdef public:
 *         Int8HashTable table
 *         Int8Vector uniques             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, size_hint: int):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_7uniques_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_7uniques_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_7uniques___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __pyx_r = ((PyObject *)__pyx_v_self->uniques);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_7uniques_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector))))) __PYX_ERR(2, 6671, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8Factorizer.uniques.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_7uniques_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_7uniques_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_7uniques_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int8Factorizer_5__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_4__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8Factorizer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_14Int8Factorizer_7__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_6__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_14Int8Factorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Int8Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6711
 *     na_string_sentinel = '__nan__'
 * 
 *     def __init__(self, int64_t size_hint=1):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_str()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __pyx_t_5numpy_int64_t __pyx_v_size_hint;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6711, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(2, 6711, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_size_hint = __Pyx_PyInt_As_npy_int64(values[0]); if (unlikely((__pyx_v_size_hint == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 6711, __pyx_L3_error)
    } else {
      __pyx_v_size_hint = ((__pyx_t_5numpy_int64_t)1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 1, __pyx_nargs); __PYX_ERR(2, 6711, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable___init__(((struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *)__pyx_v_self), __pyx_v_size_hint);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable___init__(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  khuint_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __pyx_t_5numpy_int64_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":6712
 * 
 *     def __init__(self, int64_t size_hint=1):
 *         self.table = kh_init_str()             # <<<<<<<<<<<<<<
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_str(self.table, size_hint)
 */
  __pyx_v_self->table = kh_init_str();

  /* "pandas/_libs/hashtable_class_helper.pxi":6713
 *     def __init__(self, int64_t size_hint=1):
 *         self.table = kh_init_str()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)             # <<<<<<<<<<<<<<
 *         kh_resize_str(self.table, size_hint)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = kh_needed_n_buckets(__pyx_v_size_hint);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_1, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6713, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(2, 6713, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_6) {
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_5 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6713, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_int64(__pyx_t_3); if (unlikely((__pyx_t_7 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 6713, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_size_hint = __pyx_t_7;

  /* "pandas/_libs/hashtable_class_helper.pxi":6714
 *         self.table = kh_init_str()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_str(self.table, size_hint)             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  kh_resize_str(__pyx_v_self->table, __pyx_v_size_hint);

  /* "pandas/_libs/hashtable_class_helper.pxi":6711
 *     na_string_sentinel = '__nan__'
 * 
 *     def __init__(self, int64_t size_hint=1):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_str()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6716
 *         kh_resize_str(self.table, size_hint)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_str(self.table)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_3__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_2__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":6717
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_str(self.table)
 *             self.table = NULL
 */
  __pyx_t_1 = (__pyx_v_self->table != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6718
 *     def __dealloc__(self):
 *         if self.table is not NULL:
 *             kh_destroy_str(self.table)             # <<<<<<<<<<<<<<
 *             self.table = NULL
 * 
 */
    kh_destroy_str(__pyx_v_self->table);

    /* "pandas/_libs/hashtable_class_helper.pxi":6719
 *         if self.table is not NULL:
 *             kh_destroy_str(self.table)
 *             self.table = NULL             # <<<<<<<<<<<<<<
 * 
 *     def sizeof(self, deep: bool = False) -> int:
 */
    __pyx_v_self->table = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":6717
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_str(self.table)
 *             self.table = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6716
 *         kh_resize_str(self.table, size_hint)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_str(self.table)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":6721
 *             self.table = NULL
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_5sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_5sizeof = {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_5sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_5sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_deep = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sizeof (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_deep,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_deep);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6721, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "sizeof") < 0)) __PYX_ERR(2, 6721, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_deep = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sizeof", 0, 0, 1, __pyx_nargs); __PYX_ERR(2, 6721, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_4sizeof(((struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *)__pyx_v_self), __pyx_v_deep);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_4sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep) {
  PyObject *__pyx_v_overhead = NULL;
  PyObject *__pyx_v_for_flags = NULL;
  PyObject *__pyx_v_for_pairs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  long __pyx_t_2;
  long __pyx_t_3;
  long __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sizeof", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":6722
 * 
 *     def sizeof(self, deep: bool = False) -> int:
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)             # <<<<<<<<<<<<<<
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(char *) +      # keys
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(((4 * (sizeof(__pyx_t_5numpy_uint32_t))) + (3 * (sizeof(__pyx_t_5numpy_uint32_t *))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_overhead = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6723
 *     def sizeof(self, deep: bool = False) -> int:
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)             # <<<<<<<<<<<<<<
 *         for_pairs =  self.table.n_buckets * (sizeof(char *) +      # keys
 *                                              sizeof(Py_ssize_t))   # vals
 */
  __pyx_t_2 = (__pyx_v_self->table->n_buckets >> 5);
  __pyx_t_3 = 1;
  __pyx_t_5 = (__pyx_t_2 > __pyx_t_3);
  if (__pyx_t_5) {
    __pyx_t_4 = __pyx_t_2;
  } else {
    __pyx_t_4 = __pyx_t_3;
  }
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_t_4 * (sizeof(__pyx_t_5numpy_uint32_t)))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_flags = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6724
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(char *) +      # keys             # <<<<<<<<<<<<<<
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->n_buckets * ((sizeof(char *)) + (sizeof(Py_ssize_t))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_pairs = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6726
 *         for_pairs =  self.table.n_buckets * (sizeof(char *) +      # keys
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs             # <<<<<<<<<<<<<<
 * 
 *     def get_state(self) -> dict[str, int]:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Add(__pyx_v_overhead, __pyx_v_for_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyNumber_Add(__pyx_t_1, __pyx_v_for_pairs); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6726, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(__Pyx_Py3Int_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None) || __Pyx_RaiseUnexpectedTypeError("int", __pyx_t_6))) __PYX_ERR(2, 6726, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6721
 *             self.table = NULL
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_overhead);
  __Pyx_XDECREF(__pyx_v_for_flags);
  __Pyx_XDECREF(__pyx_v_for_pairs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6728
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_7get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15StringHashTable_6get_state, " returns infos about the state of the hashtable");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_7get_state = {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_7get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15StringHashTable_6get_state};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_7get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_state (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_state", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_state", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_6get_state(((struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_6get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_state", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":6730
 *     def get_state(self) -> dict[str, int]:
 *         """ returns infos about the state of the hashtable"""
 *         return {             # <<<<<<<<<<<<<<
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 */
  __Pyx_XDECREF(__pyx_r);

  /* "pandas/_libs/hashtable_class_helper.pxi":6731
 *         """ returns infos about the state of the hashtable"""
 *         return {
 *             'n_buckets' : self.table.n_buckets,             # <<<<<<<<<<<<<<
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_buckets); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6731, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_buckets, __pyx_t_2) < 0) __PYX_ERR(2, 6731, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6732
 *         return {
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,             # <<<<<<<<<<<<<<
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->size); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6732, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_size, __pyx_t_2) < 0) __PYX_ERR(2, 6731, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6733
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,             # <<<<<<<<<<<<<<
 *             'upper_bound' : self.table.upper_bound,
 *         }
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_occupied); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6733, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_occupied, __pyx_t_2) < 0) __PYX_ERR(2, 6731, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6734
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,             # <<<<<<<<<<<<<<
 *         }
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->upper_bound); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_upper_bound, __pyx_t_2) < 0) __PYX_ERR(2, 6731, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6728
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.get_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6737
 *         }
 * 
 *     cpdef get_item(self, str val):             # <<<<<<<<<<<<<<
 *         cdef:
 *             khiter_t k
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_9get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15StringHashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, PyObject *__pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  char const *__pyx_v_v;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  char const *__pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6737, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_9get_item)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_val};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6737, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6741
 *             khiter_t k
 *             const char *v
 *         v = get_c_string(val)             # <<<<<<<<<<<<<<
 * 
 *         k = kh_get_str(self.table, v)
 */
  __pyx_t_6 = __pyx_f_6pandas_5_libs_6tslibs_4util_get_c_string(__pyx_v_val); if (unlikely(__pyx_t_6 == ((char const *)NULL))) __PYX_ERR(2, 6741, __pyx_L1_error)
  __pyx_v_v = __pyx_t_6;

  /* "pandas/_libs/hashtable_class_helper.pxi":6743
 *         v = get_c_string(val)
 * 
 *         k = kh_get_str(self.table, v)             # <<<<<<<<<<<<<<
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]
 */
  __pyx_v_k = kh_get_str(__pyx_v_self->table, __pyx_v_v);

  /* "pandas/_libs/hashtable_class_helper.pxi":6744
 * 
 *         k = kh_get_str(self.table, v)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  __pyx_t_7 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  if (likely(__pyx_t_7)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6745
 *         k = kh_get_str(self.table, v)
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(val)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->vals[__pyx_v_k])); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6745, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":6744
 * 
 *         k = kh_get_str(self.table, v)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6747
 *             return self.table.vals[k]
 *         else:
 *             raise KeyError(val)             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_item(self, str key, Py_ssize_t val):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_v_val); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6747, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(2, 6747, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6737
 *         }
 * 
 *     cpdef get_item(self, str val):             # <<<<<<<<<<<<<<
 *         cdef:
 *             khiter_t k
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_9get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_9get_item = {"get_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_9get_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_9get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_val = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6737, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_item") < 0)) __PYX_ERR(2, 6737, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_item", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 6737, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_val), (&PyUnicode_Type), 1, "val", 1))) __PYX_ERR(2, 6737, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_8get_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_8get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, PyObject *__pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_15StringHashTable_get_item(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6749
 *             raise KeyError(val)
 * 
 *     cpdef set_item(self, str key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         cdef:
 *             khiter_t k
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_11set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_15StringHashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, PyObject *__pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  char const *__pyx_v_v;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  char const *__pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6749, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_11set_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6749, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_key, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6749, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6752
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             const char *v
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6755
 *             const char *v
 * 
 *         v = get_c_string(key)             # <<<<<<<<<<<<<<
 * 
 *         k = kh_put_str(self.table, v, &ret)
 */
  __pyx_t_7 = __pyx_f_6pandas_5_libs_6tslibs_4util_get_c_string(__pyx_v_key); if (unlikely(__pyx_t_7 == ((char const *)NULL))) __PYX_ERR(2, 6755, __pyx_L1_error)
  __pyx_v_v = __pyx_t_7;

  /* "pandas/_libs/hashtable_class_helper.pxi":6757
 *         v = get_c_string(key)
 * 
 *         k = kh_put_str(self.table, v, &ret)             # <<<<<<<<<<<<<<
 *         if kh_exist_str(self.table, k):
 *             self.table.vals[k] = val
 */
  __pyx_v_k = kh_put_str(__pyx_v_self->table, __pyx_v_v, (&__pyx_v_ret));

  /* "pandas/_libs/hashtable_class_helper.pxi":6758
 * 
 *         k = kh_put_str(self.table, v, &ret)
 *         if kh_exist_str(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
  __pyx_t_8 = kh_exist_str(__pyx_v_self->table, __pyx_v_k);
  if (likely(__pyx_t_8)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6759
 *         k = kh_put_str(self.table, v, &ret)
 *         if kh_exist_str(self.table, k):
 *             self.table.vals[k] = val             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(key)
 */
    (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_val;

    /* "pandas/_libs/hashtable_class_helper.pxi":6758
 * 
 *         k = kh_put_str(self.table, v, &ret)
 *         if kh_exist_str(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6761
 *             self.table.vals[k] = val
 *         else:
 *             raise KeyError(key)             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_v_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6761, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(2, 6761, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "pandas/_libs/hashtable_class_helper.pxi":6749
 *             raise KeyError(val)
 * 
 *     cpdef set_item(self, str key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         cdef:
 *             khiter_t k
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_11set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_11set_item = {"set_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_11set_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_11set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_key = 0;
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key,&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6749, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6749, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, 1); __PYX_ERR(2, 6749, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_item") < 0)) __PYX_ERR(2, 6749, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_key = ((PyObject*)values[0]);
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 6749, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, __pyx_nargs); __PYX_ERR(2, 6749, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_key), (&PyUnicode_Type), 1, "key", 1))) __PYX_ERR(2, 6749, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_10set_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *)__pyx_v_self), __pyx_v_key, __pyx_v_val);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_10set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, PyObject *__pyx_v_key, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_15StringHashTable_set_item(__pyx_v_self, __pyx_v_key, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6763
 *             raise KeyError(key)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def get_indexer(self, ndarray[object] values) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

/* Python wrapper */
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_13get_indexer(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_13get_indexer = {"get_indexer", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_13get_indexer, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_13get_indexer(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyArrayObject *__pyx_v_values = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyArrayObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_indexer (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6763, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_indexer") < 0)) __PYX_ERR(2, 6763, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_indexer", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 6763, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.get_indexer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(2, 6764, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_12get_indexer(((struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *)__pyx_v_self), __pyx_v_values);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_12get_indexer(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  PyArrayObject *__pyx_v_labels = 0;
  __pyx_t_5numpy_intp_t *__pyx_v_resbuf;
  khiter_t __pyx_v_k;
  kh_str_t *__pyx_v_table;
  char const *__pyx_v_v;
  char const **__pyx_v_vecs;
  PyObject *__pyx_v_val = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_labels;
  __Pyx_Buffer __pyx_pybuffer_labels;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyArrayObject *__pyx_t_7 = NULL;
  char *__pyx_t_8;
  kh_str_t *__pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  char const *__pyx_t_13;
  int __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_indexer", 1);
  __pyx_pybuffer_labels.pybuffer.buf = NULL;
  __pyx_pybuffer_labels.refcount = 0;
  __pyx_pybuffernd_labels.data = NULL;
  __pyx_pybuffernd_labels.rcbuffer = &__pyx_pybuffer_labels;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(2, 6763, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_class_helper.pxi":6767
 *         # -> np.ndarray[np.intp]
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             ndarray[intp_t] labels = np.empty(n, dtype=np.intp)
 *             intp_t *resbuf = <intp_t*>labels.data
 */
  __pyx_t_1 = PyObject_Length(((PyObject *)__pyx_v_values)); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(2, 6767, __pyx_L1_error)
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":6768
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             ndarray[intp_t] labels = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *             intp_t *resbuf = <intp_t*>labels.data
 *             khiter_t k
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 6768, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 6768, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 6768, __pyx_L1_error)
  __pyx_t_7 = ((PyArrayObject *)__pyx_t_6);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_t_7, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
      __pyx_v_labels = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_labels.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(2, 6768, __pyx_L1_error)
    } else {__pyx_pybuffernd_labels.diminfo[0].strides = __pyx_pybuffernd_labels.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_labels.diminfo[0].shape = __pyx_pybuffernd_labels.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_7 = 0;
  __pyx_v_labels = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6769
 *             Py_ssize_t i, n = len(values)
 *             ndarray[intp_t] labels = np.empty(n, dtype=np.intp)
 *             intp_t *resbuf = <intp_t*>labels.data             # <<<<<<<<<<<<<<
 *             khiter_t k
 *             kh_str_t *table = self.table
 */
  __pyx_t_8 = __pyx_f_5numpy_7ndarray_4data_data(((PyArrayObject *)__pyx_v_labels)); if (unlikely(__pyx_t_8 == ((char *)NULL) && PyErr_Occurred())) __PYX_ERR(2, 6769, __pyx_L1_error)
  __pyx_v_resbuf = ((__pyx_t_5numpy_intp_t *)__pyx_t_8);

  /* "pandas/_libs/hashtable_class_helper.pxi":6771
 *             intp_t *resbuf = <intp_t*>labels.data
 *             khiter_t k
 *             kh_str_t *table = self.table             # <<<<<<<<<<<<<<
 *             const char *v
 *             const char **vecs
 */
  __pyx_t_9 = __pyx_v_self->table;
  __pyx_v_table = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":6775
 *             const char **vecs
 * 
 *         vecs = <const char **>malloc(n * sizeof(char *))             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = values[i]
 */
  __pyx_v_vecs = ((char const **)malloc((__pyx_v_n * (sizeof(char *)))));

  /* "pandas/_libs/hashtable_class_helper.pxi":6776
 * 
 *         vecs = <const char **>malloc(n * sizeof(char *))
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = values[i]
 *             v = get_c_string(val)
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_10 = __pyx_t_1;
  for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_10; __pyx_t_11+=1) {
    __pyx_v_i = __pyx_t_11;

    /* "pandas/_libs/hashtable_class_helper.pxi":6777
 *         vecs = <const char **>malloc(n * sizeof(char *))
 *         for i in range(n):
 *             val = values[i]             # <<<<<<<<<<<<<<
 *             v = get_c_string(val)
 *             vecs[i] = v
 */
    __pyx_t_12 = __pyx_v_i;
    if (__pyx_t_12 < 0) __pyx_t_12 += __pyx_pybuffernd_values.diminfo[0].shape;
    __pyx_t_6 = (PyObject *) *__Pyx_BufPtrStrided1d(PyObject **, __pyx_pybuffernd_values.rcbuffer->pybuffer.buf, __pyx_t_12, __pyx_pybuffernd_values.diminfo[0].strides);
    if (unlikely(__pyx_t_6 == NULL)) __pyx_t_6 = Py_None;
    __Pyx_INCREF((PyObject*)__pyx_t_6);
    __Pyx_XDECREF_SET(__pyx_v_val, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":6778
 *         for i in range(n):
 *             val = values[i]
 *             v = get_c_string(val)             # <<<<<<<<<<<<<<
 *             vecs[i] = v
 * 
 */
    if (!(likely(PyUnicode_CheckExact(__pyx_v_val))||((__pyx_v_val) == Py_None) || __Pyx_RaiseUnexpectedTypeError("unicode", __pyx_v_val))) __PYX_ERR(2, 6778, __pyx_L1_error)
    __pyx_t_13 = __pyx_f_6pandas_5_libs_6tslibs_4util_get_c_string(((PyObject*)__pyx_v_val)); if (unlikely(__pyx_t_13 == ((char const *)NULL))) __PYX_ERR(2, 6778, __pyx_L1_error)
    __pyx_v_v = __pyx_t_13;

    /* "pandas/_libs/hashtable_class_helper.pxi":6779
 *             val = values[i]
 *             v = get_c_string(val)
 *             vecs[i] = v             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    (__pyx_v_vecs[__pyx_v_i]) = __pyx_v_v;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6781
 *             vecs[i] = v
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 k = kh_get_str(table, vecs[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":6782
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 k = kh_get_str(table, vecs[i])
 *                 if k != table.n_buckets:
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_10 = __pyx_t_1;
        for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_10; __pyx_t_11+=1) {
          __pyx_v_i = __pyx_t_11;

          /* "pandas/_libs/hashtable_class_helper.pxi":6783
 *         with nogil:
 *             for i in range(n):
 *                 k = kh_get_str(table, vecs[i])             # <<<<<<<<<<<<<<
 *                 if k != table.n_buckets:
 *                     resbuf[i] = table.vals[k]
 */
          __pyx_v_k = kh_get_str(__pyx_v_table, (__pyx_v_vecs[__pyx_v_i]));

          /* "pandas/_libs/hashtable_class_helper.pxi":6784
 *             for i in range(n):
 *                 k = kh_get_str(table, vecs[i])
 *                 if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                     resbuf[i] = table.vals[k]
 *                 else:
 */
          __pyx_t_14 = (__pyx_v_k != __pyx_v_table->n_buckets);
          if (__pyx_t_14) {

            /* "pandas/_libs/hashtable_class_helper.pxi":6785
 *                 k = kh_get_str(table, vecs[i])
 *                 if k != table.n_buckets:
 *                     resbuf[i] = table.vals[k]             # <<<<<<<<<<<<<<
 *                 else:
 *                     resbuf[i] = -1
 */
            (__pyx_v_resbuf[__pyx_v_i]) = (__pyx_v_table->vals[__pyx_v_k]);

            /* "pandas/_libs/hashtable_class_helper.pxi":6784
 *             for i in range(n):
 *                 k = kh_get_str(table, vecs[i])
 *                 if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                     resbuf[i] = table.vals[k]
 *                 else:
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":6787
 *                     resbuf[i] = table.vals[k]
 *                 else:
 *                     resbuf[i] = -1             # <<<<<<<<<<<<<<
 * 
 *         free(vecs)
 */
          /*else*/ {
            (__pyx_v_resbuf[__pyx_v_i]) = -1;
          }
          __pyx_L10:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":6781
 *             vecs[i] = v
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 k = kh_get_str(table, vecs[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L7;
        }
        __pyx_L7:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6789
 *                     resbuf[i] = -1
 * 
 *         free(vecs)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  free(__pyx_v_vecs);

  /* "pandas/_libs/hashtable_class_helper.pxi":6790
 * 
 *         free(vecs)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_labels);
  __pyx_r = ((PyArrayObject *)__pyx_v_labels);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6763
 *             raise KeyError(key)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def get_indexer(self, ndarray[object] values) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.get_indexer", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_labels);
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6792
 *         return labels
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, ndarray[object] values, object mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

/* Python wrapper */
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_15lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_15lookup = {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_15lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_15lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyArrayObject *__pyx_v_values = 0;
  CYTHON_UNUSED PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyArrayObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lookup (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":6793
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, ndarray[object] values, object mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # mask not yet implemented
 */
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6792, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6792, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lookup") < 0)) __PYX_ERR(2, 6792, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_mask = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lookup", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 6792, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(2, 6793, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_14lookup(((struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":6792
 *         return labels
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, ndarray[object] values, object mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_14lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, CYTHON_UNUSED PyObject *__pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  CYTHON_UNUSED int __pyx_v_ret;
  PyObject *__pyx_v_val = 0;
  char const *__pyx_v_v;
  khiter_t __pyx_v_k;
  __Pyx_memviewslice __pyx_v_locs = { 0, 0, { 0 }, { 0 }, { 0 } };
  char const **__pyx_v_vecs;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  char const *__pyx_t_12;
  int __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lookup", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(2, 6792, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_class_helper.pxi":6797
 *         # mask not yet implemented
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             object val
 */
  __pyx_t_1 = PyObject_Length(((PyObject *)__pyx_v_values)); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(2, 6797, __pyx_L1_error)
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":6798
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             object val
 *             const char *v
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6802
 *             const char *v
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 * 
 *         # these by-definition *must* be strings
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 6802, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 6802, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6802, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 6802, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_locs = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":6805
 * 
 *         # these by-definition *must* be strings
 *         vecs = <const char **>malloc(n * sizeof(char *))             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = values[i]
 */
  __pyx_v_vecs = ((char const **)malloc((__pyx_v_n * (sizeof(char *)))));

  /* "pandas/_libs/hashtable_class_helper.pxi":6806
 *         # these by-definition *must* be strings
 *         vecs = <const char **>malloc(n * sizeof(char *))
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = values[i]
 * 
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_8 = __pyx_t_1;
  for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
    __pyx_v_i = __pyx_t_9;

    /* "pandas/_libs/hashtable_class_helper.pxi":6807
 *         vecs = <const char **>malloc(n * sizeof(char *))
 *         for i in range(n):
 *             val = values[i]             # <<<<<<<<<<<<<<
 * 
 *             if isinstance(val, str):
 */
    __pyx_t_10 = __pyx_v_i;
    if (__pyx_t_10 < 0) __pyx_t_10 += __pyx_pybuffernd_values.diminfo[0].shape;
    __pyx_t_6 = (PyObject *) *__Pyx_BufPtrStrided1d(PyObject **, __pyx_pybuffernd_values.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_values.diminfo[0].strides);
    if (unlikely(__pyx_t_6 == NULL)) __pyx_t_6 = Py_None;
    __Pyx_INCREF((PyObject*)__pyx_t_6);
    __Pyx_XDECREF_SET(__pyx_v_val, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":6809
 *             val = values[i]
 * 
 *             if isinstance(val, str):             # <<<<<<<<<<<<<<
 *                 # GH#31499 if we have a np.str_ get_c_string won't recognize
 *                 #  it as a str, even though isinstance does.
 */
    __pyx_t_11 = PyUnicode_Check(__pyx_v_val); 
    if (__pyx_t_11) {

      /* "pandas/_libs/hashtable_class_helper.pxi":6812
 *                 # GH#31499 if we have a np.str_ get_c_string won't recognize
 *                 #  it as a str, even though isinstance does.
 *                 v = get_c_string(<str>val)             # <<<<<<<<<<<<<<
 *             else:
 *                 v = get_c_string(self.na_string_sentinel)
 */
      __pyx_t_12 = __pyx_f_6pandas_5_libs_6tslibs_4util_get_c_string(((PyObject*)__pyx_v_val)); if (unlikely(__pyx_t_12 == ((char const *)NULL))) __PYX_ERR(2, 6812, __pyx_L1_error)
      __pyx_v_v = __pyx_t_12;

      /* "pandas/_libs/hashtable_class_helper.pxi":6809
 *             val = values[i]
 * 
 *             if isinstance(val, str):             # <<<<<<<<<<<<<<
 *                 # GH#31499 if we have a np.str_ get_c_string won't recognize
 *                 #  it as a str, even though isinstance does.
 */
      goto __pyx_L5;
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":6814
 *                 v = get_c_string(<str>val)
 *             else:
 *                 v = get_c_string(self.na_string_sentinel)             # <<<<<<<<<<<<<<
 *             vecs[i] = v
 * 
 */
    /*else*/ {
      __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_na_string_sentinel); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6814, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      if (!(likely(PyUnicode_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None) || __Pyx_RaiseUnexpectedTypeError("unicode", __pyx_t_6))) __PYX_ERR(2, 6814, __pyx_L1_error)
      __pyx_t_12 = __pyx_f_6pandas_5_libs_6tslibs_4util_get_c_string(((PyObject*)__pyx_t_6)); if (unlikely(__pyx_t_12 == ((char const *)NULL))) __PYX_ERR(2, 6814, __pyx_L1_error)
      __pyx_v_v = __pyx_t_12;
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __pyx_L5:;

    /* "pandas/_libs/hashtable_class_helper.pxi":6815
 *             else:
 *                 v = get_c_string(self.na_string_sentinel)
 *             vecs[i] = v             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    (__pyx_v_vecs[__pyx_v_i]) = __pyx_v_v;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6817
 *             vecs[i] = v
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 v = vecs[i]
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":6818
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 v = vecs[i]
 *                 k = kh_get_str(self.table, v)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_8 = __pyx_t_1;
        for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
          __pyx_v_i = __pyx_t_9;

          /* "pandas/_libs/hashtable_class_helper.pxi":6819
 *         with nogil:
 *             for i in range(n):
 *                 v = vecs[i]             # <<<<<<<<<<<<<<
 *                 k = kh_get_str(self.table, v)
 *                 if k != self.table.n_buckets:
 */
          __pyx_v_v = (__pyx_v_vecs[__pyx_v_i]);

          /* "pandas/_libs/hashtable_class_helper.pxi":6820
 *             for i in range(n):
 *                 v = vecs[i]
 *                 k = kh_get_str(self.table, v)             # <<<<<<<<<<<<<<
 *                 if k != self.table.n_buckets:
 *                     locs[i] = self.table.vals[k]
 */
          __pyx_v_k = kh_get_str(__pyx_v_self->table, __pyx_v_v);

          /* "pandas/_libs/hashtable_class_helper.pxi":6821
 *                 v = vecs[i]
 *                 k = kh_get_str(self.table, v)
 *                 if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     locs[i] = self.table.vals[k]
 *                 else:
 */
          __pyx_t_11 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
          if (__pyx_t_11) {

            /* "pandas/_libs/hashtable_class_helper.pxi":6822
 *                 k = kh_get_str(self.table, v)
 *                 if k != self.table.n_buckets:
 *                     locs[i] = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                 else:
 *                     locs[i] = -1
 */
            __pyx_t_10 = __pyx_v_i;
            if (__pyx_t_10 < 0) __pyx_t_10 += __pyx_v_locs.shape[0];
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_10)) )) = (__pyx_v_self->table->vals[__pyx_v_k]);

            /* "pandas/_libs/hashtable_class_helper.pxi":6821
 *                 v = vecs[i]
 *                 k = kh_get_str(self.table, v)
 *                 if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     locs[i] = self.table.vals[k]
 *                 else:
 */
            goto __pyx_L11;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":6824
 *                     locs[i] = self.table.vals[k]
 *                 else:
 *                     locs[i] = -1             # <<<<<<<<<<<<<<
 * 
 *         free(vecs)
 */
          /*else*/ {
            __pyx_t_10 = __pyx_v_i;
            if (__pyx_t_10 < 0) __pyx_t_10 += __pyx_v_locs.shape[0];
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_10)) )) = -1;
          }
          __pyx_L11:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":6817
 *             vecs[i] = v
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 v = vecs[i]
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6826
 *                     locs[i] = -1
 * 
 *         free(vecs)             # <<<<<<<<<<<<<<
 *         return np.asarray(locs)
 * 
 */
  free(__pyx_v_vecs);

  /* "pandas/_libs/hashtable_class_helper.pxi":6827
 * 
 *         free(vecs)
 *         return np.asarray(locs)             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_locs, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6827, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_13 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_13 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_13, 1+__pyx_t_13);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 6827, __pyx_L1_error)
  __pyx_r = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6792
 *         return labels
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, ndarray[object] values, object mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF(__pyx_v_val);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_locs, 1);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6829
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, ndarray[object] values, object mask = None) -> None:
 *         # mask not yet implemented
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_17map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_17map_locations = {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_17map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_17map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyArrayObject *__pyx_v_values = 0;
  CYTHON_UNUSED PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("map_locations (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":6830
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, ndarray[object] values, object mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # mask not yet implemented
 *         cdef:
 */
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6829, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6829, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "map_locations") < 0)) __PYX_ERR(2, 6829, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_mask = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("map_locations", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 6829, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(2, 6830, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_16map_locations(((struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* "pandas/_libs/hashtable_class_helper.pxi":6829
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, ndarray[object] values, object mask = None) -> None:
 *         # mask not yet implemented
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_16map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, CYTHON_UNUSED PyObject *__pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  int __pyx_v_ret;
  PyObject *__pyx_v_val = 0;
  char const *__pyx_v_v;
  char const **__pyx_v_vecs;
  khiter_t __pyx_v_k;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  char const *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("map_locations", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(2, 6829, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_class_helper.pxi":6833
 *         # mask not yet implemented
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             object val
 */
  __pyx_t_1 = PyObject_Length(((PyObject *)__pyx_v_values)); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(2, 6833, __pyx_L1_error)
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":6834
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             object val
 *             const char *v
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6841
 * 
 *         # these by-definition *must* be strings
 *         vecs = <const char **>malloc(n * sizeof(char *))             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = values[i]
 */
  __pyx_v_vecs = ((char const **)malloc((__pyx_v_n * (sizeof(char *)))));

  /* "pandas/_libs/hashtable_class_helper.pxi":6842
 *         # these by-definition *must* be strings
 *         vecs = <const char **>malloc(n * sizeof(char *))
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = values[i]
 * 
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "pandas/_libs/hashtable_class_helper.pxi":6843
 *         vecs = <const char **>malloc(n * sizeof(char *))
 *         for i in range(n):
 *             val = values[i]             # <<<<<<<<<<<<<<
 * 
 *             if isinstance(val, str):
 */
    __pyx_t_5 = __pyx_v_i;
    if (__pyx_t_5 < 0) __pyx_t_5 += __pyx_pybuffernd_values.diminfo[0].shape;
    __pyx_t_4 = (PyObject *) *__Pyx_BufPtrStrided1d(PyObject **, __pyx_pybuffernd_values.rcbuffer->pybuffer.buf, __pyx_t_5, __pyx_pybuffernd_values.diminfo[0].strides);
    if (unlikely(__pyx_t_4 == NULL)) __pyx_t_4 = Py_None;
    __Pyx_INCREF((PyObject*)__pyx_t_4);
    __Pyx_XDECREF_SET(__pyx_v_val, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":6845
 *             val = values[i]
 * 
 *             if isinstance(val, str):             # <<<<<<<<<<<<<<
 *                 # GH#31499 if we have a np.str_ get_c_string won't recognize
 *                 #  it as a str, even though isinstance does.
 */
    __pyx_t_6 = PyUnicode_Check(__pyx_v_val); 
    if (__pyx_t_6) {

      /* "pandas/_libs/hashtable_class_helper.pxi":6848
 *                 # GH#31499 if we have a np.str_ get_c_string won't recognize
 *                 #  it as a str, even though isinstance does.
 *                 v = get_c_string(<str>val)             # <<<<<<<<<<<<<<
 *             else:
 *                 v = get_c_string(self.na_string_sentinel)
 */
      __pyx_t_7 = __pyx_f_6pandas_5_libs_6tslibs_4util_get_c_string(((PyObject*)__pyx_v_val)); if (unlikely(__pyx_t_7 == ((char const *)NULL))) __PYX_ERR(2, 6848, __pyx_L1_error)
      __pyx_v_v = __pyx_t_7;

      /* "pandas/_libs/hashtable_class_helper.pxi":6845
 *             val = values[i]
 * 
 *             if isinstance(val, str):             # <<<<<<<<<<<<<<
 *                 # GH#31499 if we have a np.str_ get_c_string won't recognize
 *                 #  it as a str, even though isinstance does.
 */
      goto __pyx_L5;
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":6850
 *                 v = get_c_string(<str>val)
 *             else:
 *                 v = get_c_string(self.na_string_sentinel)             # <<<<<<<<<<<<<<
 *             vecs[i] = v
 * 
 */
    /*else*/ {
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_na_string_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6850, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      if (!(likely(PyUnicode_CheckExact(__pyx_t_4))||((__pyx_t_4) == Py_None) || __Pyx_RaiseUnexpectedTypeError("unicode", __pyx_t_4))) __PYX_ERR(2, 6850, __pyx_L1_error)
      __pyx_t_7 = __pyx_f_6pandas_5_libs_6tslibs_4util_get_c_string(((PyObject*)__pyx_t_4)); if (unlikely(__pyx_t_7 == ((char const *)NULL))) __PYX_ERR(2, 6850, __pyx_L1_error)
      __pyx_v_v = __pyx_t_7;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    }
    __pyx_L5:;

    /* "pandas/_libs/hashtable_class_helper.pxi":6851
 *             else:
 *                 v = get_c_string(self.na_string_sentinel)
 *             vecs[i] = v             # <<<<<<<<<<<<<<
 * 
 *         with nogil:
 */
    (__pyx_v_vecs[__pyx_v_i]) = __pyx_v_v;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6853
 *             vecs[i] = v
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 v = vecs[i]
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":6854
 * 
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 v = vecs[i]
 *                 k = kh_put_str(self.table, v, &ret)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_class_helper.pxi":6855
 *         with nogil:
 *             for i in range(n):
 *                 v = vecs[i]             # <<<<<<<<<<<<<<
 *                 k = kh_put_str(self.table, v, &ret)
 *                 self.table.vals[k] = i
 */
          __pyx_v_v = (__pyx_v_vecs[__pyx_v_i]);

          /* "pandas/_libs/hashtable_class_helper.pxi":6856
 *             for i in range(n):
 *                 v = vecs[i]
 *                 k = kh_put_str(self.table, v, &ret)             # <<<<<<<<<<<<<<
 *                 self.table.vals[k] = i
 *         free(vecs)
 */
          __pyx_v_k = kh_put_str(__pyx_v_self->table, __pyx_v_v, (&__pyx_v_ret));

          /* "pandas/_libs/hashtable_class_helper.pxi":6857
 *                 v = vecs[i]
 *                 k = kh_put_str(self.table, v, &ret)
 *                 self.table.vals[k] = i             # <<<<<<<<<<<<<<
 *         free(vecs)
 * 
 */
          (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":6853
 *             vecs[i] = v
 * 
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 v = vecs[i]
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L8;
        }
        __pyx_L8:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6858
 *                 k = kh_put_str(self.table, v, &ret)
 *                 self.table.vals[k] = i
 *         free(vecs)             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  free(__pyx_v_vecs);

  /* "pandas/_libs/hashtable_class_helper.pxi":6829
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, ndarray[object] values, object mask = None) -> None:
 *         # mask not yet implemented
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6860
 *         free(vecs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, ndarray[object] values, ObjectVector uniques,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_19_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15StringHashTable_18_unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[object]\n            Array of values of which unique will be calculated\n        uniques : ObjectVector\n            Vector into which uniques will be written\n        count_prior : Py_ssize_t, default 0\n            Number of existing entries in uniques\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then any value\n            that is not a string is considered missing. If na_value is\n            not None, then _additionally_ any value \"val\" satisfying\n            val == na_value is considered missing.\n        ignore_na : bool, default False\n            Whether NA-values should be ignored for calculating the uniques. If\n            True, the labels corresponding to missing values will be set to\n            na_sentinel.\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n\n        Returns\n        -------\n        uniques : ndarray[object]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse=True)\n            The labels from values to uniques\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_19_unique = {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_19_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15StringHashTable_18_unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_19_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyArrayObject *__pyx_v_values = 0;
  struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  int __pyx_v_ignore_na;
  int __pyx_v_return_inverse;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[7] = {0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_ignore_na,&__pyx_n_s_return_inverse,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":6864
 *     def _unique(self, ndarray[object] values, ObjectVector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 bint return_inverse=False):
 *         """
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6860, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6860, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 7, 1); __PYX_ERR(2, 6860, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6860, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6860, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6860, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6860, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[6] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6860, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_unique") < 0)) __PYX_ERR(2, 6860, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 6863, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 6863, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    if (values[5]) {
      __pyx_v_ignore_na = __Pyx_PyObject_IsTrue(values[5]); if (unlikely((__pyx_v_ignore_na == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 6864, __pyx_L3_error)
    } else {
      __pyx_v_ignore_na = ((int)0);
    }
    if (values[6]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[6]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 6865, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":6865
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 bint return_inverse=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
      __pyx_v_return_inverse = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 7, __pyx_nargs); __PYX_ERR(2, 6860, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(2, 6862, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector, 1, "uniques", 0))) __PYX_ERR(2, 6862, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_18_unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_ignore_na, __pyx_v_return_inverse);

  /* "pandas/_libs/hashtable_class_helper.pxi":6860
 *         free(vecs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, ndarray[object] values, ObjectVector uniques,
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_18_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, int __pyx_v_return_inverse) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_idx;
  Py_ssize_t __pyx_v_count;
  Py_ssize_t __pyx_v_n;
  __Pyx_memviewslice __pyx_v_labels = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_v_uindexer = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_ret;
  PyObject *__pyx_v_val = 0;
  char const *__pyx_v_v;
  char const **__pyx_v_vecs;
  khiter_t __pyx_v_k;
  int __pyx_v_use_na_value;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_8 = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  int __pyx_t_13;
  int __pyx_t_14;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  char const *__pyx_t_18;
  int __pyx_t_19;
  __pyx_t_5numpy_int64_t __pyx_t_20;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_unique", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(2, 6860, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_class_helper.pxi":6900
 *         """
 *         cdef:
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)             # <<<<<<<<<<<<<<
 *             intp_t[::1] labels
 *             int64_t[::1] uindexer
 */
  __pyx_v_count = __pyx_v_count_prior;
  __pyx_t_1 = PyObject_Length(((PyObject *)__pyx_v_values)); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(2, 6900, __pyx_L1_error)
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":6903
 *             intp_t[::1] labels
 *             int64_t[::1] uindexer
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             object val
 *             const char *v
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6910
 *             bint use_na_value
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.zeros(n, dtype=np.intp)
 *         uindexer = np.empty(n, dtype=np.int64)
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6911
 * 
 *         if return_inverse:
 *             labels = np.zeros(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *         uindexer = np.empty(n, dtype=np.int64)
 *         use_na_value = na_value is not None
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6911, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6911, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6911, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6911, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 6911, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6911, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6911, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6911, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 6911, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6911, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 6911, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_labels = __pyx_t_7;
    __pyx_t_7.memview = NULL;
    __pyx_t_7.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":6910
 *             bint use_na_value
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.zeros(n, dtype=np.intp)
 *         uindexer = np.empty(n, dtype=np.int64)
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6912
 *         if return_inverse:
 *             labels = np.zeros(n, dtype=np.intp)
 *         uindexer = np.empty(n, dtype=np.int64)             # <<<<<<<<<<<<<<
 *         use_na_value = na_value is not None
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_empty); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6)) __PYX_ERR(2, 6912, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetModuleGlobalName(__pyx_t_3, __pyx_n_s_np); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_int64); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_dtype, __pyx_t_5) < 0) __PYX_ERR(2, 6912, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, __pyx_t_6); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6912, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_8 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_5, PyBUF_WRITABLE); if (unlikely(!__pyx_t_8.memview)) __PYX_ERR(2, 6912, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_uindexer = __pyx_t_8;
  __pyx_t_8.memview = NULL;
  __pyx_t_8.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":6913
 *             labels = np.zeros(n, dtype=np.intp)
 *         uindexer = np.empty(n, dtype=np.int64)
 *         use_na_value = na_value is not None             # <<<<<<<<<<<<<<
 * 
 *         # assign pointers and pre-filter out missing (if ignore_na)
 */
  __pyx_t_9 = (__pyx_v_na_value != Py_None);
  __pyx_v_use_na_value = __pyx_t_9;

  /* "pandas/_libs/hashtable_class_helper.pxi":6916
 * 
 *         # assign pointers and pre-filter out missing (if ignore_na)
 *         vecs = <const char **>malloc(n * sizeof(char *))             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = values[i]
 */
  __pyx_v_vecs = ((char const **)malloc((__pyx_v_n * (sizeof(char *)))));

  /* "pandas/_libs/hashtable_class_helper.pxi":6917
 *         # assign pointers and pre-filter out missing (if ignore_na)
 *         vecs = <const char **>malloc(n * sizeof(char *))
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = values[i]
 * 
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_10 = __pyx_t_1;
  for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_10; __pyx_t_11+=1) {
    __pyx_v_i = __pyx_t_11;

    /* "pandas/_libs/hashtable_class_helper.pxi":6918
 *         vecs = <const char **>malloc(n * sizeof(char *))
 *         for i in range(n):
 *             val = values[i]             # <<<<<<<<<<<<<<
 * 
 *             if (ignore_na
 */
    __pyx_t_12 = __pyx_v_i;
    __pyx_t_5 = (PyObject *) *__Pyx_BufPtrStrided1d(PyObject **, __pyx_pybuffernd_values.rcbuffer->pybuffer.buf, __pyx_t_12, __pyx_pybuffernd_values.diminfo[0].strides);
    if (unlikely(__pyx_t_5 == NULL)) __pyx_t_5 = Py_None;
    __Pyx_INCREF((PyObject*)__pyx_t_5);
    __Pyx_XDECREF_SET(__pyx_v_val, __pyx_t_5);
    __pyx_t_5 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":6920
 *             val = values[i]
 * 
 *             if (ignore_na             # <<<<<<<<<<<<<<
 *                 and (not isinstance(val, str)
 *                      or (use_na_value and val == na_value))):
 */
    if (__pyx_v_ignore_na) {
    } else {
      __pyx_t_9 = __pyx_v_ignore_na;
      goto __pyx_L7_bool_binop_done;
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":6921
 * 
 *             if (ignore_na
 *                 and (not isinstance(val, str)             # <<<<<<<<<<<<<<
 *                      or (use_na_value and val == na_value))):
 *                 # if missing values do not count as unique values (i.e. if
 */
    __pyx_t_13 = PyUnicode_Check(__pyx_v_val); 
    __pyx_t_14 = (!__pyx_t_13);
    if (!__pyx_t_14) {
    } else {
      __pyx_t_9 = __pyx_t_14;
      goto __pyx_L7_bool_binop_done;
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":6922
 *             if (ignore_na
 *                 and (not isinstance(val, str)
 *                      or (use_na_value and val == na_value))):             # <<<<<<<<<<<<<<
 *                 # if missing values do not count as unique values (i.e. if
 *                 # ignore_na is True), we can skip the actual value, and
 */
    if (__pyx_v_use_na_value) {
    } else {
      __pyx_t_9 = __pyx_v_use_na_value;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_5 = PyObject_RichCompare(__pyx_v_val, __pyx_v_na_value, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6922, __pyx_L1_error)
    __pyx_t_14 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_14 < 0))) __PYX_ERR(2, 6922, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_9 = __pyx_t_14;
    __pyx_L7_bool_binop_done:;

    /* "pandas/_libs/hashtable_class_helper.pxi":6920
 *             val = values[i]
 * 
 *             if (ignore_na             # <<<<<<<<<<<<<<
 *                 and (not isinstance(val, str)
 *                      or (use_na_value and val == na_value))):
 */
    if (__pyx_t_9) {

      /* "pandas/_libs/hashtable_class_helper.pxi":6926
 *                 # ignore_na is True), we can skip the actual value, and
 *                 # replace the label with na_sentinel directly
 *                 labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *             else:
 *                 # if ignore_na is False, we also stringify NaN/None/etc.
 */
      if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundLocalError("labels"); __PYX_ERR(2, 6926, __pyx_L1_error) }
      __pyx_t_12 = __pyx_v_i;
      *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_12)) )) = __pyx_v_na_sentinel;

      /* "pandas/_libs/hashtable_class_helper.pxi":6920
 *             val = values[i]
 * 
 *             if (ignore_na             # <<<<<<<<<<<<<<
 *                 and (not isinstance(val, str)
 *                      or (use_na_value and val == na_value))):
 */
      goto __pyx_L6;
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":6929
 *             else:
 *                 # if ignore_na is False, we also stringify NaN/None/etc.
 *                 try:             # <<<<<<<<<<<<<<
 *                     v = get_c_string(<str>val)
 *                 except UnicodeEncodeError:
 */
    /*else*/ {
      {
        __Pyx_PyThreadState_declare
        __Pyx_PyThreadState_assign
        __Pyx_ExceptionSave(&__pyx_t_15, &__pyx_t_16, &__pyx_t_17);
        __Pyx_XGOTREF(__pyx_t_15);
        __Pyx_XGOTREF(__pyx_t_16);
        __Pyx_XGOTREF(__pyx_t_17);
        /*try:*/ {

          /* "pandas/_libs/hashtable_class_helper.pxi":6930
 *                 # if ignore_na is False, we also stringify NaN/None/etc.
 *                 try:
 *                     v = get_c_string(<str>val)             # <<<<<<<<<<<<<<
 *                 except UnicodeEncodeError:
 *                     v = get_c_string(<str>repr(val))
 */
          __pyx_t_18 = __pyx_f_6pandas_5_libs_6tslibs_4util_get_c_string(((PyObject*)__pyx_v_val)); if (unlikely(__pyx_t_18 == ((char const *)NULL))) __PYX_ERR(2, 6930, __pyx_L11_error)
          __pyx_v_v = __pyx_t_18;

          /* "pandas/_libs/hashtable_class_helper.pxi":6929
 *             else:
 *                 # if ignore_na is False, we also stringify NaN/None/etc.
 *                 try:             # <<<<<<<<<<<<<<
 *                     v = get_c_string(<str>val)
 *                 except UnicodeEncodeError:
 */
        }
        __Pyx_XDECREF(__pyx_t_15); __pyx_t_15 = 0;
        __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
        goto __pyx_L18_try_end;
        __pyx_L11_error:;
        __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
        __pyx_t_7.memview = NULL; __pyx_t_7.data = NULL;
        __PYX_XCLEAR_MEMVIEW(&__pyx_t_8, 1);
        __pyx_t_8.memview = NULL; __pyx_t_8.data = NULL;

        /* "pandas/_libs/hashtable_class_helper.pxi":6931
 *                 try:
 *                     v = get_c_string(<str>val)
 *                 except UnicodeEncodeError:             # <<<<<<<<<<<<<<
 *                     v = get_c_string(<str>repr(val))
 *                 vecs[i] = v
 */
        __pyx_t_19 = __Pyx_PyErr_ExceptionMatches(__pyx_builtin_UnicodeEncodeError);
        if (__pyx_t_19) {
          __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
          if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_6, &__pyx_t_4) < 0) __PYX_ERR(2, 6931, __pyx_L13_except_error)
          __Pyx_XGOTREF(__pyx_t_5);
          __Pyx_XGOTREF(__pyx_t_6);
          __Pyx_XGOTREF(__pyx_t_4);

          /* "pandas/_libs/hashtable_class_helper.pxi":6932
 *                     v = get_c_string(<str>val)
 *                 except UnicodeEncodeError:
 *                     v = get_c_string(<str>repr(val))             # <<<<<<<<<<<<<<
 *                 vecs[i] = v
 * 
 */
          __pyx_t_2 = PyObject_Repr(__pyx_v_val); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6932, __pyx_L13_except_error)
          __Pyx_GOTREF(__pyx_t_2);
          __pyx_t_18 = __pyx_f_6pandas_5_libs_6tslibs_4util_get_c_string(((PyObject*)__pyx_t_2)); if (unlikely(__pyx_t_18 == ((char const *)NULL))) __PYX_ERR(2, 6932, __pyx_L13_except_error)
          __pyx_v_v = __pyx_t_18;
          __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          goto __pyx_L12_exception_handled;
        }
        goto __pyx_L13_except_error;

        /* "pandas/_libs/hashtable_class_helper.pxi":6929
 *             else:
 *                 # if ignore_na is False, we also stringify NaN/None/etc.
 *                 try:             # <<<<<<<<<<<<<<
 *                     v = get_c_string(<str>val)
 *                 except UnicodeEncodeError:
 */
        __pyx_L13_except_error:;
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
        goto __pyx_L1_error;
        __pyx_L12_exception_handled:;
        __Pyx_XGIVEREF(__pyx_t_15);
        __Pyx_XGIVEREF(__pyx_t_16);
        __Pyx_XGIVEREF(__pyx_t_17);
        __Pyx_ExceptionReset(__pyx_t_15, __pyx_t_16, __pyx_t_17);
        __pyx_L18_try_end:;
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":6933
 *                 except UnicodeEncodeError:
 *                     v = get_c_string(<str>repr(val))
 *                 vecs[i] = v             # <<<<<<<<<<<<<<
 * 
 *         # compute
 */
      (__pyx_v_vecs[__pyx_v_i]) = __pyx_v_v;
    }
    __pyx_L6:;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6936
 * 
 *         # compute
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if ignore_na and labels[i] == na_sentinel:
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_class_helper.pxi":6937
 *         # compute
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if ignore_na and labels[i] == na_sentinel:
 *                     # skip entries for ignored missing values (see above)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_10 = __pyx_t_1;
        for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_10; __pyx_t_11+=1) {
          __pyx_v_i = __pyx_t_11;

          /* "pandas/_libs/hashtable_class_helper.pxi":6938
 *         with nogil:
 *             for i in range(n):
 *                 if ignore_na and labels[i] == na_sentinel:             # <<<<<<<<<<<<<<
 *                     # skip entries for ignored missing values (see above)
 *                     continue
 */
          if (__pyx_v_ignore_na) {
          } else {
            __pyx_t_9 = __pyx_v_ignore_na;
            goto __pyx_L27_bool_binop_done;
          }
          if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 6938, __pyx_L22_error) }
          __pyx_t_12 = __pyx_v_i;
          __pyx_t_14 = ((*((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_12)) ))) == __pyx_v_na_sentinel);
          __pyx_t_9 = __pyx_t_14;
          __pyx_L27_bool_binop_done:;
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":6940
 *                 if ignore_na and labels[i] == na_sentinel:
 *                     # skip entries for ignored missing values (see above)
 *                     continue             # <<<<<<<<<<<<<<
 * 
 *                 v = vecs[i]
 */
            goto __pyx_L24_continue;

            /* "pandas/_libs/hashtable_class_helper.pxi":6938
 *         with nogil:
 *             for i in range(n):
 *                 if ignore_na and labels[i] == na_sentinel:             # <<<<<<<<<<<<<<
 *                     # skip entries for ignored missing values (see above)
 *                     continue
 */
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":6942
 *                     continue
 * 
 *                 v = vecs[i]             # <<<<<<<<<<<<<<
 *                 k = kh_get_str(self.table, v)
 *                 if k == self.table.n_buckets:
 */
          __pyx_v_v = (__pyx_v_vecs[__pyx_v_i]);

          /* "pandas/_libs/hashtable_class_helper.pxi":6943
 * 
 *                 v = vecs[i]
 *                 k = kh_get_str(self.table, v)             # <<<<<<<<<<<<<<
 *                 if k == self.table.n_buckets:
 *                     # k hasn't been seen yet
 */
          __pyx_v_k = kh_get_str(__pyx_v_self->table, __pyx_v_v);

          /* "pandas/_libs/hashtable_class_helper.pxi":6944
 *                 v = vecs[i]
 *                 k = kh_get_str(self.table, v)
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_str(self.table, v, &ret)
 */
          __pyx_t_9 = (__pyx_v_k == __pyx_v_self->table->n_buckets);
          if (__pyx_t_9) {

            /* "pandas/_libs/hashtable_class_helper.pxi":6946
 *                 if k == self.table.n_buckets:
 *                     # k hasn't been seen yet
 *                     k = kh_put_str(self.table, v, &ret)             # <<<<<<<<<<<<<<
 *                     uindexer[count] = i
 *                     if return_inverse:
 */
            __pyx_v_k = kh_put_str(__pyx_v_self->table, __pyx_v_v, (&__pyx_v_ret));

            /* "pandas/_libs/hashtable_class_helper.pxi":6947
 *                     # k hasn't been seen yet
 *                     k = kh_put_str(self.table, v, &ret)
 *                     uindexer[count] = i             # <<<<<<<<<<<<<<
 *                     if return_inverse:
 *                         self.table.vals[k] = count
 */
            __pyx_t_12 = __pyx_v_count;
            *((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_uindexer.data) + __pyx_t_12)) )) = __pyx_v_i;

            /* "pandas/_libs/hashtable_class_helper.pxi":6948
 *                     k = kh_put_str(self.table, v, &ret)
 *                     uindexer[count] = i
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            if (__pyx_v_return_inverse) {

              /* "pandas/_libs/hashtable_class_helper.pxi":6949
 *                     uindexer[count] = i
 *                     if return_inverse:
 *                         self.table.vals[k] = count             # <<<<<<<<<<<<<<
 *                         labels[i] = count
 *                     count += 1
 */
              (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":6950
 *                     if return_inverse:
 *                         self.table.vals[k] = count
 *                         labels[i] = count             # <<<<<<<<<<<<<<
 *                     count += 1
 *                 elif return_inverse:
 */
              if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 6950, __pyx_L22_error) }
              __pyx_t_12 = __pyx_v_i;
              *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_12)) )) = __pyx_v_count;

              /* "pandas/_libs/hashtable_class_helper.pxi":6948
 *                     k = kh_put_str(self.table, v, &ret)
 *                     uindexer[count] = i
 *                     if return_inverse:             # <<<<<<<<<<<<<<
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 */
            }

            /* "pandas/_libs/hashtable_class_helper.pxi":6951
 *                         self.table.vals[k] = count
 *                         labels[i] = count
 *                     count += 1             # <<<<<<<<<<<<<<
 *                 elif return_inverse:
 *                     # k falls into a previous bucket
 */
            __pyx_v_count = (__pyx_v_count + 1);

            /* "pandas/_libs/hashtable_class_helper.pxi":6944
 *                 v = vecs[i]
 *                 k = kh_get_str(self.table, v)
 *                 if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                     # k hasn't been seen yet
 *                     k = kh_put_str(self.table, v, &ret)
 */
            goto __pyx_L29;
          }

          /* "pandas/_libs/hashtable_class_helper.pxi":6952
 *                         labels[i] = count
 *                     count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          if (__pyx_v_return_inverse) {

            /* "pandas/_libs/hashtable_class_helper.pxi":6955
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                     labels[i] = idx
 * 
 */
            __pyx_v_idx = (__pyx_v_self->table->vals[__pyx_v_k]);

            /* "pandas/_libs/hashtable_class_helper.pxi":6956
 *                     # only relevant in case we need to construct the inverse
 *                     idx = self.table.vals[k]
 *                     labels[i] = idx             # <<<<<<<<<<<<<<
 * 
 *         free(vecs)
 */
            if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundMemoryviewSliceNogil("labels"); __PYX_ERR(2, 6956, __pyx_L22_error) }
            __pyx_t_12 = __pyx_v_i;
            *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_12)) )) = __pyx_v_idx;

            /* "pandas/_libs/hashtable_class_helper.pxi":6952
 *                         labels[i] = count
 *                     count += 1
 *                 elif return_inverse:             # <<<<<<<<<<<<<<
 *                     # k falls into a previous bucket
 *                     # only relevant in case we need to construct the inverse
 */
          }
          __pyx_L29:;
          __pyx_L24_continue:;
        }
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":6936
 * 
 *         # compute
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if ignore_na and labels[i] == na_sentinel:
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L23;
        }
        __pyx_L22_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L23:;
      }
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6958
 *                     labels[i] = idx
 * 
 *         free(vecs)             # <<<<<<<<<<<<<<
 * 
 *         # uniques
 */
  free(__pyx_v_vecs);

  /* "pandas/_libs/hashtable_class_helper.pxi":6961
 * 
 *         # uniques
 *         for i in range(count):             # <<<<<<<<<<<<<<
 *             uniques.append(values[uindexer[i]])
 * 
 */
  __pyx_t_1 = __pyx_v_count;
  __pyx_t_10 = __pyx_t_1;
  for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_10; __pyx_t_11+=1) {
    __pyx_v_i = __pyx_t_11;

    /* "pandas/_libs/hashtable_class_helper.pxi":6962
 *         # uniques
 *         for i in range(count):
 *             uniques.append(values[uindexer[i]])             # <<<<<<<<<<<<<<
 * 
 *         if return_inverse:
 */
    __pyx_t_12 = __pyx_v_i;
    __pyx_t_20 = (*((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_uindexer.data) + __pyx_t_12)) )));
    __pyx_t_4 = (PyObject *) *__Pyx_BufPtrStrided1d(PyObject **, __pyx_pybuffernd_values.rcbuffer->pybuffer.buf, __pyx_t_20, __pyx_pybuffernd_values.diminfo[0].strides);
    if (unlikely(__pyx_t_4 == NULL)) __pyx_t_4 = Py_None;
    __Pyx_INCREF((PyObject*)__pyx_t_4);
    __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_v_uniques->__pyx_vtab)->append(__pyx_v_uniques, __pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6962, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6964
 *             uniques.append(values[uindexer[i]])
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         return uniques.to_array()
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":6965
 * 
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray             # <<<<<<<<<<<<<<
 *         return uniques.to_array()
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 6965, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundLocalError("labels"); __PYX_ERR(2, 6965, __pyx_L1_error) }
    __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_labels, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6965, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_base); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6965, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6965, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_6);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_6)) __PYX_ERR(2, 6965, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_5);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_5)) __PYX_ERR(2, 6965, __pyx_L1_error);
    __pyx_t_6 = 0;
    __pyx_t_5 = 0;
    __pyx_r = __pyx_t_4;
    __pyx_t_4 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":6964
 *             uniques.append(values[uindexer[i]])
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         return uniques.to_array()
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":6966
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         return uniques.to_array()             # <<<<<<<<<<<<<<
 * 
 *     def unique(self, ndarray[object] values, bint return_inverse=False, object mask=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6966, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6860
 *         free(vecs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, ndarray[object] values, ObjectVector uniques,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_8, 1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_labels, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_uindexer, 1);
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6968
 *         return uniques.to_array()
 * 
 *     def unique(self, ndarray[object] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_21unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15StringHashTable_20unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[object]\n            Array of values of which unique will be calculated\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        mask : ndarray[bool], optional\n            Not yet implemented for StringHashTable\n\n        Returns\n        -------\n        uniques : ndarray[object]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse)\n            The labels from values to uniques\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_21unique = {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_21unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15StringHashTable_20unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_21unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_return_inverse;
  CYTHON_UNUSED PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_return_inverse,&__pyx_n_s_mask,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6968, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6968, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6968, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "unique") < 0)) __PYX_ERR(2, 6968, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    if (values[1]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 6968, __pyx_L3_error)
    } else {
      __pyx_v_return_inverse = ((int)0);
    }
    __pyx_v_mask = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("unique", 0, 1, 3, __pyx_nargs); __PYX_ERR(2, 6968, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(2, 6968, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_20unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_return_inverse, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_20unique(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, int __pyx_v_return_inverse, CYTHON_UNUSED PyObject *__pyx_v_mask) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_uniques = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unique", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(2, 6968, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_class_helper.pxi":6989
 *             The labels from values to uniques
 *         """
 *         uniques = ObjectVector()             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse)
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6990
 *         """
 *         uniques = ObjectVector()
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6990, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 6990, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF((PyObject *)__pyx_v_values);
  __Pyx_GIVEREF((PyObject *)__pyx_v_values);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_values))) __PYX_ERR(2, 6990, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 6990, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 6990, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ignore_na, Py_False) < 0) __PYX_ERR(2, 6990, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6991
 *         uniques = ObjectVector()
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse)             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, ndarray[object] values, Py_ssize_t na_sentinel=-1,
 */
  __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_v_return_inverse); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6991, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return_inverse, __pyx_t_4) < 0) __PYX_ERR(2, 6990, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6990
 *         """
 *         uniques = ObjectVector()
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse)
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6990, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6968
 *         return uniques.to_array()
 * 
 *     def unique(self, ndarray[object] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":6993
 *                             return_inverse=return_inverse)
 * 
 *     def factorize(self, ndarray[object] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_23factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_15StringHashTable_22factorize, "\n        Calculate unique values and labels (no sorting!)\n\n        Missing values are not included in the \"uniques\" for this method.\n        The labels for any missing values will be set to \"na_sentinel\"\n\n        Parameters\n        ----------\n        values : ndarray[object]\n            Array of values of which unique will be calculated\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then any value\n            that is not a string is considered missing. If na_value is\n            not None, then _additionally_ any value \"val\" satisfying\n            val == na_value is considered missing.\n        mask : ndarray[bool], optional\n            Not yet implemented for StringHashTable.\n\n        Returns\n        -------\n        uniques : ndarray[object]\n            Unique values of input, not sorted\n        labels : ndarray[intp]\n            The labels from values to uniques\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_23factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_23factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15StringHashTable_22factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_23factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyArrayObject *__pyx_v_values = 0;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  CYTHON_UNUSED PyObject *__pyx_v_mask = 0;
  PyObject *__pyx_v_ignore_na = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,&__pyx_n_s_ignore_na,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":6994
 * 
 *     def factorize(self, ndarray[object] values, Py_ssize_t na_sentinel=-1,
 *                   object na_value=None, object mask=None, ignore_na=True):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_True));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6993, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6993, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6993, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6993, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 6993, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 6993, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    if (values[1]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 6993, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
    __pyx_v_ignore_na = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 5, __pyx_nargs); __PYX_ERR(2, 6993, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(2, 6993, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_22factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask, __pyx_v_ignore_na);

  /* "pandas/_libs/hashtable_class_helper.pxi":6993
 *                             return_inverse=return_inverse)
 * 
 *     def factorize(self, ndarray[object] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_22factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, CYTHON_UNUSED PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_uniques_vector = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(2, 6993, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_class_helper.pxi":7022
 *             The labels from values to uniques
 *         """
 *         uniques_vector = ObjectVector()             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7022, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques_vector = ((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7023
 *         """
 *         uniques_vector = ObjectVector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na,
 *                             return_inverse=True)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7023, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7023, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF((PyObject *)__pyx_v_values);
  __Pyx_GIVEREF((PyObject *)__pyx_v_values);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_values))) __PYX_ERR(2, 7023, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques_vector);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_uniques_vector))) __PYX_ERR(2, 7023, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7023, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 7023, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 7023, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7024
 *         uniques_vector = ObjectVector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na,             # <<<<<<<<<<<<<<
 *                             return_inverse=True)
 * 
 */
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 7023, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ignore_na, __pyx_v_ignore_na) < 0) __PYX_ERR(2, 7023, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":7025
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na,
 *                             return_inverse=True)             # <<<<<<<<<<<<<<
 * 
 *     def get_labels(self, ndarray[object] values, ObjectVector uniques,
 */
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 7023, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":7023
 *         """
 *         uniques_vector = ObjectVector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na,
 *                             return_inverse=True)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 7023, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6993
 *                             return_inverse=return_inverse)
 * 
 *     def factorize(self, ndarray[object] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":7027
 *                             return_inverse=True)
 * 
 *     def get_labels(self, ndarray[object] values, ObjectVector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_25get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_25get_labels = {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_25get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_25get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyArrayObject *__pyx_v_values = 0;
  struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_labels (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":7029
 *     def get_labels(self, ndarray[object] values, ObjectVector uniques,
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None):             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7027, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7027, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 5, 1); __PYX_ERR(2, 7027, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7027, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7027, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7027, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_labels") < 0)) __PYX_ERR(2, 7027, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 7028, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 7028, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 5, __pyx_nargs); __PYX_ERR(2, 7027, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(2, 7027, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector, 1, "uniques", 0))) __PYX_ERR(2, 7027, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_24get_labels(((struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value);

  /* "pandas/_libs/hashtable_class_helper.pxi":7027
 *                             return_inverse=True)
 * 
 *     def get_labels(self, ndarray[object] values, ObjectVector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_24get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value) {
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_v_labels = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_labels", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(2, 7027, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_class_helper.pxi":7031
 *                    object na_value=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF((PyObject *)__pyx_v_values);
  __Pyx_GIVEREF((PyObject *)__pyx_v_values);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_values))) __PYX_ERR(2, 7031, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 7031, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_count_prior); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 7031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_count_prior, __pyx_t_4) < 0) __PYX_ERR(2, 7031, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7032
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,             # <<<<<<<<<<<<<<
 *                                  ignore_na=True, return_inverse=True)
 *         return labels
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 7032, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 7031, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 7031, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":7033
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True)             # <<<<<<<<<<<<<<
 *         return labels
 * 
 */
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ignore_na, Py_True) < 0) __PYX_ERR(2, 7031, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 7031, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":7031
 *                    object na_value=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 7031, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
    PyObject* sequence = __pyx_t_4;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(2, 7031, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_2 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7031, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7031, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7031, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
    index = 0; __pyx_t_3 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_2 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_1), 2) < 0) __PYX_ERR(2, 7031, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(2, 7031, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v__ = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_labels = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7034
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True)
 *         return labels             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_labels);
  __pyx_r = __pyx_v_labels;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7027
 *                             return_inverse=True)
 * 
 *     def get_labels(self, ndarray[object] values, ObjectVector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XDECREF(__pyx_v_labels);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_27__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_27__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_27__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_27__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_26__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_26__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_self_table_cannot_be_converted_t, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_29__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_29__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_29__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_29__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_28__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_15StringHashTable_28__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_self_table_cannot_be_converted_t, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.StringHashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":7039
 * cdef class PyObjectHashTable(HashTable):
 * 
 *     def __init__(self, int64_t size_hint=1):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_pymap()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __pyx_t_5numpy_int64_t __pyx_v_size_hint;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint);
          if (value) { values[0] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7039, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__init__") < 0)) __PYX_ERR(2, 7039, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    if (values[0]) {
      __pyx_v_size_hint = __Pyx_PyInt_As_npy_int64(values[0]); if (unlikely((__pyx_v_size_hint == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 7039, __pyx_L3_error)
    } else {
      __pyx_v_size_hint = ((__pyx_t_5numpy_int64_t)1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 0, 1, __pyx_nargs); __PYX_ERR(2, 7039, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable___init__(((struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *)__pyx_v_self), __pyx_v_size_hint);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable___init__(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, __pyx_t_5numpy_int64_t __pyx_v_size_hint) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  khuint_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  __pyx_t_5numpy_int64_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":7040
 * 
 *     def __init__(self, int64_t size_hint=1):
 *         self.table = kh_init_pymap()             # <<<<<<<<<<<<<<
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_pymap(self.table, size_hint)
 */
  __pyx_v_self->table = kh_init_pymap();

  /* "pandas/_libs/hashtable_class_helper.pxi":7041
 *     def __init__(self, int64_t size_hint=1):
 *         self.table = kh_init_pymap()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)             # <<<<<<<<<<<<<<
 *         kh_resize_pymap(self.table, size_hint)
 * 
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = kh_needed_n_buckets(__pyx_v_size_hint);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 7041, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_1, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 7041, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(2, 7041, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__pyx_t_6) {
    __Pyx_INCREF(__pyx_t_1);
    __pyx_t_3 = __pyx_t_1;
  } else {
    __pyx_t_5 = __Pyx_PyInt_From_npy_uint32(__pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 7041, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_3 = __pyx_t_5;
    __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_int64(__pyx_t_3); if (unlikely((__pyx_t_7 == ((npy_int64)-1)) && PyErr_Occurred())) __PYX_ERR(2, 7041, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_size_hint = __pyx_t_7;

  /* "pandas/_libs/hashtable_class_helper.pxi":7042
 *         self.table = kh_init_pymap()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 *         kh_resize_pymap(self.table, size_hint)             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  kh_resize_pymap(__pyx_v_self->table, __pyx_v_size_hint);

  /* "pandas/_libs/hashtable_class_helper.pxi":7039
 * cdef class PyObjectHashTable(HashTable):
 * 
 *     def __init__(self, int64_t size_hint=1):             # <<<<<<<<<<<<<<
 *         self.table = kh_init_pymap()
 *         size_hint = min(kh_needed_n_buckets(size_hint), SIZE_HINT_LIMIT)
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":7044
 *         kh_resize_pymap(self.table, size_hint)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_pymap(self.table)
 */

/* Python wrapper */
static void __pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_3__dealloc__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_2__dealloc__(((struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_2__dealloc__(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self) {
  int __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":7045
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_pymap(self.table)
 *             self.table = NULL
 */
  __pyx_t_1 = (__pyx_v_self->table != NULL);
  if (__pyx_t_1) {

    /* "pandas/_libs/hashtable_class_helper.pxi":7046
 *     def __dealloc__(self):
 *         if self.table is not NULL:
 *             kh_destroy_pymap(self.table)             # <<<<<<<<<<<<<<
 *             self.table = NULL
 * 
 */
    kh_destroy_pymap(__pyx_v_self->table);

    /* "pandas/_libs/hashtable_class_helper.pxi":7047
 *         if self.table is not NULL:
 *             kh_destroy_pymap(self.table)
 *             self.table = NULL             # <<<<<<<<<<<<<<
 * 
 *     def __len__(self) -> int:
 */
    __pyx_v_self->table = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":7045
 * 
 *     def __dealloc__(self):
 *         if self.table is not NULL:             # <<<<<<<<<<<<<<
 *             kh_destroy_pymap(self.table)
 *             self.table = NULL
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":7044
 *         kh_resize_pymap(self.table, size_hint)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self.table is not NULL:
 *             kh_destroy_pymap(self.table)
 */

  /* function exit code */
}

/* "pandas/_libs/hashtable_class_helper.pxi":7049
 *             self.table = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size
 * 
 */

/* Python wrapper */
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_5__len__(PyObject *__pyx_v_self); /*proto*/
static Py_ssize_t __pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_5__len__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  Py_ssize_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__len__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_4__len__(((struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static Py_ssize_t __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_4__len__(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self) {
  Py_ssize_t __pyx_r;

  /* "pandas/_libs/hashtable_class_helper.pxi":7050
 * 
 *     def __len__(self) -> int:
 *         return self.table.size             # <<<<<<<<<<<<<<
 * 
 *     def __contains__(self, object key) -> bool:
 */
  __pyx_r = __pyx_v_self->table->size;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7049
 *             self.table = NULL
 * 
 *     def __len__(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.table.size
 * 
 */

  /* function exit code */
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":7052
 *         return self.table.size
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         cdef:
 *             khiter_t k
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_7__contains__(PyObject *__pyx_v_self, PyObject *__pyx_v_key) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__contains__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_6__contains__(((struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *)__pyx_v_self), ((PyObject *)__pyx_v_key));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_6__contains__(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, PyObject *__pyx_v_key) {
  khiter_t __pyx_v_k;
  int __pyx_r;
  Py_hash_t __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7055
 *         cdef:
 *             khiter_t k
 *         hash(key)             # <<<<<<<<<<<<<<
 * 
 *         k = kh_get_pymap(self.table, <PyObject*>key)
 */
  __pyx_t_1 = PyObject_Hash(__pyx_v_key); if (unlikely(__pyx_t_1 == ((Py_hash_t)-1))) __PYX_ERR(2, 7055, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":7057
 *         hash(key)
 * 
 *         k = kh_get_pymap(self.table, <PyObject*>key)             # <<<<<<<<<<<<<<
 *         return k != self.table.n_buckets
 * 
 */
  __pyx_v_k = kh_get_pymap(__pyx_v_self->table, ((PyObject *)__pyx_v_key));

  /* "pandas/_libs/hashtable_class_helper.pxi":7058
 * 
 *         k = kh_get_pymap(self.table, <PyObject*>key)
 *         return k != self.table.n_buckets             # <<<<<<<<<<<<<<
 * 
 *     def sizeof(self, deep: bool = False) -> int:
 */
  __pyx_r = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7052
 *         return self.table.size
 * 
 *     def __contains__(self, object key) -> bool:             # <<<<<<<<<<<<<<
 *         cdef:
 *             khiter_t k
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.__contains__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":7060
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_17PyObjectHashTable_8sizeof, " return the size of my table in bytes ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_9sizeof = {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_17PyObjectHashTable_8sizeof};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_9sizeof(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_deep = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sizeof (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_deep,0};
    values[0] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_False));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_deep);
          if (value) { values[0] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7060, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "sizeof") < 0)) __PYX_ERR(2, 7060, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_deep = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sizeof", 0, 0, 1, __pyx_nargs); __PYX_ERR(2, 7060, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_8sizeof(((struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *)__pyx_v_self), __pyx_v_deep);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_8sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_deep) {
  PyObject *__pyx_v_overhead = NULL;
  PyObject *__pyx_v_for_flags = NULL;
  PyObject *__pyx_v_for_pairs = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  long __pyx_t_2;
  long __pyx_t_3;
  long __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sizeof", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":7062
 *     def sizeof(self, deep: bool = False) -> int:
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)             # <<<<<<<<<<<<<<
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(PyObject *) +  # keys
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t(((4 * (sizeof(__pyx_t_5numpy_uint32_t))) + (3 * (sizeof(__pyx_t_5numpy_uint32_t *))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7062, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_overhead = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7063
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)             # <<<<<<<<<<<<<<
 *         for_pairs =  self.table.n_buckets * (sizeof(PyObject *) +  # keys
 *                                              sizeof(Py_ssize_t))   # vals
 */
  __pyx_t_2 = (__pyx_v_self->table->n_buckets >> 5);
  __pyx_t_3 = 1;
  __pyx_t_5 = (__pyx_t_2 > __pyx_t_3);
  if (__pyx_t_5) {
    __pyx_t_4 = __pyx_t_2;
  } else {
    __pyx_t_4 = __pyx_t_3;
  }
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_t_4 * (sizeof(__pyx_t_5numpy_uint32_t)))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7063, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_flags = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7064
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 *         for_pairs =  self.table.n_buckets * (sizeof(PyObject *) +  # keys             # <<<<<<<<<<<<<<
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs
 */
  __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->n_buckets * ((sizeof(PyObject *)) + (sizeof(Py_ssize_t))))); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7064, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_for_pairs = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7066
 *         for_pairs =  self.table.n_buckets * (sizeof(PyObject *) +  # keys
 *                                              sizeof(Py_ssize_t))   # vals
 *         return overhead + for_flags + for_pairs             # <<<<<<<<<<<<<<
 * 
 *     def get_state(self) -> dict[str, int]:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyNumber_Add(__pyx_v_overhead, __pyx_v_for_flags); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7066, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_6 = PyNumber_Add(__pyx_t_1, __pyx_v_for_pairs); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 7066, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(__Pyx_Py3Int_CheckExact(__pyx_t_6))||((__pyx_t_6) == Py_None) || __Pyx_RaiseUnexpectedTypeError("int", __pyx_t_6))) __PYX_ERR(2, 7066, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7060
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.sizeof", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_overhead);
  __Pyx_XDECREF(__pyx_v_for_flags);
  __Pyx_XDECREF(__pyx_v_for_pairs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":7068
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """
 *         returns infos about the current state of the hashtable like size,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_17PyObjectHashTable_10get_state, "\n        returns infos about the current state of the hashtable like size,\n        number of buckets and so on.\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_11get_state = {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_17PyObjectHashTable_10get_state};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_11get_state(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_state (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_state", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_state", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_10get_state(((struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_10get_state(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_state", 1);

  /* "pandas/_libs/hashtable_class_helper.pxi":7073
 *         number of buckets and so on.
 *         """
 *         return {             # <<<<<<<<<<<<<<
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 */
  __Pyx_XDECREF(__pyx_r);

  /* "pandas/_libs/hashtable_class_helper.pxi":7074
 *         """
 *         return {
 *             'n_buckets' : self.table.n_buckets,             # <<<<<<<<<<<<<<
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7074, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_buckets); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7074, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_buckets, __pyx_t_2) < 0) __PYX_ERR(2, 7074, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7075
 *         return {
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,             # <<<<<<<<<<<<<<
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->size); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7075, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_size, __pyx_t_2) < 0) __PYX_ERR(2, 7074, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7076
 *             'n_buckets' : self.table.n_buckets,
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,             # <<<<<<<<<<<<<<
 *             'upper_bound' : self.table.upper_bound,
 *         }
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->n_occupied); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7076, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_n_occupied, __pyx_t_2) < 0) __PYX_ERR(2, 7074, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7077
 *             'size' : self.table.size,
 *             'n_occupied' : self.table.n_occupied,
 *             'upper_bound' : self.table.upper_bound,             # <<<<<<<<<<<<<<
 *         }
 * 
 */
  __pyx_t_2 = __Pyx_PyInt_From_npy_uint32(__pyx_v_self->table->upper_bound); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7077, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_u_upper_bound, __pyx_t_2) < 0) __PYX_ERR(2, 7074, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7068
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """
 *         returns infos about the current state of the hashtable like size,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.get_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":7080
 *         }
 * 
 *     cpdef get_item(self, object val):             # <<<<<<<<<<<<<<
 *         cdef:
 *             khiter_t k
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_17PyObjectHashTable_get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, PyObject *__pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7080, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_13get_item)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        __pyx_t_5 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
            __pyx_t_5 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v_val};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
          __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7080, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":7084
 *             khiter_t k
 * 
 *         k = kh_get_pymap(self.table, <PyObject*>val)             # <<<<<<<<<<<<<<
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]
 */
  __pyx_v_k = kh_get_pymap(__pyx_v_self->table, ((PyObject *)__pyx_v_val));

  /* "pandas/_libs/hashtable_class_helper.pxi":7085
 * 
 *         k = kh_get_pymap(self.table, <PyObject*>val)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  __pyx_t_6 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
  if (likely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":7086
 *         k = kh_get_pymap(self.table, <PyObject*>val)
 *         if k != self.table.n_buckets:
 *             return self.table.vals[k]             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(val)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_1 = __Pyx_PyInt_FromSize_t((__pyx_v_self->table->vals[__pyx_v_k])); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7086, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_r = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":7085
 * 
 *         k = kh_get_pymap(self.table, <PyObject*>val)
 *         if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *             return self.table.vals[k]
 *         else:
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":7088
 *             return self.table.vals[k]
 *         else:
 *             raise KeyError(val)             # <<<<<<<<<<<<<<
 * 
 *     cpdef set_item(self, object key, Py_ssize_t val):
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_v_val); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7088, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(2, 7088, __pyx_L1_error)
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":7080
 *         }
 * 
 *     cpdef get_item(self, object val):             # <<<<<<<<<<<<<<
 *         cdef:
 *             khiter_t k
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_13get_item = {"get_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_13get_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_13get_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_val = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7080, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_item") < 0)) __PYX_ERR(2, 7080, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_val = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_item", 1, 1, 1, __pyx_nargs); __PYX_ERR(2, 7080, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_12get_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *)__pyx_v_self), __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_12get_item(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, PyObject *__pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_17PyObjectHashTable_get_item(__pyx_v_self, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.get_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":7090
 *             raise KeyError(val)
 * 
 *     cpdef set_item(self, object key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         cdef:
 *             khiter_t k
 */

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_15set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyObject *__pyx_f_6pandas_5_libs_9hashtable_17PyObjectHashTable_set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, PyObject *__pyx_v_key, Py_ssize_t __pyx_v_val, int __pyx_skip_dispatch) {
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  Py_hash_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || __Pyx_PyType_HasFeature(Py_TYPE(((PyObject *)__pyx_v_self)), (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_typedict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_set_item); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7090, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!__Pyx_IsSameCFunction(__pyx_t_1, (void*) __pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_15set_item)) {
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_3 = PyInt_FromSsize_t(__pyx_v_val); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7090, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        __pyx_t_6 = 0;
        #if CYTHON_UNPACK_METHODS
        if (unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
            __pyx_t_6 = 1;
          }
        }
        #endif
        {
          PyObject *__pyx_callargs[3] = {__pyx_t_5, __pyx_v_key, __pyx_t_3};
          __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_6, 2+__pyx_t_6);
          __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
          __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
          if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7090, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_2);
          __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        }
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_typedict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":7093
 *         cdef:
 *             khiter_t k
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             char* buf
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7096
 *             char* buf
 * 
 *         hash(key)             # <<<<<<<<<<<<<<
 * 
 *         k = kh_put_pymap(self.table, <PyObject*>key, &ret)
 */
  __pyx_t_7 = PyObject_Hash(__pyx_v_key); if (unlikely(__pyx_t_7 == ((Py_hash_t)-1))) __PYX_ERR(2, 7096, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":7098
 *         hash(key)
 * 
 *         k = kh_put_pymap(self.table, <PyObject*>key, &ret)             # <<<<<<<<<<<<<<
 *         if kh_exist_pymap(self.table, k):
 *             self.table.vals[k] = val
 */
  __pyx_v_k = kh_put_pymap(__pyx_v_self->table, ((PyObject *)__pyx_v_key), (&__pyx_v_ret));

  /* "pandas/_libs/hashtable_class_helper.pxi":7099
 * 
 *         k = kh_put_pymap(self.table, <PyObject*>key, &ret)
 *         if kh_exist_pymap(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
  __pyx_t_8 = kh_exist_pymap(__pyx_v_self->table, __pyx_v_k);
  if (likely(__pyx_t_8)) {

    /* "pandas/_libs/hashtable_class_helper.pxi":7100
 *         k = kh_put_pymap(self.table, <PyObject*>key, &ret)
 *         if kh_exist_pymap(self.table, k):
 *             self.table.vals[k] = val             # <<<<<<<<<<<<<<
 *         else:
 *             raise KeyError(key)
 */
    (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_val;

    /* "pandas/_libs/hashtable_class_helper.pxi":7099
 * 
 *         k = kh_put_pymap(self.table, <PyObject*>key, &ret)
 *         if kh_exist_pymap(self.table, k):             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = val
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":7102
 *             self.table.vals[k] = val
 *         else:
 *             raise KeyError(key)             # <<<<<<<<<<<<<<
 * 
 *     def map_locations(self, ndarray[object] values, object mask = None) -> None:
 */
  /*else*/ {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_builtin_KeyError, __pyx_v_key); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7102, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(2, 7102, __pyx_L1_error)
  }
  __pyx_L3:;

  /* "pandas/_libs/hashtable_class_helper.pxi":7090
 *             raise KeyError(val)
 * 
 *     cpdef set_item(self, object key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         cdef:
 *             khiter_t k
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_15set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_15set_item = {"set_item", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_15set_item, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_15set_item(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v_key = 0;
  Py_ssize_t __pyx_v_val;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("set_item (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_key,&__pyx_n_s_val,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_key)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7090, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_val)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7090, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, 1); __PYX_ERR(2, 7090, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "set_item") < 0)) __PYX_ERR(2, 7090, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
    }
    __pyx_v_key = values[0];
    __pyx_v_val = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_val == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 7090, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("set_item", 1, 2, 2, __pyx_nargs); __PYX_ERR(2, 7090, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_14set_item(((struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *)__pyx_v_self), __pyx_v_key, __pyx_v_val);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_14set_item(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, PyObject *__pyx_v_key, Py_ssize_t __pyx_v_val) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_item", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_17PyObjectHashTable_set_item(__pyx_v_self, __pyx_v_key, __pyx_v_val, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7090, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.set_item", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":7104
 *             raise KeyError(key)
 * 
 *     def map_locations(self, ndarray[object] values, object mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # mask not yet implemented
 *         cdef:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_17map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_17map_locations = {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_17map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_17map_locations(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyArrayObject *__pyx_v_values = 0;
  CYTHON_UNUSED PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("map_locations (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7104, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7104, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "map_locations") < 0)) __PYX_ERR(2, 7104, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_mask = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("map_locations", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 7104, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(2, 7104, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_16map_locations(((struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_16map_locations(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, CYTHON_UNUSED PyObject *__pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  int __pyx_v_ret;
  PyObject *__pyx_v_val = 0;
  khiter_t __pyx_v_k;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  Py_hash_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("map_locations", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(2, 7104, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_class_helper.pxi":7107
 *         # mask not yet implemented
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             object val
 */
  __pyx_t_1 = PyObject_Length(((PyObject *)__pyx_v_values)); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(2, 7107, __pyx_L1_error)
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":7108
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             object val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7112
 *             khiter_t k
 * 
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = values[i]
 *             hash(val)
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "pandas/_libs/hashtable_class_helper.pxi":7113
 * 
 *         for i in range(n):
 *             val = values[i]             # <<<<<<<<<<<<<<
 *             hash(val)
 * 
 */
    __pyx_t_5 = __pyx_v_i;
    __pyx_t_6 = -1;
    if (__pyx_t_5 < 0) {
      __pyx_t_5 += __pyx_pybuffernd_values.diminfo[0].shape;
      if (unlikely(__pyx_t_5 < 0)) __pyx_t_6 = 0;
    } else if (unlikely(__pyx_t_5 >= __pyx_pybuffernd_values.diminfo[0].shape)) __pyx_t_6 = 0;
    if (unlikely(__pyx_t_6 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_6);
      __PYX_ERR(2, 7113, __pyx_L1_error)
    }
    __pyx_t_4 = (PyObject *) *__Pyx_BufPtrStrided1d(PyObject **, __pyx_pybuffernd_values.rcbuffer->pybuffer.buf, __pyx_t_5, __pyx_pybuffernd_values.diminfo[0].strides);
    if (unlikely(__pyx_t_4 == NULL)) __pyx_t_4 = Py_None;
    __Pyx_INCREF((PyObject*)__pyx_t_4);
    __Pyx_XDECREF_SET(__pyx_v_val, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":7114
 *         for i in range(n):
 *             val = values[i]
 *             hash(val)             # <<<<<<<<<<<<<<
 * 
 *             k = kh_put_pymap(self.table, <PyObject*>val, &ret)
 */
    __pyx_t_7 = PyObject_Hash(__pyx_v_val); if (unlikely(__pyx_t_7 == ((Py_hash_t)-1))) __PYX_ERR(2, 7114, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":7116
 *             hash(val)
 * 
 *             k = kh_put_pymap(self.table, <PyObject*>val, &ret)             # <<<<<<<<<<<<<<
 *             self.table.vals[k] = i
 * 
 */
    __pyx_v_k = kh_put_pymap(__pyx_v_self->table, ((PyObject *)__pyx_v_val), (&__pyx_v_ret));

    /* "pandas/_libs/hashtable_class_helper.pxi":7117
 * 
 *             k = kh_put_pymap(self.table, <PyObject*>val, &ret)
 *             self.table.vals[k] = i             # <<<<<<<<<<<<<<
 * 
 *     def lookup(self, ndarray[object] values, object mask = None) -> ndarray:
 */
    (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_i;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":7104
 *             raise KeyError(key)
 * 
 *     def map_locations(self, ndarray[object] values, object mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # mask not yet implemented
 *         cdef:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.map_locations", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":7119
 *             self.table.vals[k] = i
 * 
 *     def lookup(self, ndarray[object] values, object mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # mask not yet implemented
 */

/* Python wrapper */
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_19lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_19lookup = {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_19lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_19lookup(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyArrayObject *__pyx_v_values = 0;
  CYTHON_UNUSED PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyArrayObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("lookup (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7119, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7119, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "lookup") < 0)) __PYX_ERR(2, 7119, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_mask = values[1];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("lookup", 0, 1, 2, __pyx_nargs); __PYX_ERR(2, 7119, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(2, 7119, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_18lookup(((struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_18lookup(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, CYTHON_UNUSED PyObject *__pyx_v_mask) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  CYTHON_UNUSED int __pyx_v_ret;
  PyObject *__pyx_v_val = 0;
  khiter_t __pyx_v_k;
  __Pyx_memviewslice __pyx_v_locs = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  Py_ssize_t __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  Py_hash_t __pyx_t_12;
  int __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("lookup", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(2, 7119, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_class_helper.pxi":7123
 *         # mask not yet implemented
 *         cdef:
 *             Py_ssize_t i, n = len(values)             # <<<<<<<<<<<<<<
 *             int ret = 0
 *             object val
 */
  __pyx_t_1 = PyObject_Length(((PyObject *)__pyx_v_values)); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(2, 7123, __pyx_L1_error)
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":7124
 *         cdef:
 *             Py_ssize_t i, n = len(values)
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             object val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7127
 *             object val
 *             khiter_t k
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 * 
 *         for i in range(n):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 7127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 7127, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 7127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 7127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 7127, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 7127, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 7127, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_v_locs = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":7129
 *             intp_t[::1] locs = np.empty(n, dtype=np.intp)
 * 
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = values[i]
 *             hash(val)
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_8 = __pyx_t_1;
  for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
    __pyx_v_i = __pyx_t_9;

    /* "pandas/_libs/hashtable_class_helper.pxi":7130
 * 
 *         for i in range(n):
 *             val = values[i]             # <<<<<<<<<<<<<<
 *             hash(val)
 * 
 */
    __pyx_t_10 = __pyx_v_i;
    __pyx_t_11 = -1;
    if (__pyx_t_10 < 0) {
      __pyx_t_10 += __pyx_pybuffernd_values.diminfo[0].shape;
      if (unlikely(__pyx_t_10 < 0)) __pyx_t_11 = 0;
    } else if (unlikely(__pyx_t_10 >= __pyx_pybuffernd_values.diminfo[0].shape)) __pyx_t_11 = 0;
    if (unlikely(__pyx_t_11 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_11);
      __PYX_ERR(2, 7130, __pyx_L1_error)
    }
    __pyx_t_6 = (PyObject *) *__Pyx_BufPtrStrided1d(PyObject **, __pyx_pybuffernd_values.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_values.diminfo[0].strides);
    if (unlikely(__pyx_t_6 == NULL)) __pyx_t_6 = Py_None;
    __Pyx_INCREF((PyObject*)__pyx_t_6);
    __Pyx_XDECREF_SET(__pyx_v_val, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":7131
 *         for i in range(n):
 *             val = values[i]
 *             hash(val)             # <<<<<<<<<<<<<<
 * 
 *             k = kh_get_pymap(self.table, <PyObject*>val)
 */
    __pyx_t_12 = PyObject_Hash(__pyx_v_val); if (unlikely(__pyx_t_12 == ((Py_hash_t)-1))) __PYX_ERR(2, 7131, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":7133
 *             hash(val)
 * 
 *             k = kh_get_pymap(self.table, <PyObject*>val)             # <<<<<<<<<<<<<<
 *             if k != self.table.n_buckets:
 *                 locs[i] = self.table.vals[k]
 */
    __pyx_v_k = kh_get_pymap(__pyx_v_self->table, ((PyObject *)__pyx_v_val));

    /* "pandas/_libs/hashtable_class_helper.pxi":7134
 * 
 *             k = kh_get_pymap(self.table, <PyObject*>val)
 *             if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                 locs[i] = self.table.vals[k]
 *             else:
 */
    __pyx_t_13 = (__pyx_v_k != __pyx_v_self->table->n_buckets);
    if (__pyx_t_13) {

      /* "pandas/_libs/hashtable_class_helper.pxi":7135
 *             k = kh_get_pymap(self.table, <PyObject*>val)
 *             if k != self.table.n_buckets:
 *                 locs[i] = self.table.vals[k]             # <<<<<<<<<<<<<<
 *             else:
 *                 locs[i] = -1
 */
      __pyx_t_10 = __pyx_v_i;
      __pyx_t_11 = -1;
      if (__pyx_t_10 < 0) {
        __pyx_t_10 += __pyx_v_locs.shape[0];
        if (unlikely(__pyx_t_10 < 0)) __pyx_t_11 = 0;
      } else if (unlikely(__pyx_t_10 >= __pyx_v_locs.shape[0])) __pyx_t_11 = 0;
      if (unlikely(__pyx_t_11 != -1)) {
        __Pyx_RaiseBufferIndexError(__pyx_t_11);
        __PYX_ERR(2, 7135, __pyx_L1_error)
      }
      *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_10)) )) = (__pyx_v_self->table->vals[__pyx_v_k]);

      /* "pandas/_libs/hashtable_class_helper.pxi":7134
 * 
 *             k = kh_get_pymap(self.table, <PyObject*>val)
 *             if k != self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                 locs[i] = self.table.vals[k]
 *             else:
 */
      goto __pyx_L5;
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":7137
 *                 locs[i] = self.table.vals[k]
 *             else:
 *                 locs[i] = -1             # <<<<<<<<<<<<<<
 * 
 *         return np.asarray(locs)
 */
    /*else*/ {
      __pyx_t_10 = __pyx_v_i;
      __pyx_t_11 = -1;
      if (__pyx_t_10 < 0) {
        __pyx_t_10 += __pyx_v_locs.shape[0];
        if (unlikely(__pyx_t_10 < 0)) __pyx_t_11 = 0;
      } else if (unlikely(__pyx_t_10 >= __pyx_v_locs.shape[0])) __pyx_t_11 = 0;
      if (unlikely(__pyx_t_11 != -1)) {
        __Pyx_RaiseBufferIndexError(__pyx_t_11);
        __PYX_ERR(2, 7137, __pyx_L1_error)
      }
      *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_locs.data) + __pyx_t_10)) )) = -1;
    }
    __pyx_L5:;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":7139
 *                 locs[i] = -1
 * 
 *         return np.asarray(locs)             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_asarray); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 7139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_locs, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7139, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = NULL;
  __pyx_t_11 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_11 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_3, __pyx_t_2};
    __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_11, 1+__pyx_t_11);
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 7139, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(2, 7139, __pyx_L1_error)
  __pyx_r = ((PyArrayObject *)__pyx_t_6);
  __pyx_t_6 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7119
 *             self.table.vals[k] = i
 * 
 *     def lookup(self, ndarray[object] values, object mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # mask not yet implemented
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.lookup", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF(__pyx_v_val);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_locs, 1);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":7141
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, ndarray[object] values, ObjectVector uniques,
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_21_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_17PyObjectHashTable_20_unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[object]\n            Array of values of which unique will be calculated\n        uniques : ObjectVector\n            Vector into which uniques will be written\n        count_prior : Py_ssize_t, default 0\n            Number of existing entries in uniques\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then None _plus_\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        ignore_na : bool, default False\n            Whether NA-values should be ignored for calculating the uniques. If\n            True, the labels corresponding to missing values will be set to\n            na_sentinel.\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n\n        Returns\n        -------\n        uniques : ndarray[object]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse=True)\n            The labels from values to uniques\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_21_unique = {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_21_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_17PyObjectHashTable_20_unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_21_unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyArrayObject *__pyx_v_values = 0;
  struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  int __pyx_v_ignore_na;
  int __pyx_v_return_inverse;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[7] = {0,0,0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_ignore_na,&__pyx_n_s_return_inverse,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":7145
 *     def _unique(self, ndarray[object] values, ObjectVector uniques,
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,             # <<<<<<<<<<<<<<
 *                 bint return_inverse=False):
 *         """
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7141, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7141, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 7, 1); __PYX_ERR(2, 7141, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7141, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7141, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7141, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  5:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[5] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7141, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  6:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[6] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7141, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_unique") < 0)) __PYX_ERR(2, 7141, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  7: values[6] = __Pyx_Arg_FASTCALL(__pyx_args, 6);
        CYTHON_FALLTHROUGH;
        case  6: values[5] = __Pyx_Arg_FASTCALL(__pyx_args, 5);
        CYTHON_FALLTHROUGH;
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 7144, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 7144, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
    if (values[5]) {
      __pyx_v_ignore_na = __Pyx_PyObject_IsTrue(values[5]); if (unlikely((__pyx_v_ignore_na == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 7145, __pyx_L3_error)
    } else {
      __pyx_v_ignore_na = ((int)0);
    }
    if (values[6]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[6]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 7146, __pyx_L3_error)
    } else {

      /* "pandas/_libs/hashtable_class_helper.pxi":7146
 *                 Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                 object na_value=None, bint ignore_na=False,
 *                 bint return_inverse=False):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
      __pyx_v_return_inverse = ((int)0);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_unique", 0, 2, 7, __pyx_nargs); __PYX_ERR(2, 7141, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(2, 7143, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector, 1, "uniques", 0))) __PYX_ERR(2, 7143, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_20_unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_ignore_na, __pyx_v_return_inverse);

  /* "pandas/_libs/hashtable_class_helper.pxi":7141
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, ndarray[object] values, ObjectVector uniques,
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_20_unique(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, int __pyx_v_ignore_na, int __pyx_v_return_inverse) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_idx;
  Py_ssize_t __pyx_v_count;
  Py_ssize_t __pyx_v_n;
  __Pyx_memviewslice __pyx_v_labels = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_v_ret;
  PyObject *__pyx_v_val = 0;
  khiter_t __pyx_v_k;
  int __pyx_v_use_na_value;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_hash_t __pyx_t_12;
  int __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_unique", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(2, 7141, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_class_helper.pxi":7181
 *         """
 *         cdef:
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)             # <<<<<<<<<<<<<<
 *             intp_t[::1] labels
 *             int ret = 0
 */
  __pyx_v_count = __pyx_v_count_prior;
  __pyx_t_1 = PyObject_Length(((PyObject *)__pyx_v_values)); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(2, 7181, __pyx_L1_error)
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_class_helper.pxi":7183
 *             Py_ssize_t i, idx, count = count_prior, n = len(values)
 *             intp_t[::1] labels
 *             int ret = 0             # <<<<<<<<<<<<<<
 *             object val
 *             khiter_t k
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7188
 *             bint use_na_value
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         use_na_value = na_value is not None
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":7189
 * 
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)             # <<<<<<<<<<<<<<
 *         use_na_value = na_value is not None
 * 
 */
    __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 7189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(2, 7189, __pyx_L1_error);
    __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 7189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 7189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_t_6) < 0) __PYX_ERR(2, 7189, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 7189, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(__pyx_t_6, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(2, 7189, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_v_labels = __pyx_t_7;
    __pyx_t_7.memview = NULL;
    __pyx_t_7.data = NULL;

    /* "pandas/_libs/hashtable_class_helper.pxi":7188
 *             bint use_na_value
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             labels = np.empty(n, dtype=np.intp)
 *         use_na_value = na_value is not None
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":7190
 *         if return_inverse:
 *             labels = np.empty(n, dtype=np.intp)
 *         use_na_value = na_value is not None             # <<<<<<<<<<<<<<
 * 
 *         for i in range(n):
 */
  __pyx_t_8 = (__pyx_v_na_value != Py_None);
  __pyx_v_use_na_value = __pyx_t_8;

  /* "pandas/_libs/hashtable_class_helper.pxi":7192
 *         use_na_value = na_value is not None
 * 
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = values[i]
 *             hash(val)
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_9 = __pyx_t_1;
  for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
    __pyx_v_i = __pyx_t_10;

    /* "pandas/_libs/hashtable_class_helper.pxi":7193
 * 
 *         for i in range(n):
 *             val = values[i]             # <<<<<<<<<<<<<<
 *             hash(val)
 * 
 */
    __pyx_t_11 = __pyx_v_i;
    __pyx_t_6 = (PyObject *) *__Pyx_BufPtrStrided1d(PyObject **, __pyx_pybuffernd_values.rcbuffer->pybuffer.buf, __pyx_t_11, __pyx_pybuffernd_values.diminfo[0].strides);
    if (unlikely(__pyx_t_6 == NULL)) __pyx_t_6 = Py_None;
    __Pyx_INCREF((PyObject*)__pyx_t_6);
    __Pyx_XDECREF_SET(__pyx_v_val, __pyx_t_6);
    __pyx_t_6 = 0;

    /* "pandas/_libs/hashtable_class_helper.pxi":7194
 *         for i in range(n):
 *             val = values[i]
 *             hash(val)             # <<<<<<<<<<<<<<
 * 
 *             if ignore_na and (
 */
    __pyx_t_12 = PyObject_Hash(__pyx_v_val); if (unlikely(__pyx_t_12 == ((Py_hash_t)-1))) __PYX_ERR(2, 7194, __pyx_L1_error)

    /* "pandas/_libs/hashtable_class_helper.pxi":7196
 *             hash(val)
 * 
 *             if ignore_na and (             # <<<<<<<<<<<<<<
 *                 checknull(val)
 *                 or (use_na_value and val == na_value)
 */
    if (__pyx_v_ignore_na) {
    } else {
      __pyx_t_8 = __pyx_v_ignore_na;
      goto __pyx_L7_bool_binop_done;
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":7197
 * 
 *             if ignore_na and (
 *                 checknull(val)             # <<<<<<<<<<<<<<
 *                 or (use_na_value and val == na_value)
 *             ):
 */
    __pyx_t_13 = __pyx_f_6pandas_5_libs_7missing_checknull(__pyx_v_val, 0, NULL); if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7197, __pyx_L1_error)
    if (!__pyx_t_13) {
    } else {
      __pyx_t_8 = __pyx_t_13;
      goto __pyx_L7_bool_binop_done;
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":7198
 *             if ignore_na and (
 *                 checknull(val)
 *                 or (use_na_value and val == na_value)             # <<<<<<<<<<<<<<
 *             ):
 *                 # if missing values do not count as unique values (i.e. if
 */
    if (__pyx_v_use_na_value) {
    } else {
      __pyx_t_8 = __pyx_v_use_na_value;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_6 = PyObject_RichCompare(__pyx_v_val, __pyx_v_na_value, Py_EQ); __Pyx_XGOTREF(__pyx_t_6); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 7198, __pyx_L1_error)
    __pyx_t_13 = __Pyx_PyObject_IsTrue(__pyx_t_6); if (unlikely((__pyx_t_13 < 0))) __PYX_ERR(2, 7198, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_8 = __pyx_t_13;
    __pyx_L7_bool_binop_done:;

    /* "pandas/_libs/hashtable_class_helper.pxi":7196
 *             hash(val)
 * 
 *             if ignore_na and (             # <<<<<<<<<<<<<<
 *                 checknull(val)
 *                 or (use_na_value and val == na_value)
 */
    if (__pyx_t_8) {

      /* "pandas/_libs/hashtable_class_helper.pxi":7203
 *                 # ignore_na is True), skip the hashtable entry for them, and
 *                 # replace the corresponding label with na_sentinel
 *                 labels[i] = na_sentinel             # <<<<<<<<<<<<<<
 *                 continue
 * 
 */
      if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundLocalError("labels"); __PYX_ERR(2, 7203, __pyx_L1_error) }
      __pyx_t_11 = __pyx_v_i;
      *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_11)) )) = __pyx_v_na_sentinel;

      /* "pandas/_libs/hashtable_class_helper.pxi":7204
 *                 # replace the corresponding label with na_sentinel
 *                 labels[i] = na_sentinel
 *                 continue             # <<<<<<<<<<<<<<
 * 
 *             k = kh_get_pymap(self.table, <PyObject*>val)
 */
      goto __pyx_L4_continue;

      /* "pandas/_libs/hashtable_class_helper.pxi":7196
 *             hash(val)
 * 
 *             if ignore_na and (             # <<<<<<<<<<<<<<
 *                 checknull(val)
 *                 or (use_na_value and val == na_value)
 */
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":7206
 *                 continue
 * 
 *             k = kh_get_pymap(self.table, <PyObject*>val)             # <<<<<<<<<<<<<<
 *             if k == self.table.n_buckets:
 *                 # k hasn't been seen yet
 */
    __pyx_v_k = kh_get_pymap(__pyx_v_self->table, ((PyObject *)__pyx_v_val));

    /* "pandas/_libs/hashtable_class_helper.pxi":7207
 * 
 *             k = kh_get_pymap(self.table, <PyObject*>val)
 *             if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                 # k hasn't been seen yet
 *                 k = kh_put_pymap(self.table, <PyObject*>val, &ret)
 */
    __pyx_t_8 = (__pyx_v_k == __pyx_v_self->table->n_buckets);
    if (__pyx_t_8) {

      /* "pandas/_libs/hashtable_class_helper.pxi":7209
 *             if k == self.table.n_buckets:
 *                 # k hasn't been seen yet
 *                 k = kh_put_pymap(self.table, <PyObject*>val, &ret)             # <<<<<<<<<<<<<<
 *                 uniques.append(val)
 *                 if return_inverse:
 */
      __pyx_v_k = kh_put_pymap(__pyx_v_self->table, ((PyObject *)__pyx_v_val), (&__pyx_v_ret));

      /* "pandas/_libs/hashtable_class_helper.pxi":7210
 *                 # k hasn't been seen yet
 *                 k = kh_put_pymap(self.table, <PyObject*>val, &ret)
 *                 uniques.append(val)             # <<<<<<<<<<<<<<
 *                 if return_inverse:
 *                     self.table.vals[k] = count
 */
      __pyx_t_6 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_v_uniques->__pyx_vtab)->append(__pyx_v_uniques, __pyx_v_val); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 7210, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

      /* "pandas/_libs/hashtable_class_helper.pxi":7211
 *                 k = kh_put_pymap(self.table, <PyObject*>val, &ret)
 *                 uniques.append(val)
 *                 if return_inverse:             # <<<<<<<<<<<<<<
 *                     self.table.vals[k] = count
 *                     labels[i] = count
 */
      if (__pyx_v_return_inverse) {

        /* "pandas/_libs/hashtable_class_helper.pxi":7212
 *                 uniques.append(val)
 *                 if return_inverse:
 *                     self.table.vals[k] = count             # <<<<<<<<<<<<<<
 *                     labels[i] = count
 *                     count += 1
 */
        (__pyx_v_self->table->vals[__pyx_v_k]) = __pyx_v_count;

        /* "pandas/_libs/hashtable_class_helper.pxi":7213
 *                 if return_inverse:
 *                     self.table.vals[k] = count
 *                     labels[i] = count             # <<<<<<<<<<<<<<
 *                     count += 1
 *             elif return_inverse:
 */
        if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundLocalError("labels"); __PYX_ERR(2, 7213, __pyx_L1_error) }
        __pyx_t_11 = __pyx_v_i;
        *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_11)) )) = __pyx_v_count;

        /* "pandas/_libs/hashtable_class_helper.pxi":7214
 *                     self.table.vals[k] = count
 *                     labels[i] = count
 *                     count += 1             # <<<<<<<<<<<<<<
 *             elif return_inverse:
 *                 # k falls into a previous bucket
 */
        __pyx_v_count = (__pyx_v_count + 1);

        /* "pandas/_libs/hashtable_class_helper.pxi":7211
 *                 k = kh_put_pymap(self.table, <PyObject*>val, &ret)
 *                 uniques.append(val)
 *                 if return_inverse:             # <<<<<<<<<<<<<<
 *                     self.table.vals[k] = count
 *                     labels[i] = count
 */
      }

      /* "pandas/_libs/hashtable_class_helper.pxi":7207
 * 
 *             k = kh_get_pymap(self.table, <PyObject*>val)
 *             if k == self.table.n_buckets:             # <<<<<<<<<<<<<<
 *                 # k hasn't been seen yet
 *                 k = kh_put_pymap(self.table, <PyObject*>val, &ret)
 */
      goto __pyx_L11;
    }

    /* "pandas/_libs/hashtable_class_helper.pxi":7215
 *                     labels[i] = count
 *                     count += 1
 *             elif return_inverse:             # <<<<<<<<<<<<<<
 *                 # k falls into a previous bucket
 *                 # only relevant in case we need to construct the inverse
 */
    if (__pyx_v_return_inverse) {

      /* "pandas/_libs/hashtable_class_helper.pxi":7218
 *                 # k falls into a previous bucket
 *                 # only relevant in case we need to construct the inverse
 *                 idx = self.table.vals[k]             # <<<<<<<<<<<<<<
 *                 labels[i] = idx
 * 
 */
      __pyx_v_idx = (__pyx_v_self->table->vals[__pyx_v_k]);

      /* "pandas/_libs/hashtable_class_helper.pxi":7219
 *                 # only relevant in case we need to construct the inverse
 *                 idx = self.table.vals[k]
 *                 labels[i] = idx             # <<<<<<<<<<<<<<
 * 
 *         if return_inverse:
 */
      if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundLocalError("labels"); __PYX_ERR(2, 7219, __pyx_L1_error) }
      __pyx_t_11 = __pyx_v_i;
      *((__pyx_t_5numpy_intp_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_intp_t *) __pyx_v_labels.data) + __pyx_t_11)) )) = __pyx_v_idx;

      /* "pandas/_libs/hashtable_class_helper.pxi":7215
 *                     labels[i] = count
 *                     count += 1
 *             elif return_inverse:             # <<<<<<<<<<<<<<
 *                 # k falls into a previous bucket
 *                 # only relevant in case we need to construct the inverse
 */
    }
    __pyx_L11:;
    __pyx_L4_continue:;
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":7221
 *                 labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         return uniques.to_array()
 */
  if (__pyx_v_return_inverse) {

    /* "pandas/_libs/hashtable_class_helper.pxi":7222
 * 
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray             # <<<<<<<<<<<<<<
 *         return uniques.to_array()
 * 
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_6 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_6)) __PYX_ERR(2, 7222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    if (unlikely(!__pyx_v_labels.memview)) { __Pyx_RaiseUnboundLocalError("labels"); __PYX_ERR(2, 7222, __pyx_L1_error) }
    __pyx_t_2 = __pyx_memoryview_fromslice(__pyx_v_labels, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_intp_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_intp_t, 0);; if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_base); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 7222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7222, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_6);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_6)) __PYX_ERR(2, 7222, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_4);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_4)) __PYX_ERR(2, 7222, __pyx_L1_error);
    __pyx_t_6 = 0;
    __pyx_t_4 = 0;
    __pyx_r = __pyx_t_2;
    __pyx_t_2 = 0;
    goto __pyx_L0;

    /* "pandas/_libs/hashtable_class_helper.pxi":7221
 *                 labels[i] = idx
 * 
 *         if return_inverse:             # <<<<<<<<<<<<<<
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         return uniques.to_array()
 */
  }

  /* "pandas/_libs/hashtable_class_helper.pxi":7223
 *         if return_inverse:
 *             return uniques.to_array(), labels.base  # .base -> underlying ndarray
 *         return uniques.to_array()             # <<<<<<<<<<<<<<
 * 
 *     def unique(self, ndarray[object] values, bint return_inverse=False, object mask=None):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_v_uniques->__pyx_vtab)->to_array(__pyx_v_uniques, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7141
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, ndarray[object] values, ObjectVector uniques,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable._unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_labels, 1);
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":7225
 *         return uniques.to_array()
 * 
 *     def unique(self, ndarray[object] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_23unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_17PyObjectHashTable_22unique, "\n        Calculate unique values and labels (no sorting!)\n\n        Parameters\n        ----------\n        values : ndarray[object]\n            Array of values of which unique will be calculated\n        return_inverse : bool, default False\n            Whether the mapping of the original array values to their location\n            in the vector of uniques should be returned.\n        mask : ndarray[bool], optional\n            Not yet implemented for PyObjectHashTable\n\n        Returns\n        -------\n        uniques : ndarray[object]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t] (if return_inverse)\n            The labels from values to uniques\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_23unique = {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_23unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_17PyObjectHashTable_22unique};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_23unique(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_return_inverse;
  CYTHON_UNUSED PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("unique (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_return_inverse,&__pyx_n_s_mask,0};
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7225, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_return_inverse);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7225, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7225, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "unique") < 0)) __PYX_ERR(2, 7225, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    if (values[1]) {
      __pyx_v_return_inverse = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_return_inverse == (int)-1) && PyErr_Occurred())) __PYX_ERR(2, 7225, __pyx_L3_error)
    } else {
      __pyx_v_return_inverse = ((int)0);
    }
    __pyx_v_mask = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("unique", 0, 1, 3, __pyx_nargs); __PYX_ERR(2, 7225, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(2, 7225, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_22unique(((struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_return_inverse, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_22unique(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, int __pyx_v_return_inverse, CYTHON_UNUSED PyObject *__pyx_v_mask) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_uniques = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("unique", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(2, 7225, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_class_helper.pxi":7246
 *             The labels from values to uniques
 *         """
 *         uniques = ObjectVector()             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse)
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7247
 *         """
 *         uniques = ObjectVector()
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF((PyObject *)__pyx_v_values);
  __Pyx_GIVEREF((PyObject *)__pyx_v_values);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_values))) __PYX_ERR(2, 7247, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 7247, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ignore_na, Py_False) < 0) __PYX_ERR(2, 7247, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":7248
 *         uniques = ObjectVector()
 *         return self._unique(values, uniques, ignore_na=False,
 *                             return_inverse=return_inverse)             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, ndarray[object] values, Py_ssize_t na_sentinel=-1,
 */
  __pyx_t_4 = __Pyx_PyBool_FromLong(__pyx_v_return_inverse); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 7248, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return_inverse, __pyx_t_4) < 0) __PYX_ERR(2, 7247, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7247
 *         """
 *         uniques = ObjectVector()
 *         return self._unique(values, uniques, ignore_na=False,             # <<<<<<<<<<<<<<
 *                             return_inverse=return_inverse)
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 7247, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7225
 *         return uniques.to_array()
 * 
 *     def unique(self, ndarray[object] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.unique", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":7250
 *                             return_inverse=return_inverse)
 * 
 *     def factorize(self, ndarray[object] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_25factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_17PyObjectHashTable_24factorize, "\n        Calculate unique values and labels (no sorting!)\n\n        Missing values are not included in the \"uniques\" for this method.\n        The labels for any missing values will be set to \"na_sentinel\"\n\n        Parameters\n        ----------\n        values : ndarray[object]\n            Array of values of which unique will be calculated\n        na_sentinel : Py_ssize_t, default -1\n            Sentinel value used for all NA-values in inverse\n        na_value : object, default None\n            Value to identify as missing. If na_value is None, then None _plus_\n            any value \"val\" satisfying val != val is considered missing.\n            If na_value is not None, then _additionally_, any value \"val\"\n            satisfying val == na_value is considered missing.\n        mask : ndarray[bool], optional\n            Not yet implemented for PyObjectHashTable.\n\n        Returns\n        -------\n        uniques : ndarray[object]\n            Unique values of input, not sorted\n        labels : ndarray[intp_t]\n            The labels from values to uniques\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_25factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_25factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_17PyObjectHashTable_24factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_25factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyArrayObject *__pyx_v_values = 0;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  CYTHON_UNUSED PyObject *__pyx_v_mask = 0;
  PyObject *__pyx_v_ignore_na = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,&__pyx_n_s_ignore_na,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":7251
 * 
 *     def factorize(self, ndarray[object] values, Py_ssize_t na_sentinel=-1,
 *                   object na_value=None, object mask=None, ignore_na=True):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_True));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7250, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7250, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7250, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7250, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_ignore_na);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7250, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(2, 7250, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    if (values[1]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[1]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 7250, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
    __pyx_v_ignore_na = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 5, __pyx_nargs); __PYX_ERR(2, 7250, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(2, 7250, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_24factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask, __pyx_v_ignore_na);

  /* "pandas/_libs/hashtable_class_helper.pxi":7250
 *                             return_inverse=return_inverse)
 * 
 *     def factorize(self, ndarray[object] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_24factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value, CYTHON_UNUSED PyObject *__pyx_v_mask, PyObject *__pyx_v_ignore_na) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_uniques_vector = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(2, 7250, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_class_helper.pxi":7279
 *             The labels from values to uniques
 *         """
 *         uniques_vector = ObjectVector()             # <<<<<<<<<<<<<<
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na,
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_uniques_vector = ((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7280
 *         """
 *         uniques_vector = ObjectVector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na,
 *                             return_inverse=True)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF((PyObject *)__pyx_v_values);
  __Pyx_GIVEREF((PyObject *)__pyx_v_values);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_values))) __PYX_ERR(2, 7280, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques_vector);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_uniques_vector))) __PYX_ERR(2, 7280, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(4); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 7280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 7280, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7281
 *         uniques_vector = ObjectVector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na,             # <<<<<<<<<<<<<<
 *                             return_inverse=True)
 * 
 */
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 7280, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ignore_na, __pyx_v_ignore_na) < 0) __PYX_ERR(2, 7280, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":7282
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,
 *                             na_value=na_value, ignore_na=ignore_na,
 *                             return_inverse=True)             # <<<<<<<<<<<<<<
 * 
 *     def get_labels(self, ndarray[object] values, ObjectVector uniques,
 */
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 7280, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":7280
 *         """
 *         uniques_vector = ObjectVector()
 *         return self._unique(values, uniques_vector, na_sentinel=na_sentinel,             # <<<<<<<<<<<<<<
 *                             na_value=na_value, ignore_na=ignore_na,
 *                             return_inverse=True)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 7280, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7250
 *                             return_inverse=return_inverse)
 * 
 *     def factorize(self, ndarray[object] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques_vector);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_class_helper.pxi":7284
 *                             return_inverse=True)
 * 
 *     def get_labels(self, ndarray[object] values, ObjectVector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_27get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_27get_labels = {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_27get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_27get_labels(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyArrayObject *__pyx_v_values = 0;
  struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_uniques = 0;
  Py_ssize_t __pyx_v_count_prior;
  Py_ssize_t __pyx_v_na_sentinel;
  PyObject *__pyx_v_na_value = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_labels (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_uniques,&__pyx_n_s_count_prior,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,0};

    /* "pandas/_libs/hashtable_class_helper.pxi":7286
 *     def get_labels(self, ndarray[object] values, ObjectVector uniques,
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None):             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 */
    values[4] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7284, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_uniques)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7284, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 5, 1); __PYX_ERR(2, 7284, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_count_prior);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7284, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7284, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[4] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(2, 7284, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "get_labels") < 0)) __PYX_ERR(2, 7284, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_FASTCALL(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)values[1]);
    if (values[2]) {
      __pyx_v_count_prior = __Pyx_PyIndex_AsSsize_t(values[2]); if (unlikely((__pyx_v_count_prior == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 7285, __pyx_L3_error)
    } else {
      __pyx_v_count_prior = ((Py_ssize_t)0);
    }
    if (values[3]) {
      __pyx_v_na_sentinel = __Pyx_PyIndex_AsSsize_t(values[3]); if (unlikely((__pyx_v_na_sentinel == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(2, 7285, __pyx_L3_error)
    } else {
      __pyx_v_na_sentinel = ((Py_ssize_t)-1L);
    }
    __pyx_v_na_value = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("get_labels", 0, 2, 5, __pyx_nargs); __PYX_ERR(2, 7284, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(2, 7284, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_uniques), __pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector, 1, "uniques", 0))) __PYX_ERR(2, 7284, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_26get_labels(((struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *)__pyx_v_self), __pyx_v_values, __pyx_v_uniques, __pyx_v_count_prior, __pyx_v_na_sentinel, __pyx_v_na_value);

  /* "pandas/_libs/hashtable_class_helper.pxi":7284
 *                             return_inverse=True)
 * 
 *     def get_labels(self, ndarray[object] values, ObjectVector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None):
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_26get_labels(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, PyArrayObject *__pyx_v_values, struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_uniques, Py_ssize_t __pyx_v_count_prior, Py_ssize_t __pyx_v_na_sentinel, PyObject *__pyx_v_na_value) {
  CYTHON_UNUSED PyObject *__pyx_v__ = NULL;
  PyObject *__pyx_v_labels = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_labels", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(2, 7284, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_class_helper.pxi":7288
 *                    object na_value=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True)
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_unique); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF((PyObject *)__pyx_v_values);
  __Pyx_GIVEREF((PyObject *)__pyx_v_values);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_values))) __PYX_ERR(2, 7288, __pyx_L1_error);
  __Pyx_INCREF((PyObject *)__pyx_v_uniques);
  __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_uniques))) __PYX_ERR(2, 7288, __pyx_L1_error);
  __pyx_t_3 = __Pyx_PyDict_NewPresized(5); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_count_prior); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 7288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_count_prior, __pyx_t_4) < 0) __PYX_ERR(2, 7288, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7289
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,             # <<<<<<<<<<<<<<
 *                                  ignore_na=True, return_inverse=True)
 *         return labels
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_na_sentinel); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 7289, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_na_sentinel, __pyx_t_4) < 0) __PYX_ERR(2, 7288, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_na_value, __pyx_v_na_value) < 0) __PYX_ERR(2, 7288, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":7290
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True)             # <<<<<<<<<<<<<<
 *         return labels
 */
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_ignore_na, Py_True) < 0) __PYX_ERR(2, 7288, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_return_inverse, Py_True) < 0) __PYX_ERR(2, 7288, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":7288
 *                    object na_value=None):
 *         # -> np.ndarray[np.intp]
 *         _, labels = self._unique(values, uniques, count_prior=count_prior,             # <<<<<<<<<<<<<<
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True)
 */
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_1, __pyx_t_2, __pyx_t_3); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 7288, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_4))) || (PyList_CheckExact(__pyx_t_4))) {
    PyObject* sequence = __pyx_t_4;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(2, 7288, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_2 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_2 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_2);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(2, 7288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(2, 7288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    #endif
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7288, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_1);
    index = 0; __pyx_t_3 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_2 = __pyx_t_5(__pyx_t_1); if (unlikely(!__pyx_t_2)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_2);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_1), 2) < 0) __PYX_ERR(2, 7288, __pyx_L1_error)
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(2, 7288, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  __pyx_v__ = __pyx_t_3;
  __pyx_t_3 = 0;
  __pyx_v_labels = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7291
 *                                  na_sentinel=na_sentinel, na_value=na_value,
 *                                  ignore_na=True, return_inverse=True)
 *         return labels             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_labels);
  __pyx_r = __pyx_v_labels;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7284
 *                             return_inverse=True)
 * 
 *     def get_labels(self, ndarray[object] values, ObjectVector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.get_labels", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF(__pyx_v__);
  __Pyx_XDECREF(__pyx_v_labels);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_29__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_29__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_29__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_29__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_28__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_28__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_self_table_cannot_be_converted_t, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_31__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_31__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_31__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_31__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_30__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_17PyObjectHashTable_30__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_self_table_cannot_be_converted_t, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.PyObjectHashTable.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":10
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_complex128(const complex128_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_complex128(__Pyx_memviewslice __pyx_v_values, int __pyx_v_dropna, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_complex128 *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__40;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  kh_complex128_t *__pyx_v_table;
  khiter_t __pyx_v_k;
  khcomplex128_t __pyx_v_val;
  int __pyx_v_ret;
  int __pyx_v_uses_mask;
  int __pyx_v_isna_entry;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *__pyx_v_result_keys = NULL;
  __Pyx_memviewslice __pyx_v_result_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  khcomplex128_t __pyx_t_8;
  khiter_t __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  __Pyx_memviewslice __pyx_t_14 = { 0, 0, { 0 }, { 0 }, { 0 } };
  khuint_t __pyx_t_15;
  khuint_t __pyx_t_16;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("value_count_complex128", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":12
 * cdef value_count_complex128(const complex128_t[:] values, bint dropna, const uint8_t[:] mask=None):
 *     cdef:
 *         Py_ssize_t i = 0             # <<<<<<<<<<<<<<
 *         Py_ssize_t n = len(values)
 *         kh_complex128_t *table
 */
  __pyx_v_i = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":13
 *     cdef:
 *         Py_ssize_t i = 0
 *         Py_ssize_t n = len(values)             # <<<<<<<<<<<<<<
 *         kh_complex128_t *table
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":21
 *         khcomplex128_t val
 * 
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":22
 * 
 *         int ret = 0
 *         bint uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint isna_entry = False
 * 
 */
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":23
 *         int ret = 0
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False             # <<<<<<<<<<<<<<
 * 
 *     if uses_mask and not dropna:
 */
  __pyx_v_isna_entry = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":25
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  if (__pyx_v_uses_mask) {
  } else {
    __pyx_t_2 = __pyx_v_uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (!__pyx_v_dropna);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_2)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":26
 * 
 *     if uses_mask and not dropna:
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")             # <<<<<<<<<<<<<<
 * 
 *     # we track the order in which keys are first seen (GH39009),
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_NotImplementedError, __pyx_tuple__41, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 26, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(5, 26, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":25
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":33
 *     #    result_keys remembers the original order of keys
 * 
 *     result_keys = Complex128Vector()             # <<<<<<<<<<<<<<
 *     table = kh_init_complex128()
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector)); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 33, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_result_keys = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":34
 * 
 *     result_keys = Complex128Vector()
 *     table = kh_init_complex128()             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_complex128(table, n)
 */
  __pyx_v_table = kh_init_complex128();

  /* "pandas/_libs/hashtable_func_helper.pxi":36
 *     table = kh_init_complex128()
 * 
 *     kh_resize_complex128(table, n)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(n):
 */
  kh_resize_complex128(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":38
 *     kh_resize_complex128(table, n)
 * 
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         val = to_khcomplex128_t(values[i])
 * 
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_5 = __pyx_t_1;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "pandas/_libs/hashtable_func_helper.pxi":39
 * 
 *     for i in range(n):
 *         val = to_khcomplex128_t(values[i])             # <<<<<<<<<<<<<<
 * 
 *         if dropna:
 */
    __pyx_t_7 = __pyx_v_i;
    __pyx_t_8 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex128_t((*((__pyx_t_double_complex const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )))); if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 39, __pyx_L1_error)
    __pyx_v_val = __pyx_t_8;

    /* "pandas/_libs/hashtable_func_helper.pxi":41
 *         val = to_khcomplex128_t(values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    if (__pyx_v_dropna) {

      /* "pandas/_libs/hashtable_func_helper.pxi":42
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
      if (__pyx_v_uses_mask) {

        /* "pandas/_libs/hashtable_func_helper.pxi":43
 *         if dropna:
 *             if uses_mask:
 *                 isna_entry = mask[i]             # <<<<<<<<<<<<<<
 *             else:
 *                 isna_entry = is_nan_khcomplex128_t(val)
 */
        __pyx_t_7 = __pyx_v_i;
        __pyx_v_isna_entry = (*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) )));

        /* "pandas/_libs/hashtable_func_helper.pxi":42
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
        goto __pyx_L9;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":45
 *                 isna_entry = mask[i]
 *             else:
 *                 isna_entry = is_nan_khcomplex128_t(val)             # <<<<<<<<<<<<<<
 * 
 *         if not dropna or not isna_entry:
 */
      /*else*/ {
        __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_khcomplex128_t(__pyx_v_val); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 45, __pyx_L1_error)
        __pyx_v_isna_entry = __pyx_t_2;
      }
      __pyx_L9:;

      /* "pandas/_libs/hashtable_func_helper.pxi":41
 *         val = to_khcomplex128_t(values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":47
 *                 isna_entry = is_nan_khcomplex128_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_complex128(table, val)
 *             if k != table.n_buckets:
 */
    __pyx_t_3 = (!__pyx_v_dropna);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L11_bool_binop_done;
    }
    __pyx_t_3 = (!__pyx_v_isna_entry);
    __pyx_t_2 = __pyx_t_3;
    __pyx_L11_bool_binop_done:;
    if (__pyx_t_2) {

      /* "pandas/_libs/hashtable_func_helper.pxi":48
 * 
 *         if not dropna or not isna_entry:
 *             k = kh_get_complex128(table, val)             # <<<<<<<<<<<<<<
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1
 */
      __pyx_v_k = kh_get_complex128(__pyx_v_table, __pyx_v_val);

      /* "pandas/_libs/hashtable_func_helper.pxi":49
 *         if not dropna or not isna_entry:
 *             k = kh_get_complex128(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
      __pyx_t_2 = (__pyx_v_k != __pyx_v_table->n_buckets);
      if (__pyx_t_2) {

        /* "pandas/_libs/hashtable_func_helper.pxi":50
 *             k = kh_get_complex128(table, val)
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 k = kh_put_complex128(table, val, &ret)
 */
        __pyx_t_9 = __pyx_v_k;
        (__pyx_v_table->vals[__pyx_t_9]) = ((__pyx_v_table->vals[__pyx_t_9]) + 1);

        /* "pandas/_libs/hashtable_func_helper.pxi":49
 *         if not dropna or not isna_entry:
 *             k = kh_get_complex128(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
        goto __pyx_L13;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":52
 *                 table.vals[k] += 1
 *             else:
 *                 k = kh_put_complex128(table, val, &ret)             # <<<<<<<<<<<<<<
 *                 table.vals[k] = 1
 *                 result_keys.append(val)
 */
      /*else*/ {
        __pyx_v_k = kh_put_complex128(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret));

        /* "pandas/_libs/hashtable_func_helper.pxi":53
 *             else:
 *                 k = kh_put_complex128(table, val, &ret)
 *                 table.vals[k] = 1             # <<<<<<<<<<<<<<
 *                 result_keys.append(val)
 * 
 */
        (__pyx_v_table->vals[__pyx_v_k]) = 1;

        /* "pandas/_libs/hashtable_func_helper.pxi":54
 *                 k = kh_put_complex128(table, val, &ret)
 *                 table.vals[k] = 1
 *                 result_keys.append(val)             # <<<<<<<<<<<<<<
 * 
 *     # collect counts in the order corresponding to result_keys:
 */
        ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex128Vector *)__pyx_v_result_keys->__pyx_vtab)->append(__pyx_v_result_keys, __pyx_v_val); if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 54, __pyx_L1_error)
      }
      __pyx_L13:;

      /* "pandas/_libs/hashtable_func_helper.pxi":47
 *                 isna_entry = is_nan_khcomplex128_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_complex128(table, val)
 *             if k != table.n_buckets:
 */
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":58
 *     # collect counts in the order corresponding to result_keys:
 *     cdef:
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(table.size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_empty); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_v_table->size); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_11 = PyTuple_New(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(5, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_4)) __PYX_ERR(5, 58, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_np); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_int64); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_dtype, __pyx_t_13) < 0) __PYX_ERR(5, 58, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_11, __pyx_t_4); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 58, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_14 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_13, PyBUF_WRITABLE); if (unlikely(!__pyx_t_14.memview)) __PYX_ERR(5, 58, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_v_result_counts = __pyx_t_14;
  __pyx_t_14.memview = NULL;
  __pyx_t_14.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":60
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)
 * 
 *     for i in range(table.size):             # <<<<<<<<<<<<<<
 *         k = kh_get_complex128(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]
 */
  __pyx_t_15 = __pyx_v_table->size;
  __pyx_t_16 = __pyx_t_15;
  for (__pyx_t_1 = 0; __pyx_t_1 < __pyx_t_16; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "pandas/_libs/hashtable_func_helper.pxi":61
 * 
 *     for i in range(table.size):
 *         k = kh_get_complex128(table, result_keys.data.data[i])             # <<<<<<<<<<<<<<
 *         result_counts[i] = table.vals[k]
 * 
 */
    __pyx_v_k = kh_get_complex128(__pyx_v_table, (__pyx_v_result_keys->data->data[__pyx_v_i]));

    /* "pandas/_libs/hashtable_func_helper.pxi":62
 *     for i in range(table.size):
 *         k = kh_get_complex128(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_complex128(table)
 */
    __pyx_t_7 = __pyx_v_i;
    *((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_result_counts.data) + __pyx_t_7)) )) = (__pyx_v_table->vals[__pyx_v_k]);
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":64
 *         result_counts[i] = table.vals[k]
 * 
 *     kh_destroy_complex128(table)             # <<<<<<<<<<<<<<
 * 
 *     return result_keys.to_array(), result_counts.base
 */
  kh_destroy_complex128(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":66
 *     kh_destroy_complex128(table)
 * 
 *     return result_keys.to_array(), result_counts.base             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_13 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex128Vector *)__pyx_v_result_keys->__pyx_vtab)->to_array(__pyx_v_result_keys, 0)); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_result_counts, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int64_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int64_t, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_base); if (unlikely(!__pyx_t_11)) __PYX_ERR(5, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 66, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_13);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_13)) __PYX_ERR(5, 66, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_11);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_11)) __PYX_ERR(5, 66, __pyx_L1_error);
  __pyx_t_13 = 0;
  __pyx_t_11 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":10
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_complex128(const complex128_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_14, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count_complex128", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result_keys);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_result_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":71
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_complex128(const complex128_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_complex128(__Pyx_memviewslice __pyx_v_values, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_complex128 *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__42;
  int __pyx_v_ret;
  khcomplex128_t __pyx_v_value;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  Py_ssize_t __pyx_v_first_na;
  khiter_t __pyx_v_k;
  kh_complex128_t *__pyx_v_table;
  PyArrayObject *__pyx_v_out = 0;
  int __pyx_v_seen_na;
  int __pyx_v_uses_mask;
  int __pyx_v_seen_multiple_na;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_out;
  __Pyx_Buffer __pyx_pybuffer_out;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  khuint_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  khcomplex128_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  size_t __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("duplicated_complex128", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_out.pybuffer.buf = NULL;
  __pyx_pybuffer_out.refcount = 0;
  __pyx_pybuffernd_out.data = NULL;
  __pyx_pybuffernd_out.rcbuffer = &__pyx_pybuffer_out;

  /* "pandas/_libs/hashtable_func_helper.pxi":73
 * cdef duplicated_complex128(const complex128_t[:] values, object keep='first', const uint8_t[:] mask=None):
 *     cdef:
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         khcomplex128_t value
 *         Py_ssize_t i, n = len(values), first_na = -1
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":75
 *         int ret = 0
 *         khcomplex128_t value
 *         Py_ssize_t i, n = len(values), first_na = -1             # <<<<<<<<<<<<<<
 *         khiter_t k
 *         kh_complex128_t *table = kh_init_complex128()
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;
  __pyx_v_first_na = -1L;

  /* "pandas/_libs/hashtable_func_helper.pxi":77
 *         Py_ssize_t i, n = len(values), first_na = -1
 *         khiter_t k
 *         kh_complex128_t *table = kh_init_complex128()             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 */
  __pyx_v_table = kh_init_complex128();

  /* "pandas/_libs/hashtable_func_helper.pxi":78
 *         khiter_t k
 *         kh_complex128_t *table = kh_init_complex128()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')             # <<<<<<<<<<<<<<
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 78, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 78, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 78, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 78, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(5, 78, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 78, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_n_u_bool) < 0) __PYX_ERR(5, 78, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 78, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 78, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_out.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 1, __pyx_stack) == -1)) {
      __pyx_v_out = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_out.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(5, 78, __pyx_L1_error)
    } else {__pyx_pybuffernd_out.diminfo[0].strides = __pyx_pybuffernd_out.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_out.diminfo[0].shape = __pyx_pybuffernd_out.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_out = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":79
 *         kh_complex128_t *table = kh_init_complex128()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint seen_multiple_na = False
 * 
 */
  __pyx_v_seen_na = 0;
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":80
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_complex128(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 */
  __pyx_v_seen_multiple_na = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":82
 *         bint seen_multiple_na = False
 * 
 *     kh_resize_complex128(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))             # <<<<<<<<<<<<<<
 * 
 *     if keep not in ('last', 'first', False):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 82, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = kh_needed_n_buckets(__pyx_v_n);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 82, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_5, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 82, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(5, 82, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_8) {
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_2 = __pyx_t_5;
  } else {
    __pyx_t_3 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 82, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_uint32(__pyx_t_2); if (unlikely((__pyx_t_7 == ((khuint_t)-1)) && PyErr_Occurred())) __PYX_ERR(5, 82, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  kh_resize_complex128(__pyx_v_table, __pyx_t_7);

  /* "pandas/_libs/hashtable_func_helper.pxi":84
 *     kh_resize_complex128(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  __Pyx_INCREF(__pyx_v_keep);
  __pyx_t_2 = __pyx_v_keep;
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_last, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 84, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_first, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 84, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, Py_False, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 84, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 84, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_8 = __pyx_t_9;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_9 = __pyx_t_8;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":85
 * 
 *     if keep not in ('last', 'first', False):
 *         raise ValueError('keep must be either "first", "last" or False')             # <<<<<<<<<<<<<<
 * 
 *     if keep == "last":
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__43, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 85, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(5, 85, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":84
 *     kh_resize_complex128(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":87
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_last, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 87, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":88
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":89
 *     if keep == "last":
 *         with nogil:
 *             for i in range(n - 1, -1, -1):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          for (__pyx_t_1 = (__pyx_v_n - 1); __pyx_t_1 > -1L; __pyx_t_1-=1) {
            __pyx_v_i = __pyx_t_1;

            /* "pandas/_libs/hashtable_func_helper.pxi":90
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L14_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L14_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":91
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":92
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":91
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L16;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":94
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":95
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = to_khcomplex128_t(values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L16:;

              /* "pandas/_libs/hashtable_func_helper.pxi":90
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L13;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":97
 *                         seen_na = True
 *                 else:
 *                     value = to_khcomplex128_t(values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_complex128(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_t_11 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex128_t((*((__pyx_t_double_complex const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )))); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(5, 97, __pyx_L9_error)
              __pyx_v_value = __pyx_t_11;

              /* "pandas/_libs/hashtable_func_helper.pxi":98
 *                 else:
 *                     value = to_khcomplex128_t(values[i])
 *                     kh_put_complex128(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 *     elif keep == "first":
 */
              (void)(kh_put_complex128(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":99
 *                     value = to_khcomplex128_t(values[i])
 *                     kh_put_complex128(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 *     elif keep == "first":
 *         with nogil:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L13:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":88
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L10;
          }
          __pyx_L9_error: {
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L1_error;
          }
          __pyx_L10:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":87
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":100
 *                     kh_put_complex128(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_first, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 100, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":101
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":102
 *     elif keep == "first":
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_12 = __pyx_t_1;
          for (__pyx_t_13 = 0; __pyx_t_13 < __pyx_t_12; __pyx_t_13+=1) {
            __pyx_v_i = __pyx_t_13;

            /* "pandas/_libs/hashtable_func_helper.pxi":103
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L23_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L23_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":104
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":105
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":104
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L25;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":107
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":108
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = to_khcomplex128_t(values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L25:;

              /* "pandas/_libs/hashtable_func_helper.pxi":103
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L22;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":110
 *                         seen_na = True
 *                 else:
 *                     value = to_khcomplex128_t(values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_complex128(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_t_11 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex128_t((*((__pyx_t_double_complex const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )))); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(5, 110, __pyx_L18_error)
              __pyx_v_value = __pyx_t_11;

              /* "pandas/_libs/hashtable_func_helper.pxi":111
 *                 else:
 *                     value = to_khcomplex128_t(values[i])
 *                     kh_put_complex128(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 * 
 */
              (void)(kh_put_complex128(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":112
 *                     value = to_khcomplex128_t(values[i])
 *                     kh_put_complex128(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 * 
 *     else:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L22:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":101
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L19;
          }
          __pyx_L18_error: {
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L1_error;
          }
          __pyx_L19:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":100
 *                     kh_put_complex128(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":115
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
  /*else*/ {
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":116
 *     else:
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_12 = __pyx_t_1;
          for (__pyx_t_13 = 0; __pyx_t_13 < __pyx_t_12; __pyx_t_13+=1) {
            __pyx_v_i = __pyx_t_13;

            /* "pandas/_libs/hashtable_func_helper.pxi":117
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L32_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L32_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":118
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
              __pyx_t_9 = (!__pyx_v_seen_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":119
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 *                         first_na = i             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                         out[i] = 0
 */
                __pyx_v_first_na = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":120
 *                     if not seen_na:
 *                         first_na = i
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 */
                __pyx_v_seen_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":121
 *                         first_na = i
 *                         seen_na = True
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":118
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":122
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
              __pyx_t_9 = (!__pyx_v_seen_multiple_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":123
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                         out[first_na] = 1
 *                         seen_multiple_na = True
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":124
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 *                         out[first_na] = 1             # <<<<<<<<<<<<<<
 *                         seen_multiple_na = True
 *                     else:
 */
                __pyx_t_10 = __pyx_v_first_na;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":125
 *                         out[i] = 1
 *                         out[first_na] = 1
 *                         seen_multiple_na = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = 1
 */
                __pyx_v_seen_multiple_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":122
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":127
 *                         seen_multiple_na = True
 *                     else:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 * 
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;
              }
              __pyx_L34:;

              /* "pandas/_libs/hashtable_func_helper.pxi":117
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
              goto __pyx_L31;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":130
 * 
 *                 else:
 *                     value = to_khcomplex128_t(values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_complex128(table, value)
 *                     if k != table.n_buckets:
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_t_11 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex128_t((*((__pyx_t_double_complex const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )))); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(5, 130, __pyx_L27_error)
              __pyx_v_value = __pyx_t_11;

              /* "pandas/_libs/hashtable_func_helper.pxi":131
 *                 else:
 *                     value = to_khcomplex128_t(values[i])
 *                     k = kh_get_complex128(table, value)             # <<<<<<<<<<<<<<
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 */
              __pyx_v_k = kh_get_complex128(__pyx_v_table, __pyx_v_value);

              /* "pandas/_libs/hashtable_func_helper.pxi":132
 *                     value = to_khcomplex128_t(values[i])
 *                     k = kh_get_complex128(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
              __pyx_t_9 = (__pyx_v_k != __pyx_v_table->n_buckets);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":133
 *                     k = kh_get_complex128(table, value)
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                     else:
 */
                __pyx_t_14 = (__pyx_v_table->vals[__pyx_v_k]);
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_14, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":134
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                     else:
 *                         k = kh_put_complex128(table, value, &ret)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":132
 *                     value = to_khcomplex128_t(values[i])
 *                     k = kh_get_complex128(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
                goto __pyx_L35;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":136
 *                         out[i] = 1
 *                     else:
 *                         k = kh_put_complex128(table, value, &ret)             # <<<<<<<<<<<<<<
 *                         table.vals[k] = i
 *                         out[i] = 0
 */
              /*else*/ {
                __pyx_v_k = kh_put_complex128(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret));

                /* "pandas/_libs/hashtable_func_helper.pxi":137
 *                     else:
 *                         k = kh_put_complex128(table, value, &ret)
 *                         table.vals[k] = i             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 * 
 */
                (__pyx_v_table->vals[__pyx_v_k]) = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":138
 *                         k = kh_put_complex128(table, value, &ret)
 *                         table.vals[k] = i
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_complex128(table)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;
              }
              __pyx_L35:;
            }
            __pyx_L31:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":115
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L28;
          }
          __pyx_L27_error: {
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L1_error;
          }
          __pyx_L28:;
        }
    }
  }
  __pyx_L7:;

  /* "pandas/_libs/hashtable_func_helper.pxi":140
 *                         out[i] = 0
 * 
 *     kh_destroy_complex128(table)             # <<<<<<<<<<<<<<
 *     return out
 * 
 */
  kh_destroy_complex128(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":141
 * 
 *     kh_destroy_complex128(table)
 *     return out             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_out);
  __pyx_r = ((PyObject *)__pyx_v_out);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":71
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_complex128(const complex128_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated_complex128", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_out);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":151
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_complex128(const complex128_t[:] arr, const complex128_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_complex128(__Pyx_memviewslice __pyx_v_arr, __Pyx_memviewslice __pyx_v_values) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  PyArrayObject *__pyx_v_result = 0;
  khcomplex128_t __pyx_v_val;
  kh_complex128_t *__pyx_v_table;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  khcomplex128_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyArrayObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ismember_complex128", 1);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "pandas/_libs/hashtable_func_helper.pxi":168
 *         Py_ssize_t i, n
 *         khiter_t k
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t] result
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":173
 *         khcomplex128_t val
 * 
 *         kh_complex128_t *table = kh_init_complex128()             # <<<<<<<<<<<<<<
 * 
 *     # construct the table
 */
  __pyx_v_table = kh_init_complex128();

  /* "pandas/_libs/hashtable_func_helper.pxi":176
 * 
 *     # construct the table
 *     n = len(values)             # <<<<<<<<<<<<<<
 *     kh_resize_complex128(table, n)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":177
 *     # construct the table
 *     n = len(values)
 *     kh_resize_complex128(table, n)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  kh_resize_complex128(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":179
 *     kh_resize_complex128(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = to_khcomplex128_t(values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":180
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = to_khcomplex128_t(values[i])
 *             kh_put_complex128(table, val, &ret)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":181
 *     with nogil:
 *         for i in range(n):
 *             val = to_khcomplex128_t(values[i])             # <<<<<<<<<<<<<<
 *             kh_put_complex128(table, val, &ret)
 * 
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_t_5 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex128_t((*((__pyx_t_double_complex const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_4 * __pyx_v_values.strides[0]) )))); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(5, 181, __pyx_L4_error)
          __pyx_v_val = __pyx_t_5;

          /* "pandas/_libs/hashtable_func_helper.pxi":182
 *         for i in range(n):
 *             val = to_khcomplex128_t(values[i])
 *             kh_put_complex128(table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *     # test membership
 */
          (void)(kh_put_complex128(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret)));
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":179
 *     kh_resize_complex128(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = to_khcomplex128_t(values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":185
 * 
 *     # test membership
 *     n = len(arr)             # <<<<<<<<<<<<<<
 *     result = np.empty(n, dtype=np.uint8)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_arr); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":186
 *     # test membership
 *     n = len(arr)
 *     result = np.empty(n, dtype=np.uint8)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_empty); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(5, 186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6)) __PYX_ERR(5, 186, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_np); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_uint8); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_dtype, __pyx_t_10) < 0) __PYX_ERR(5, 186, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, __pyx_t_6); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 186, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (!(likely(((__pyx_t_10) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_10, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 186, __pyx_L1_error)
  __pyx_t_11 = ((PyArrayObject *)__pyx_t_10);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_12 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_11, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_12 < 0)) {
      PyErr_Fetch(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_13); Py_XDECREF(__pyx_t_14); Py_XDECREF(__pyx_t_15);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_13, __pyx_t_14, __pyx_t_15);
      }
      __pyx_t_13 = __pyx_t_14 = __pyx_t_15 = 0;
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(5, 186, __pyx_L1_error)
  }
  __pyx_t_11 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_10);
  __pyx_t_10 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":188
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = to_khcomplex128_t(arr[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":189
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = to_khcomplex128_t(arr[i])
 *             k = kh_get_complex128(table, val)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":190
 *     with nogil:
 *         for i in range(n):
 *             val = to_khcomplex128_t(arr[i])             # <<<<<<<<<<<<<<
 *             k = kh_get_complex128(table, val)
 *             result[i] = (k != table.n_buckets)
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_t_5 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex128_t((*((__pyx_t_double_complex const  *) ( /* dim=0 */ (__pyx_v_arr.data + __pyx_t_4 * __pyx_v_arr.strides[0]) )))); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(5, 190, __pyx_L9_error)
          __pyx_v_val = __pyx_t_5;

          /* "pandas/_libs/hashtable_func_helper.pxi":191
 *         for i in range(n):
 *             val = to_khcomplex128_t(arr[i])
 *             k = kh_get_complex128(table, val)             # <<<<<<<<<<<<<<
 *             result[i] = (k != table.n_buckets)
 * 
 */
          __pyx_v_k = kh_get_complex128(__pyx_v_table, __pyx_v_val);

          /* "pandas/_libs/hashtable_func_helper.pxi":192
 *             val = to_khcomplex128_t(arr[i])
 *             k = kh_get_complex128(table, val)
 *             result[i] = (k != table.n_buckets)             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_complex128(table)
 */
          __pyx_t_4 = __pyx_v_i;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_result.rcbuffer->pybuffer.buf, __pyx_t_4, __pyx_pybuffernd_result.diminfo[0].strides) = (__pyx_v_k != __pyx_v_table->n_buckets);
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":188
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = to_khcomplex128_t(arr[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L10;
        }
        __pyx_L9_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L10:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":194
 *             result[i] = (k != table.n_buckets)
 * 
 *     kh_destroy_complex128(table)             # <<<<<<<<<<<<<<
 *     return result.view(np.bool_)
 * 
 */
  kh_destroy_complex128(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":195
 * 
 *     kh_destroy_complex128(table)
 *     return result.view(np.bool_)             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_result), __pyx_n_s_view); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(5, 195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_bool_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  __pyx_t_12 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_12 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_7};
    __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_12, 1+__pyx_t_12);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 195, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_r = __pyx_t_10;
  __pyx_t_10 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":151
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_complex128(const complex128_t[:] arr, const complex128_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember_complex128", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":204
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_complex64(const complex64_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_complex64(__Pyx_memviewslice __pyx_v_values, int __pyx_v_dropna, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_complex64 *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__44;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  kh_complex64_t *__pyx_v_table;
  khiter_t __pyx_v_k;
  khcomplex64_t __pyx_v_val;
  int __pyx_v_ret;
  int __pyx_v_uses_mask;
  int __pyx_v_isna_entry;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *__pyx_v_result_keys = NULL;
  __Pyx_memviewslice __pyx_v_result_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  khcomplex64_t __pyx_t_8;
  khiter_t __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  __Pyx_memviewslice __pyx_t_14 = { 0, 0, { 0 }, { 0 }, { 0 } };
  khuint_t __pyx_t_15;
  khuint_t __pyx_t_16;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("value_count_complex64", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":206
 * cdef value_count_complex64(const complex64_t[:] values, bint dropna, const uint8_t[:] mask=None):
 *     cdef:
 *         Py_ssize_t i = 0             # <<<<<<<<<<<<<<
 *         Py_ssize_t n = len(values)
 *         kh_complex64_t *table
 */
  __pyx_v_i = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":207
 *     cdef:
 *         Py_ssize_t i = 0
 *         Py_ssize_t n = len(values)             # <<<<<<<<<<<<<<
 *         kh_complex64_t *table
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":215
 *         khcomplex64_t val
 * 
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":216
 * 
 *         int ret = 0
 *         bint uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint isna_entry = False
 * 
 */
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":217
 *         int ret = 0
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False             # <<<<<<<<<<<<<<
 * 
 *     if uses_mask and not dropna:
 */
  __pyx_v_isna_entry = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":219
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  if (__pyx_v_uses_mask) {
  } else {
    __pyx_t_2 = __pyx_v_uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (!__pyx_v_dropna);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_2)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":220
 * 
 *     if uses_mask and not dropna:
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")             # <<<<<<<<<<<<<<
 * 
 *     # we track the order in which keys are first seen (GH39009),
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_NotImplementedError, __pyx_tuple__41, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 220, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(5, 220, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":219
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":227
 *     #    result_keys remembers the original order of keys
 * 
 *     result_keys = Complex64Vector()             # <<<<<<<<<<<<<<
 *     table = kh_init_complex64()
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector)); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_result_keys = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":228
 * 
 *     result_keys = Complex64Vector()
 *     table = kh_init_complex64()             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_complex64(table, n)
 */
  __pyx_v_table = kh_init_complex64();

  /* "pandas/_libs/hashtable_func_helper.pxi":230
 *     table = kh_init_complex64()
 * 
 *     kh_resize_complex64(table, n)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(n):
 */
  kh_resize_complex64(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":232
 *     kh_resize_complex64(table, n)
 * 
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         val = to_khcomplex64_t(values[i])
 * 
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_5 = __pyx_t_1;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "pandas/_libs/hashtable_func_helper.pxi":233
 * 
 *     for i in range(n):
 *         val = to_khcomplex64_t(values[i])             # <<<<<<<<<<<<<<
 * 
 *         if dropna:
 */
    __pyx_t_7 = __pyx_v_i;
    __pyx_t_8 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex64_t((*((__pyx_t_float_complex const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )))); if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 233, __pyx_L1_error)
    __pyx_v_val = __pyx_t_8;

    /* "pandas/_libs/hashtable_func_helper.pxi":235
 *         val = to_khcomplex64_t(values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    if (__pyx_v_dropna) {

      /* "pandas/_libs/hashtable_func_helper.pxi":236
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
      if (__pyx_v_uses_mask) {

        /* "pandas/_libs/hashtable_func_helper.pxi":237
 *         if dropna:
 *             if uses_mask:
 *                 isna_entry = mask[i]             # <<<<<<<<<<<<<<
 *             else:
 *                 isna_entry = is_nan_khcomplex64_t(val)
 */
        __pyx_t_7 = __pyx_v_i;
        __pyx_v_isna_entry = (*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) )));

        /* "pandas/_libs/hashtable_func_helper.pxi":236
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
        goto __pyx_L9;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":239
 *                 isna_entry = mask[i]
 *             else:
 *                 isna_entry = is_nan_khcomplex64_t(val)             # <<<<<<<<<<<<<<
 * 
 *         if not dropna or not isna_entry:
 */
      /*else*/ {
        __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_khcomplex64_t(__pyx_v_val); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 239, __pyx_L1_error)
        __pyx_v_isna_entry = __pyx_t_2;
      }
      __pyx_L9:;

      /* "pandas/_libs/hashtable_func_helper.pxi":235
 *         val = to_khcomplex64_t(values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":241
 *                 isna_entry = is_nan_khcomplex64_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_complex64(table, val)
 *             if k != table.n_buckets:
 */
    __pyx_t_3 = (!__pyx_v_dropna);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L11_bool_binop_done;
    }
    __pyx_t_3 = (!__pyx_v_isna_entry);
    __pyx_t_2 = __pyx_t_3;
    __pyx_L11_bool_binop_done:;
    if (__pyx_t_2) {

      /* "pandas/_libs/hashtable_func_helper.pxi":242
 * 
 *         if not dropna or not isna_entry:
 *             k = kh_get_complex64(table, val)             # <<<<<<<<<<<<<<
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1
 */
      __pyx_v_k = kh_get_complex64(__pyx_v_table, __pyx_v_val);

      /* "pandas/_libs/hashtable_func_helper.pxi":243
 *         if not dropna or not isna_entry:
 *             k = kh_get_complex64(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
      __pyx_t_2 = (__pyx_v_k != __pyx_v_table->n_buckets);
      if (__pyx_t_2) {

        /* "pandas/_libs/hashtable_func_helper.pxi":244
 *             k = kh_get_complex64(table, val)
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 k = kh_put_complex64(table, val, &ret)
 */
        __pyx_t_9 = __pyx_v_k;
        (__pyx_v_table->vals[__pyx_t_9]) = ((__pyx_v_table->vals[__pyx_t_9]) + 1);

        /* "pandas/_libs/hashtable_func_helper.pxi":243
 *         if not dropna or not isna_entry:
 *             k = kh_get_complex64(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
        goto __pyx_L13;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":246
 *                 table.vals[k] += 1
 *             else:
 *                 k = kh_put_complex64(table, val, &ret)             # <<<<<<<<<<<<<<
 *                 table.vals[k] = 1
 *                 result_keys.append(val)
 */
      /*else*/ {
        __pyx_v_k = kh_put_complex64(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret));

        /* "pandas/_libs/hashtable_func_helper.pxi":247
 *             else:
 *                 k = kh_put_complex64(table, val, &ret)
 *                 table.vals[k] = 1             # <<<<<<<<<<<<<<
 *                 result_keys.append(val)
 * 
 */
        (__pyx_v_table->vals[__pyx_v_k]) = 1;

        /* "pandas/_libs/hashtable_func_helper.pxi":248
 *                 k = kh_put_complex64(table, val, &ret)
 *                 table.vals[k] = 1
 *                 result_keys.append(val)             # <<<<<<<<<<<<<<
 * 
 *     # collect counts in the order corresponding to result_keys:
 */
        ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex64Vector *)__pyx_v_result_keys->__pyx_vtab)->append(__pyx_v_result_keys, __pyx_v_val); if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 248, __pyx_L1_error)
      }
      __pyx_L13:;

      /* "pandas/_libs/hashtable_func_helper.pxi":241
 *                 isna_entry = is_nan_khcomplex64_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_complex64(table, val)
 *             if k != table.n_buckets:
 */
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":252
 *     # collect counts in the order corresponding to result_keys:
 *     cdef:
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(table.size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_empty); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_v_table->size); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_11 = PyTuple_New(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(5, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_4)) __PYX_ERR(5, 252, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_np); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_int64); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_dtype, __pyx_t_13) < 0) __PYX_ERR(5, 252, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_11, __pyx_t_4); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 252, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_14 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_13, PyBUF_WRITABLE); if (unlikely(!__pyx_t_14.memview)) __PYX_ERR(5, 252, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_v_result_counts = __pyx_t_14;
  __pyx_t_14.memview = NULL;
  __pyx_t_14.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":254
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)
 * 
 *     for i in range(table.size):             # <<<<<<<<<<<<<<
 *         k = kh_get_complex64(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]
 */
  __pyx_t_15 = __pyx_v_table->size;
  __pyx_t_16 = __pyx_t_15;
  for (__pyx_t_1 = 0; __pyx_t_1 < __pyx_t_16; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "pandas/_libs/hashtable_func_helper.pxi":255
 * 
 *     for i in range(table.size):
 *         k = kh_get_complex64(table, result_keys.data.data[i])             # <<<<<<<<<<<<<<
 *         result_counts[i] = table.vals[k]
 * 
 */
    __pyx_v_k = kh_get_complex64(__pyx_v_table, (__pyx_v_result_keys->data->data[__pyx_v_i]));

    /* "pandas/_libs/hashtable_func_helper.pxi":256
 *     for i in range(table.size):
 *         k = kh_get_complex64(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_complex64(table)
 */
    __pyx_t_7 = __pyx_v_i;
    *((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_result_counts.data) + __pyx_t_7)) )) = (__pyx_v_table->vals[__pyx_v_k]);
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":258
 *         result_counts[i] = table.vals[k]
 * 
 *     kh_destroy_complex64(table)             # <<<<<<<<<<<<<<
 * 
 *     return result_keys.to_array(), result_counts.base
 */
  kh_destroy_complex64(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":260
 *     kh_destroy_complex64(table)
 * 
 *     return result_keys.to_array(), result_counts.base             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_13 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex64Vector *)__pyx_v_result_keys->__pyx_vtab)->to_array(__pyx_v_result_keys, 0)); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_result_counts, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int64_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int64_t, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_base); if (unlikely(!__pyx_t_11)) __PYX_ERR(5, 260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 260, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_13);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_13)) __PYX_ERR(5, 260, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_11);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_11)) __PYX_ERR(5, 260, __pyx_L1_error);
  __pyx_t_13 = 0;
  __pyx_t_11 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":204
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_complex64(const complex64_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_14, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count_complex64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result_keys);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_result_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":265
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_complex64(const complex64_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_complex64(__Pyx_memviewslice __pyx_v_values, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_complex64 *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__45;
  int __pyx_v_ret;
  khcomplex64_t __pyx_v_value;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  Py_ssize_t __pyx_v_first_na;
  khiter_t __pyx_v_k;
  kh_complex64_t *__pyx_v_table;
  PyArrayObject *__pyx_v_out = 0;
  int __pyx_v_seen_na;
  int __pyx_v_uses_mask;
  int __pyx_v_seen_multiple_na;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_out;
  __Pyx_Buffer __pyx_pybuffer_out;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  khuint_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  khcomplex64_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  Py_ssize_t __pyx_t_13;
  size_t __pyx_t_14;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("duplicated_complex64", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_out.pybuffer.buf = NULL;
  __pyx_pybuffer_out.refcount = 0;
  __pyx_pybuffernd_out.data = NULL;
  __pyx_pybuffernd_out.rcbuffer = &__pyx_pybuffer_out;

  /* "pandas/_libs/hashtable_func_helper.pxi":267
 * cdef duplicated_complex64(const complex64_t[:] values, object keep='first', const uint8_t[:] mask=None):
 *     cdef:
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         khcomplex64_t value
 *         Py_ssize_t i, n = len(values), first_na = -1
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":269
 *         int ret = 0
 *         khcomplex64_t value
 *         Py_ssize_t i, n = len(values), first_na = -1             # <<<<<<<<<<<<<<
 *         khiter_t k
 *         kh_complex64_t *table = kh_init_complex64()
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;
  __pyx_v_first_na = -1L;

  /* "pandas/_libs/hashtable_func_helper.pxi":271
 *         Py_ssize_t i, n = len(values), first_na = -1
 *         khiter_t k
 *         kh_complex64_t *table = kh_init_complex64()             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 */
  __pyx_v_table = kh_init_complex64();

  /* "pandas/_libs/hashtable_func_helper.pxi":272
 *         khiter_t k
 *         kh_complex64_t *table = kh_init_complex64()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')             # <<<<<<<<<<<<<<
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(5, 272, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_n_u_bool) < 0) __PYX_ERR(5, 272, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 272, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 272, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_out.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 1, __pyx_stack) == -1)) {
      __pyx_v_out = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_out.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(5, 272, __pyx_L1_error)
    } else {__pyx_pybuffernd_out.diminfo[0].strides = __pyx_pybuffernd_out.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_out.diminfo[0].shape = __pyx_pybuffernd_out.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_out = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":273
 *         kh_complex64_t *table = kh_init_complex64()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint seen_multiple_na = False
 * 
 */
  __pyx_v_seen_na = 0;
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":274
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_complex64(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 */
  __pyx_v_seen_multiple_na = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":276
 *         bint seen_multiple_na = False
 * 
 *     kh_resize_complex64(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))             # <<<<<<<<<<<<<<
 * 
 *     if keep not in ('last', 'first', False):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = kh_needed_n_buckets(__pyx_v_n);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 276, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_5, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 276, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(5, 276, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_8) {
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_2 = __pyx_t_5;
  } else {
    __pyx_t_3 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 276, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_uint32(__pyx_t_2); if (unlikely((__pyx_t_7 == ((khuint_t)-1)) && PyErr_Occurred())) __PYX_ERR(5, 276, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  kh_resize_complex64(__pyx_v_table, __pyx_t_7);

  /* "pandas/_libs/hashtable_func_helper.pxi":278
 *     kh_resize_complex64(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  __Pyx_INCREF(__pyx_v_keep);
  __pyx_t_2 = __pyx_v_keep;
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_last, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 278, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_first, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 278, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, Py_False, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 278, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 278, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_8 = __pyx_t_9;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_9 = __pyx_t_8;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":279
 * 
 *     if keep not in ('last', 'first', False):
 *         raise ValueError('keep must be either "first", "last" or False')             # <<<<<<<<<<<<<<
 * 
 *     if keep == "last":
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__43, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 279, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(5, 279, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":278
 *     kh_resize_complex64(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":281
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_last, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 281, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":282
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":283
 *     if keep == "last":
 *         with nogil:
 *             for i in range(n - 1, -1, -1):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          for (__pyx_t_1 = (__pyx_v_n - 1); __pyx_t_1 > -1L; __pyx_t_1-=1) {
            __pyx_v_i = __pyx_t_1;

            /* "pandas/_libs/hashtable_func_helper.pxi":284
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L14_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L14_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":285
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":286
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":285
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L16;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":288
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":289
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = to_khcomplex64_t(values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L16:;

              /* "pandas/_libs/hashtable_func_helper.pxi":284
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L13;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":291
 *                         seen_na = True
 *                 else:
 *                     value = to_khcomplex64_t(values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_complex64(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_t_11 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex64_t((*((__pyx_t_float_complex const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )))); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(5, 291, __pyx_L9_error)
              __pyx_v_value = __pyx_t_11;

              /* "pandas/_libs/hashtable_func_helper.pxi":292
 *                 else:
 *                     value = to_khcomplex64_t(values[i])
 *                     kh_put_complex64(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 *     elif keep == "first":
 */
              (void)(kh_put_complex64(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":293
 *                     value = to_khcomplex64_t(values[i])
 *                     kh_put_complex64(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 *     elif keep == "first":
 *         with nogil:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L13:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":282
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L10;
          }
          __pyx_L9_error: {
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L1_error;
          }
          __pyx_L10:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":281
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":294
 *                     kh_put_complex64(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_first, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 294, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":295
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":296
 *     elif keep == "first":
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_12 = __pyx_t_1;
          for (__pyx_t_13 = 0; __pyx_t_13 < __pyx_t_12; __pyx_t_13+=1) {
            __pyx_v_i = __pyx_t_13;

            /* "pandas/_libs/hashtable_func_helper.pxi":297
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L23_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L23_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":298
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":299
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":298
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L25;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":301
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":302
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = to_khcomplex64_t(values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L25:;

              /* "pandas/_libs/hashtable_func_helper.pxi":297
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L22;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":304
 *                         seen_na = True
 *                 else:
 *                     value = to_khcomplex64_t(values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_complex64(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_t_11 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex64_t((*((__pyx_t_float_complex const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )))); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(5, 304, __pyx_L18_error)
              __pyx_v_value = __pyx_t_11;

              /* "pandas/_libs/hashtable_func_helper.pxi":305
 *                 else:
 *                     value = to_khcomplex64_t(values[i])
 *                     kh_put_complex64(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 * 
 */
              (void)(kh_put_complex64(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":306
 *                     value = to_khcomplex64_t(values[i])
 *                     kh_put_complex64(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 * 
 *     else:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L22:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":295
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L19;
          }
          __pyx_L18_error: {
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L1_error;
          }
          __pyx_L19:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":294
 *                     kh_put_complex64(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":309
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
  /*else*/ {
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":310
 *     else:
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_12 = __pyx_t_1;
          for (__pyx_t_13 = 0; __pyx_t_13 < __pyx_t_12; __pyx_t_13+=1) {
            __pyx_v_i = __pyx_t_13;

            /* "pandas/_libs/hashtable_func_helper.pxi":311
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L32_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L32_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":312
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
              __pyx_t_9 = (!__pyx_v_seen_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":313
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 *                         first_na = i             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                         out[i] = 0
 */
                __pyx_v_first_na = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":314
 *                     if not seen_na:
 *                         first_na = i
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 */
                __pyx_v_seen_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":315
 *                         first_na = i
 *                         seen_na = True
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":312
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":316
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
              __pyx_t_9 = (!__pyx_v_seen_multiple_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":317
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                         out[first_na] = 1
 *                         seen_multiple_na = True
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":318
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 *                         out[first_na] = 1             # <<<<<<<<<<<<<<
 *                         seen_multiple_na = True
 *                     else:
 */
                __pyx_t_10 = __pyx_v_first_na;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":319
 *                         out[i] = 1
 *                         out[first_na] = 1
 *                         seen_multiple_na = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = 1
 */
                __pyx_v_seen_multiple_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":316
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":321
 *                         seen_multiple_na = True
 *                     else:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 * 
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;
              }
              __pyx_L34:;

              /* "pandas/_libs/hashtable_func_helper.pxi":311
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
              goto __pyx_L31;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":324
 * 
 *                 else:
 *                     value = to_khcomplex64_t(values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_complex64(table, value)
 *                     if k != table.n_buckets:
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_t_11 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex64_t((*((__pyx_t_float_complex const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )))); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(5, 324, __pyx_L27_error)
              __pyx_v_value = __pyx_t_11;

              /* "pandas/_libs/hashtable_func_helper.pxi":325
 *                 else:
 *                     value = to_khcomplex64_t(values[i])
 *                     k = kh_get_complex64(table, value)             # <<<<<<<<<<<<<<
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 */
              __pyx_v_k = kh_get_complex64(__pyx_v_table, __pyx_v_value);

              /* "pandas/_libs/hashtable_func_helper.pxi":326
 *                     value = to_khcomplex64_t(values[i])
 *                     k = kh_get_complex64(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
              __pyx_t_9 = (__pyx_v_k != __pyx_v_table->n_buckets);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":327
 *                     k = kh_get_complex64(table, value)
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                     else:
 */
                __pyx_t_14 = (__pyx_v_table->vals[__pyx_v_k]);
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_14, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":328
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                     else:
 *                         k = kh_put_complex64(table, value, &ret)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":326
 *                     value = to_khcomplex64_t(values[i])
 *                     k = kh_get_complex64(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
                goto __pyx_L35;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":330
 *                         out[i] = 1
 *                     else:
 *                         k = kh_put_complex64(table, value, &ret)             # <<<<<<<<<<<<<<
 *                         table.vals[k] = i
 *                         out[i] = 0
 */
              /*else*/ {
                __pyx_v_k = kh_put_complex64(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret));

                /* "pandas/_libs/hashtable_func_helper.pxi":331
 *                     else:
 *                         k = kh_put_complex64(table, value, &ret)
 *                         table.vals[k] = i             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 * 
 */
                (__pyx_v_table->vals[__pyx_v_k]) = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":332
 *                         k = kh_put_complex64(table, value, &ret)
 *                         table.vals[k] = i
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_complex64(table)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;
              }
              __pyx_L35:;
            }
            __pyx_L31:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":309
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L28;
          }
          __pyx_L27_error: {
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L1_error;
          }
          __pyx_L28:;
        }
    }
  }
  __pyx_L7:;

  /* "pandas/_libs/hashtable_func_helper.pxi":334
 *                         out[i] = 0
 * 
 *     kh_destroy_complex64(table)             # <<<<<<<<<<<<<<
 *     return out
 * 
 */
  kh_destroy_complex64(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":335
 * 
 *     kh_destroy_complex64(table)
 *     return out             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_out);
  __pyx_r = ((PyObject *)__pyx_v_out);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":265
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_complex64(const complex64_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated_complex64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_out);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":345
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_complex64(const complex64_t[:] arr, const complex64_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_complex64(__Pyx_memviewslice __pyx_v_arr, __Pyx_memviewslice __pyx_v_values) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  PyArrayObject *__pyx_v_result = 0;
  khcomplex64_t __pyx_v_val;
  kh_complex64_t *__pyx_v_table;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  khcomplex64_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyArrayObject *__pyx_t_11 = NULL;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ismember_complex64", 1);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "pandas/_libs/hashtable_func_helper.pxi":362
 *         Py_ssize_t i, n
 *         khiter_t k
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t] result
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":367
 *         khcomplex64_t val
 * 
 *         kh_complex64_t *table = kh_init_complex64()             # <<<<<<<<<<<<<<
 * 
 *     # construct the table
 */
  __pyx_v_table = kh_init_complex64();

  /* "pandas/_libs/hashtable_func_helper.pxi":370
 * 
 *     # construct the table
 *     n = len(values)             # <<<<<<<<<<<<<<
 *     kh_resize_complex64(table, n)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":371
 *     # construct the table
 *     n = len(values)
 *     kh_resize_complex64(table, n)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  kh_resize_complex64(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":373
 *     kh_resize_complex64(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = to_khcomplex64_t(values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":374
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = to_khcomplex64_t(values[i])
 *             kh_put_complex64(table, val, &ret)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":375
 *     with nogil:
 *         for i in range(n):
 *             val = to_khcomplex64_t(values[i])             # <<<<<<<<<<<<<<
 *             kh_put_complex64(table, val, &ret)
 * 
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_t_5 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex64_t((*((__pyx_t_float_complex const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_4 * __pyx_v_values.strides[0]) )))); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(5, 375, __pyx_L4_error)
          __pyx_v_val = __pyx_t_5;

          /* "pandas/_libs/hashtable_func_helper.pxi":376
 *         for i in range(n):
 *             val = to_khcomplex64_t(values[i])
 *             kh_put_complex64(table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *     # test membership
 */
          (void)(kh_put_complex64(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret)));
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":373
 *     kh_resize_complex64(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = to_khcomplex64_t(values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":379
 * 
 *     # test membership
 *     n = len(arr)             # <<<<<<<<<<<<<<
 *     result = np.empty(n, dtype=np.uint8)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_arr); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":380
 *     # test membership
 *     n = len(arr)
 *     result = np.empty(n, dtype=np.uint8)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_6, __pyx_n_s_np); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_empty); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = PyTuple_New(1); if (unlikely(!__pyx_t_8)) __PYX_ERR(5, 380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_6);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_8, 0, __pyx_t_6)) __PYX_ERR(5, 380, __pyx_L1_error);
  __pyx_t_6 = 0;
  __pyx_t_6 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetModuleGlobalName(__pyx_t_9, __pyx_n_s_np); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_9, __pyx_n_s_uint8); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  if (PyDict_SetItem(__pyx_t_6, __pyx_n_s_dtype, __pyx_t_10) < 0) __PYX_ERR(5, 380, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = __Pyx_PyObject_Call(__pyx_t_7, __pyx_t_8, __pyx_t_6); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 380, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (!(likely(((__pyx_t_10) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_10, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 380, __pyx_L1_error)
  __pyx_t_11 = ((PyArrayObject *)__pyx_t_10);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_12 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_11, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_12 < 0)) {
      PyErr_Fetch(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_13); Py_XDECREF(__pyx_t_14); Py_XDECREF(__pyx_t_15);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_13, __pyx_t_14, __pyx_t_15);
      }
      __pyx_t_13 = __pyx_t_14 = __pyx_t_15 = 0;
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(5, 380, __pyx_L1_error)
  }
  __pyx_t_11 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_10);
  __pyx_t_10 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":382
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = to_khcomplex64_t(arr[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":383
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = to_khcomplex64_t(arr[i])
 *             k = kh_get_complex64(table, val)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":384
 *     with nogil:
 *         for i in range(n):
 *             val = to_khcomplex64_t(arr[i])             # <<<<<<<<<<<<<<
 *             k = kh_get_complex64(table, val)
 *             result[i] = (k != table.n_buckets)
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_t_5 = __pyx_f_6pandas_5_libs_9hashtable_to_khcomplex64_t((*((__pyx_t_float_complex const  *) ( /* dim=0 */ (__pyx_v_arr.data + __pyx_t_4 * __pyx_v_arr.strides[0]) )))); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(5, 384, __pyx_L9_error)
          __pyx_v_val = __pyx_t_5;

          /* "pandas/_libs/hashtable_func_helper.pxi":385
 *         for i in range(n):
 *             val = to_khcomplex64_t(arr[i])
 *             k = kh_get_complex64(table, val)             # <<<<<<<<<<<<<<
 *             result[i] = (k != table.n_buckets)
 * 
 */
          __pyx_v_k = kh_get_complex64(__pyx_v_table, __pyx_v_val);

          /* "pandas/_libs/hashtable_func_helper.pxi":386
 *             val = to_khcomplex64_t(arr[i])
 *             k = kh_get_complex64(table, val)
 *             result[i] = (k != table.n_buckets)             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_complex64(table)
 */
          __pyx_t_4 = __pyx_v_i;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_result.rcbuffer->pybuffer.buf, __pyx_t_4, __pyx_pybuffernd_result.diminfo[0].strides) = (__pyx_v_k != __pyx_v_table->n_buckets);
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":382
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = to_khcomplex64_t(arr[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L10;
        }
        __pyx_L9_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L10:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":388
 *             result[i] = (k != table.n_buckets)
 * 
 *     kh_destroy_complex64(table)             # <<<<<<<<<<<<<<
 *     return result.view(np.bool_)
 * 
 */
  kh_destroy_complex64(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":389
 * 
 *     kh_destroy_complex64(table)
 *     return result.view(np.bool_)             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_result), __pyx_n_s_view); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(5, 389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_bool_2); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 389, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  __pyx_t_8 = NULL;
  __pyx_t_12 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_12 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_8, __pyx_t_7};
    __pyx_t_10 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_12, 1+__pyx_t_12);
    __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 389, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_10);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_r = __pyx_t_10;
  __pyx_t_10 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":345
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_complex64(const complex64_t[:] arr, const complex64_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember_complex64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":398
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_float64(const float64_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_float64(__Pyx_memviewslice __pyx_v_values, int __pyx_v_dropna, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_float64 *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__46;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  kh_float64_t *__pyx_v_table;
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_float64_t __pyx_v_val;
  int __pyx_v_ret;
  int __pyx_v_uses_mask;
  int __pyx_v_isna_entry;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *__pyx_v_result_keys = NULL;
  __Pyx_memviewslice __pyx_v_result_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  khiter_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  khuint_t __pyx_t_14;
  khuint_t __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("value_count_float64", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":400
 * cdef value_count_float64(const float64_t[:] values, bint dropna, const uint8_t[:] mask=None):
 *     cdef:
 *         Py_ssize_t i = 0             # <<<<<<<<<<<<<<
 *         Py_ssize_t n = len(values)
 *         kh_float64_t *table
 */
  __pyx_v_i = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":401
 *     cdef:
 *         Py_ssize_t i = 0
 *         Py_ssize_t n = len(values)             # <<<<<<<<<<<<<<
 *         kh_float64_t *table
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":409
 *         float64_t val
 * 
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":410
 * 
 *         int ret = 0
 *         bint uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint isna_entry = False
 * 
 */
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":411
 *         int ret = 0
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False             # <<<<<<<<<<<<<<
 * 
 *     if uses_mask and not dropna:
 */
  __pyx_v_isna_entry = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":413
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  if (__pyx_v_uses_mask) {
  } else {
    __pyx_t_2 = __pyx_v_uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (!__pyx_v_dropna);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_2)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":414
 * 
 *     if uses_mask and not dropna:
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")             # <<<<<<<<<<<<<<
 * 
 *     # we track the order in which keys are first seen (GH39009),
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_NotImplementedError, __pyx_tuple__41, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 414, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(5, 414, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":413
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":421
 *     #    result_keys remembers the original order of keys
 * 
 *     result_keys = Float64Vector()             # <<<<<<<<<<<<<<
 *     table = kh_init_float64()
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector)); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_result_keys = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":422
 * 
 *     result_keys = Float64Vector()
 *     table = kh_init_float64()             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_float64(table, n)
 */
  __pyx_v_table = kh_init_float64();

  /* "pandas/_libs/hashtable_func_helper.pxi":424
 *     table = kh_init_float64()
 * 
 *     kh_resize_float64(table, n)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(n):
 */
  kh_resize_float64(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":426
 *     kh_resize_float64(table, n)
 * 
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         val = (values[i])
 * 
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_5 = __pyx_t_1;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "pandas/_libs/hashtable_func_helper.pxi":427
 * 
 *     for i in range(n):
 *         val = (values[i])             # <<<<<<<<<<<<<<
 * 
 *         if dropna:
 */
    __pyx_t_7 = __pyx_v_i;
    __pyx_v_val = (*((__pyx_t_5numpy_float64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

    /* "pandas/_libs/hashtable_func_helper.pxi":429
 *         val = (values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    if (__pyx_v_dropna) {

      /* "pandas/_libs/hashtable_func_helper.pxi":430
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
      if (__pyx_v_uses_mask) {

        /* "pandas/_libs/hashtable_func_helper.pxi":431
 *         if dropna:
 *             if uses_mask:
 *                 isna_entry = mask[i]             # <<<<<<<<<<<<<<
 *             else:
 *                 isna_entry = is_nan_float64_t(val)
 */
        __pyx_t_7 = __pyx_v_i;
        __pyx_v_isna_entry = (*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) )));

        /* "pandas/_libs/hashtable_func_helper.pxi":430
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
        goto __pyx_L9;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":433
 *                 isna_entry = mask[i]
 *             else:
 *                 isna_entry = is_nan_float64_t(val)             # <<<<<<<<<<<<<<
 * 
 *         if not dropna or not isna_entry:
 */
      /*else*/ {
        __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_float64_t(__pyx_v_val); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 433, __pyx_L1_error)
        __pyx_v_isna_entry = __pyx_t_2;
      }
      __pyx_L9:;

      /* "pandas/_libs/hashtable_func_helper.pxi":429
 *         val = (values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":435
 *                 isna_entry = is_nan_float64_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_float64(table, val)
 *             if k != table.n_buckets:
 */
    __pyx_t_3 = (!__pyx_v_dropna);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L11_bool_binop_done;
    }
    __pyx_t_3 = (!__pyx_v_isna_entry);
    __pyx_t_2 = __pyx_t_3;
    __pyx_L11_bool_binop_done:;
    if (__pyx_t_2) {

      /* "pandas/_libs/hashtable_func_helper.pxi":436
 * 
 *         if not dropna or not isna_entry:
 *             k = kh_get_float64(table, val)             # <<<<<<<<<<<<<<
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1
 */
      __pyx_v_k = kh_get_float64(__pyx_v_table, __pyx_v_val);

      /* "pandas/_libs/hashtable_func_helper.pxi":437
 *         if not dropna or not isna_entry:
 *             k = kh_get_float64(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
      __pyx_t_2 = (__pyx_v_k != __pyx_v_table->n_buckets);
      if (__pyx_t_2) {

        /* "pandas/_libs/hashtable_func_helper.pxi":438
 *             k = kh_get_float64(table, val)
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 k = kh_put_float64(table, val, &ret)
 */
        __pyx_t_8 = __pyx_v_k;
        (__pyx_v_table->vals[__pyx_t_8]) = ((__pyx_v_table->vals[__pyx_t_8]) + 1);

        /* "pandas/_libs/hashtable_func_helper.pxi":437
 *         if not dropna or not isna_entry:
 *             k = kh_get_float64(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
        goto __pyx_L13;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":440
 *                 table.vals[k] += 1
 *             else:
 *                 k = kh_put_float64(table, val, &ret)             # <<<<<<<<<<<<<<
 *                 table.vals[k] = 1
 *                 result_keys.append(val)
 */
      /*else*/ {
        __pyx_v_k = kh_put_float64(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret));

        /* "pandas/_libs/hashtable_func_helper.pxi":441
 *             else:
 *                 k = kh_put_float64(table, val, &ret)
 *                 table.vals[k] = 1             # <<<<<<<<<<<<<<
 *                 result_keys.append(val)
 * 
 */
        (__pyx_v_table->vals[__pyx_v_k]) = 1;

        /* "pandas/_libs/hashtable_func_helper.pxi":442
 *                 k = kh_put_float64(table, val, &ret)
 *                 table.vals[k] = 1
 *                 result_keys.append(val)             # <<<<<<<<<<<<<<
 * 
 *     # collect counts in the order corresponding to result_keys:
 */
        ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float64Vector *)__pyx_v_result_keys->__pyx_vtab)->append(__pyx_v_result_keys, __pyx_v_val); if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 442, __pyx_L1_error)
      }
      __pyx_L13:;

      /* "pandas/_libs/hashtable_func_helper.pxi":435
 *                 isna_entry = is_nan_float64_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_float64(table, val)
 *             if k != table.n_buckets:
 */
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":446
 *     # collect counts in the order corresponding to result_keys:
 *     cdef:
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(table.size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_empty); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_v_table->size); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_4)) __PYX_ERR(5, 446, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_np); if (unlikely(!__pyx_t_11)) __PYX_ERR(5, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_int64); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_dtype, __pyx_t_12) < 0) __PYX_ERR(5, 446, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_10, __pyx_t_4); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 446, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_12, PyBUF_WRITABLE); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(5, 446, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_v_result_counts = __pyx_t_13;
  __pyx_t_13.memview = NULL;
  __pyx_t_13.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":448
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)
 * 
 *     for i in range(table.size):             # <<<<<<<<<<<<<<
 *         k = kh_get_float64(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]
 */
  __pyx_t_14 = __pyx_v_table->size;
  __pyx_t_15 = __pyx_t_14;
  for (__pyx_t_1 = 0; __pyx_t_1 < __pyx_t_15; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "pandas/_libs/hashtable_func_helper.pxi":449
 * 
 *     for i in range(table.size):
 *         k = kh_get_float64(table, result_keys.data.data[i])             # <<<<<<<<<<<<<<
 *         result_counts[i] = table.vals[k]
 * 
 */
    __pyx_v_k = kh_get_float64(__pyx_v_table, (__pyx_v_result_keys->data->data[__pyx_v_i]));

    /* "pandas/_libs/hashtable_func_helper.pxi":450
 *     for i in range(table.size):
 *         k = kh_get_float64(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_float64(table)
 */
    __pyx_t_7 = __pyx_v_i;
    *((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_result_counts.data) + __pyx_t_7)) )) = (__pyx_v_table->vals[__pyx_v_k]);
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":452
 *         result_counts[i] = table.vals[k]
 * 
 *     kh_destroy_float64(table)             # <<<<<<<<<<<<<<
 * 
 *     return result_keys.to_array(), result_counts.base
 */
  kh_destroy_float64(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":454
 *     kh_destroy_float64(table)
 * 
 *     return result_keys.to_array(), result_counts.base             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_12 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float64Vector *)__pyx_v_result_keys->__pyx_vtab)->to_array(__pyx_v_result_keys, 0)); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_result_counts, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int64_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int64_t, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_base); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 454, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_12);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_12)) __PYX_ERR(5, 454, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_10);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_10)) __PYX_ERR(5, 454, __pyx_L1_error);
  __pyx_t_12 = 0;
  __pyx_t_10 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":398
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_float64(const float64_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_13, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count_float64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result_keys);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_result_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":459
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_float64(const float64_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_float64(__Pyx_memviewslice __pyx_v_values, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_float64 *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__47;
  int __pyx_v_ret;
  __pyx_t_5numpy_float64_t __pyx_v_value;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  Py_ssize_t __pyx_v_first_na;
  khiter_t __pyx_v_k;
  kh_float64_t *__pyx_v_table;
  PyArrayObject *__pyx_v_out = 0;
  int __pyx_v_seen_na;
  int __pyx_v_uses_mask;
  int __pyx_v_seen_multiple_na;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_out;
  __Pyx_Buffer __pyx_pybuffer_out;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  khuint_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  size_t __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("duplicated_float64", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_out.pybuffer.buf = NULL;
  __pyx_pybuffer_out.refcount = 0;
  __pyx_pybuffernd_out.data = NULL;
  __pyx_pybuffernd_out.rcbuffer = &__pyx_pybuffer_out;

  /* "pandas/_libs/hashtable_func_helper.pxi":461
 * cdef duplicated_float64(const float64_t[:] values, object keep='first', const uint8_t[:] mask=None):
 *     cdef:
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         float64_t value
 *         Py_ssize_t i, n = len(values), first_na = -1
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":463
 *         int ret = 0
 *         float64_t value
 *         Py_ssize_t i, n = len(values), first_na = -1             # <<<<<<<<<<<<<<
 *         khiter_t k
 *         kh_float64_t *table = kh_init_float64()
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;
  __pyx_v_first_na = -1L;

  /* "pandas/_libs/hashtable_func_helper.pxi":465
 *         Py_ssize_t i, n = len(values), first_na = -1
 *         khiter_t k
 *         kh_float64_t *table = kh_init_float64()             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 */
  __pyx_v_table = kh_init_float64();

  /* "pandas/_libs/hashtable_func_helper.pxi":466
 *         khiter_t k
 *         kh_float64_t *table = kh_init_float64()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')             # <<<<<<<<<<<<<<
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(5, 466, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_n_u_bool) < 0) __PYX_ERR(5, 466, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 466, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_out.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 1, __pyx_stack) == -1)) {
      __pyx_v_out = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_out.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(5, 466, __pyx_L1_error)
    } else {__pyx_pybuffernd_out.diminfo[0].strides = __pyx_pybuffernd_out.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_out.diminfo[0].shape = __pyx_pybuffernd_out.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_out = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":467
 *         kh_float64_t *table = kh_init_float64()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint seen_multiple_na = False
 * 
 */
  __pyx_v_seen_na = 0;
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":468
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_float64(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 */
  __pyx_v_seen_multiple_na = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":470
 *         bint seen_multiple_na = False
 * 
 *     kh_resize_float64(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))             # <<<<<<<<<<<<<<
 * 
 *     if keep not in ('last', 'first', False):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = kh_needed_n_buckets(__pyx_v_n);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 470, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_5, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 470, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(5, 470, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_8) {
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_2 = __pyx_t_5;
  } else {
    __pyx_t_3 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 470, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_uint32(__pyx_t_2); if (unlikely((__pyx_t_7 == ((khuint_t)-1)) && PyErr_Occurred())) __PYX_ERR(5, 470, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  kh_resize_float64(__pyx_v_table, __pyx_t_7);

  /* "pandas/_libs/hashtable_func_helper.pxi":472
 *     kh_resize_float64(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  __Pyx_INCREF(__pyx_v_keep);
  __pyx_t_2 = __pyx_v_keep;
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_last, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 472, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_first, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 472, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, Py_False, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 472, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 472, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_8 = __pyx_t_9;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_9 = __pyx_t_8;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":473
 * 
 *     if keep not in ('last', 'first', False):
 *         raise ValueError('keep must be either "first", "last" or False')             # <<<<<<<<<<<<<<
 * 
 *     if keep == "last":
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__43, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 473, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(5, 473, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":472
 *     kh_resize_float64(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":475
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_last, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 475, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":476
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":477
 *     if keep == "last":
 *         with nogil:
 *             for i in range(n - 1, -1, -1):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          for (__pyx_t_1 = (__pyx_v_n - 1); __pyx_t_1 > -1L; __pyx_t_1-=1) {
            __pyx_v_i = __pyx_t_1;

            /* "pandas/_libs/hashtable_func_helper.pxi":478
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L14_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L14_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":479
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":480
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":479
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L16;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":482
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":483
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = (values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L16:;

              /* "pandas/_libs/hashtable_func_helper.pxi":478
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L13;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":485
 *                         seen_na = True
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_float64(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_float64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":486
 *                 else:
 *                     value = (values[i])
 *                     kh_put_float64(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 *     elif keep == "first":
 */
              (void)(kh_put_float64(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":487
 *                     value = (values[i])
 *                     kh_put_float64(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 *     elif keep == "first":
 *         with nogil:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L13:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":476
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L10;
          }
          __pyx_L10:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":475
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":488
 *                     kh_put_float64(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_first, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 488, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":489
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":490
 *     elif keep == "first":
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_11 = __pyx_t_1;
          for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
            __pyx_v_i = __pyx_t_12;

            /* "pandas/_libs/hashtable_func_helper.pxi":491
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L23_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L23_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":492
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":493
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":492
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L25;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":495
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":496
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = (values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L25:;

              /* "pandas/_libs/hashtable_func_helper.pxi":491
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L22;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":498
 *                         seen_na = True
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_float64(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_float64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":499
 *                 else:
 *                     value = (values[i])
 *                     kh_put_float64(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 * 
 */
              (void)(kh_put_float64(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":500
 *                     value = (values[i])
 *                     kh_put_float64(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 * 
 *     else:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L22:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":489
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L19;
          }
          __pyx_L19:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":488
 *                     kh_put_float64(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":503
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
  /*else*/ {
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":504
 *     else:
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_11 = __pyx_t_1;
          for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
            __pyx_v_i = __pyx_t_12;

            /* "pandas/_libs/hashtable_func_helper.pxi":505
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L32_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L32_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":506
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
              __pyx_t_9 = (!__pyx_v_seen_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":507
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 *                         first_na = i             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                         out[i] = 0
 */
                __pyx_v_first_na = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":508
 *                     if not seen_na:
 *                         first_na = i
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 */
                __pyx_v_seen_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":509
 *                         first_na = i
 *                         seen_na = True
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":506
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":510
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
              __pyx_t_9 = (!__pyx_v_seen_multiple_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":511
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                         out[first_na] = 1
 *                         seen_multiple_na = True
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":512
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 *                         out[first_na] = 1             # <<<<<<<<<<<<<<
 *                         seen_multiple_na = True
 *                     else:
 */
                __pyx_t_10 = __pyx_v_first_na;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":513
 *                         out[i] = 1
 *                         out[first_na] = 1
 *                         seen_multiple_na = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = 1
 */
                __pyx_v_seen_multiple_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":510
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":515
 *                         seen_multiple_na = True
 *                     else:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 * 
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;
              }
              __pyx_L34:;

              /* "pandas/_libs/hashtable_func_helper.pxi":505
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
              goto __pyx_L31;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":518
 * 
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_float64(table, value)
 *                     if k != table.n_buckets:
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_float64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":519
 *                 else:
 *                     value = (values[i])
 *                     k = kh_get_float64(table, value)             # <<<<<<<<<<<<<<
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 */
              __pyx_v_k = kh_get_float64(__pyx_v_table, __pyx_v_value);

              /* "pandas/_libs/hashtable_func_helper.pxi":520
 *                     value = (values[i])
 *                     k = kh_get_float64(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
              __pyx_t_9 = (__pyx_v_k != __pyx_v_table->n_buckets);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":521
 *                     k = kh_get_float64(table, value)
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                     else:
 */
                __pyx_t_13 = (__pyx_v_table->vals[__pyx_v_k]);
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_13, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":522
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                     else:
 *                         k = kh_put_float64(table, value, &ret)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":520
 *                     value = (values[i])
 *                     k = kh_get_float64(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
                goto __pyx_L35;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":524
 *                         out[i] = 1
 *                     else:
 *                         k = kh_put_float64(table, value, &ret)             # <<<<<<<<<<<<<<
 *                         table.vals[k] = i
 *                         out[i] = 0
 */
              /*else*/ {
                __pyx_v_k = kh_put_float64(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret));

                /* "pandas/_libs/hashtable_func_helper.pxi":525
 *                     else:
 *                         k = kh_put_float64(table, value, &ret)
 *                         table.vals[k] = i             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 * 
 */
                (__pyx_v_table->vals[__pyx_v_k]) = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":526
 *                         k = kh_put_float64(table, value, &ret)
 *                         table.vals[k] = i
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_float64(table)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;
              }
              __pyx_L35:;
            }
            __pyx_L31:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":503
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L28;
          }
          __pyx_L28:;
        }
    }
  }
  __pyx_L7:;

  /* "pandas/_libs/hashtable_func_helper.pxi":528
 *                         out[i] = 0
 * 
 *     kh_destroy_float64(table)             # <<<<<<<<<<<<<<
 *     return out
 * 
 */
  kh_destroy_float64(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":529
 * 
 *     kh_destroy_float64(table)
 *     return out             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_out);
  __pyx_r = ((PyObject *)__pyx_v_out);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":459
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_float64(const float64_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated_float64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_out);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":539
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_float64(const float64_t[:] arr, const float64_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_float64(__Pyx_memviewslice __pyx_v_arr, __Pyx_memviewslice __pyx_v_values) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  PyArrayObject *__pyx_v_result = 0;
  __pyx_t_5numpy_float64_t __pyx_v_val;
  kh_float64_t *__pyx_v_table;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyArrayObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ismember_float64", 1);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "pandas/_libs/hashtable_func_helper.pxi":556
 *         Py_ssize_t i, n
 *         khiter_t k
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t] result
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":561
 *         float64_t val
 * 
 *         kh_float64_t *table = kh_init_float64()             # <<<<<<<<<<<<<<
 * 
 *     # construct the table
 */
  __pyx_v_table = kh_init_float64();

  /* "pandas/_libs/hashtable_func_helper.pxi":564
 * 
 *     # construct the table
 *     n = len(values)             # <<<<<<<<<<<<<<
 *     kh_resize_float64(table, n)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":565
 *     # construct the table
 *     n = len(values)
 *     kh_resize_float64(table, n)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  kh_resize_float64(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":567
 *     kh_resize_float64(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":568
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = (values[i])
 *             kh_put_float64(table, val, &ret)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":569
 *     with nogil:
 *         for i in range(n):
 *             val = (values[i])             # <<<<<<<<<<<<<<
 *             kh_put_float64(table, val, &ret)
 * 
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_float64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_4 * __pyx_v_values.strides[0]) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":570
 *         for i in range(n):
 *             val = (values[i])
 *             kh_put_float64(table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *     # test membership
 */
          (void)(kh_put_float64(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret)));
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":567
 *     kh_resize_float64(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":573
 * 
 *     # test membership
 *     n = len(arr)             # <<<<<<<<<<<<<<
 *     result = np.empty(n, dtype=np.uint8)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_arr); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":574
 *     # test membership
 *     n = len(arr)
 *     result = np.empty(n, dtype=np.uint8)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_empty); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5)) __PYX_ERR(5, 574, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(5, 574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_uint8); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dtype, __pyx_t_9) < 0) __PYX_ERR(5, 574, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, __pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 574, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (!(likely(((__pyx_t_9) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_9, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 574, __pyx_L1_error)
  __pyx_t_10 = ((PyArrayObject *)__pyx_t_9);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_11 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_10, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_11 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_13); Py_XDECREF(__pyx_t_14);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __pyx_t_12 = __pyx_t_13 = __pyx_t_14 = 0;
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(5, 574, __pyx_L1_error)
  }
  __pyx_t_10 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_9);
  __pyx_t_9 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":576
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (arr[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":577
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = (arr[i])
 *             k = kh_get_float64(table, val)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":578
 *     with nogil:
 *         for i in range(n):
 *             val = (arr[i])             # <<<<<<<<<<<<<<
 *             k = kh_get_float64(table, val)
 *             result[i] = (k != table.n_buckets)
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_float64_t const  *) ( /* dim=0 */ (__pyx_v_arr.data + __pyx_t_4 * __pyx_v_arr.strides[0]) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":579
 *         for i in range(n):
 *             val = (arr[i])
 *             k = kh_get_float64(table, val)             # <<<<<<<<<<<<<<
 *             result[i] = (k != table.n_buckets)
 * 
 */
          __pyx_v_k = kh_get_float64(__pyx_v_table, __pyx_v_val);

          /* "pandas/_libs/hashtable_func_helper.pxi":580
 *             val = (arr[i])
 *             k = kh_get_float64(table, val)
 *             result[i] = (k != table.n_buckets)             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_float64(table)
 */
          __pyx_t_4 = __pyx_v_i;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_result.rcbuffer->pybuffer.buf, __pyx_t_4, __pyx_pybuffernd_result.diminfo[0].strides) = (__pyx_v_k != __pyx_v_table->n_buckets);
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":576
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (arr[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L10;
        }
        __pyx_L10:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":582
 *             result[i] = (k != table.n_buckets)
 * 
 *     kh_destroy_float64(table)             # <<<<<<<<<<<<<<
 *     return result.view(np.bool_)
 * 
 */
  kh_destroy_float64(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":583
 * 
 *     kh_destroy_float64(table)
 *     return result.view(np.bool_)             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_result), __pyx_n_s_view); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_bool_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_11 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_11 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_6};
    __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_11, 1+__pyx_t_11);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 583, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_r = __pyx_t_9;
  __pyx_t_9 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":539
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_float64(const float64_t[:] arr, const float64_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember_float64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":592
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_float32(const float32_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_float32(__Pyx_memviewslice __pyx_v_values, int __pyx_v_dropna, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_float32 *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__48;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  kh_float32_t *__pyx_v_table;
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_float32_t __pyx_v_val;
  int __pyx_v_ret;
  int __pyx_v_uses_mask;
  int __pyx_v_isna_entry;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *__pyx_v_result_keys = NULL;
  __Pyx_memviewslice __pyx_v_result_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  khiter_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  khuint_t __pyx_t_14;
  khuint_t __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("value_count_float32", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":594
 * cdef value_count_float32(const float32_t[:] values, bint dropna, const uint8_t[:] mask=None):
 *     cdef:
 *         Py_ssize_t i = 0             # <<<<<<<<<<<<<<
 *         Py_ssize_t n = len(values)
 *         kh_float32_t *table
 */
  __pyx_v_i = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":595
 *     cdef:
 *         Py_ssize_t i = 0
 *         Py_ssize_t n = len(values)             # <<<<<<<<<<<<<<
 *         kh_float32_t *table
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":603
 *         float32_t val
 * 
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":604
 * 
 *         int ret = 0
 *         bint uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint isna_entry = False
 * 
 */
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":605
 *         int ret = 0
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False             # <<<<<<<<<<<<<<
 * 
 *     if uses_mask and not dropna:
 */
  __pyx_v_isna_entry = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":607
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  if (__pyx_v_uses_mask) {
  } else {
    __pyx_t_2 = __pyx_v_uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (!__pyx_v_dropna);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_2)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":608
 * 
 *     if uses_mask and not dropna:
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")             # <<<<<<<<<<<<<<
 * 
 *     # we track the order in which keys are first seen (GH39009),
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_NotImplementedError, __pyx_tuple__41, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 608, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(5, 608, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":607
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":615
 *     #    result_keys remembers the original order of keys
 * 
 *     result_keys = Float32Vector()             # <<<<<<<<<<<<<<
 *     table = kh_init_float32()
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector)); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 615, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_result_keys = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":616
 * 
 *     result_keys = Float32Vector()
 *     table = kh_init_float32()             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_float32(table, n)
 */
  __pyx_v_table = kh_init_float32();

  /* "pandas/_libs/hashtable_func_helper.pxi":618
 *     table = kh_init_float32()
 * 
 *     kh_resize_float32(table, n)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(n):
 */
  kh_resize_float32(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":620
 *     kh_resize_float32(table, n)
 * 
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         val = (values[i])
 * 
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_5 = __pyx_t_1;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "pandas/_libs/hashtable_func_helper.pxi":621
 * 
 *     for i in range(n):
 *         val = (values[i])             # <<<<<<<<<<<<<<
 * 
 *         if dropna:
 */
    __pyx_t_7 = __pyx_v_i;
    __pyx_v_val = (*((__pyx_t_5numpy_float32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

    /* "pandas/_libs/hashtable_func_helper.pxi":623
 *         val = (values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    if (__pyx_v_dropna) {

      /* "pandas/_libs/hashtable_func_helper.pxi":624
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
      if (__pyx_v_uses_mask) {

        /* "pandas/_libs/hashtable_func_helper.pxi":625
 *         if dropna:
 *             if uses_mask:
 *                 isna_entry = mask[i]             # <<<<<<<<<<<<<<
 *             else:
 *                 isna_entry = is_nan_float32_t(val)
 */
        __pyx_t_7 = __pyx_v_i;
        __pyx_v_isna_entry = (*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) )));

        /* "pandas/_libs/hashtable_func_helper.pxi":624
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
        goto __pyx_L9;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":627
 *                 isna_entry = mask[i]
 *             else:
 *                 isna_entry = is_nan_float32_t(val)             # <<<<<<<<<<<<<<
 * 
 *         if not dropna or not isna_entry:
 */
      /*else*/ {
        __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_float32_t(__pyx_v_val); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 627, __pyx_L1_error)
        __pyx_v_isna_entry = __pyx_t_2;
      }
      __pyx_L9:;

      /* "pandas/_libs/hashtable_func_helper.pxi":623
 *         val = (values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":629
 *                 isna_entry = is_nan_float32_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_float32(table, val)
 *             if k != table.n_buckets:
 */
    __pyx_t_3 = (!__pyx_v_dropna);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L11_bool_binop_done;
    }
    __pyx_t_3 = (!__pyx_v_isna_entry);
    __pyx_t_2 = __pyx_t_3;
    __pyx_L11_bool_binop_done:;
    if (__pyx_t_2) {

      /* "pandas/_libs/hashtable_func_helper.pxi":630
 * 
 *         if not dropna or not isna_entry:
 *             k = kh_get_float32(table, val)             # <<<<<<<<<<<<<<
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1
 */
      __pyx_v_k = kh_get_float32(__pyx_v_table, __pyx_v_val);

      /* "pandas/_libs/hashtable_func_helper.pxi":631
 *         if not dropna or not isna_entry:
 *             k = kh_get_float32(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
      __pyx_t_2 = (__pyx_v_k != __pyx_v_table->n_buckets);
      if (__pyx_t_2) {

        /* "pandas/_libs/hashtable_func_helper.pxi":632
 *             k = kh_get_float32(table, val)
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 k = kh_put_float32(table, val, &ret)
 */
        __pyx_t_8 = __pyx_v_k;
        (__pyx_v_table->vals[__pyx_t_8]) = ((__pyx_v_table->vals[__pyx_t_8]) + 1);

        /* "pandas/_libs/hashtable_func_helper.pxi":631
 *         if not dropna or not isna_entry:
 *             k = kh_get_float32(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
        goto __pyx_L13;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":634
 *                 table.vals[k] += 1
 *             else:
 *                 k = kh_put_float32(table, val, &ret)             # <<<<<<<<<<<<<<
 *                 table.vals[k] = 1
 *                 result_keys.append(val)
 */
      /*else*/ {
        __pyx_v_k = kh_put_float32(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret));

        /* "pandas/_libs/hashtable_func_helper.pxi":635
 *             else:
 *                 k = kh_put_float32(table, val, &ret)
 *                 table.vals[k] = 1             # <<<<<<<<<<<<<<
 *                 result_keys.append(val)
 * 
 */
        (__pyx_v_table->vals[__pyx_v_k]) = 1;

        /* "pandas/_libs/hashtable_func_helper.pxi":636
 *                 k = kh_put_float32(table, val, &ret)
 *                 table.vals[k] = 1
 *                 result_keys.append(val)             # <<<<<<<<<<<<<<
 * 
 *     # collect counts in the order corresponding to result_keys:
 */
        ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float32Vector *)__pyx_v_result_keys->__pyx_vtab)->append(__pyx_v_result_keys, __pyx_v_val); if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 636, __pyx_L1_error)
      }
      __pyx_L13:;

      /* "pandas/_libs/hashtable_func_helper.pxi":629
 *                 isna_entry = is_nan_float32_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_float32(table, val)
 *             if k != table.n_buckets:
 */
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":640
 *     # collect counts in the order corresponding to result_keys:
 *     cdef:
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(table.size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_empty); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_v_table->size); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_4)) __PYX_ERR(5, 640, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_np); if (unlikely(!__pyx_t_11)) __PYX_ERR(5, 640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_int64); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_dtype, __pyx_t_12) < 0) __PYX_ERR(5, 640, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_10, __pyx_t_4); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_12, PyBUF_WRITABLE); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(5, 640, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_v_result_counts = __pyx_t_13;
  __pyx_t_13.memview = NULL;
  __pyx_t_13.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":642
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)
 * 
 *     for i in range(table.size):             # <<<<<<<<<<<<<<
 *         k = kh_get_float32(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]
 */
  __pyx_t_14 = __pyx_v_table->size;
  __pyx_t_15 = __pyx_t_14;
  for (__pyx_t_1 = 0; __pyx_t_1 < __pyx_t_15; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "pandas/_libs/hashtable_func_helper.pxi":643
 * 
 *     for i in range(table.size):
 *         k = kh_get_float32(table, result_keys.data.data[i])             # <<<<<<<<<<<<<<
 *         result_counts[i] = table.vals[k]
 * 
 */
    __pyx_v_k = kh_get_float32(__pyx_v_table, (__pyx_v_result_keys->data->data[__pyx_v_i]));

    /* "pandas/_libs/hashtable_func_helper.pxi":644
 *     for i in range(table.size):
 *         k = kh_get_float32(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_float32(table)
 */
    __pyx_t_7 = __pyx_v_i;
    *((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_result_counts.data) + __pyx_t_7)) )) = (__pyx_v_table->vals[__pyx_v_k]);
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":646
 *         result_counts[i] = table.vals[k]
 * 
 *     kh_destroy_float32(table)             # <<<<<<<<<<<<<<
 * 
 *     return result_keys.to_array(), result_counts.base
 */
  kh_destroy_float32(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":648
 *     kh_destroy_float32(table)
 * 
 *     return result_keys.to_array(), result_counts.base             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_12 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float32Vector *)__pyx_v_result_keys->__pyx_vtab)->to_array(__pyx_v_result_keys, 0)); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_result_counts, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int64_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int64_t, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_base); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 648, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_12);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_12)) __PYX_ERR(5, 648, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_10);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_10)) __PYX_ERR(5, 648, __pyx_L1_error);
  __pyx_t_12 = 0;
  __pyx_t_10 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":592
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_float32(const float32_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_13, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count_float32", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result_keys);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_result_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":653
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_float32(const float32_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_float32(__Pyx_memviewslice __pyx_v_values, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_float32 *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__49;
  int __pyx_v_ret;
  __pyx_t_5numpy_float32_t __pyx_v_value;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  Py_ssize_t __pyx_v_first_na;
  khiter_t __pyx_v_k;
  kh_float32_t *__pyx_v_table;
  PyArrayObject *__pyx_v_out = 0;
  int __pyx_v_seen_na;
  int __pyx_v_uses_mask;
  int __pyx_v_seen_multiple_na;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_out;
  __Pyx_Buffer __pyx_pybuffer_out;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  khuint_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  size_t __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("duplicated_float32", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_out.pybuffer.buf = NULL;
  __pyx_pybuffer_out.refcount = 0;
  __pyx_pybuffernd_out.data = NULL;
  __pyx_pybuffernd_out.rcbuffer = &__pyx_pybuffer_out;

  /* "pandas/_libs/hashtable_func_helper.pxi":655
 * cdef duplicated_float32(const float32_t[:] values, object keep='first', const uint8_t[:] mask=None):
 *     cdef:
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         float32_t value
 *         Py_ssize_t i, n = len(values), first_na = -1
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":657
 *         int ret = 0
 *         float32_t value
 *         Py_ssize_t i, n = len(values), first_na = -1             # <<<<<<<<<<<<<<
 *         khiter_t k
 *         kh_float32_t *table = kh_init_float32()
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;
  __pyx_v_first_na = -1L;

  /* "pandas/_libs/hashtable_func_helper.pxi":659
 *         Py_ssize_t i, n = len(values), first_na = -1
 *         khiter_t k
 *         kh_float32_t *table = kh_init_float32()             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 */
  __pyx_v_table = kh_init_float32();

  /* "pandas/_libs/hashtable_func_helper.pxi":660
 *         khiter_t k
 *         kh_float32_t *table = kh_init_float32()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')             # <<<<<<<<<<<<<<
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(5, 660, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_n_u_bool) < 0) __PYX_ERR(5, 660, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 660, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 660, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_out.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 1, __pyx_stack) == -1)) {
      __pyx_v_out = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_out.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(5, 660, __pyx_L1_error)
    } else {__pyx_pybuffernd_out.diminfo[0].strides = __pyx_pybuffernd_out.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_out.diminfo[0].shape = __pyx_pybuffernd_out.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_out = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":661
 *         kh_float32_t *table = kh_init_float32()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint seen_multiple_na = False
 * 
 */
  __pyx_v_seen_na = 0;
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":662
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_float32(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 */
  __pyx_v_seen_multiple_na = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":664
 *         bint seen_multiple_na = False
 * 
 *     kh_resize_float32(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))             # <<<<<<<<<<<<<<
 * 
 *     if keep not in ('last', 'first', False):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = kh_needed_n_buckets(__pyx_v_n);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 664, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_5, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 664, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(5, 664, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_8) {
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_2 = __pyx_t_5;
  } else {
    __pyx_t_3 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 664, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_uint32(__pyx_t_2); if (unlikely((__pyx_t_7 == ((khuint_t)-1)) && PyErr_Occurred())) __PYX_ERR(5, 664, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  kh_resize_float32(__pyx_v_table, __pyx_t_7);

  /* "pandas/_libs/hashtable_func_helper.pxi":666
 *     kh_resize_float32(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  __Pyx_INCREF(__pyx_v_keep);
  __pyx_t_2 = __pyx_v_keep;
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_last, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 666, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_first, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 666, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, Py_False, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 666, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 666, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_8 = __pyx_t_9;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_9 = __pyx_t_8;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":667
 * 
 *     if keep not in ('last', 'first', False):
 *         raise ValueError('keep must be either "first", "last" or False')             # <<<<<<<<<<<<<<
 * 
 *     if keep == "last":
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__43, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 667, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(5, 667, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":666
 *     kh_resize_float32(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":669
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_last, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 669, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":670
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":671
 *     if keep == "last":
 *         with nogil:
 *             for i in range(n - 1, -1, -1):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          for (__pyx_t_1 = (__pyx_v_n - 1); __pyx_t_1 > -1L; __pyx_t_1-=1) {
            __pyx_v_i = __pyx_t_1;

            /* "pandas/_libs/hashtable_func_helper.pxi":672
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L14_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L14_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":673
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":674
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":673
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L16;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":676
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":677
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = (values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L16:;

              /* "pandas/_libs/hashtable_func_helper.pxi":672
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L13;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":679
 *                         seen_na = True
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_float32(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_float32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":680
 *                 else:
 *                     value = (values[i])
 *                     kh_put_float32(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 *     elif keep == "first":
 */
              (void)(kh_put_float32(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":681
 *                     value = (values[i])
 *                     kh_put_float32(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 *     elif keep == "first":
 *         with nogil:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L13:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":670
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L10;
          }
          __pyx_L10:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":669
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":682
 *                     kh_put_float32(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_first, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 682, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":683
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":684
 *     elif keep == "first":
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_11 = __pyx_t_1;
          for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
            __pyx_v_i = __pyx_t_12;

            /* "pandas/_libs/hashtable_func_helper.pxi":685
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L23_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L23_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":686
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":687
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":686
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L25;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":689
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":690
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = (values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L25:;

              /* "pandas/_libs/hashtable_func_helper.pxi":685
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L22;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":692
 *                         seen_na = True
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_float32(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_float32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":693
 *                 else:
 *                     value = (values[i])
 *                     kh_put_float32(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 * 
 */
              (void)(kh_put_float32(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":694
 *                     value = (values[i])
 *                     kh_put_float32(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 * 
 *     else:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L22:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":683
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L19;
          }
          __pyx_L19:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":682
 *                     kh_put_float32(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":697
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
  /*else*/ {
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":698
 *     else:
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_11 = __pyx_t_1;
          for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
            __pyx_v_i = __pyx_t_12;

            /* "pandas/_libs/hashtable_func_helper.pxi":699
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L32_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L32_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":700
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
              __pyx_t_9 = (!__pyx_v_seen_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":701
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 *                         first_na = i             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                         out[i] = 0
 */
                __pyx_v_first_na = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":702
 *                     if not seen_na:
 *                         first_na = i
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 */
                __pyx_v_seen_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":703
 *                         first_na = i
 *                         seen_na = True
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":700
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":704
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
              __pyx_t_9 = (!__pyx_v_seen_multiple_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":705
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                         out[first_na] = 1
 *                         seen_multiple_na = True
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":706
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 *                         out[first_na] = 1             # <<<<<<<<<<<<<<
 *                         seen_multiple_na = True
 *                     else:
 */
                __pyx_t_10 = __pyx_v_first_na;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":707
 *                         out[i] = 1
 *                         out[first_na] = 1
 *                         seen_multiple_na = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = 1
 */
                __pyx_v_seen_multiple_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":704
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":709
 *                         seen_multiple_na = True
 *                     else:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 * 
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;
              }
              __pyx_L34:;

              /* "pandas/_libs/hashtable_func_helper.pxi":699
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
              goto __pyx_L31;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":712
 * 
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_float32(table, value)
 *                     if k != table.n_buckets:
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_float32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":713
 *                 else:
 *                     value = (values[i])
 *                     k = kh_get_float32(table, value)             # <<<<<<<<<<<<<<
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 */
              __pyx_v_k = kh_get_float32(__pyx_v_table, __pyx_v_value);

              /* "pandas/_libs/hashtable_func_helper.pxi":714
 *                     value = (values[i])
 *                     k = kh_get_float32(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
              __pyx_t_9 = (__pyx_v_k != __pyx_v_table->n_buckets);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":715
 *                     k = kh_get_float32(table, value)
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                     else:
 */
                __pyx_t_13 = (__pyx_v_table->vals[__pyx_v_k]);
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_13, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":716
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                     else:
 *                         k = kh_put_float32(table, value, &ret)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":714
 *                     value = (values[i])
 *                     k = kh_get_float32(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
                goto __pyx_L35;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":718
 *                         out[i] = 1
 *                     else:
 *                         k = kh_put_float32(table, value, &ret)             # <<<<<<<<<<<<<<
 *                         table.vals[k] = i
 *                         out[i] = 0
 */
              /*else*/ {
                __pyx_v_k = kh_put_float32(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret));

                /* "pandas/_libs/hashtable_func_helper.pxi":719
 *                     else:
 *                         k = kh_put_float32(table, value, &ret)
 *                         table.vals[k] = i             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 * 
 */
                (__pyx_v_table->vals[__pyx_v_k]) = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":720
 *                         k = kh_put_float32(table, value, &ret)
 *                         table.vals[k] = i
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_float32(table)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;
              }
              __pyx_L35:;
            }
            __pyx_L31:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":697
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L28;
          }
          __pyx_L28:;
        }
    }
  }
  __pyx_L7:;

  /* "pandas/_libs/hashtable_func_helper.pxi":722
 *                         out[i] = 0
 * 
 *     kh_destroy_float32(table)             # <<<<<<<<<<<<<<
 *     return out
 * 
 */
  kh_destroy_float32(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":723
 * 
 *     kh_destroy_float32(table)
 *     return out             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_out);
  __pyx_r = ((PyObject *)__pyx_v_out);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":653
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_float32(const float32_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated_float32", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_out);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":733
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_float32(const float32_t[:] arr, const float32_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_float32(__Pyx_memviewslice __pyx_v_arr, __Pyx_memviewslice __pyx_v_values) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  PyArrayObject *__pyx_v_result = 0;
  __pyx_t_5numpy_float32_t __pyx_v_val;
  kh_float32_t *__pyx_v_table;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyArrayObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ismember_float32", 1);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "pandas/_libs/hashtable_func_helper.pxi":750
 *         Py_ssize_t i, n
 *         khiter_t k
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t] result
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":755
 *         float32_t val
 * 
 *         kh_float32_t *table = kh_init_float32()             # <<<<<<<<<<<<<<
 * 
 *     # construct the table
 */
  __pyx_v_table = kh_init_float32();

  /* "pandas/_libs/hashtable_func_helper.pxi":758
 * 
 *     # construct the table
 *     n = len(values)             # <<<<<<<<<<<<<<
 *     kh_resize_float32(table, n)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":759
 *     # construct the table
 *     n = len(values)
 *     kh_resize_float32(table, n)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  kh_resize_float32(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":761
 *     kh_resize_float32(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":762
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = (values[i])
 *             kh_put_float32(table, val, &ret)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":763
 *     with nogil:
 *         for i in range(n):
 *             val = (values[i])             # <<<<<<<<<<<<<<
 *             kh_put_float32(table, val, &ret)
 * 
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_float32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_4 * __pyx_v_values.strides[0]) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":764
 *         for i in range(n):
 *             val = (values[i])
 *             kh_put_float32(table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *     # test membership
 */
          (void)(kh_put_float32(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret)));
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":761
 *     kh_resize_float32(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":767
 * 
 *     # test membership
 *     n = len(arr)             # <<<<<<<<<<<<<<
 *     result = np.empty(n, dtype=np.uint8)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_arr); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":768
 *     # test membership
 *     n = len(arr)
 *     result = np.empty(n, dtype=np.uint8)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_empty); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5)) __PYX_ERR(5, 768, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(5, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_uint8); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dtype, __pyx_t_9) < 0) __PYX_ERR(5, 768, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, __pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (!(likely(((__pyx_t_9) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_9, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 768, __pyx_L1_error)
  __pyx_t_10 = ((PyArrayObject *)__pyx_t_9);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_11 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_10, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_11 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_13); Py_XDECREF(__pyx_t_14);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __pyx_t_12 = __pyx_t_13 = __pyx_t_14 = 0;
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(5, 768, __pyx_L1_error)
  }
  __pyx_t_10 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_9);
  __pyx_t_9 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":770
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (arr[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":771
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = (arr[i])
 *             k = kh_get_float32(table, val)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":772
 *     with nogil:
 *         for i in range(n):
 *             val = (arr[i])             # <<<<<<<<<<<<<<
 *             k = kh_get_float32(table, val)
 *             result[i] = (k != table.n_buckets)
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_float32_t const  *) ( /* dim=0 */ (__pyx_v_arr.data + __pyx_t_4 * __pyx_v_arr.strides[0]) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":773
 *         for i in range(n):
 *             val = (arr[i])
 *             k = kh_get_float32(table, val)             # <<<<<<<<<<<<<<
 *             result[i] = (k != table.n_buckets)
 * 
 */
          __pyx_v_k = kh_get_float32(__pyx_v_table, __pyx_v_val);

          /* "pandas/_libs/hashtable_func_helper.pxi":774
 *             val = (arr[i])
 *             k = kh_get_float32(table, val)
 *             result[i] = (k != table.n_buckets)             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_float32(table)
 */
          __pyx_t_4 = __pyx_v_i;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_result.rcbuffer->pybuffer.buf, __pyx_t_4, __pyx_pybuffernd_result.diminfo[0].strides) = (__pyx_v_k != __pyx_v_table->n_buckets);
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":770
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (arr[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L10;
        }
        __pyx_L10:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":776
 *             result[i] = (k != table.n_buckets)
 * 
 *     kh_destroy_float32(table)             # <<<<<<<<<<<<<<
 *     return result.view(np.bool_)
 * 
 */
  kh_destroy_float32(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":777
 * 
 *     kh_destroy_float32(table)
 *     return result.view(np.bool_)             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_result), __pyx_n_s_view); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_bool_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 777, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_11 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_11 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_6};
    __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_11, 1+__pyx_t_11);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 777, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_r = __pyx_t_9;
  __pyx_t_9 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":733
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_float32(const float32_t[:] arr, const float32_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember_float32", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":786
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_uint64(const uint64_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_uint64(__Pyx_memviewslice __pyx_v_values, int __pyx_v_dropna, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_uint64 *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__50;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  kh_uint64_t *__pyx_v_table;
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_uint64_t __pyx_v_val;
  int __pyx_v_ret;
  int __pyx_v_uses_mask;
  int __pyx_v_isna_entry;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *__pyx_v_result_keys = NULL;
  __Pyx_memviewslice __pyx_v_result_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  khiter_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  khuint_t __pyx_t_14;
  khuint_t __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("value_count_uint64", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":788
 * cdef value_count_uint64(const uint64_t[:] values, bint dropna, const uint8_t[:] mask=None):
 *     cdef:
 *         Py_ssize_t i = 0             # <<<<<<<<<<<<<<
 *         Py_ssize_t n = len(values)
 *         kh_uint64_t *table
 */
  __pyx_v_i = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":789
 *     cdef:
 *         Py_ssize_t i = 0
 *         Py_ssize_t n = len(values)             # <<<<<<<<<<<<<<
 *         kh_uint64_t *table
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":797
 *         uint64_t val
 * 
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":798
 * 
 *         int ret = 0
 *         bint uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint isna_entry = False
 * 
 */
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":799
 *         int ret = 0
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False             # <<<<<<<<<<<<<<
 * 
 *     if uses_mask and not dropna:
 */
  __pyx_v_isna_entry = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":801
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  if (__pyx_v_uses_mask) {
  } else {
    __pyx_t_2 = __pyx_v_uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (!__pyx_v_dropna);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_2)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":802
 * 
 *     if uses_mask and not dropna:
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")             # <<<<<<<<<<<<<<
 * 
 *     # we track the order in which keys are first seen (GH39009),
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_NotImplementedError, __pyx_tuple__41, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 802, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(5, 802, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":801
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":809
 *     #    result_keys remembers the original order of keys
 * 
 *     result_keys = UInt64Vector()             # <<<<<<<<<<<<<<
 *     table = kh_init_uint64()
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector)); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 809, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_result_keys = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":810
 * 
 *     result_keys = UInt64Vector()
 *     table = kh_init_uint64()             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_uint64(table, n)
 */
  __pyx_v_table = kh_init_uint64();

  /* "pandas/_libs/hashtable_func_helper.pxi":812
 *     table = kh_init_uint64()
 * 
 *     kh_resize_uint64(table, n)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(n):
 */
  kh_resize_uint64(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":814
 *     kh_resize_uint64(table, n)
 * 
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         val = (values[i])
 * 
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_5 = __pyx_t_1;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "pandas/_libs/hashtable_func_helper.pxi":815
 * 
 *     for i in range(n):
 *         val = (values[i])             # <<<<<<<<<<<<<<
 * 
 *         if dropna:
 */
    __pyx_t_7 = __pyx_v_i;
    __pyx_v_val = (*((__pyx_t_5numpy_uint64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

    /* "pandas/_libs/hashtable_func_helper.pxi":817
 *         val = (values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    if (__pyx_v_dropna) {

      /* "pandas/_libs/hashtable_func_helper.pxi":818
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
      if (__pyx_v_uses_mask) {

        /* "pandas/_libs/hashtable_func_helper.pxi":819
 *         if dropna:
 *             if uses_mask:
 *                 isna_entry = mask[i]             # <<<<<<<<<<<<<<
 *             else:
 *                 isna_entry = is_nan_uint64_t(val)
 */
        __pyx_t_7 = __pyx_v_i;
        __pyx_v_isna_entry = (*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) )));

        /* "pandas/_libs/hashtable_func_helper.pxi":818
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
        goto __pyx_L9;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":821
 *                 isna_entry = mask[i]
 *             else:
 *                 isna_entry = is_nan_uint64_t(val)             # <<<<<<<<<<<<<<
 * 
 *         if not dropna or not isna_entry:
 */
      /*else*/ {
        __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_uint64_t(__pyx_v_val); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 821, __pyx_L1_error)
        __pyx_v_isna_entry = __pyx_t_2;
      }
      __pyx_L9:;

      /* "pandas/_libs/hashtable_func_helper.pxi":817
 *         val = (values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":823
 *                 isna_entry = is_nan_uint64_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_uint64(table, val)
 *             if k != table.n_buckets:
 */
    __pyx_t_3 = (!__pyx_v_dropna);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L11_bool_binop_done;
    }
    __pyx_t_3 = (!__pyx_v_isna_entry);
    __pyx_t_2 = __pyx_t_3;
    __pyx_L11_bool_binop_done:;
    if (__pyx_t_2) {

      /* "pandas/_libs/hashtable_func_helper.pxi":824
 * 
 *         if not dropna or not isna_entry:
 *             k = kh_get_uint64(table, val)             # <<<<<<<<<<<<<<
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1
 */
      __pyx_v_k = kh_get_uint64(__pyx_v_table, __pyx_v_val);

      /* "pandas/_libs/hashtable_func_helper.pxi":825
 *         if not dropna or not isna_entry:
 *             k = kh_get_uint64(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
      __pyx_t_2 = (__pyx_v_k != __pyx_v_table->n_buckets);
      if (__pyx_t_2) {

        /* "pandas/_libs/hashtable_func_helper.pxi":826
 *             k = kh_get_uint64(table, val)
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 k = kh_put_uint64(table, val, &ret)
 */
        __pyx_t_8 = __pyx_v_k;
        (__pyx_v_table->vals[__pyx_t_8]) = ((__pyx_v_table->vals[__pyx_t_8]) + 1);

        /* "pandas/_libs/hashtable_func_helper.pxi":825
 *         if not dropna or not isna_entry:
 *             k = kh_get_uint64(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
        goto __pyx_L13;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":828
 *                 table.vals[k] += 1
 *             else:
 *                 k = kh_put_uint64(table, val, &ret)             # <<<<<<<<<<<<<<
 *                 table.vals[k] = 1
 *                 result_keys.append(val)
 */
      /*else*/ {
        __pyx_v_k = kh_put_uint64(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret));

        /* "pandas/_libs/hashtable_func_helper.pxi":829
 *             else:
 *                 k = kh_put_uint64(table, val, &ret)
 *                 table.vals[k] = 1             # <<<<<<<<<<<<<<
 *                 result_keys.append(val)
 * 
 */
        (__pyx_v_table->vals[__pyx_v_k]) = 1;

        /* "pandas/_libs/hashtable_func_helper.pxi":830
 *                 k = kh_put_uint64(table, val, &ret)
 *                 table.vals[k] = 1
 *                 result_keys.append(val)             # <<<<<<<<<<<<<<
 * 
 *     # collect counts in the order corresponding to result_keys:
 */
        ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt64Vector *)__pyx_v_result_keys->__pyx_vtab)->append(__pyx_v_result_keys, __pyx_v_val); if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 830, __pyx_L1_error)
      }
      __pyx_L13:;

      /* "pandas/_libs/hashtable_func_helper.pxi":823
 *                 isna_entry = is_nan_uint64_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_uint64(table, val)
 *             if k != table.n_buckets:
 */
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":834
 *     # collect counts in the order corresponding to result_keys:
 *     cdef:
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(table.size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_empty); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_v_table->size); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_4)) __PYX_ERR(5, 834, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_np); if (unlikely(!__pyx_t_11)) __PYX_ERR(5, 834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_int64); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_dtype, __pyx_t_12) < 0) __PYX_ERR(5, 834, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_10, __pyx_t_4); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_12, PyBUF_WRITABLE); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(5, 834, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_v_result_counts = __pyx_t_13;
  __pyx_t_13.memview = NULL;
  __pyx_t_13.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":836
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)
 * 
 *     for i in range(table.size):             # <<<<<<<<<<<<<<
 *         k = kh_get_uint64(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]
 */
  __pyx_t_14 = __pyx_v_table->size;
  __pyx_t_15 = __pyx_t_14;
  for (__pyx_t_1 = 0; __pyx_t_1 < __pyx_t_15; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "pandas/_libs/hashtable_func_helper.pxi":837
 * 
 *     for i in range(table.size):
 *         k = kh_get_uint64(table, result_keys.data.data[i])             # <<<<<<<<<<<<<<
 *         result_counts[i] = table.vals[k]
 * 
 */
    __pyx_v_k = kh_get_uint64(__pyx_v_table, (__pyx_v_result_keys->data->data[__pyx_v_i]));

    /* "pandas/_libs/hashtable_func_helper.pxi":838
 *     for i in range(table.size):
 *         k = kh_get_uint64(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_uint64(table)
 */
    __pyx_t_7 = __pyx_v_i;
    *((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_result_counts.data) + __pyx_t_7)) )) = (__pyx_v_table->vals[__pyx_v_k]);
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":840
 *         result_counts[i] = table.vals[k]
 * 
 *     kh_destroy_uint64(table)             # <<<<<<<<<<<<<<
 * 
 *     return result_keys.to_array(), result_counts.base
 */
  kh_destroy_uint64(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":842
 *     kh_destroy_uint64(table)
 * 
 *     return result_keys.to_array(), result_counts.base             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_12 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt64Vector *)__pyx_v_result_keys->__pyx_vtab)->to_array(__pyx_v_result_keys, 0)); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_result_counts, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int64_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int64_t, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_base); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 842, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_12);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_12)) __PYX_ERR(5, 842, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_10);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_10)) __PYX_ERR(5, 842, __pyx_L1_error);
  __pyx_t_12 = 0;
  __pyx_t_10 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":786
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_uint64(const uint64_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_13, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count_uint64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result_keys);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_result_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":847
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_uint64(const uint64_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_uint64(__Pyx_memviewslice __pyx_v_values, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_uint64 *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__51;
  int __pyx_v_ret;
  __pyx_t_5numpy_uint64_t __pyx_v_value;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  Py_ssize_t __pyx_v_first_na;
  khiter_t __pyx_v_k;
  kh_uint64_t *__pyx_v_table;
  PyArrayObject *__pyx_v_out = 0;
  int __pyx_v_seen_na;
  int __pyx_v_uses_mask;
  int __pyx_v_seen_multiple_na;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_out;
  __Pyx_Buffer __pyx_pybuffer_out;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  khuint_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  size_t __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("duplicated_uint64", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_out.pybuffer.buf = NULL;
  __pyx_pybuffer_out.refcount = 0;
  __pyx_pybuffernd_out.data = NULL;
  __pyx_pybuffernd_out.rcbuffer = &__pyx_pybuffer_out;

  /* "pandas/_libs/hashtable_func_helper.pxi":849
 * cdef duplicated_uint64(const uint64_t[:] values, object keep='first', const uint8_t[:] mask=None):
 *     cdef:
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         uint64_t value
 *         Py_ssize_t i, n = len(values), first_na = -1
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":851
 *         int ret = 0
 *         uint64_t value
 *         Py_ssize_t i, n = len(values), first_na = -1             # <<<<<<<<<<<<<<
 *         khiter_t k
 *         kh_uint64_t *table = kh_init_uint64()
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;
  __pyx_v_first_na = -1L;

  /* "pandas/_libs/hashtable_func_helper.pxi":853
 *         Py_ssize_t i, n = len(values), first_na = -1
 *         khiter_t k
 *         kh_uint64_t *table = kh_init_uint64()             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 */
  __pyx_v_table = kh_init_uint64();

  /* "pandas/_libs/hashtable_func_helper.pxi":854
 *         khiter_t k
 *         kh_uint64_t *table = kh_init_uint64()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')             # <<<<<<<<<<<<<<
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(5, 854, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_n_u_bool) < 0) __PYX_ERR(5, 854, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 854, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 854, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_out.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 1, __pyx_stack) == -1)) {
      __pyx_v_out = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_out.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(5, 854, __pyx_L1_error)
    } else {__pyx_pybuffernd_out.diminfo[0].strides = __pyx_pybuffernd_out.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_out.diminfo[0].shape = __pyx_pybuffernd_out.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_out = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":855
 *         kh_uint64_t *table = kh_init_uint64()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint seen_multiple_na = False
 * 
 */
  __pyx_v_seen_na = 0;
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":856
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_uint64(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 */
  __pyx_v_seen_multiple_na = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":858
 *         bint seen_multiple_na = False
 * 
 *     kh_resize_uint64(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))             # <<<<<<<<<<<<<<
 * 
 *     if keep not in ('last', 'first', False):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = kh_needed_n_buckets(__pyx_v_n);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_5, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 858, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(5, 858, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_8) {
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_2 = __pyx_t_5;
  } else {
    __pyx_t_3 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 858, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_uint32(__pyx_t_2); if (unlikely((__pyx_t_7 == ((khuint_t)-1)) && PyErr_Occurred())) __PYX_ERR(5, 858, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  kh_resize_uint64(__pyx_v_table, __pyx_t_7);

  /* "pandas/_libs/hashtable_func_helper.pxi":860
 *     kh_resize_uint64(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  __Pyx_INCREF(__pyx_v_keep);
  __pyx_t_2 = __pyx_v_keep;
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_last, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 860, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_first, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 860, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, Py_False, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 860, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 860, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_8 = __pyx_t_9;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_9 = __pyx_t_8;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":861
 * 
 *     if keep not in ('last', 'first', False):
 *         raise ValueError('keep must be either "first", "last" or False')             # <<<<<<<<<<<<<<
 * 
 *     if keep == "last":
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__43, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 861, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(5, 861, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":860
 *     kh_resize_uint64(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":863
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_last, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 863, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":864
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":865
 *     if keep == "last":
 *         with nogil:
 *             for i in range(n - 1, -1, -1):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          for (__pyx_t_1 = (__pyx_v_n - 1); __pyx_t_1 > -1L; __pyx_t_1-=1) {
            __pyx_v_i = __pyx_t_1;

            /* "pandas/_libs/hashtable_func_helper.pxi":866
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L14_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L14_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":867
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":868
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":867
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L16;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":870
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":871
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = (values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L16:;

              /* "pandas/_libs/hashtable_func_helper.pxi":866
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L13;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":873
 *                         seen_na = True
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_uint64(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_uint64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":874
 *                 else:
 *                     value = (values[i])
 *                     kh_put_uint64(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 *     elif keep == "first":
 */
              (void)(kh_put_uint64(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":875
 *                     value = (values[i])
 *                     kh_put_uint64(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 *     elif keep == "first":
 *         with nogil:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L13:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":864
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L10;
          }
          __pyx_L10:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":863
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":876
 *                     kh_put_uint64(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_first, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 876, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":877
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":878
 *     elif keep == "first":
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_11 = __pyx_t_1;
          for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
            __pyx_v_i = __pyx_t_12;

            /* "pandas/_libs/hashtable_func_helper.pxi":879
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L23_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L23_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":880
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":881
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":880
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L25;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":883
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":884
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = (values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L25:;

              /* "pandas/_libs/hashtable_func_helper.pxi":879
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L22;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":886
 *                         seen_na = True
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_uint64(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_uint64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":887
 *                 else:
 *                     value = (values[i])
 *                     kh_put_uint64(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 * 
 */
              (void)(kh_put_uint64(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":888
 *                     value = (values[i])
 *                     kh_put_uint64(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 * 
 *     else:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L22:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":877
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L19;
          }
          __pyx_L19:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":876
 *                     kh_put_uint64(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":891
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
  /*else*/ {
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":892
 *     else:
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_11 = __pyx_t_1;
          for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
            __pyx_v_i = __pyx_t_12;

            /* "pandas/_libs/hashtable_func_helper.pxi":893
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L32_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L32_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":894
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
              __pyx_t_9 = (!__pyx_v_seen_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":895
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 *                         first_na = i             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                         out[i] = 0
 */
                __pyx_v_first_na = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":896
 *                     if not seen_na:
 *                         first_na = i
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 */
                __pyx_v_seen_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":897
 *                         first_na = i
 *                         seen_na = True
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":894
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":898
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
              __pyx_t_9 = (!__pyx_v_seen_multiple_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":899
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                         out[first_na] = 1
 *                         seen_multiple_na = True
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":900
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 *                         out[first_na] = 1             # <<<<<<<<<<<<<<
 *                         seen_multiple_na = True
 *                     else:
 */
                __pyx_t_10 = __pyx_v_first_na;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":901
 *                         out[i] = 1
 *                         out[first_na] = 1
 *                         seen_multiple_na = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = 1
 */
                __pyx_v_seen_multiple_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":898
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":903
 *                         seen_multiple_na = True
 *                     else:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 * 
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;
              }
              __pyx_L34:;

              /* "pandas/_libs/hashtable_func_helper.pxi":893
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
              goto __pyx_L31;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":906
 * 
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_uint64(table, value)
 *                     if k != table.n_buckets:
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_uint64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":907
 *                 else:
 *                     value = (values[i])
 *                     k = kh_get_uint64(table, value)             # <<<<<<<<<<<<<<
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 */
              __pyx_v_k = kh_get_uint64(__pyx_v_table, __pyx_v_value);

              /* "pandas/_libs/hashtable_func_helper.pxi":908
 *                     value = (values[i])
 *                     k = kh_get_uint64(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
              __pyx_t_9 = (__pyx_v_k != __pyx_v_table->n_buckets);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":909
 *                     k = kh_get_uint64(table, value)
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                     else:
 */
                __pyx_t_13 = (__pyx_v_table->vals[__pyx_v_k]);
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_13, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":910
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                     else:
 *                         k = kh_put_uint64(table, value, &ret)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":908
 *                     value = (values[i])
 *                     k = kh_get_uint64(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
                goto __pyx_L35;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":912
 *                         out[i] = 1
 *                     else:
 *                         k = kh_put_uint64(table, value, &ret)             # <<<<<<<<<<<<<<
 *                         table.vals[k] = i
 *                         out[i] = 0
 */
              /*else*/ {
                __pyx_v_k = kh_put_uint64(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret));

                /* "pandas/_libs/hashtable_func_helper.pxi":913
 *                     else:
 *                         k = kh_put_uint64(table, value, &ret)
 *                         table.vals[k] = i             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 * 
 */
                (__pyx_v_table->vals[__pyx_v_k]) = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":914
 *                         k = kh_put_uint64(table, value, &ret)
 *                         table.vals[k] = i
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_uint64(table)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;
              }
              __pyx_L35:;
            }
            __pyx_L31:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":891
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L28;
          }
          __pyx_L28:;
        }
    }
  }
  __pyx_L7:;

  /* "pandas/_libs/hashtable_func_helper.pxi":916
 *                         out[i] = 0
 * 
 *     kh_destroy_uint64(table)             # <<<<<<<<<<<<<<
 *     return out
 * 
 */
  kh_destroy_uint64(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":917
 * 
 *     kh_destroy_uint64(table)
 *     return out             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_out);
  __pyx_r = ((PyObject *)__pyx_v_out);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":847
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_uint64(const uint64_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated_uint64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_out);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":927
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_uint64(const uint64_t[:] arr, const uint64_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_uint64(__Pyx_memviewslice __pyx_v_arr, __Pyx_memviewslice __pyx_v_values) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  PyArrayObject *__pyx_v_result = 0;
  __pyx_t_5numpy_uint64_t __pyx_v_val;
  kh_uint64_t *__pyx_v_table;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyArrayObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ismember_uint64", 1);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "pandas/_libs/hashtable_func_helper.pxi":944
 *         Py_ssize_t i, n
 *         khiter_t k
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t] result
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":949
 *         uint64_t val
 * 
 *         kh_uint64_t *table = kh_init_uint64()             # <<<<<<<<<<<<<<
 * 
 *     # construct the table
 */
  __pyx_v_table = kh_init_uint64();

  /* "pandas/_libs/hashtable_func_helper.pxi":952
 * 
 *     # construct the table
 *     n = len(values)             # <<<<<<<<<<<<<<
 *     kh_resize_uint64(table, n)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":953
 *     # construct the table
 *     n = len(values)
 *     kh_resize_uint64(table, n)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  kh_resize_uint64(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":955
 *     kh_resize_uint64(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":956
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = (values[i])
 *             kh_put_uint64(table, val, &ret)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":957
 *     with nogil:
 *         for i in range(n):
 *             val = (values[i])             # <<<<<<<<<<<<<<
 *             kh_put_uint64(table, val, &ret)
 * 
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_uint64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_4 * __pyx_v_values.strides[0]) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":958
 *         for i in range(n):
 *             val = (values[i])
 *             kh_put_uint64(table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *     # test membership
 */
          (void)(kh_put_uint64(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret)));
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":955
 *     kh_resize_uint64(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":961
 * 
 *     # test membership
 *     n = len(arr)             # <<<<<<<<<<<<<<
 *     result = np.empty(n, dtype=np.uint8)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_arr); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":962
 *     # test membership
 *     n = len(arr)
 *     result = np.empty(n, dtype=np.uint8)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_empty); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5)) __PYX_ERR(5, 962, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(5, 962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_uint8); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dtype, __pyx_t_9) < 0) __PYX_ERR(5, 962, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, __pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 962, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (!(likely(((__pyx_t_9) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_9, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 962, __pyx_L1_error)
  __pyx_t_10 = ((PyArrayObject *)__pyx_t_9);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_11 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_10, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_11 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_13); Py_XDECREF(__pyx_t_14);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __pyx_t_12 = __pyx_t_13 = __pyx_t_14 = 0;
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(5, 962, __pyx_L1_error)
  }
  __pyx_t_10 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_9);
  __pyx_t_9 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":964
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (arr[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":965
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = (arr[i])
 *             k = kh_get_uint64(table, val)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":966
 *     with nogil:
 *         for i in range(n):
 *             val = (arr[i])             # <<<<<<<<<<<<<<
 *             k = kh_get_uint64(table, val)
 *             result[i] = (k != table.n_buckets)
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_uint64_t const  *) ( /* dim=0 */ (__pyx_v_arr.data + __pyx_t_4 * __pyx_v_arr.strides[0]) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":967
 *         for i in range(n):
 *             val = (arr[i])
 *             k = kh_get_uint64(table, val)             # <<<<<<<<<<<<<<
 *             result[i] = (k != table.n_buckets)
 * 
 */
          __pyx_v_k = kh_get_uint64(__pyx_v_table, __pyx_v_val);

          /* "pandas/_libs/hashtable_func_helper.pxi":968
 *             val = (arr[i])
 *             k = kh_get_uint64(table, val)
 *             result[i] = (k != table.n_buckets)             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_uint64(table)
 */
          __pyx_t_4 = __pyx_v_i;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_result.rcbuffer->pybuffer.buf, __pyx_t_4, __pyx_pybuffernd_result.diminfo[0].strides) = (__pyx_v_k != __pyx_v_table->n_buckets);
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":964
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (arr[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L10;
        }
        __pyx_L10:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":970
 *             result[i] = (k != table.n_buckets)
 * 
 *     kh_destroy_uint64(table)             # <<<<<<<<<<<<<<
 *     return result.view(np.bool_)
 * 
 */
  kh_destroy_uint64(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":971
 * 
 *     kh_destroy_uint64(table)
 *     return result.view(np.bool_)             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_result), __pyx_n_s_view); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_bool_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 971, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_11 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_11 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_6};
    __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_11, 1+__pyx_t_11);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 971, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_r = __pyx_t_9;
  __pyx_t_9 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":927
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_uint64(const uint64_t[:] arr, const uint64_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember_uint64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":980
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_uint32(const uint32_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_uint32(__Pyx_memviewslice __pyx_v_values, int __pyx_v_dropna, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_uint32 *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__52;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  kh_uint32_t *__pyx_v_table;
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_uint32_t __pyx_v_val;
  int __pyx_v_ret;
  int __pyx_v_uses_mask;
  int __pyx_v_isna_entry;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *__pyx_v_result_keys = NULL;
  __Pyx_memviewslice __pyx_v_result_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  khiter_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  khuint_t __pyx_t_14;
  khuint_t __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("value_count_uint32", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":982
 * cdef value_count_uint32(const uint32_t[:] values, bint dropna, const uint8_t[:] mask=None):
 *     cdef:
 *         Py_ssize_t i = 0             # <<<<<<<<<<<<<<
 *         Py_ssize_t n = len(values)
 *         kh_uint32_t *table
 */
  __pyx_v_i = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":983
 *     cdef:
 *         Py_ssize_t i = 0
 *         Py_ssize_t n = len(values)             # <<<<<<<<<<<<<<
 *         kh_uint32_t *table
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":991
 *         uint32_t val
 * 
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":992
 * 
 *         int ret = 0
 *         bint uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint isna_entry = False
 * 
 */
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":993
 *         int ret = 0
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False             # <<<<<<<<<<<<<<
 * 
 *     if uses_mask and not dropna:
 */
  __pyx_v_isna_entry = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":995
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  if (__pyx_v_uses_mask) {
  } else {
    __pyx_t_2 = __pyx_v_uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (!__pyx_v_dropna);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_2)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":996
 * 
 *     if uses_mask and not dropna:
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")             # <<<<<<<<<<<<<<
 * 
 *     # we track the order in which keys are first seen (GH39009),
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_NotImplementedError, __pyx_tuple__41, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 996, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(5, 996, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":995
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1003
 *     #    result_keys remembers the original order of keys
 * 
 *     result_keys = UInt32Vector()             # <<<<<<<<<<<<<<
 *     table = kh_init_uint32()
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector)); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1003, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_result_keys = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1004
 * 
 *     result_keys = UInt32Vector()
 *     table = kh_init_uint32()             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_uint32(table, n)
 */
  __pyx_v_table = kh_init_uint32();

  /* "pandas/_libs/hashtable_func_helper.pxi":1006
 *     table = kh_init_uint32()
 * 
 *     kh_resize_uint32(table, n)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(n):
 */
  kh_resize_uint32(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":1008
 *     kh_resize_uint32(table, n)
 * 
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         val = (values[i])
 * 
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_5 = __pyx_t_1;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "pandas/_libs/hashtable_func_helper.pxi":1009
 * 
 *     for i in range(n):
 *         val = (values[i])             # <<<<<<<<<<<<<<
 * 
 *         if dropna:
 */
    __pyx_t_7 = __pyx_v_i;
    __pyx_v_val = (*((__pyx_t_5numpy_uint32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

    /* "pandas/_libs/hashtable_func_helper.pxi":1011
 *         val = (values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    if (__pyx_v_dropna) {

      /* "pandas/_libs/hashtable_func_helper.pxi":1012
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
      if (__pyx_v_uses_mask) {

        /* "pandas/_libs/hashtable_func_helper.pxi":1013
 *         if dropna:
 *             if uses_mask:
 *                 isna_entry = mask[i]             # <<<<<<<<<<<<<<
 *             else:
 *                 isna_entry = is_nan_uint32_t(val)
 */
        __pyx_t_7 = __pyx_v_i;
        __pyx_v_isna_entry = (*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) )));

        /* "pandas/_libs/hashtable_func_helper.pxi":1012
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
        goto __pyx_L9;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":1015
 *                 isna_entry = mask[i]
 *             else:
 *                 isna_entry = is_nan_uint32_t(val)             # <<<<<<<<<<<<<<
 * 
 *         if not dropna or not isna_entry:
 */
      /*else*/ {
        __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_uint32_t(__pyx_v_val); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 1015, __pyx_L1_error)
        __pyx_v_isna_entry = __pyx_t_2;
      }
      __pyx_L9:;

      /* "pandas/_libs/hashtable_func_helper.pxi":1011
 *         val = (values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":1017
 *                 isna_entry = is_nan_uint32_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_uint32(table, val)
 *             if k != table.n_buckets:
 */
    __pyx_t_3 = (!__pyx_v_dropna);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L11_bool_binop_done;
    }
    __pyx_t_3 = (!__pyx_v_isna_entry);
    __pyx_t_2 = __pyx_t_3;
    __pyx_L11_bool_binop_done:;
    if (__pyx_t_2) {

      /* "pandas/_libs/hashtable_func_helper.pxi":1018
 * 
 *         if not dropna or not isna_entry:
 *             k = kh_get_uint32(table, val)             # <<<<<<<<<<<<<<
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1
 */
      __pyx_v_k = kh_get_uint32(__pyx_v_table, __pyx_v_val);

      /* "pandas/_libs/hashtable_func_helper.pxi":1019
 *         if not dropna or not isna_entry:
 *             k = kh_get_uint32(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
      __pyx_t_2 = (__pyx_v_k != __pyx_v_table->n_buckets);
      if (__pyx_t_2) {

        /* "pandas/_libs/hashtable_func_helper.pxi":1020
 *             k = kh_get_uint32(table, val)
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 k = kh_put_uint32(table, val, &ret)
 */
        __pyx_t_8 = __pyx_v_k;
        (__pyx_v_table->vals[__pyx_t_8]) = ((__pyx_v_table->vals[__pyx_t_8]) + 1);

        /* "pandas/_libs/hashtable_func_helper.pxi":1019
 *         if not dropna or not isna_entry:
 *             k = kh_get_uint32(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
        goto __pyx_L13;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":1022
 *                 table.vals[k] += 1
 *             else:
 *                 k = kh_put_uint32(table, val, &ret)             # <<<<<<<<<<<<<<
 *                 table.vals[k] = 1
 *                 result_keys.append(val)
 */
      /*else*/ {
        __pyx_v_k = kh_put_uint32(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret));

        /* "pandas/_libs/hashtable_func_helper.pxi":1023
 *             else:
 *                 k = kh_put_uint32(table, val, &ret)
 *                 table.vals[k] = 1             # <<<<<<<<<<<<<<
 *                 result_keys.append(val)
 * 
 */
        (__pyx_v_table->vals[__pyx_v_k]) = 1;

        /* "pandas/_libs/hashtable_func_helper.pxi":1024
 *                 k = kh_put_uint32(table, val, &ret)
 *                 table.vals[k] = 1
 *                 result_keys.append(val)             # <<<<<<<<<<<<<<
 * 
 *     # collect counts in the order corresponding to result_keys:
 */
        ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt32Vector *)__pyx_v_result_keys->__pyx_vtab)->append(__pyx_v_result_keys, __pyx_v_val); if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 1024, __pyx_L1_error)
      }
      __pyx_L13:;

      /* "pandas/_libs/hashtable_func_helper.pxi":1017
 *                 isna_entry = is_nan_uint32_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_uint32(table, val)
 *             if k != table.n_buckets:
 */
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1028
 *     # collect counts in the order corresponding to result_keys:
 *     cdef:
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(table.size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_empty); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 1028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_v_table->size); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 1028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_4)) __PYX_ERR(5, 1028, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_np); if (unlikely(!__pyx_t_11)) __PYX_ERR(5, 1028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_int64); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 1028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_dtype, __pyx_t_12) < 0) __PYX_ERR(5, 1028, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_10, __pyx_t_4); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 1028, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_12, PyBUF_WRITABLE); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(5, 1028, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_v_result_counts = __pyx_t_13;
  __pyx_t_13.memview = NULL;
  __pyx_t_13.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":1030
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)
 * 
 *     for i in range(table.size):             # <<<<<<<<<<<<<<
 *         k = kh_get_uint32(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]
 */
  __pyx_t_14 = __pyx_v_table->size;
  __pyx_t_15 = __pyx_t_14;
  for (__pyx_t_1 = 0; __pyx_t_1 < __pyx_t_15; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "pandas/_libs/hashtable_func_helper.pxi":1031
 * 
 *     for i in range(table.size):
 *         k = kh_get_uint32(table, result_keys.data.data[i])             # <<<<<<<<<<<<<<
 *         result_counts[i] = table.vals[k]
 * 
 */
    __pyx_v_k = kh_get_uint32(__pyx_v_table, (__pyx_v_result_keys->data->data[__pyx_v_i]));

    /* "pandas/_libs/hashtable_func_helper.pxi":1032
 *     for i in range(table.size):
 *         k = kh_get_uint32(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_uint32(table)
 */
    __pyx_t_7 = __pyx_v_i;
    *((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_result_counts.data) + __pyx_t_7)) )) = (__pyx_v_table->vals[__pyx_v_k]);
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1034
 *         result_counts[i] = table.vals[k]
 * 
 *     kh_destroy_uint32(table)             # <<<<<<<<<<<<<<
 * 
 *     return result_keys.to_array(), result_counts.base
 */
  kh_destroy_uint32(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":1036
 *     kh_destroy_uint32(table)
 * 
 *     return result_keys.to_array(), result_counts.base             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_12 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt32Vector *)__pyx_v_result_keys->__pyx_vtab)->to_array(__pyx_v_result_keys, 0)); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 1036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_result_counts, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int64_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int64_t, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_base); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 1036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_12);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_12)) __PYX_ERR(5, 1036, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_10);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_10)) __PYX_ERR(5, 1036, __pyx_L1_error);
  __pyx_t_12 = 0;
  __pyx_t_10 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":980
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_uint32(const uint32_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_13, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count_uint32", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result_keys);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_result_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":1041
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_uint32(const uint32_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_uint32(__Pyx_memviewslice __pyx_v_values, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_uint32 *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__53;
  int __pyx_v_ret;
  __pyx_t_5numpy_uint32_t __pyx_v_value;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  Py_ssize_t __pyx_v_first_na;
  khiter_t __pyx_v_k;
  kh_uint32_t *__pyx_v_table;
  PyArrayObject *__pyx_v_out = 0;
  int __pyx_v_seen_na;
  int __pyx_v_uses_mask;
  int __pyx_v_seen_multiple_na;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_out;
  __Pyx_Buffer __pyx_pybuffer_out;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  khuint_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  size_t __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("duplicated_uint32", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_out.pybuffer.buf = NULL;
  __pyx_pybuffer_out.refcount = 0;
  __pyx_pybuffernd_out.data = NULL;
  __pyx_pybuffernd_out.rcbuffer = &__pyx_pybuffer_out;

  /* "pandas/_libs/hashtable_func_helper.pxi":1043
 * cdef duplicated_uint32(const uint32_t[:] values, object keep='first', const uint8_t[:] mask=None):
 *     cdef:
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         uint32_t value
 *         Py_ssize_t i, n = len(values), first_na = -1
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1045
 *         int ret = 0
 *         uint32_t value
 *         Py_ssize_t i, n = len(values), first_na = -1             # <<<<<<<<<<<<<<
 *         khiter_t k
 *         kh_uint32_t *table = kh_init_uint32()
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;
  __pyx_v_first_na = -1L;

  /* "pandas/_libs/hashtable_func_helper.pxi":1047
 *         Py_ssize_t i, n = len(values), first_na = -1
 *         khiter_t k
 *         kh_uint32_t *table = kh_init_uint32()             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 */
  __pyx_v_table = kh_init_uint32();

  /* "pandas/_libs/hashtable_func_helper.pxi":1048
 *         khiter_t k
 *         kh_uint32_t *table = kh_init_uint32()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')             # <<<<<<<<<<<<<<
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 1048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 1048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 1048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(5, 1048, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 1048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_n_u_bool) < 0) __PYX_ERR(5, 1048, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1048, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 1048, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_out.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 1, __pyx_stack) == -1)) {
      __pyx_v_out = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_out.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(5, 1048, __pyx_L1_error)
    } else {__pyx_pybuffernd_out.diminfo[0].strides = __pyx_pybuffernd_out.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_out.diminfo[0].shape = __pyx_pybuffernd_out.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_out = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1049
 *         kh_uint32_t *table = kh_init_uint32()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint seen_multiple_na = False
 * 
 */
  __pyx_v_seen_na = 0;
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":1050
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_uint32(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 */
  __pyx_v_seen_multiple_na = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1052
 *         bint seen_multiple_na = False
 * 
 *     kh_resize_uint32(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))             # <<<<<<<<<<<<<<
 * 
 *     if keep not in ('last', 'first', False):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = kh_needed_n_buckets(__pyx_v_n);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1052, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_5, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 1052, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(5, 1052, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_8) {
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_2 = __pyx_t_5;
  } else {
    __pyx_t_3 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 1052, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_uint32(__pyx_t_2); if (unlikely((__pyx_t_7 == ((khuint_t)-1)) && PyErr_Occurred())) __PYX_ERR(5, 1052, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  kh_resize_uint32(__pyx_v_table, __pyx_t_7);

  /* "pandas/_libs/hashtable_func_helper.pxi":1054
 *     kh_resize_uint32(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  __Pyx_INCREF(__pyx_v_keep);
  __pyx_t_2 = __pyx_v_keep;
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_last, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1054, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_first, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1054, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, Py_False, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1054, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1054, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_8 = __pyx_t_9;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_9 = __pyx_t_8;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":1055
 * 
 *     if keep not in ('last', 'first', False):
 *         raise ValueError('keep must be either "first", "last" or False')             # <<<<<<<<<<<<<<
 * 
 *     if keep == "last":
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__43, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 1055, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(5, 1055, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":1054
 *     kh_resize_uint32(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1057
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_last, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1057, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":1058
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":1059
 *     if keep == "last":
 *         with nogil:
 *             for i in range(n - 1, -1, -1):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          for (__pyx_t_1 = (__pyx_v_n - 1); __pyx_t_1 > -1L; __pyx_t_1-=1) {
            __pyx_v_i = __pyx_t_1;

            /* "pandas/_libs/hashtable_func_helper.pxi":1060
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L14_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L14_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":1061
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":1062
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1061
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L16;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":1064
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":1065
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = (values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L16:;

              /* "pandas/_libs/hashtable_func_helper.pxi":1060
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L13;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":1067
 *                         seen_na = True
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_uint32(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_uint32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":1068
 *                 else:
 *                     value = (values[i])
 *                     kh_put_uint32(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 *     elif keep == "first":
 */
              (void)(kh_put_uint32(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":1069
 *                     value = (values[i])
 *                     kh_put_uint32(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 *     elif keep == "first":
 *         with nogil:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L13:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":1058
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L10;
          }
          __pyx_L10:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":1057
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1070
 *                     kh_put_uint32(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_first, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1070, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":1071
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":1072
 *     elif keep == "first":
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_11 = __pyx_t_1;
          for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
            __pyx_v_i = __pyx_t_12;

            /* "pandas/_libs/hashtable_func_helper.pxi":1073
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L23_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L23_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":1074
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":1075
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1074
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L25;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":1077
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":1078
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = (values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L25:;

              /* "pandas/_libs/hashtable_func_helper.pxi":1073
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L22;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":1080
 *                         seen_na = True
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_uint32(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_uint32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":1081
 *                 else:
 *                     value = (values[i])
 *                     kh_put_uint32(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 * 
 */
              (void)(kh_put_uint32(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":1082
 *                     value = (values[i])
 *                     kh_put_uint32(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 * 
 *     else:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L22:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":1071
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L19;
          }
          __pyx_L19:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":1070
 *                     kh_put_uint32(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1085
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
  /*else*/ {
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":1086
 *     else:
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_11 = __pyx_t_1;
          for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
            __pyx_v_i = __pyx_t_12;

            /* "pandas/_libs/hashtable_func_helper.pxi":1087
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L32_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L32_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":1088
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
              __pyx_t_9 = (!__pyx_v_seen_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":1089
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 *                         first_na = i             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                         out[i] = 0
 */
                __pyx_v_first_na = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":1090
 *                     if not seen_na:
 *                         first_na = i
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 */
                __pyx_v_seen_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1091
 *                         first_na = i
 *                         seen_na = True
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":1088
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":1092
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
              __pyx_t_9 = (!__pyx_v_seen_multiple_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":1093
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                         out[first_na] = 1
 *                         seen_multiple_na = True
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1094
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 *                         out[first_na] = 1             # <<<<<<<<<<<<<<
 *                         seen_multiple_na = True
 *                     else:
 */
                __pyx_t_10 = __pyx_v_first_na;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1095
 *                         out[i] = 1
 *                         out[first_na] = 1
 *                         seen_multiple_na = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = 1
 */
                __pyx_v_seen_multiple_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1092
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":1097
 *                         seen_multiple_na = True
 *                     else:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 * 
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;
              }
              __pyx_L34:;

              /* "pandas/_libs/hashtable_func_helper.pxi":1087
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
              goto __pyx_L31;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":1100
 * 
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_uint32(table, value)
 *                     if k != table.n_buckets:
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_uint32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":1101
 *                 else:
 *                     value = (values[i])
 *                     k = kh_get_uint32(table, value)             # <<<<<<<<<<<<<<
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 */
              __pyx_v_k = kh_get_uint32(__pyx_v_table, __pyx_v_value);

              /* "pandas/_libs/hashtable_func_helper.pxi":1102
 *                     value = (values[i])
 *                     k = kh_get_uint32(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
              __pyx_t_9 = (__pyx_v_k != __pyx_v_table->n_buckets);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":1103
 *                     k = kh_get_uint32(table, value)
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                     else:
 */
                __pyx_t_13 = (__pyx_v_table->vals[__pyx_v_k]);
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_13, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1104
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                     else:
 *                         k = kh_put_uint32(table, value, &ret)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1102
 *                     value = (values[i])
 *                     k = kh_get_uint32(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
                goto __pyx_L35;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":1106
 *                         out[i] = 1
 *                     else:
 *                         k = kh_put_uint32(table, value, &ret)             # <<<<<<<<<<<<<<
 *                         table.vals[k] = i
 *                         out[i] = 0
 */
              /*else*/ {
                __pyx_v_k = kh_put_uint32(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret));

                /* "pandas/_libs/hashtable_func_helper.pxi":1107
 *                     else:
 *                         k = kh_put_uint32(table, value, &ret)
 *                         table.vals[k] = i             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 * 
 */
                (__pyx_v_table->vals[__pyx_v_k]) = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":1108
 *                         k = kh_put_uint32(table, value, &ret)
 *                         table.vals[k] = i
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_uint32(table)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;
              }
              __pyx_L35:;
            }
            __pyx_L31:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":1085
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L28;
          }
          __pyx_L28:;
        }
    }
  }
  __pyx_L7:;

  /* "pandas/_libs/hashtable_func_helper.pxi":1110
 *                         out[i] = 0
 * 
 *     kh_destroy_uint32(table)             # <<<<<<<<<<<<<<
 *     return out
 * 
 */
  kh_destroy_uint32(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":1111
 * 
 *     kh_destroy_uint32(table)
 *     return out             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_out);
  __pyx_r = ((PyObject *)__pyx_v_out);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1041
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_uint32(const uint32_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated_uint32", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_out);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":1121
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_uint32(const uint32_t[:] arr, const uint32_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_uint32(__Pyx_memviewslice __pyx_v_arr, __Pyx_memviewslice __pyx_v_values) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  PyArrayObject *__pyx_v_result = 0;
  __pyx_t_5numpy_uint32_t __pyx_v_val;
  kh_uint32_t *__pyx_v_table;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyArrayObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ismember_uint32", 1);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "pandas/_libs/hashtable_func_helper.pxi":1138
 *         Py_ssize_t i, n
 *         khiter_t k
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t] result
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1143
 *         uint32_t val
 * 
 *         kh_uint32_t *table = kh_init_uint32()             # <<<<<<<<<<<<<<
 * 
 *     # construct the table
 */
  __pyx_v_table = kh_init_uint32();

  /* "pandas/_libs/hashtable_func_helper.pxi":1146
 * 
 *     # construct the table
 *     n = len(values)             # <<<<<<<<<<<<<<
 *     kh_resize_uint32(table, n)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":1147
 *     # construct the table
 *     n = len(values)
 *     kh_resize_uint32(table, n)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  kh_resize_uint32(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":1149
 *     kh_resize_uint32(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":1150
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = (values[i])
 *             kh_put_uint32(table, val, &ret)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":1151
 *     with nogil:
 *         for i in range(n):
 *             val = (values[i])             # <<<<<<<<<<<<<<
 *             kh_put_uint32(table, val, &ret)
 * 
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_uint32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_4 * __pyx_v_values.strides[0]) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":1152
 *         for i in range(n):
 *             val = (values[i])
 *             kh_put_uint32(table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *     # test membership
 */
          (void)(kh_put_uint32(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret)));
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":1149
 *     kh_resize_uint32(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1155
 * 
 *     # test membership
 *     n = len(arr)             # <<<<<<<<<<<<<<
 *     result = np.empty(n, dtype=np.uint8)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_arr); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":1156
 *     # test membership
 *     n = len(arr)
 *     result = np.empty(n, dtype=np.uint8)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_empty); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 1156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 1156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5)) __PYX_ERR(5, 1156, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(5, 1156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_uint8); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 1156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dtype, __pyx_t_9) < 0) __PYX_ERR(5, 1156, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, __pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 1156, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (!(likely(((__pyx_t_9) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_9, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 1156, __pyx_L1_error)
  __pyx_t_10 = ((PyArrayObject *)__pyx_t_9);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_11 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_10, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_11 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_13); Py_XDECREF(__pyx_t_14);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __pyx_t_12 = __pyx_t_13 = __pyx_t_14 = 0;
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(5, 1156, __pyx_L1_error)
  }
  __pyx_t_10 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_9);
  __pyx_t_9 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1158
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (arr[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":1159
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = (arr[i])
 *             k = kh_get_uint32(table, val)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":1160
 *     with nogil:
 *         for i in range(n):
 *             val = (arr[i])             # <<<<<<<<<<<<<<
 *             k = kh_get_uint32(table, val)
 *             result[i] = (k != table.n_buckets)
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_uint32_t const  *) ( /* dim=0 */ (__pyx_v_arr.data + __pyx_t_4 * __pyx_v_arr.strides[0]) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":1161
 *         for i in range(n):
 *             val = (arr[i])
 *             k = kh_get_uint32(table, val)             # <<<<<<<<<<<<<<
 *             result[i] = (k != table.n_buckets)
 * 
 */
          __pyx_v_k = kh_get_uint32(__pyx_v_table, __pyx_v_val);

          /* "pandas/_libs/hashtable_func_helper.pxi":1162
 *             val = (arr[i])
 *             k = kh_get_uint32(table, val)
 *             result[i] = (k != table.n_buckets)             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_uint32(table)
 */
          __pyx_t_4 = __pyx_v_i;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_result.rcbuffer->pybuffer.buf, __pyx_t_4, __pyx_pybuffernd_result.diminfo[0].strides) = (__pyx_v_k != __pyx_v_table->n_buckets);
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":1158
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (arr[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L10;
        }
        __pyx_L10:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1164
 *             result[i] = (k != table.n_buckets)
 * 
 *     kh_destroy_uint32(table)             # <<<<<<<<<<<<<<
 *     return result.view(np.bool_)
 * 
 */
  kh_destroy_uint32(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":1165
 * 
 *     kh_destroy_uint32(table)
 *     return result.view(np.bool_)             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_result), __pyx_n_s_view); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 1165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_bool_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 1165, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_11 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_11 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_6};
    __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_11, 1+__pyx_t_11);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 1165, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_r = __pyx_t_9;
  __pyx_t_9 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1121
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_uint32(const uint32_t[:] arr, const uint32_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember_uint32", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":1174
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_uint16(const uint16_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_uint16(__Pyx_memviewslice __pyx_v_values, int __pyx_v_dropna, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_uint16 *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__54;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  kh_uint16_t *__pyx_v_table;
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_uint16_t __pyx_v_val;
  int __pyx_v_ret;
  int __pyx_v_uses_mask;
  int __pyx_v_isna_entry;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *__pyx_v_result_keys = NULL;
  __Pyx_memviewslice __pyx_v_result_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  khiter_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  khuint_t __pyx_t_14;
  khuint_t __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("value_count_uint16", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1176
 * cdef value_count_uint16(const uint16_t[:] values, bint dropna, const uint8_t[:] mask=None):
 *     cdef:
 *         Py_ssize_t i = 0             # <<<<<<<<<<<<<<
 *         Py_ssize_t n = len(values)
 *         kh_uint16_t *table
 */
  __pyx_v_i = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1177
 *     cdef:
 *         Py_ssize_t i = 0
 *         Py_ssize_t n = len(values)             # <<<<<<<<<<<<<<
 *         kh_uint16_t *table
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":1185
 *         uint16_t val
 * 
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1186
 * 
 *         int ret = 0
 *         bint uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint isna_entry = False
 * 
 */
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":1187
 *         int ret = 0
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False             # <<<<<<<<<<<<<<
 * 
 *     if uses_mask and not dropna:
 */
  __pyx_v_isna_entry = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1189
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  if (__pyx_v_uses_mask) {
  } else {
    __pyx_t_2 = __pyx_v_uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (!__pyx_v_dropna);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_2)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":1190
 * 
 *     if uses_mask and not dropna:
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")             # <<<<<<<<<<<<<<
 * 
 *     # we track the order in which keys are first seen (GH39009),
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_NotImplementedError, __pyx_tuple__41, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1190, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(5, 1190, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":1189
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1197
 *     #    result_keys remembers the original order of keys
 * 
 *     result_keys = UInt16Vector()             # <<<<<<<<<<<<<<
 *     table = kh_init_uint16()
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector)); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1197, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_result_keys = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1198
 * 
 *     result_keys = UInt16Vector()
 *     table = kh_init_uint16()             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_uint16(table, n)
 */
  __pyx_v_table = kh_init_uint16();

  /* "pandas/_libs/hashtable_func_helper.pxi":1200
 *     table = kh_init_uint16()
 * 
 *     kh_resize_uint16(table, n)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(n):
 */
  kh_resize_uint16(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":1202
 *     kh_resize_uint16(table, n)
 * 
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         val = (values[i])
 * 
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_5 = __pyx_t_1;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "pandas/_libs/hashtable_func_helper.pxi":1203
 * 
 *     for i in range(n):
 *         val = (values[i])             # <<<<<<<<<<<<<<
 * 
 *         if dropna:
 */
    __pyx_t_7 = __pyx_v_i;
    __pyx_v_val = (*((__pyx_t_5numpy_uint16_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

    /* "pandas/_libs/hashtable_func_helper.pxi":1205
 *         val = (values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    if (__pyx_v_dropna) {

      /* "pandas/_libs/hashtable_func_helper.pxi":1206
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
      if (__pyx_v_uses_mask) {

        /* "pandas/_libs/hashtable_func_helper.pxi":1207
 *         if dropna:
 *             if uses_mask:
 *                 isna_entry = mask[i]             # <<<<<<<<<<<<<<
 *             else:
 *                 isna_entry = is_nan_uint16_t(val)
 */
        __pyx_t_7 = __pyx_v_i;
        __pyx_v_isna_entry = (*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) )));

        /* "pandas/_libs/hashtable_func_helper.pxi":1206
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
        goto __pyx_L9;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":1209
 *                 isna_entry = mask[i]
 *             else:
 *                 isna_entry = is_nan_uint16_t(val)             # <<<<<<<<<<<<<<
 * 
 *         if not dropna or not isna_entry:
 */
      /*else*/ {
        __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_uint16_t(__pyx_v_val); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 1209, __pyx_L1_error)
        __pyx_v_isna_entry = __pyx_t_2;
      }
      __pyx_L9:;

      /* "pandas/_libs/hashtable_func_helper.pxi":1205
 *         val = (values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":1211
 *                 isna_entry = is_nan_uint16_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_uint16(table, val)
 *             if k != table.n_buckets:
 */
    __pyx_t_3 = (!__pyx_v_dropna);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L11_bool_binop_done;
    }
    __pyx_t_3 = (!__pyx_v_isna_entry);
    __pyx_t_2 = __pyx_t_3;
    __pyx_L11_bool_binop_done:;
    if (__pyx_t_2) {

      /* "pandas/_libs/hashtable_func_helper.pxi":1212
 * 
 *         if not dropna or not isna_entry:
 *             k = kh_get_uint16(table, val)             # <<<<<<<<<<<<<<
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1
 */
      __pyx_v_k = kh_get_uint16(__pyx_v_table, __pyx_v_val);

      /* "pandas/_libs/hashtable_func_helper.pxi":1213
 *         if not dropna or not isna_entry:
 *             k = kh_get_uint16(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
      __pyx_t_2 = (__pyx_v_k != __pyx_v_table->n_buckets);
      if (__pyx_t_2) {

        /* "pandas/_libs/hashtable_func_helper.pxi":1214
 *             k = kh_get_uint16(table, val)
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 k = kh_put_uint16(table, val, &ret)
 */
        __pyx_t_8 = __pyx_v_k;
        (__pyx_v_table->vals[__pyx_t_8]) = ((__pyx_v_table->vals[__pyx_t_8]) + 1);

        /* "pandas/_libs/hashtable_func_helper.pxi":1213
 *         if not dropna or not isna_entry:
 *             k = kh_get_uint16(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
        goto __pyx_L13;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":1216
 *                 table.vals[k] += 1
 *             else:
 *                 k = kh_put_uint16(table, val, &ret)             # <<<<<<<<<<<<<<
 *                 table.vals[k] = 1
 *                 result_keys.append(val)
 */
      /*else*/ {
        __pyx_v_k = kh_put_uint16(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret));

        /* "pandas/_libs/hashtable_func_helper.pxi":1217
 *             else:
 *                 k = kh_put_uint16(table, val, &ret)
 *                 table.vals[k] = 1             # <<<<<<<<<<<<<<
 *                 result_keys.append(val)
 * 
 */
        (__pyx_v_table->vals[__pyx_v_k]) = 1;

        /* "pandas/_libs/hashtable_func_helper.pxi":1218
 *                 k = kh_put_uint16(table, val, &ret)
 *                 table.vals[k] = 1
 *                 result_keys.append(val)             # <<<<<<<<<<<<<<
 * 
 *     # collect counts in the order corresponding to result_keys:
 */
        ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt16Vector *)__pyx_v_result_keys->__pyx_vtab)->append(__pyx_v_result_keys, __pyx_v_val); if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 1218, __pyx_L1_error)
      }
      __pyx_L13:;

      /* "pandas/_libs/hashtable_func_helper.pxi":1211
 *                 isna_entry = is_nan_uint16_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_uint16(table, val)
 *             if k != table.n_buckets:
 */
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1222
 *     # collect counts in the order corresponding to result_keys:
 *     cdef:
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(table.size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_empty); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 1222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_v_table->size); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 1222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_4)) __PYX_ERR(5, 1222, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_np); if (unlikely(!__pyx_t_11)) __PYX_ERR(5, 1222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_int64); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 1222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_dtype, __pyx_t_12) < 0) __PYX_ERR(5, 1222, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_10, __pyx_t_4); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 1222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_12, PyBUF_WRITABLE); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(5, 1222, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_v_result_counts = __pyx_t_13;
  __pyx_t_13.memview = NULL;
  __pyx_t_13.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":1224
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)
 * 
 *     for i in range(table.size):             # <<<<<<<<<<<<<<
 *         k = kh_get_uint16(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]
 */
  __pyx_t_14 = __pyx_v_table->size;
  __pyx_t_15 = __pyx_t_14;
  for (__pyx_t_1 = 0; __pyx_t_1 < __pyx_t_15; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "pandas/_libs/hashtable_func_helper.pxi":1225
 * 
 *     for i in range(table.size):
 *         k = kh_get_uint16(table, result_keys.data.data[i])             # <<<<<<<<<<<<<<
 *         result_counts[i] = table.vals[k]
 * 
 */
    __pyx_v_k = kh_get_uint16(__pyx_v_table, (__pyx_v_result_keys->data->data[__pyx_v_i]));

    /* "pandas/_libs/hashtable_func_helper.pxi":1226
 *     for i in range(table.size):
 *         k = kh_get_uint16(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_uint16(table)
 */
    __pyx_t_7 = __pyx_v_i;
    *((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_result_counts.data) + __pyx_t_7)) )) = (__pyx_v_table->vals[__pyx_v_k]);
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1228
 *         result_counts[i] = table.vals[k]
 * 
 *     kh_destroy_uint16(table)             # <<<<<<<<<<<<<<
 * 
 *     return result_keys.to_array(), result_counts.base
 */
  kh_destroy_uint16(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":1230
 *     kh_destroy_uint16(table)
 * 
 *     return result_keys.to_array(), result_counts.base             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_12 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt16Vector *)__pyx_v_result_keys->__pyx_vtab)->to_array(__pyx_v_result_keys, 0)); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 1230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_result_counts, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int64_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int64_t, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_base); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 1230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_12);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_12)) __PYX_ERR(5, 1230, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_10);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_10)) __PYX_ERR(5, 1230, __pyx_L1_error);
  __pyx_t_12 = 0;
  __pyx_t_10 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1174
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_uint16(const uint16_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_13, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count_uint16", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result_keys);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_result_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":1235
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_uint16(const uint16_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_uint16(__Pyx_memviewslice __pyx_v_values, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_uint16 *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__55;
  int __pyx_v_ret;
  __pyx_t_5numpy_uint16_t __pyx_v_value;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  Py_ssize_t __pyx_v_first_na;
  khiter_t __pyx_v_k;
  kh_uint16_t *__pyx_v_table;
  PyArrayObject *__pyx_v_out = 0;
  int __pyx_v_seen_na;
  int __pyx_v_uses_mask;
  int __pyx_v_seen_multiple_na;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_out;
  __Pyx_Buffer __pyx_pybuffer_out;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  khuint_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  size_t __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("duplicated_uint16", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_out.pybuffer.buf = NULL;
  __pyx_pybuffer_out.refcount = 0;
  __pyx_pybuffernd_out.data = NULL;
  __pyx_pybuffernd_out.rcbuffer = &__pyx_pybuffer_out;

  /* "pandas/_libs/hashtable_func_helper.pxi":1237
 * cdef duplicated_uint16(const uint16_t[:] values, object keep='first', const uint8_t[:] mask=None):
 *     cdef:
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         uint16_t value
 *         Py_ssize_t i, n = len(values), first_na = -1
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1239
 *         int ret = 0
 *         uint16_t value
 *         Py_ssize_t i, n = len(values), first_na = -1             # <<<<<<<<<<<<<<
 *         khiter_t k
 *         kh_uint16_t *table = kh_init_uint16()
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;
  __pyx_v_first_na = -1L;

  /* "pandas/_libs/hashtable_func_helper.pxi":1241
 *         Py_ssize_t i, n = len(values), first_na = -1
 *         khiter_t k
 *         kh_uint16_t *table = kh_init_uint16()             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 */
  __pyx_v_table = kh_init_uint16();

  /* "pandas/_libs/hashtable_func_helper.pxi":1242
 *         khiter_t k
 *         kh_uint16_t *table = kh_init_uint16()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')             # <<<<<<<<<<<<<<
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 1242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 1242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 1242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(5, 1242, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 1242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_n_u_bool) < 0) __PYX_ERR(5, 1242, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1242, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 1242, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_out.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 1, __pyx_stack) == -1)) {
      __pyx_v_out = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_out.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(5, 1242, __pyx_L1_error)
    } else {__pyx_pybuffernd_out.diminfo[0].strides = __pyx_pybuffernd_out.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_out.diminfo[0].shape = __pyx_pybuffernd_out.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_out = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1243
 *         kh_uint16_t *table = kh_init_uint16()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint seen_multiple_na = False
 * 
 */
  __pyx_v_seen_na = 0;
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":1244
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_uint16(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 */
  __pyx_v_seen_multiple_na = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1246
 *         bint seen_multiple_na = False
 * 
 *     kh_resize_uint16(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))             # <<<<<<<<<<<<<<
 * 
 *     if keep not in ('last', 'first', False):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = kh_needed_n_buckets(__pyx_v_n);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1246, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_5, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 1246, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(5, 1246, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_8) {
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_2 = __pyx_t_5;
  } else {
    __pyx_t_3 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 1246, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_uint32(__pyx_t_2); if (unlikely((__pyx_t_7 == ((khuint_t)-1)) && PyErr_Occurred())) __PYX_ERR(5, 1246, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  kh_resize_uint16(__pyx_v_table, __pyx_t_7);

  /* "pandas/_libs/hashtable_func_helper.pxi":1248
 *     kh_resize_uint16(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  __Pyx_INCREF(__pyx_v_keep);
  __pyx_t_2 = __pyx_v_keep;
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_last, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1248, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_first, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1248, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, Py_False, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1248, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1248, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_8 = __pyx_t_9;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_9 = __pyx_t_8;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":1249
 * 
 *     if keep not in ('last', 'first', False):
 *         raise ValueError('keep must be either "first", "last" or False')             # <<<<<<<<<<<<<<
 * 
 *     if keep == "last":
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__43, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 1249, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(5, 1249, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":1248
 *     kh_resize_uint16(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1251
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_last, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1251, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":1252
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":1253
 *     if keep == "last":
 *         with nogil:
 *             for i in range(n - 1, -1, -1):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          for (__pyx_t_1 = (__pyx_v_n - 1); __pyx_t_1 > -1L; __pyx_t_1-=1) {
            __pyx_v_i = __pyx_t_1;

            /* "pandas/_libs/hashtable_func_helper.pxi":1254
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L14_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L14_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":1255
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":1256
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1255
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L16;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":1258
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":1259
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = (values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L16:;

              /* "pandas/_libs/hashtable_func_helper.pxi":1254
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L13;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":1261
 *                         seen_na = True
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_uint16(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_uint16_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":1262
 *                 else:
 *                     value = (values[i])
 *                     kh_put_uint16(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 *     elif keep == "first":
 */
              (void)(kh_put_uint16(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":1263
 *                     value = (values[i])
 *                     kh_put_uint16(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 *     elif keep == "first":
 *         with nogil:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L13:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":1252
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L10;
          }
          __pyx_L10:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":1251
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1264
 *                     kh_put_uint16(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_first, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1264, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":1265
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":1266
 *     elif keep == "first":
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_11 = __pyx_t_1;
          for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
            __pyx_v_i = __pyx_t_12;

            /* "pandas/_libs/hashtable_func_helper.pxi":1267
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L23_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L23_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":1268
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":1269
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1268
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L25;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":1271
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":1272
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = (values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L25:;

              /* "pandas/_libs/hashtable_func_helper.pxi":1267
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L22;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":1274
 *                         seen_na = True
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_uint16(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_uint16_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":1275
 *                 else:
 *                     value = (values[i])
 *                     kh_put_uint16(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 * 
 */
              (void)(kh_put_uint16(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":1276
 *                     value = (values[i])
 *                     kh_put_uint16(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 * 
 *     else:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L22:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":1265
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L19;
          }
          __pyx_L19:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":1264
 *                     kh_put_uint16(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1279
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
  /*else*/ {
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":1280
 *     else:
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_11 = __pyx_t_1;
          for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
            __pyx_v_i = __pyx_t_12;

            /* "pandas/_libs/hashtable_func_helper.pxi":1281
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L32_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L32_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":1282
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
              __pyx_t_9 = (!__pyx_v_seen_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":1283
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 *                         first_na = i             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                         out[i] = 0
 */
                __pyx_v_first_na = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":1284
 *                     if not seen_na:
 *                         first_na = i
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 */
                __pyx_v_seen_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1285
 *                         first_na = i
 *                         seen_na = True
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":1282
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":1286
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
              __pyx_t_9 = (!__pyx_v_seen_multiple_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":1287
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                         out[first_na] = 1
 *                         seen_multiple_na = True
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1288
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 *                         out[first_na] = 1             # <<<<<<<<<<<<<<
 *                         seen_multiple_na = True
 *                     else:
 */
                __pyx_t_10 = __pyx_v_first_na;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1289
 *                         out[i] = 1
 *                         out[first_na] = 1
 *                         seen_multiple_na = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = 1
 */
                __pyx_v_seen_multiple_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1286
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":1291
 *                         seen_multiple_na = True
 *                     else:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 * 
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;
              }
              __pyx_L34:;

              /* "pandas/_libs/hashtable_func_helper.pxi":1281
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
              goto __pyx_L31;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":1294
 * 
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_uint16(table, value)
 *                     if k != table.n_buckets:
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_uint16_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":1295
 *                 else:
 *                     value = (values[i])
 *                     k = kh_get_uint16(table, value)             # <<<<<<<<<<<<<<
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 */
              __pyx_v_k = kh_get_uint16(__pyx_v_table, __pyx_v_value);

              /* "pandas/_libs/hashtable_func_helper.pxi":1296
 *                     value = (values[i])
 *                     k = kh_get_uint16(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
              __pyx_t_9 = (__pyx_v_k != __pyx_v_table->n_buckets);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":1297
 *                     k = kh_get_uint16(table, value)
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                     else:
 */
                __pyx_t_13 = (__pyx_v_table->vals[__pyx_v_k]);
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_13, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1298
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                     else:
 *                         k = kh_put_uint16(table, value, &ret)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1296
 *                     value = (values[i])
 *                     k = kh_get_uint16(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
                goto __pyx_L35;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":1300
 *                         out[i] = 1
 *                     else:
 *                         k = kh_put_uint16(table, value, &ret)             # <<<<<<<<<<<<<<
 *                         table.vals[k] = i
 *                         out[i] = 0
 */
              /*else*/ {
                __pyx_v_k = kh_put_uint16(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret));

                /* "pandas/_libs/hashtable_func_helper.pxi":1301
 *                     else:
 *                         k = kh_put_uint16(table, value, &ret)
 *                         table.vals[k] = i             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 * 
 */
                (__pyx_v_table->vals[__pyx_v_k]) = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":1302
 *                         k = kh_put_uint16(table, value, &ret)
 *                         table.vals[k] = i
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_uint16(table)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;
              }
              __pyx_L35:;
            }
            __pyx_L31:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":1279
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L28;
          }
          __pyx_L28:;
        }
    }
  }
  __pyx_L7:;

  /* "pandas/_libs/hashtable_func_helper.pxi":1304
 *                         out[i] = 0
 * 
 *     kh_destroy_uint16(table)             # <<<<<<<<<<<<<<
 *     return out
 * 
 */
  kh_destroy_uint16(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":1305
 * 
 *     kh_destroy_uint16(table)
 *     return out             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_out);
  __pyx_r = ((PyObject *)__pyx_v_out);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1235
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_uint16(const uint16_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated_uint16", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_out);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":1315
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_uint16(const uint16_t[:] arr, const uint16_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_uint16(__Pyx_memviewslice __pyx_v_arr, __Pyx_memviewslice __pyx_v_values) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  PyArrayObject *__pyx_v_result = 0;
  __pyx_t_5numpy_uint16_t __pyx_v_val;
  kh_uint16_t *__pyx_v_table;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyArrayObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ismember_uint16", 1);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "pandas/_libs/hashtable_func_helper.pxi":1332
 *         Py_ssize_t i, n
 *         khiter_t k
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t] result
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1337
 *         uint16_t val
 * 
 *         kh_uint16_t *table = kh_init_uint16()             # <<<<<<<<<<<<<<
 * 
 *     # construct the table
 */
  __pyx_v_table = kh_init_uint16();

  /* "pandas/_libs/hashtable_func_helper.pxi":1340
 * 
 *     # construct the table
 *     n = len(values)             # <<<<<<<<<<<<<<
 *     kh_resize_uint16(table, n)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":1341
 *     # construct the table
 *     n = len(values)
 *     kh_resize_uint16(table, n)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  kh_resize_uint16(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":1343
 *     kh_resize_uint16(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":1344
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = (values[i])
 *             kh_put_uint16(table, val, &ret)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":1345
 *     with nogil:
 *         for i in range(n):
 *             val = (values[i])             # <<<<<<<<<<<<<<
 *             kh_put_uint16(table, val, &ret)
 * 
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_uint16_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_4 * __pyx_v_values.strides[0]) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":1346
 *         for i in range(n):
 *             val = (values[i])
 *             kh_put_uint16(table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *     # test membership
 */
          (void)(kh_put_uint16(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret)));
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":1343
 *     kh_resize_uint16(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1349
 * 
 *     # test membership
 *     n = len(arr)             # <<<<<<<<<<<<<<
 *     result = np.empty(n, dtype=np.uint8)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_arr); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":1350
 *     # test membership
 *     n = len(arr)
 *     result = np.empty(n, dtype=np.uint8)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_empty); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 1350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 1350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5)) __PYX_ERR(5, 1350, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(5, 1350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_uint8); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 1350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dtype, __pyx_t_9) < 0) __PYX_ERR(5, 1350, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, __pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 1350, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (!(likely(((__pyx_t_9) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_9, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 1350, __pyx_L1_error)
  __pyx_t_10 = ((PyArrayObject *)__pyx_t_9);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_11 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_10, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_11 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_13); Py_XDECREF(__pyx_t_14);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __pyx_t_12 = __pyx_t_13 = __pyx_t_14 = 0;
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(5, 1350, __pyx_L1_error)
  }
  __pyx_t_10 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_9);
  __pyx_t_9 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1352
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (arr[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":1353
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = (arr[i])
 *             k = kh_get_uint16(table, val)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":1354
 *     with nogil:
 *         for i in range(n):
 *             val = (arr[i])             # <<<<<<<<<<<<<<
 *             k = kh_get_uint16(table, val)
 *             result[i] = (k != table.n_buckets)
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_uint16_t const  *) ( /* dim=0 */ (__pyx_v_arr.data + __pyx_t_4 * __pyx_v_arr.strides[0]) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":1355
 *         for i in range(n):
 *             val = (arr[i])
 *             k = kh_get_uint16(table, val)             # <<<<<<<<<<<<<<
 *             result[i] = (k != table.n_buckets)
 * 
 */
          __pyx_v_k = kh_get_uint16(__pyx_v_table, __pyx_v_val);

          /* "pandas/_libs/hashtable_func_helper.pxi":1356
 *             val = (arr[i])
 *             k = kh_get_uint16(table, val)
 *             result[i] = (k != table.n_buckets)             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_uint16(table)
 */
          __pyx_t_4 = __pyx_v_i;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_result.rcbuffer->pybuffer.buf, __pyx_t_4, __pyx_pybuffernd_result.diminfo[0].strides) = (__pyx_v_k != __pyx_v_table->n_buckets);
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":1352
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (arr[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L10;
        }
        __pyx_L10:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1358
 *             result[i] = (k != table.n_buckets)
 * 
 *     kh_destroy_uint16(table)             # <<<<<<<<<<<<<<
 *     return result.view(np.bool_)
 * 
 */
  kh_destroy_uint16(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":1359
 * 
 *     kh_destroy_uint16(table)
 *     return result.view(np.bool_)             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_result), __pyx_n_s_view); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 1359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_bool_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 1359, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_11 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_11 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_6};
    __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_11, 1+__pyx_t_11);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 1359, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_r = __pyx_t_9;
  __pyx_t_9 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1315
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_uint16(const uint16_t[:] arr, const uint16_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember_uint16", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":1368
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_uint8(const uint8_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_uint8(__Pyx_memviewslice __pyx_v_values, int __pyx_v_dropna, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_uint8 *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__56;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  kh_uint8_t *__pyx_v_table;
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_uint8_t __pyx_v_val;
  int __pyx_v_ret;
  int __pyx_v_uses_mask;
  int __pyx_v_isna_entry;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *__pyx_v_result_keys = NULL;
  __Pyx_memviewslice __pyx_v_result_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  khiter_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  khuint_t __pyx_t_14;
  khuint_t __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("value_count_uint8", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1370
 * cdef value_count_uint8(const uint8_t[:] values, bint dropna, const uint8_t[:] mask=None):
 *     cdef:
 *         Py_ssize_t i = 0             # <<<<<<<<<<<<<<
 *         Py_ssize_t n = len(values)
 *         kh_uint8_t *table
 */
  __pyx_v_i = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1371
 *     cdef:
 *         Py_ssize_t i = 0
 *         Py_ssize_t n = len(values)             # <<<<<<<<<<<<<<
 *         kh_uint8_t *table
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":1379
 *         uint8_t val
 * 
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1380
 * 
 *         int ret = 0
 *         bint uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint isna_entry = False
 * 
 */
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":1381
 *         int ret = 0
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False             # <<<<<<<<<<<<<<
 * 
 *     if uses_mask and not dropna:
 */
  __pyx_v_isna_entry = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1383
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  if (__pyx_v_uses_mask) {
  } else {
    __pyx_t_2 = __pyx_v_uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (!__pyx_v_dropna);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_2)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":1384
 * 
 *     if uses_mask and not dropna:
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")             # <<<<<<<<<<<<<<
 * 
 *     # we track the order in which keys are first seen (GH39009),
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_NotImplementedError, __pyx_tuple__41, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1384, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(5, 1384, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":1383
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1391
 *     #    result_keys remembers the original order of keys
 * 
 *     result_keys = UInt8Vector()             # <<<<<<<<<<<<<<
 *     table = kh_init_uint8()
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector)); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1391, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_result_keys = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1392
 * 
 *     result_keys = UInt8Vector()
 *     table = kh_init_uint8()             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_uint8(table, n)
 */
  __pyx_v_table = kh_init_uint8();

  /* "pandas/_libs/hashtable_func_helper.pxi":1394
 *     table = kh_init_uint8()
 * 
 *     kh_resize_uint8(table, n)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(n):
 */
  kh_resize_uint8(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":1396
 *     kh_resize_uint8(table, n)
 * 
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         val = (values[i])
 * 
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_5 = __pyx_t_1;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "pandas/_libs/hashtable_func_helper.pxi":1397
 * 
 *     for i in range(n):
 *         val = (values[i])             # <<<<<<<<<<<<<<
 * 
 *         if dropna:
 */
    __pyx_t_7 = __pyx_v_i;
    __pyx_v_val = (*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

    /* "pandas/_libs/hashtable_func_helper.pxi":1399
 *         val = (values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    if (__pyx_v_dropna) {

      /* "pandas/_libs/hashtable_func_helper.pxi":1400
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
      if (__pyx_v_uses_mask) {

        /* "pandas/_libs/hashtable_func_helper.pxi":1401
 *         if dropna:
 *             if uses_mask:
 *                 isna_entry = mask[i]             # <<<<<<<<<<<<<<
 *             else:
 *                 isna_entry = is_nan_uint8_t(val)
 */
        __pyx_t_7 = __pyx_v_i;
        __pyx_v_isna_entry = (*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) )));

        /* "pandas/_libs/hashtable_func_helper.pxi":1400
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
        goto __pyx_L9;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":1403
 *                 isna_entry = mask[i]
 *             else:
 *                 isna_entry = is_nan_uint8_t(val)             # <<<<<<<<<<<<<<
 * 
 *         if not dropna or not isna_entry:
 */
      /*else*/ {
        __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_uint8_t(__pyx_v_val); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 1403, __pyx_L1_error)
        __pyx_v_isna_entry = __pyx_t_2;
      }
      __pyx_L9:;

      /* "pandas/_libs/hashtable_func_helper.pxi":1399
 *         val = (values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":1405
 *                 isna_entry = is_nan_uint8_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_uint8(table, val)
 *             if k != table.n_buckets:
 */
    __pyx_t_3 = (!__pyx_v_dropna);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L11_bool_binop_done;
    }
    __pyx_t_3 = (!__pyx_v_isna_entry);
    __pyx_t_2 = __pyx_t_3;
    __pyx_L11_bool_binop_done:;
    if (__pyx_t_2) {

      /* "pandas/_libs/hashtable_func_helper.pxi":1406
 * 
 *         if not dropna or not isna_entry:
 *             k = kh_get_uint8(table, val)             # <<<<<<<<<<<<<<
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1
 */
      __pyx_v_k = kh_get_uint8(__pyx_v_table, __pyx_v_val);

      /* "pandas/_libs/hashtable_func_helper.pxi":1407
 *         if not dropna or not isna_entry:
 *             k = kh_get_uint8(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
      __pyx_t_2 = (__pyx_v_k != __pyx_v_table->n_buckets);
      if (__pyx_t_2) {

        /* "pandas/_libs/hashtable_func_helper.pxi":1408
 *             k = kh_get_uint8(table, val)
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 k = kh_put_uint8(table, val, &ret)
 */
        __pyx_t_8 = __pyx_v_k;
        (__pyx_v_table->vals[__pyx_t_8]) = ((__pyx_v_table->vals[__pyx_t_8]) + 1);

        /* "pandas/_libs/hashtable_func_helper.pxi":1407
 *         if not dropna or not isna_entry:
 *             k = kh_get_uint8(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
        goto __pyx_L13;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":1410
 *                 table.vals[k] += 1
 *             else:
 *                 k = kh_put_uint8(table, val, &ret)             # <<<<<<<<<<<<<<
 *                 table.vals[k] = 1
 *                 result_keys.append(val)
 */
      /*else*/ {
        __pyx_v_k = kh_put_uint8(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret));

        /* "pandas/_libs/hashtable_func_helper.pxi":1411
 *             else:
 *                 k = kh_put_uint8(table, val, &ret)
 *                 table.vals[k] = 1             # <<<<<<<<<<<<<<
 *                 result_keys.append(val)
 * 
 */
        (__pyx_v_table->vals[__pyx_v_k]) = 1;

        /* "pandas/_libs/hashtable_func_helper.pxi":1412
 *                 k = kh_put_uint8(table, val, &ret)
 *                 table.vals[k] = 1
 *                 result_keys.append(val)             # <<<<<<<<<<<<<<
 * 
 *     # collect counts in the order corresponding to result_keys:
 */
        ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_keys->__pyx_vtab)->append(__pyx_v_result_keys, __pyx_v_val); if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 1412, __pyx_L1_error)
      }
      __pyx_L13:;

      /* "pandas/_libs/hashtable_func_helper.pxi":1405
 *                 isna_entry = is_nan_uint8_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_uint8(table, val)
 *             if k != table.n_buckets:
 */
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1416
 *     # collect counts in the order corresponding to result_keys:
 *     cdef:
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(table.size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_empty); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 1416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_v_table->size); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 1416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_4)) __PYX_ERR(5, 1416, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_np); if (unlikely(!__pyx_t_11)) __PYX_ERR(5, 1416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_int64); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 1416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_dtype, __pyx_t_12) < 0) __PYX_ERR(5, 1416, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_10, __pyx_t_4); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 1416, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_12, PyBUF_WRITABLE); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(5, 1416, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_v_result_counts = __pyx_t_13;
  __pyx_t_13.memview = NULL;
  __pyx_t_13.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":1418
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)
 * 
 *     for i in range(table.size):             # <<<<<<<<<<<<<<
 *         k = kh_get_uint8(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]
 */
  __pyx_t_14 = __pyx_v_table->size;
  __pyx_t_15 = __pyx_t_14;
  for (__pyx_t_1 = 0; __pyx_t_1 < __pyx_t_15; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "pandas/_libs/hashtable_func_helper.pxi":1419
 * 
 *     for i in range(table.size):
 *         k = kh_get_uint8(table, result_keys.data.data[i])             # <<<<<<<<<<<<<<
 *         result_counts[i] = table.vals[k]
 * 
 */
    __pyx_v_k = kh_get_uint8(__pyx_v_table, (__pyx_v_result_keys->data->data[__pyx_v_i]));

    /* "pandas/_libs/hashtable_func_helper.pxi":1420
 *     for i in range(table.size):
 *         k = kh_get_uint8(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_uint8(table)
 */
    __pyx_t_7 = __pyx_v_i;
    *((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_result_counts.data) + __pyx_t_7)) )) = (__pyx_v_table->vals[__pyx_v_k]);
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1422
 *         result_counts[i] = table.vals[k]
 * 
 *     kh_destroy_uint8(table)             # <<<<<<<<<<<<<<
 * 
 *     return result_keys.to_array(), result_counts.base
 */
  kh_destroy_uint8(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":1424
 *     kh_destroy_uint8(table)
 * 
 *     return result_keys.to_array(), result_counts.base             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_12 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector *)__pyx_v_result_keys->__pyx_vtab)->to_array(__pyx_v_result_keys, 0)); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 1424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_result_counts, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int64_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int64_t, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_base); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 1424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1424, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_12);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_12)) __PYX_ERR(5, 1424, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_10);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_10)) __PYX_ERR(5, 1424, __pyx_L1_error);
  __pyx_t_12 = 0;
  __pyx_t_10 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1368
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_uint8(const uint8_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_13, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count_uint8", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result_keys);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_result_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":1429
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_uint8(const uint8_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_uint8(__Pyx_memviewslice __pyx_v_values, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_uint8 *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__57;
  int __pyx_v_ret;
  __pyx_t_5numpy_uint8_t __pyx_v_value;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  Py_ssize_t __pyx_v_first_na;
  khiter_t __pyx_v_k;
  kh_uint8_t *__pyx_v_table;
  PyArrayObject *__pyx_v_out = 0;
  int __pyx_v_seen_na;
  int __pyx_v_uses_mask;
  int __pyx_v_seen_multiple_na;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_out;
  __Pyx_Buffer __pyx_pybuffer_out;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  khuint_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  size_t __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("duplicated_uint8", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_out.pybuffer.buf = NULL;
  __pyx_pybuffer_out.refcount = 0;
  __pyx_pybuffernd_out.data = NULL;
  __pyx_pybuffernd_out.rcbuffer = &__pyx_pybuffer_out;

  /* "pandas/_libs/hashtable_func_helper.pxi":1431
 * cdef duplicated_uint8(const uint8_t[:] values, object keep='first', const uint8_t[:] mask=None):
 *     cdef:
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         uint8_t value
 *         Py_ssize_t i, n = len(values), first_na = -1
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1433
 *         int ret = 0
 *         uint8_t value
 *         Py_ssize_t i, n = len(values), first_na = -1             # <<<<<<<<<<<<<<
 *         khiter_t k
 *         kh_uint8_t *table = kh_init_uint8()
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;
  __pyx_v_first_na = -1L;

  /* "pandas/_libs/hashtable_func_helper.pxi":1435
 *         Py_ssize_t i, n = len(values), first_na = -1
 *         khiter_t k
 *         kh_uint8_t *table = kh_init_uint8()             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 */
  __pyx_v_table = kh_init_uint8();

  /* "pandas/_libs/hashtable_func_helper.pxi":1436
 *         khiter_t k
 *         kh_uint8_t *table = kh_init_uint8()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')             # <<<<<<<<<<<<<<
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 1436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 1436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 1436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(5, 1436, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 1436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_n_u_bool) < 0) __PYX_ERR(5, 1436, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1436, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 1436, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_out.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 1, __pyx_stack) == -1)) {
      __pyx_v_out = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_out.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(5, 1436, __pyx_L1_error)
    } else {__pyx_pybuffernd_out.diminfo[0].strides = __pyx_pybuffernd_out.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_out.diminfo[0].shape = __pyx_pybuffernd_out.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_out = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1437
 *         kh_uint8_t *table = kh_init_uint8()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint seen_multiple_na = False
 * 
 */
  __pyx_v_seen_na = 0;
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":1438
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_uint8(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 */
  __pyx_v_seen_multiple_na = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1440
 *         bint seen_multiple_na = False
 * 
 *     kh_resize_uint8(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))             # <<<<<<<<<<<<<<
 * 
 *     if keep not in ('last', 'first', False):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = kh_needed_n_buckets(__pyx_v_n);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1440, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_5, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 1440, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(5, 1440, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_8) {
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_2 = __pyx_t_5;
  } else {
    __pyx_t_3 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 1440, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_uint32(__pyx_t_2); if (unlikely((__pyx_t_7 == ((khuint_t)-1)) && PyErr_Occurred())) __PYX_ERR(5, 1440, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  kh_resize_uint8(__pyx_v_table, __pyx_t_7);

  /* "pandas/_libs/hashtable_func_helper.pxi":1442
 *     kh_resize_uint8(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  __Pyx_INCREF(__pyx_v_keep);
  __pyx_t_2 = __pyx_v_keep;
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_last, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1442, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_first, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1442, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, Py_False, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1442, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1442, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_8 = __pyx_t_9;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_9 = __pyx_t_8;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":1443
 * 
 *     if keep not in ('last', 'first', False):
 *         raise ValueError('keep must be either "first", "last" or False')             # <<<<<<<<<<<<<<
 * 
 *     if keep == "last":
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__43, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 1443, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(5, 1443, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":1442
 *     kh_resize_uint8(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1445
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_last, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1445, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":1446
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":1447
 *     if keep == "last":
 *         with nogil:
 *             for i in range(n - 1, -1, -1):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          for (__pyx_t_1 = (__pyx_v_n - 1); __pyx_t_1 > -1L; __pyx_t_1-=1) {
            __pyx_v_i = __pyx_t_1;

            /* "pandas/_libs/hashtable_func_helper.pxi":1448
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L14_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L14_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":1449
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":1450
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1449
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L16;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":1452
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":1453
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = (values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L16:;

              /* "pandas/_libs/hashtable_func_helper.pxi":1448
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L13;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":1455
 *                         seen_na = True
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_uint8(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":1456
 *                 else:
 *                     value = (values[i])
 *                     kh_put_uint8(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 *     elif keep == "first":
 */
              (void)(kh_put_uint8(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":1457
 *                     value = (values[i])
 *                     kh_put_uint8(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 *     elif keep == "first":
 *         with nogil:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L13:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":1446
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L10;
          }
          __pyx_L10:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":1445
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1458
 *                     kh_put_uint8(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_first, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1458, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":1459
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":1460
 *     elif keep == "first":
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_11 = __pyx_t_1;
          for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
            __pyx_v_i = __pyx_t_12;

            /* "pandas/_libs/hashtable_func_helper.pxi":1461
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L23_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L23_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":1462
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":1463
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1462
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L25;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":1465
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":1466
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = (values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L25:;

              /* "pandas/_libs/hashtable_func_helper.pxi":1461
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L22;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":1468
 *                         seen_na = True
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_uint8(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":1469
 *                 else:
 *                     value = (values[i])
 *                     kh_put_uint8(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 * 
 */
              (void)(kh_put_uint8(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":1470
 *                     value = (values[i])
 *                     kh_put_uint8(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 * 
 *     else:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L22:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":1459
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L19;
          }
          __pyx_L19:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":1458
 *                     kh_put_uint8(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1473
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
  /*else*/ {
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":1474
 *     else:
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_11 = __pyx_t_1;
          for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
            __pyx_v_i = __pyx_t_12;

            /* "pandas/_libs/hashtable_func_helper.pxi":1475
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L32_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L32_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":1476
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
              __pyx_t_9 = (!__pyx_v_seen_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":1477
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 *                         first_na = i             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                         out[i] = 0
 */
                __pyx_v_first_na = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":1478
 *                     if not seen_na:
 *                         first_na = i
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 */
                __pyx_v_seen_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1479
 *                         first_na = i
 *                         seen_na = True
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":1476
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":1480
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
              __pyx_t_9 = (!__pyx_v_seen_multiple_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":1481
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                         out[first_na] = 1
 *                         seen_multiple_na = True
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1482
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 *                         out[first_na] = 1             # <<<<<<<<<<<<<<
 *                         seen_multiple_na = True
 *                     else:
 */
                __pyx_t_10 = __pyx_v_first_na;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1483
 *                         out[i] = 1
 *                         out[first_na] = 1
 *                         seen_multiple_na = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = 1
 */
                __pyx_v_seen_multiple_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1480
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":1485
 *                         seen_multiple_na = True
 *                     else:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 * 
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;
              }
              __pyx_L34:;

              /* "pandas/_libs/hashtable_func_helper.pxi":1475
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
              goto __pyx_L31;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":1488
 * 
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_uint8(table, value)
 *                     if k != table.n_buckets:
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":1489
 *                 else:
 *                     value = (values[i])
 *                     k = kh_get_uint8(table, value)             # <<<<<<<<<<<<<<
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 */
              __pyx_v_k = kh_get_uint8(__pyx_v_table, __pyx_v_value);

              /* "pandas/_libs/hashtable_func_helper.pxi":1490
 *                     value = (values[i])
 *                     k = kh_get_uint8(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
              __pyx_t_9 = (__pyx_v_k != __pyx_v_table->n_buckets);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":1491
 *                     k = kh_get_uint8(table, value)
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                     else:
 */
                __pyx_t_13 = (__pyx_v_table->vals[__pyx_v_k]);
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_13, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1492
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                     else:
 *                         k = kh_put_uint8(table, value, &ret)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1490
 *                     value = (values[i])
 *                     k = kh_get_uint8(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
                goto __pyx_L35;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":1494
 *                         out[i] = 1
 *                     else:
 *                         k = kh_put_uint8(table, value, &ret)             # <<<<<<<<<<<<<<
 *                         table.vals[k] = i
 *                         out[i] = 0
 */
              /*else*/ {
                __pyx_v_k = kh_put_uint8(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret));

                /* "pandas/_libs/hashtable_func_helper.pxi":1495
 *                     else:
 *                         k = kh_put_uint8(table, value, &ret)
 *                         table.vals[k] = i             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 * 
 */
                (__pyx_v_table->vals[__pyx_v_k]) = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":1496
 *                         k = kh_put_uint8(table, value, &ret)
 *                         table.vals[k] = i
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_uint8(table)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;
              }
              __pyx_L35:;
            }
            __pyx_L31:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":1473
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L28;
          }
          __pyx_L28:;
        }
    }
  }
  __pyx_L7:;

  /* "pandas/_libs/hashtable_func_helper.pxi":1498
 *                         out[i] = 0
 * 
 *     kh_destroy_uint8(table)             # <<<<<<<<<<<<<<
 *     return out
 * 
 */
  kh_destroy_uint8(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":1499
 * 
 *     kh_destroy_uint8(table)
 *     return out             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_out);
  __pyx_r = ((PyObject *)__pyx_v_out);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1429
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_uint8(const uint8_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated_uint8", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_out);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":1509
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_uint8(const uint8_t[:] arr, const uint8_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_uint8(__Pyx_memviewslice __pyx_v_arr, __Pyx_memviewslice __pyx_v_values) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  PyArrayObject *__pyx_v_result = 0;
  __pyx_t_5numpy_uint8_t __pyx_v_val;
  kh_uint8_t *__pyx_v_table;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyArrayObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ismember_uint8", 1);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "pandas/_libs/hashtable_func_helper.pxi":1526
 *         Py_ssize_t i, n
 *         khiter_t k
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t] result
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1531
 *         uint8_t val
 * 
 *         kh_uint8_t *table = kh_init_uint8()             # <<<<<<<<<<<<<<
 * 
 *     # construct the table
 */
  __pyx_v_table = kh_init_uint8();

  /* "pandas/_libs/hashtable_func_helper.pxi":1534
 * 
 *     # construct the table
 *     n = len(values)             # <<<<<<<<<<<<<<
 *     kh_resize_uint8(table, n)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":1535
 *     # construct the table
 *     n = len(values)
 *     kh_resize_uint8(table, n)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  kh_resize_uint8(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":1537
 *     kh_resize_uint8(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":1538
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = (values[i])
 *             kh_put_uint8(table, val, &ret)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":1539
 *     with nogil:
 *         for i in range(n):
 *             val = (values[i])             # <<<<<<<<<<<<<<
 *             kh_put_uint8(table, val, &ret)
 * 
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_4 * __pyx_v_values.strides[0]) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":1540
 *         for i in range(n):
 *             val = (values[i])
 *             kh_put_uint8(table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *     # test membership
 */
          (void)(kh_put_uint8(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret)));
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":1537
 *     kh_resize_uint8(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1543
 * 
 *     # test membership
 *     n = len(arr)             # <<<<<<<<<<<<<<
 *     result = np.empty(n, dtype=np.uint8)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_arr); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":1544
 *     # test membership
 *     n = len(arr)
 *     result = np.empty(n, dtype=np.uint8)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_empty); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 1544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 1544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5)) __PYX_ERR(5, 1544, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(5, 1544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_uint8); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 1544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dtype, __pyx_t_9) < 0) __PYX_ERR(5, 1544, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, __pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 1544, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (!(likely(((__pyx_t_9) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_9, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 1544, __pyx_L1_error)
  __pyx_t_10 = ((PyArrayObject *)__pyx_t_9);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_11 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_10, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_11 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_13); Py_XDECREF(__pyx_t_14);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __pyx_t_12 = __pyx_t_13 = __pyx_t_14 = 0;
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(5, 1544, __pyx_L1_error)
  }
  __pyx_t_10 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_9);
  __pyx_t_9 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1546
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (arr[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":1547
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = (arr[i])
 *             k = kh_get_uint8(table, val)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":1548
 *     with nogil:
 *         for i in range(n):
 *             val = (arr[i])             # <<<<<<<<<<<<<<
 *             k = kh_get_uint8(table, val)
 *             result[i] = (k != table.n_buckets)
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_arr.data + __pyx_t_4 * __pyx_v_arr.strides[0]) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":1549
 *         for i in range(n):
 *             val = (arr[i])
 *             k = kh_get_uint8(table, val)             # <<<<<<<<<<<<<<
 *             result[i] = (k != table.n_buckets)
 * 
 */
          __pyx_v_k = kh_get_uint8(__pyx_v_table, __pyx_v_val);

          /* "pandas/_libs/hashtable_func_helper.pxi":1550
 *             val = (arr[i])
 *             k = kh_get_uint8(table, val)
 *             result[i] = (k != table.n_buckets)             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_uint8(table)
 */
          __pyx_t_4 = __pyx_v_i;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_result.rcbuffer->pybuffer.buf, __pyx_t_4, __pyx_pybuffernd_result.diminfo[0].strides) = (__pyx_v_k != __pyx_v_table->n_buckets);
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":1546
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (arr[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L10;
        }
        __pyx_L10:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1552
 *             result[i] = (k != table.n_buckets)
 * 
 *     kh_destroy_uint8(table)             # <<<<<<<<<<<<<<
 *     return result.view(np.bool_)
 * 
 */
  kh_destroy_uint8(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":1553
 * 
 *     kh_destroy_uint8(table)
 *     return result.view(np.bool_)             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_result), __pyx_n_s_view); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 1553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_bool_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 1553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_11 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_11 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_6};
    __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_11, 1+__pyx_t_11);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 1553, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_r = __pyx_t_9;
  __pyx_t_9 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1509
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_uint8(const uint8_t[:] arr, const uint8_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember_uint8", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":1562
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_object(ndarray[object] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_object(PyArrayObject *__pyx_v_values, int __pyx_v_dropna, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_object *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__58;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  kh_pymap_t *__pyx_v_table;
  khiter_t __pyx_v_k;
  PyObject *__pyx_v_val = 0;
  int __pyx_v_ret;
  int __pyx_v_uses_mask;
  CYTHON_UNUSED int __pyx_v_isna_entry;
  struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_result_keys = NULL;
  __Pyx_memviewslice __pyx_v_result_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  int __pyx_t_8;
  khiter_t __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  __Pyx_memviewslice __pyx_t_14 = { 0, 0, { 0 }, { 0 }, { 0 } };
  khuint_t __pyx_t_15;
  khuint_t __pyx_t_16;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("value_count_object", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 1562, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":1564
 * cdef value_count_object(ndarray[object] values, bint dropna, const uint8_t[:] mask=None):
 *     cdef:
 *         Py_ssize_t i = 0             # <<<<<<<<<<<<<<
 *         Py_ssize_t n = len(values)
 *         kh_pymap_t *table
 */
  __pyx_v_i = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1565
 *     cdef:
 *         Py_ssize_t i = 0
 *         Py_ssize_t n = len(values)             # <<<<<<<<<<<<<<
 *         kh_pymap_t *table
 * 
 */
  __pyx_t_1 = PyObject_Length(((PyObject *)__pyx_v_values)); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(5, 1565, __pyx_L1_error)
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":1573
 *         object val
 * 
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1574
 * 
 *         int ret = 0
 *         bint uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint isna_entry = False
 * 
 */
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":1575
 *         int ret = 0
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False             # <<<<<<<<<<<<<<
 * 
 *     if uses_mask and not dropna:
 */
  __pyx_v_isna_entry = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1577
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  if (__pyx_v_uses_mask) {
  } else {
    __pyx_t_2 = __pyx_v_uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (!__pyx_v_dropna);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_2)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":1578
 * 
 *     if uses_mask and not dropna:
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")             # <<<<<<<<<<<<<<
 * 
 *     # we track the order in which keys are first seen (GH39009),
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_NotImplementedError, __pyx_tuple__41, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1578, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(5, 1578, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":1577
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1585
 *     #    result_keys remembers the original order of keys
 * 
 *     result_keys = ObjectVector()             # <<<<<<<<<<<<<<
 *     table = kh_init_pymap()
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector)); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1585, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_result_keys = ((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1586
 * 
 *     result_keys = ObjectVector()
 *     table = kh_init_pymap()             # <<<<<<<<<<<<<<
 * 
 *     if uses_mask:
 */
  __pyx_v_table = kh_init_pymap();

  /* "pandas/_libs/hashtable_func_helper.pxi":1588
 *     table = kh_init_pymap()
 * 
 *     if uses_mask:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with object dtype")
 * 
 */
  if (unlikely(__pyx_v_uses_mask)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":1589
 * 
 *     if uses_mask:
 *         raise NotImplementedError("uses_mask not implemented with object dtype")             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_pymap(table, n // 10)
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_NotImplementedError, __pyx_tuple__59, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1589, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(5, 1589, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":1588
 *     table = kh_init_pymap()
 * 
 *     if uses_mask:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with object dtype")
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1591
 *         raise NotImplementedError("uses_mask not implemented with object dtype")
 * 
 *     kh_resize_pymap(table, n // 10)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(n):
 */
  kh_resize_pymap(__pyx_v_table, __Pyx_div_Py_ssize_t(__pyx_v_n, 10));

  /* "pandas/_libs/hashtable_func_helper.pxi":1593
 *     kh_resize_pymap(table, n // 10)
 * 
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         val = values[i]
 *         if not dropna or not checknull(val):
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_5 = __pyx_t_1;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "pandas/_libs/hashtable_func_helper.pxi":1594
 * 
 *     for i in range(n):
 *         val = values[i]             # <<<<<<<<<<<<<<
 *         if not dropna or not checknull(val):
 *             k = kh_get_pymap(table, <PyObject*>val)
 */
    __pyx_t_7 = __pyx_v_i;
    __pyx_t_4 = (PyObject *) *__Pyx_BufPtrStrided1d(PyObject **, __pyx_pybuffernd_values.rcbuffer->pybuffer.buf, __pyx_t_7, __pyx_pybuffernd_values.diminfo[0].strides);
    if (unlikely(__pyx_t_4 == NULL)) __pyx_t_4 = Py_None;
    __Pyx_INCREF((PyObject*)__pyx_t_4);
    __Pyx_XDECREF_SET(__pyx_v_val, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "pandas/_libs/hashtable_func_helper.pxi":1595
 *     for i in range(n):
 *         val = values[i]
 *         if not dropna or not checknull(val):             # <<<<<<<<<<<<<<
 *             k = kh_get_pymap(table, <PyObject*>val)
 *             if k != table.n_buckets:
 */
    __pyx_t_3 = (!__pyx_v_dropna);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L10_bool_binop_done;
    }
    __pyx_t_3 = __pyx_f_6pandas_5_libs_7missing_checknull(__pyx_v_val, 0, NULL); if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 1595, __pyx_L1_error)
    __pyx_t_8 = (!__pyx_t_3);
    __pyx_t_2 = __pyx_t_8;
    __pyx_L10_bool_binop_done:;
    if (__pyx_t_2) {

      /* "pandas/_libs/hashtable_func_helper.pxi":1596
 *         val = values[i]
 *         if not dropna or not checknull(val):
 *             k = kh_get_pymap(table, <PyObject*>val)             # <<<<<<<<<<<<<<
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1
 */
      __pyx_v_k = kh_get_pymap(__pyx_v_table, ((PyObject *)__pyx_v_val));

      /* "pandas/_libs/hashtable_func_helper.pxi":1597
 *         if not dropna or not checknull(val):
 *             k = kh_get_pymap(table, <PyObject*>val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
      __pyx_t_2 = (__pyx_v_k != __pyx_v_table->n_buckets);
      if (__pyx_t_2) {

        /* "pandas/_libs/hashtable_func_helper.pxi":1598
 *             k = kh_get_pymap(table, <PyObject*>val)
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 k = kh_put_pymap(table, <PyObject*>val, &ret)
 */
        __pyx_t_9 = __pyx_v_k;
        (__pyx_v_table->vals[__pyx_t_9]) = ((__pyx_v_table->vals[__pyx_t_9]) + 1);

        /* "pandas/_libs/hashtable_func_helper.pxi":1597
 *         if not dropna or not checknull(val):
 *             k = kh_get_pymap(table, <PyObject*>val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
        goto __pyx_L12;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":1600
 *                 table.vals[k] += 1
 *             else:
 *                 k = kh_put_pymap(table, <PyObject*>val, &ret)             # <<<<<<<<<<<<<<
 *                 table.vals[k] = 1
 *                 result_keys.append(val)
 */
      /*else*/ {
        __pyx_v_k = kh_put_pymap(__pyx_v_table, ((PyObject *)__pyx_v_val), (&__pyx_v_ret));

        /* "pandas/_libs/hashtable_func_helper.pxi":1601
 *             else:
 *                 k = kh_put_pymap(table, <PyObject*>val, &ret)
 *                 table.vals[k] = 1             # <<<<<<<<<<<<<<
 *                 result_keys.append(val)
 * 
 */
        (__pyx_v_table->vals[__pyx_v_k]) = 1;

        /* "pandas/_libs/hashtable_func_helper.pxi":1602
 *                 k = kh_put_pymap(table, <PyObject*>val, &ret)
 *                 table.vals[k] = 1
 *                 result_keys.append(val)             # <<<<<<<<<<<<<<
 * 
 *     # collect counts in the order corresponding to result_keys:
 */
        __pyx_t_4 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_v_result_keys->__pyx_vtab)->append(__pyx_v_result_keys, __pyx_v_val); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1602, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_L12:;

      /* "pandas/_libs/hashtable_func_helper.pxi":1595
 *     for i in range(n):
 *         val = values[i]
 *         if not dropna or not checknull(val):             # <<<<<<<<<<<<<<
 *             k = kh_get_pymap(table, <PyObject*>val)
 *             if k != table.n_buckets:
 */
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1606
 *     # collect counts in the order corresponding to result_keys:
 *     cdef:
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(table.size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_empty); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 1606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_v_table->size); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_11 = PyTuple_New(1); if (unlikely(!__pyx_t_11)) __PYX_ERR(5, 1606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_11, 0, __pyx_t_4)) __PYX_ERR(5, 1606, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_12, __pyx_n_s_np); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 1606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_13 = __Pyx_PyObject_GetAttrStr(__pyx_t_12, __pyx_n_s_int64); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 1606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_dtype, __pyx_t_13) < 0) __PYX_ERR(5, 1606, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyObject_Call(__pyx_t_10, __pyx_t_11, __pyx_t_4); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 1606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_14 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_13, PyBUF_WRITABLE); if (unlikely(!__pyx_t_14.memview)) __PYX_ERR(5, 1606, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_v_result_counts = __pyx_t_14;
  __pyx_t_14.memview = NULL;
  __pyx_t_14.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":1608
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)
 * 
 *     for i in range(table.size):             # <<<<<<<<<<<<<<
 *         k = kh_get_pymap(table, result_keys.data[i])
 *         result_counts[i] = table.vals[k]
 */
  __pyx_t_15 = __pyx_v_table->size;
  __pyx_t_16 = __pyx_t_15;
  for (__pyx_t_1 = 0; __pyx_t_1 < __pyx_t_16; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "pandas/_libs/hashtable_func_helper.pxi":1609
 * 
 *     for i in range(table.size):
 *         k = kh_get_pymap(table, result_keys.data[i])             # <<<<<<<<<<<<<<
 *         result_counts[i] = table.vals[k]
 * 
 */
    __pyx_v_k = kh_get_pymap(__pyx_v_table, (__pyx_v_result_keys->data[__pyx_v_i]));

    /* "pandas/_libs/hashtable_func_helper.pxi":1610
 *     for i in range(table.size):
 *         k = kh_get_pymap(table, result_keys.data[i])
 *         result_counts[i] = table.vals[k]             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_pymap(table)
 */
    __pyx_t_7 = __pyx_v_i;
    *((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_result_counts.data) + __pyx_t_7)) )) = (__pyx_v_table->vals[__pyx_v_k]);
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1612
 *         result_counts[i] = table.vals[k]
 * 
 *     kh_destroy_pymap(table)             # <<<<<<<<<<<<<<
 * 
 *     return result_keys.to_array(), result_counts.base
 */
  kh_destroy_pymap(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":1614
 *     kh_destroy_pymap(table)
 * 
 *     return result_keys.to_array(), result_counts.base             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_13 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_v_result_keys->__pyx_vtab)->to_array(__pyx_v_result_keys, 0)); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 1614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_result_counts, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int64_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int64_t, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_11 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_base); if (unlikely(!__pyx_t_11)) __PYX_ERR(5, 1614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1614, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_13);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_13)) __PYX_ERR(5, 1614, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_11);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_11)) __PYX_ERR(5, 1614, __pyx_L1_error);
  __pyx_t_13 = 0;
  __pyx_t_11 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1562
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_object(ndarray[object] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_14, 1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF(__pyx_v_val);
  __Pyx_XDECREF((PyObject *)__pyx_v_result_keys);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_result_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":1619
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_object(ndarray[object] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_object(PyArrayObject *__pyx_v_values, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_object *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__60;
  int __pyx_v_ret;
  PyObject *__pyx_v_value;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  Py_ssize_t __pyx_v_first_na;
  khiter_t __pyx_v_k;
  kh_pymap_t *__pyx_v_table;
  PyArrayObject *__pyx_v_out = 0;
  int __pyx_v_seen_na;
  int __pyx_v_uses_mask;
  int __pyx_v_seen_multiple_na;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_out;
  __Pyx_Buffer __pyx_pybuffer_out;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  khuint_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  size_t __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("duplicated_object", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_out.pybuffer.buf = NULL;
  __pyx_pybuffer_out.refcount = 0;
  __pyx_pybuffernd_out.data = NULL;
  __pyx_pybuffernd_out.rcbuffer = &__pyx_pybuffer_out;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 1619, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":1621
 * cdef duplicated_object(ndarray[object] values, object keep='first', const uint8_t[:] mask=None):
 *     cdef:
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         PyObject* value
 *         Py_ssize_t i, n = len(values), first_na = -1
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1623
 *         int ret = 0
 *         PyObject* value
 *         Py_ssize_t i, n = len(values), first_na = -1             # <<<<<<<<<<<<<<
 *         khiter_t k
 *         kh_pymap_t *table = kh_init_pymap()
 */
  __pyx_t_1 = PyObject_Length(((PyObject *)__pyx_v_values)); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(5, 1623, __pyx_L1_error)
  __pyx_v_n = __pyx_t_1;
  __pyx_v_first_na = -1L;

  /* "pandas/_libs/hashtable_func_helper.pxi":1625
 *         Py_ssize_t i, n = len(values), first_na = -1
 *         khiter_t k
 *         kh_pymap_t *table = kh_init_pymap()             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 */
  __pyx_v_table = kh_init_pymap();

  /* "pandas/_libs/hashtable_func_helper.pxi":1626
 *         khiter_t k
 *         kh_pymap_t *table = kh_init_pymap()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')             # <<<<<<<<<<<<<<
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 1626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 1626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 1626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(5, 1626, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 1626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_n_u_bool) < 0) __PYX_ERR(5, 1626, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1626, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 1626, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_out.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 1, __pyx_stack) == -1)) {
      __pyx_v_out = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_out.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(5, 1626, __pyx_L1_error)
    } else {__pyx_pybuffernd_out.diminfo[0].strides = __pyx_pybuffernd_out.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_out.diminfo[0].shape = __pyx_pybuffernd_out.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_out = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1627
 *         kh_pymap_t *table = kh_init_pymap()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint seen_multiple_na = False
 * 
 */
  __pyx_v_seen_na = 0;
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":1628
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_pymap(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 */
  __pyx_v_seen_multiple_na = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1630
 *         bint seen_multiple_na = False
 * 
 *     kh_resize_pymap(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))             # <<<<<<<<<<<<<<
 * 
 *     if keep not in ('last', 'first', False):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = kh_needed_n_buckets(__pyx_v_n);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1630, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_5, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 1630, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(5, 1630, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_8) {
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_2 = __pyx_t_5;
  } else {
    __pyx_t_3 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 1630, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_uint32(__pyx_t_2); if (unlikely((__pyx_t_7 == ((khuint_t)-1)) && PyErr_Occurred())) __PYX_ERR(5, 1630, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  kh_resize_pymap(__pyx_v_table, __pyx_t_7);

  /* "pandas/_libs/hashtable_func_helper.pxi":1632
 *     kh_resize_pymap(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  __Pyx_INCREF(__pyx_v_keep);
  __pyx_t_2 = __pyx_v_keep;
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_last, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1632, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_first, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1632, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, Py_False, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1632, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1632, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_8 = __pyx_t_9;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_9 = __pyx_t_8;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":1633
 * 
 *     if keep not in ('last', 'first', False):
 *         raise ValueError('keep must be either "first", "last" or False')             # <<<<<<<<<<<<<<
 * 
 *     if keep == "last":
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__43, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 1633, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(5, 1633, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":1632
 *     kh_resize_pymap(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1635
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         if True:
 *             for i in range(n - 1, -1, -1):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_last, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1635, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":1637
 *     if keep == "last":
 *         if True:
 *             for i in range(n - 1, -1, -1):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
    for (__pyx_t_1 = (__pyx_v_n - 1); __pyx_t_1 > -1L; __pyx_t_1-=1) {
      __pyx_v_i = __pyx_t_1;

      /* "pandas/_libs/hashtable_func_helper.pxi":1638
 *         if True:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
      if (__pyx_v_uses_mask) {
      } else {
        __pyx_t_9 = __pyx_v_uses_mask;
        goto __pyx_L11_bool_binop_done;
      }
      __pyx_t_10 = __pyx_v_i;
      __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
      __pyx_t_9 = __pyx_t_8;
      __pyx_L11_bool_binop_done:;
      if (__pyx_t_9) {

        /* "pandas/_libs/hashtable_func_helper.pxi":1639
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
        if (__pyx_v_seen_na) {

          /* "pandas/_libs/hashtable_func_helper.pxi":1640
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
          __pyx_t_10 = __pyx_v_i;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

          /* "pandas/_libs/hashtable_func_helper.pxi":1639
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
          goto __pyx_L13;
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":1642
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
        /*else*/ {
          __pyx_t_10 = __pyx_v_i;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

          /* "pandas/_libs/hashtable_func_helper.pxi":1643
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = <PyObject*>(values[i])
 */
          __pyx_v_seen_na = 1;
        }
        __pyx_L13:;

        /* "pandas/_libs/hashtable_func_helper.pxi":1638
 *         if True:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
        goto __pyx_L10;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":1645
 *                         seen_na = True
 *                 else:
 *                     value = <PyObject*>(values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_pymap(table, value, &ret)
 *                     out[i] = ret == 0
 */
      /*else*/ {
        __pyx_t_10 = __pyx_v_i;
        __pyx_t_2 = (PyObject *) *__Pyx_BufPtrStrided1d(PyObject **, __pyx_pybuffernd_values.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_values.diminfo[0].strides);
        if (unlikely(__pyx_t_2 == NULL)) __pyx_t_2 = Py_None;
        __Pyx_INCREF((PyObject*)__pyx_t_2);
        __pyx_v_value = ((PyObject *)__pyx_t_2);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "pandas/_libs/hashtable_func_helper.pxi":1646
 *                 else:
 *                     value = <PyObject*>(values[i])
 *                     kh_put_pymap(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 *     elif keep == "first":
 */
        (void)(kh_put_pymap(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

        /* "pandas/_libs/hashtable_func_helper.pxi":1647
 *                     value = <PyObject*>(values[i])
 *                     kh_put_pymap(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 *     elif keep == "first":
 *         if True:
 */
        __pyx_t_10 = __pyx_v_i;
        *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
      }
      __pyx_L10:;
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":1635
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         if True:
 *             for i in range(n - 1, -1, -1):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1648
 *                     kh_put_pymap(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         if True:
 *             for i in range(n):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_first, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1648, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":1650
 *     elif keep == "first":
 *         if True:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
    __pyx_t_1 = __pyx_v_n;
    __pyx_t_11 = __pyx_t_1;
    for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
      __pyx_v_i = __pyx_t_12;

      /* "pandas/_libs/hashtable_func_helper.pxi":1651
 *         if True:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
      if (__pyx_v_uses_mask) {
      } else {
        __pyx_t_9 = __pyx_v_uses_mask;
        goto __pyx_L17_bool_binop_done;
      }
      __pyx_t_10 = __pyx_v_i;
      __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
      __pyx_t_9 = __pyx_t_8;
      __pyx_L17_bool_binop_done:;
      if (__pyx_t_9) {

        /* "pandas/_libs/hashtable_func_helper.pxi":1652
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
        if (__pyx_v_seen_na) {

          /* "pandas/_libs/hashtable_func_helper.pxi":1653
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
          __pyx_t_10 = __pyx_v_i;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

          /* "pandas/_libs/hashtable_func_helper.pxi":1652
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
          goto __pyx_L19;
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":1655
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
        /*else*/ {
          __pyx_t_10 = __pyx_v_i;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

          /* "pandas/_libs/hashtable_func_helper.pxi":1656
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = <PyObject*>(values[i])
 */
          __pyx_v_seen_na = 1;
        }
        __pyx_L19:;

        /* "pandas/_libs/hashtable_func_helper.pxi":1651
 *         if True:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
        goto __pyx_L16;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":1658
 *                         seen_na = True
 *                 else:
 *                     value = <PyObject*>(values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_pymap(table, value, &ret)
 *                     out[i] = ret == 0
 */
      /*else*/ {
        __pyx_t_10 = __pyx_v_i;
        __pyx_t_2 = (PyObject *) *__Pyx_BufPtrStrided1d(PyObject **, __pyx_pybuffernd_values.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_values.diminfo[0].strides);
        if (unlikely(__pyx_t_2 == NULL)) __pyx_t_2 = Py_None;
        __Pyx_INCREF((PyObject*)__pyx_t_2);
        __pyx_v_value = ((PyObject *)__pyx_t_2);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "pandas/_libs/hashtable_func_helper.pxi":1659
 *                 else:
 *                     value = <PyObject*>(values[i])
 *                     kh_put_pymap(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 * 
 */
        (void)(kh_put_pymap(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

        /* "pandas/_libs/hashtable_func_helper.pxi":1660
 *                     value = <PyObject*>(values[i])
 *                     kh_put_pymap(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 * 
 *     else:
 */
        __pyx_t_10 = __pyx_v_i;
        *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
      }
      __pyx_L16:;
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":1648
 *                     kh_put_pymap(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         if True:
 *             for i in range(n):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1663
 * 
 *     else:
 *         if True:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
  /*else*/ {

    /* "pandas/_libs/hashtable_func_helper.pxi":1664
 *     else:
 *         if True:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 */
    __pyx_t_1 = __pyx_v_n;
    __pyx_t_11 = __pyx_t_1;
    for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
      __pyx_v_i = __pyx_t_12;

      /* "pandas/_libs/hashtable_func_helper.pxi":1665
 *         if True:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
      if (__pyx_v_uses_mask) {
      } else {
        __pyx_t_9 = __pyx_v_uses_mask;
        goto __pyx_L23_bool_binop_done;
      }
      __pyx_t_10 = __pyx_v_i;
      __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
      __pyx_t_9 = __pyx_t_8;
      __pyx_L23_bool_binop_done:;
      if (__pyx_t_9) {

        /* "pandas/_libs/hashtable_func_helper.pxi":1666
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
        __pyx_t_9 = (!__pyx_v_seen_na);
        if (__pyx_t_9) {

          /* "pandas/_libs/hashtable_func_helper.pxi":1667
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 *                         first_na = i             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                         out[i] = 0
 */
          __pyx_v_first_na = __pyx_v_i;

          /* "pandas/_libs/hashtable_func_helper.pxi":1668
 *                     if not seen_na:
 *                         first_na = i
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 */
          __pyx_v_seen_na = 1;

          /* "pandas/_libs/hashtable_func_helper.pxi":1669
 *                         first_na = i
 *                         seen_na = True
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 */
          __pyx_t_10 = __pyx_v_i;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

          /* "pandas/_libs/hashtable_func_helper.pxi":1666
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
          goto __pyx_L25;
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":1670
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
        __pyx_t_9 = (!__pyx_v_seen_multiple_na);
        if (__pyx_t_9) {

          /* "pandas/_libs/hashtable_func_helper.pxi":1671
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                         out[first_na] = 1
 *                         seen_multiple_na = True
 */
          __pyx_t_10 = __pyx_v_i;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

          /* "pandas/_libs/hashtable_func_helper.pxi":1672
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 *                         out[first_na] = 1             # <<<<<<<<<<<<<<
 *                         seen_multiple_na = True
 *                     else:
 */
          __pyx_t_10 = __pyx_v_first_na;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

          /* "pandas/_libs/hashtable_func_helper.pxi":1673
 *                         out[i] = 1
 *                         out[first_na] = 1
 *                         seen_multiple_na = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = 1
 */
          __pyx_v_seen_multiple_na = 1;

          /* "pandas/_libs/hashtable_func_helper.pxi":1670
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
          goto __pyx_L25;
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":1675
 *                         seen_multiple_na = True
 *                     else:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 * 
 *                 else:
 */
        /*else*/ {
          __pyx_t_10 = __pyx_v_i;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;
        }
        __pyx_L25:;

        /* "pandas/_libs/hashtable_func_helper.pxi":1665
 *         if True:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
        goto __pyx_L22;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":1678
 * 
 *                 else:
 *                     value = <PyObject*>(values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_pymap(table, value)
 *                     if k != table.n_buckets:
 */
      /*else*/ {
        __pyx_t_10 = __pyx_v_i;
        __pyx_t_2 = (PyObject *) *__Pyx_BufPtrStrided1d(PyObject **, __pyx_pybuffernd_values.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_values.diminfo[0].strides);
        if (unlikely(__pyx_t_2 == NULL)) __pyx_t_2 = Py_None;
        __Pyx_INCREF((PyObject*)__pyx_t_2);
        __pyx_v_value = ((PyObject *)__pyx_t_2);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

        /* "pandas/_libs/hashtable_func_helper.pxi":1679
 *                 else:
 *                     value = <PyObject*>(values[i])
 *                     k = kh_get_pymap(table, value)             # <<<<<<<<<<<<<<
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 */
        __pyx_v_k = kh_get_pymap(__pyx_v_table, __pyx_v_value);

        /* "pandas/_libs/hashtable_func_helper.pxi":1680
 *                     value = <PyObject*>(values[i])
 *                     k = kh_get_pymap(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
        __pyx_t_9 = (__pyx_v_k != __pyx_v_table->n_buckets);
        if (__pyx_t_9) {

          /* "pandas/_libs/hashtable_func_helper.pxi":1681
 *                     k = kh_get_pymap(table, value)
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                     else:
 */
          __pyx_t_13 = (__pyx_v_table->vals[__pyx_v_k]);
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_13, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

          /* "pandas/_libs/hashtable_func_helper.pxi":1682
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                     else:
 *                         k = kh_put_pymap(table, value, &ret)
 */
          __pyx_t_10 = __pyx_v_i;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

          /* "pandas/_libs/hashtable_func_helper.pxi":1680
 *                     value = <PyObject*>(values[i])
 *                     k = kh_get_pymap(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
          goto __pyx_L26;
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":1684
 *                         out[i] = 1
 *                     else:
 *                         k = kh_put_pymap(table, value, &ret)             # <<<<<<<<<<<<<<
 *                         table.vals[k] = i
 *                         out[i] = 0
 */
        /*else*/ {
          __pyx_v_k = kh_put_pymap(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret));

          /* "pandas/_libs/hashtable_func_helper.pxi":1685
 *                     else:
 *                         k = kh_put_pymap(table, value, &ret)
 *                         table.vals[k] = i             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 * 
 */
          (__pyx_v_table->vals[__pyx_v_k]) = __pyx_v_i;

          /* "pandas/_libs/hashtable_func_helper.pxi":1686
 *                         k = kh_put_pymap(table, value, &ret)
 *                         table.vals[k] = i
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_pymap(table)
 */
          __pyx_t_10 = __pyx_v_i;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;
        }
        __pyx_L26:;
      }
      __pyx_L22:;
    }
  }
  __pyx_L7:;

  /* "pandas/_libs/hashtable_func_helper.pxi":1688
 *                         out[i] = 0
 * 
 *     kh_destroy_pymap(table)             # <<<<<<<<<<<<<<
 *     return out
 * 
 */
  kh_destroy_pymap(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":1689
 * 
 *     kh_destroy_pymap(table)
 *     return out             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_out);
  __pyx_r = ((PyObject *)__pyx_v_out);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1619
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_object(ndarray[object] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_out);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":1699
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_object(ndarray[object] arr, ndarray[object] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_object(PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  PyArrayObject *__pyx_v_result = 0;
  PyObject *__pyx_v_val;
  kh_pymap_t *__pyx_v_table;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyArrayObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ismember_object", 1);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 1699, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 1699, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":1716
 *         Py_ssize_t i, n
 *         khiter_t k
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t] result
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1721
 *         PyObject* val
 * 
 *         kh_pymap_t *table = kh_init_pymap()             # <<<<<<<<<<<<<<
 * 
 *     # construct the table
 */
  __pyx_v_table = kh_init_pymap();

  /* "pandas/_libs/hashtable_func_helper.pxi":1724
 * 
 *     # construct the table
 *     n = len(values)             # <<<<<<<<<<<<<<
 *     kh_resize_pymap(table, n)
 * 
 */
  __pyx_t_1 = PyObject_Length(((PyObject *)__pyx_v_values)); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(5, 1724, __pyx_L1_error)
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":1725
 *     # construct the table
 *     n = len(values)
 *     kh_resize_pymap(table, n)             # <<<<<<<<<<<<<<
 * 
 *     if True:
 */
  kh_resize_pymap(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":1728
 * 
 *     if True:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = <PyObject*>(values[i])
 *             kh_put_pymap(table, val, &ret)
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "pandas/_libs/hashtable_func_helper.pxi":1729
 *     if True:
 *         for i in range(n):
 *             val = <PyObject*>(values[i])             # <<<<<<<<<<<<<<
 *             kh_put_pymap(table, val, &ret)
 * 
 */
    __pyx_t_5 = __pyx_v_i;
    __pyx_t_4 = (PyObject *) *__Pyx_BufPtrStrided1d(PyObject **, __pyx_pybuffernd_values.rcbuffer->pybuffer.buf, __pyx_t_5, __pyx_pybuffernd_values.diminfo[0].strides);
    if (unlikely(__pyx_t_4 == NULL)) __pyx_t_4 = Py_None;
    __Pyx_INCREF((PyObject*)__pyx_t_4);
    __pyx_v_val = ((PyObject *)__pyx_t_4);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pandas/_libs/hashtable_func_helper.pxi":1730
 *         for i in range(n):
 *             val = <PyObject*>(values[i])
 *             kh_put_pymap(table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *     # test membership
 */
    (void)(kh_put_pymap(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret)));
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1733
 * 
 *     # test membership
 *     n = len(arr)             # <<<<<<<<<<<<<<
 *     result = np.empty(n, dtype=np.uint8)
 * 
 */
  __pyx_t_1 = PyObject_Length(((PyObject *)__pyx_v_arr)); if (unlikely(__pyx_t_1 == ((Py_ssize_t)-1))) __PYX_ERR(5, 1733, __pyx_L1_error)
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":1734
 *     # test membership
 *     n = len(arr)
 *     result = np.empty(n, dtype=np.uint8)             # <<<<<<<<<<<<<<
 * 
 *     if True:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_empty); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 1734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 1734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_4)) __PYX_ERR(5, 1734, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(5, 1734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_uint8); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 1734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_dtype, __pyx_t_9) < 0) __PYX_ERR(5, 1734, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, __pyx_t_4); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 1734, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (!(likely(((__pyx_t_9) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_9, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 1734, __pyx_L1_error)
  __pyx_t_10 = ((PyArrayObject *)__pyx_t_9);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_11 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_10, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_11 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_13); Py_XDECREF(__pyx_t_14);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __pyx_t_12 = __pyx_t_13 = __pyx_t_14 = 0;
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(5, 1734, __pyx_L1_error)
  }
  __pyx_t_10 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_9);
  __pyx_t_9 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1737
 * 
 *     if True:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = <PyObject*>(arr[i])
 *             k = kh_get_pymap(table, val)
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_2 = __pyx_t_1;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "pandas/_libs/hashtable_func_helper.pxi":1738
 *     if True:
 *         for i in range(n):
 *             val = <PyObject*>(arr[i])             # <<<<<<<<<<<<<<
 *             k = kh_get_pymap(table, val)
 *             result[i] = (k != table.n_buckets)
 */
    __pyx_t_5 = __pyx_v_i;
    __pyx_t_9 = (PyObject *) *__Pyx_BufPtrStrided1d(PyObject **, __pyx_pybuffernd_arr.rcbuffer->pybuffer.buf, __pyx_t_5, __pyx_pybuffernd_arr.diminfo[0].strides);
    if (unlikely(__pyx_t_9 == NULL)) __pyx_t_9 = Py_None;
    __Pyx_INCREF((PyObject*)__pyx_t_9);
    __pyx_v_val = ((PyObject *)__pyx_t_9);
    __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;

    /* "pandas/_libs/hashtable_func_helper.pxi":1739
 *         for i in range(n):
 *             val = <PyObject*>(arr[i])
 *             k = kh_get_pymap(table, val)             # <<<<<<<<<<<<<<
 *             result[i] = (k != table.n_buckets)
 * 
 */
    __pyx_v_k = kh_get_pymap(__pyx_v_table, __pyx_v_val);

    /* "pandas/_libs/hashtable_func_helper.pxi":1740
 *             val = <PyObject*>(arr[i])
 *             k = kh_get_pymap(table, val)
 *             result[i] = (k != table.n_buckets)             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_pymap(table)
 */
    __pyx_t_5 = __pyx_v_i;
    *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_result.rcbuffer->pybuffer.buf, __pyx_t_5, __pyx_pybuffernd_result.diminfo[0].strides) = (__pyx_v_k != __pyx_v_table->n_buckets);
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1742
 *             result[i] = (k != table.n_buckets)
 * 
 *     kh_destroy_pymap(table)             # <<<<<<<<<<<<<<
 *     return result.view(np.bool_)
 * 
 */
  kh_destroy_pymap(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":1743
 * 
 *     kh_destroy_pymap(table)
 *     return result.view(np.bool_)             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_result), __pyx_n_s_view); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 1743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_bool_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 1743, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_11 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
      __pyx_t_11 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_6};
    __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_4, __pyx_callargs+1-__pyx_t_11, 1+__pyx_t_11);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 1743, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_r = __pyx_t_9;
  __pyx_t_9 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1699
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_object(ndarray[object] arr, ndarray[object] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember_object", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":1752
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_int64(const int64_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_int64(__Pyx_memviewslice __pyx_v_values, int __pyx_v_dropna, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_int64 *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__61;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  kh_int64_t *__pyx_v_table;
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int64_t __pyx_v_val;
  int __pyx_v_ret;
  int __pyx_v_uses_mask;
  int __pyx_v_isna_entry;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_result_keys = NULL;
  __Pyx_memviewslice __pyx_v_result_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  khiter_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  khuint_t __pyx_t_14;
  khuint_t __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("value_count_int64", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1754
 * cdef value_count_int64(const int64_t[:] values, bint dropna, const uint8_t[:] mask=None):
 *     cdef:
 *         Py_ssize_t i = 0             # <<<<<<<<<<<<<<
 *         Py_ssize_t n = len(values)
 *         kh_int64_t *table
 */
  __pyx_v_i = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1755
 *     cdef:
 *         Py_ssize_t i = 0
 *         Py_ssize_t n = len(values)             # <<<<<<<<<<<<<<
 *         kh_int64_t *table
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":1763
 *         int64_t val
 * 
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1764
 * 
 *         int ret = 0
 *         bint uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint isna_entry = False
 * 
 */
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":1765
 *         int ret = 0
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False             # <<<<<<<<<<<<<<
 * 
 *     if uses_mask and not dropna:
 */
  __pyx_v_isna_entry = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1767
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  if (__pyx_v_uses_mask) {
  } else {
    __pyx_t_2 = __pyx_v_uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (!__pyx_v_dropna);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_2)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":1768
 * 
 *     if uses_mask and not dropna:
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")             # <<<<<<<<<<<<<<
 * 
 *     # we track the order in which keys are first seen (GH39009),
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_NotImplementedError, __pyx_tuple__41, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1768, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(5, 1768, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":1767
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1775
 *     #    result_keys remembers the original order of keys
 * 
 *     result_keys = Int64Vector()             # <<<<<<<<<<<<<<
 *     table = kh_init_int64()
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector)); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1775, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_result_keys = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1776
 * 
 *     result_keys = Int64Vector()
 *     table = kh_init_int64()             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_int64(table, n)
 */
  __pyx_v_table = kh_init_int64();

  /* "pandas/_libs/hashtable_func_helper.pxi":1778
 *     table = kh_init_int64()
 * 
 *     kh_resize_int64(table, n)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(n):
 */
  kh_resize_int64(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":1780
 *     kh_resize_int64(table, n)
 * 
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         val = (values[i])
 * 
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_5 = __pyx_t_1;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "pandas/_libs/hashtable_func_helper.pxi":1781
 * 
 *     for i in range(n):
 *         val = (values[i])             # <<<<<<<<<<<<<<
 * 
 *         if dropna:
 */
    __pyx_t_7 = __pyx_v_i;
    __pyx_v_val = (*((__pyx_t_5numpy_int64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

    /* "pandas/_libs/hashtable_func_helper.pxi":1783
 *         val = (values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    if (__pyx_v_dropna) {

      /* "pandas/_libs/hashtable_func_helper.pxi":1784
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
      if (__pyx_v_uses_mask) {

        /* "pandas/_libs/hashtable_func_helper.pxi":1785
 *         if dropna:
 *             if uses_mask:
 *                 isna_entry = mask[i]             # <<<<<<<<<<<<<<
 *             else:
 *                 isna_entry = is_nan_int64_t(val)
 */
        __pyx_t_7 = __pyx_v_i;
        __pyx_v_isna_entry = (*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) )));

        /* "pandas/_libs/hashtable_func_helper.pxi":1784
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
        goto __pyx_L9;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":1787
 *                 isna_entry = mask[i]
 *             else:
 *                 isna_entry = is_nan_int64_t(val)             # <<<<<<<<<<<<<<
 * 
 *         if not dropna or not isna_entry:
 */
      /*else*/ {
        __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_int64_t(__pyx_v_val); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 1787, __pyx_L1_error)
        __pyx_v_isna_entry = __pyx_t_2;
      }
      __pyx_L9:;

      /* "pandas/_libs/hashtable_func_helper.pxi":1783
 *         val = (values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":1789
 *                 isna_entry = is_nan_int64_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_int64(table, val)
 *             if k != table.n_buckets:
 */
    __pyx_t_3 = (!__pyx_v_dropna);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L11_bool_binop_done;
    }
    __pyx_t_3 = (!__pyx_v_isna_entry);
    __pyx_t_2 = __pyx_t_3;
    __pyx_L11_bool_binop_done:;
    if (__pyx_t_2) {

      /* "pandas/_libs/hashtable_func_helper.pxi":1790
 * 
 *         if not dropna or not isna_entry:
 *             k = kh_get_int64(table, val)             # <<<<<<<<<<<<<<
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1
 */
      __pyx_v_k = kh_get_int64(__pyx_v_table, __pyx_v_val);

      /* "pandas/_libs/hashtable_func_helper.pxi":1791
 *         if not dropna or not isna_entry:
 *             k = kh_get_int64(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
      __pyx_t_2 = (__pyx_v_k != __pyx_v_table->n_buckets);
      if (__pyx_t_2) {

        /* "pandas/_libs/hashtable_func_helper.pxi":1792
 *             k = kh_get_int64(table, val)
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 k = kh_put_int64(table, val, &ret)
 */
        __pyx_t_8 = __pyx_v_k;
        (__pyx_v_table->vals[__pyx_t_8]) = ((__pyx_v_table->vals[__pyx_t_8]) + 1);

        /* "pandas/_libs/hashtable_func_helper.pxi":1791
 *         if not dropna or not isna_entry:
 *             k = kh_get_int64(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
        goto __pyx_L13;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":1794
 *                 table.vals[k] += 1
 *             else:
 *                 k = kh_put_int64(table, val, &ret)             # <<<<<<<<<<<<<<
 *                 table.vals[k] = 1
 *                 result_keys.append(val)
 */
      /*else*/ {
        __pyx_v_k = kh_put_int64(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret));

        /* "pandas/_libs/hashtable_func_helper.pxi":1795
 *             else:
 *                 k = kh_put_int64(table, val, &ret)
 *                 table.vals[k] = 1             # <<<<<<<<<<<<<<
 *                 result_keys.append(val)
 * 
 */
        (__pyx_v_table->vals[__pyx_v_k]) = 1;

        /* "pandas/_libs/hashtable_func_helper.pxi":1796
 *                 k = kh_put_int64(table, val, &ret)
 *                 table.vals[k] = 1
 *                 result_keys.append(val)             # <<<<<<<<<<<<<<
 * 
 *     # collect counts in the order corresponding to result_keys:
 */
        ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_v_result_keys->__pyx_vtab)->append(__pyx_v_result_keys, __pyx_v_val); if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 1796, __pyx_L1_error)
      }
      __pyx_L13:;

      /* "pandas/_libs/hashtable_func_helper.pxi":1789
 *                 isna_entry = is_nan_int64_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_int64(table, val)
 *             if k != table.n_buckets:
 */
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1800
 *     # collect counts in the order corresponding to result_keys:
 *     cdef:
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(table.size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_empty); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 1800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_v_table->size); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 1800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_4)) __PYX_ERR(5, 1800, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_np); if (unlikely(!__pyx_t_11)) __PYX_ERR(5, 1800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_int64); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 1800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_dtype, __pyx_t_12) < 0) __PYX_ERR(5, 1800, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_10, __pyx_t_4); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 1800, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_12, PyBUF_WRITABLE); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(5, 1800, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_v_result_counts = __pyx_t_13;
  __pyx_t_13.memview = NULL;
  __pyx_t_13.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":1802
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)
 * 
 *     for i in range(table.size):             # <<<<<<<<<<<<<<
 *         k = kh_get_int64(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]
 */
  __pyx_t_14 = __pyx_v_table->size;
  __pyx_t_15 = __pyx_t_14;
  for (__pyx_t_1 = 0; __pyx_t_1 < __pyx_t_15; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "pandas/_libs/hashtable_func_helper.pxi":1803
 * 
 *     for i in range(table.size):
 *         k = kh_get_int64(table, result_keys.data.data[i])             # <<<<<<<<<<<<<<
 *         result_counts[i] = table.vals[k]
 * 
 */
    __pyx_v_k = kh_get_int64(__pyx_v_table, (__pyx_v_result_keys->data->data[__pyx_v_i]));

    /* "pandas/_libs/hashtable_func_helper.pxi":1804
 *     for i in range(table.size):
 *         k = kh_get_int64(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_int64(table)
 */
    __pyx_t_7 = __pyx_v_i;
    *((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_result_counts.data) + __pyx_t_7)) )) = (__pyx_v_table->vals[__pyx_v_k]);
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1806
 *         result_counts[i] = table.vals[k]
 * 
 *     kh_destroy_int64(table)             # <<<<<<<<<<<<<<
 * 
 *     return result_keys.to_array(), result_counts.base
 */
  kh_destroy_int64(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":1808
 *     kh_destroy_int64(table)
 * 
 *     return result_keys.to_array(), result_counts.base             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_12 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_v_result_keys->__pyx_vtab)->to_array(__pyx_v_result_keys, 0)); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 1808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_result_counts, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int64_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int64_t, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_base); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 1808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1808, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_12);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_12)) __PYX_ERR(5, 1808, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_10);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_10)) __PYX_ERR(5, 1808, __pyx_L1_error);
  __pyx_t_12 = 0;
  __pyx_t_10 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1752
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_int64(const int64_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_13, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count_int64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result_keys);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_result_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":1813
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_int64(const int64_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_int64(__Pyx_memviewslice __pyx_v_values, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_int64 *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__62;
  int __pyx_v_ret;
  __pyx_t_5numpy_int64_t __pyx_v_value;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  Py_ssize_t __pyx_v_first_na;
  khiter_t __pyx_v_k;
  kh_int64_t *__pyx_v_table;
  PyArrayObject *__pyx_v_out = 0;
  int __pyx_v_seen_na;
  int __pyx_v_uses_mask;
  int __pyx_v_seen_multiple_na;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_out;
  __Pyx_Buffer __pyx_pybuffer_out;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  khuint_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  size_t __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("duplicated_int64", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_out.pybuffer.buf = NULL;
  __pyx_pybuffer_out.refcount = 0;
  __pyx_pybuffernd_out.data = NULL;
  __pyx_pybuffernd_out.rcbuffer = &__pyx_pybuffer_out;

  /* "pandas/_libs/hashtable_func_helper.pxi":1815
 * cdef duplicated_int64(const int64_t[:] values, object keep='first', const uint8_t[:] mask=None):
 *     cdef:
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         int64_t value
 *         Py_ssize_t i, n = len(values), first_na = -1
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1817
 *         int ret = 0
 *         int64_t value
 *         Py_ssize_t i, n = len(values), first_na = -1             # <<<<<<<<<<<<<<
 *         khiter_t k
 *         kh_int64_t *table = kh_init_int64()
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;
  __pyx_v_first_na = -1L;

  /* "pandas/_libs/hashtable_func_helper.pxi":1819
 *         Py_ssize_t i, n = len(values), first_na = -1
 *         khiter_t k
 *         kh_int64_t *table = kh_init_int64()             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 */
  __pyx_v_table = kh_init_int64();

  /* "pandas/_libs/hashtable_func_helper.pxi":1820
 *         khiter_t k
 *         kh_int64_t *table = kh_init_int64()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')             # <<<<<<<<<<<<<<
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 1820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 1820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 1820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(5, 1820, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 1820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_n_u_bool) < 0) __PYX_ERR(5, 1820, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1820, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 1820, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_out.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 1, __pyx_stack) == -1)) {
      __pyx_v_out = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_out.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(5, 1820, __pyx_L1_error)
    } else {__pyx_pybuffernd_out.diminfo[0].strides = __pyx_pybuffernd_out.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_out.diminfo[0].shape = __pyx_pybuffernd_out.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_out = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1821
 *         kh_int64_t *table = kh_init_int64()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint seen_multiple_na = False
 * 
 */
  __pyx_v_seen_na = 0;
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":1822
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_int64(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 */
  __pyx_v_seen_multiple_na = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1824
 *         bint seen_multiple_na = False
 * 
 *     kh_resize_int64(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))             # <<<<<<<<<<<<<<
 * 
 *     if keep not in ('last', 'first', False):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1824, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = kh_needed_n_buckets(__pyx_v_n);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1824, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_5, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 1824, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(5, 1824, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_8) {
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_2 = __pyx_t_5;
  } else {
    __pyx_t_3 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 1824, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_uint32(__pyx_t_2); if (unlikely((__pyx_t_7 == ((khuint_t)-1)) && PyErr_Occurred())) __PYX_ERR(5, 1824, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  kh_resize_int64(__pyx_v_table, __pyx_t_7);

  /* "pandas/_libs/hashtable_func_helper.pxi":1826
 *     kh_resize_int64(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  __Pyx_INCREF(__pyx_v_keep);
  __pyx_t_2 = __pyx_v_keep;
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_last, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1826, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_first, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1826, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, Py_False, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1826, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1826, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_8 = __pyx_t_9;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_9 = __pyx_t_8;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":1827
 * 
 *     if keep not in ('last', 'first', False):
 *         raise ValueError('keep must be either "first", "last" or False')             # <<<<<<<<<<<<<<
 * 
 *     if keep == "last":
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__43, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 1827, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(5, 1827, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":1826
 *     kh_resize_int64(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1829
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_last, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1829, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":1830
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":1831
 *     if keep == "last":
 *         with nogil:
 *             for i in range(n - 1, -1, -1):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          for (__pyx_t_1 = (__pyx_v_n - 1); __pyx_t_1 > -1L; __pyx_t_1-=1) {
            __pyx_v_i = __pyx_t_1;

            /* "pandas/_libs/hashtable_func_helper.pxi":1832
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L14_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L14_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":1833
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":1834
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1833
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L16;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":1836
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":1837
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = (values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L16:;

              /* "pandas/_libs/hashtable_func_helper.pxi":1832
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L13;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":1839
 *                         seen_na = True
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_int64(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_int64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":1840
 *                 else:
 *                     value = (values[i])
 *                     kh_put_int64(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 *     elif keep == "first":
 */
              (void)(kh_put_int64(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":1841
 *                     value = (values[i])
 *                     kh_put_int64(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 *     elif keep == "first":
 *         with nogil:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L13:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":1830
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L10;
          }
          __pyx_L10:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":1829
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1842
 *                     kh_put_int64(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_first, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 1842, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":1843
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":1844
 *     elif keep == "first":
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_11 = __pyx_t_1;
          for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
            __pyx_v_i = __pyx_t_12;

            /* "pandas/_libs/hashtable_func_helper.pxi":1845
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L23_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L23_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":1846
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":1847
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1846
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L25;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":1849
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":1850
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = (values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L25:;

              /* "pandas/_libs/hashtable_func_helper.pxi":1845
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L22;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":1852
 *                         seen_na = True
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_int64(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_int64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":1853
 *                 else:
 *                     value = (values[i])
 *                     kh_put_int64(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 * 
 */
              (void)(kh_put_int64(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":1854
 *                     value = (values[i])
 *                     kh_put_int64(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 * 
 *     else:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L22:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":1843
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L19;
          }
          __pyx_L19:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":1842
 *                     kh_put_int64(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1857
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
  /*else*/ {
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":1858
 *     else:
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_11 = __pyx_t_1;
          for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
            __pyx_v_i = __pyx_t_12;

            /* "pandas/_libs/hashtable_func_helper.pxi":1859
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L32_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L32_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":1860
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
              __pyx_t_9 = (!__pyx_v_seen_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":1861
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 *                         first_na = i             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                         out[i] = 0
 */
                __pyx_v_first_na = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":1862
 *                     if not seen_na:
 *                         first_na = i
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 */
                __pyx_v_seen_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1863
 *                         first_na = i
 *                         seen_na = True
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":1860
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":1864
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
              __pyx_t_9 = (!__pyx_v_seen_multiple_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":1865
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                         out[first_na] = 1
 *                         seen_multiple_na = True
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1866
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 *                         out[first_na] = 1             # <<<<<<<<<<<<<<
 *                         seen_multiple_na = True
 *                     else:
 */
                __pyx_t_10 = __pyx_v_first_na;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1867
 *                         out[i] = 1
 *                         out[first_na] = 1
 *                         seen_multiple_na = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = 1
 */
                __pyx_v_seen_multiple_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1864
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":1869
 *                         seen_multiple_na = True
 *                     else:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 * 
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;
              }
              __pyx_L34:;

              /* "pandas/_libs/hashtable_func_helper.pxi":1859
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
              goto __pyx_L31;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":1872
 * 
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_int64(table, value)
 *                     if k != table.n_buckets:
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_int64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":1873
 *                 else:
 *                     value = (values[i])
 *                     k = kh_get_int64(table, value)             # <<<<<<<<<<<<<<
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 */
              __pyx_v_k = kh_get_int64(__pyx_v_table, __pyx_v_value);

              /* "pandas/_libs/hashtable_func_helper.pxi":1874
 *                     value = (values[i])
 *                     k = kh_get_int64(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
              __pyx_t_9 = (__pyx_v_k != __pyx_v_table->n_buckets);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":1875
 *                     k = kh_get_int64(table, value)
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                     else:
 */
                __pyx_t_13 = (__pyx_v_table->vals[__pyx_v_k]);
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_13, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1876
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                     else:
 *                         k = kh_put_int64(table, value, &ret)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":1874
 *                     value = (values[i])
 *                     k = kh_get_int64(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
                goto __pyx_L35;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":1878
 *                         out[i] = 1
 *                     else:
 *                         k = kh_put_int64(table, value, &ret)             # <<<<<<<<<<<<<<
 *                         table.vals[k] = i
 *                         out[i] = 0
 */
              /*else*/ {
                __pyx_v_k = kh_put_int64(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret));

                /* "pandas/_libs/hashtable_func_helper.pxi":1879
 *                     else:
 *                         k = kh_put_int64(table, value, &ret)
 *                         table.vals[k] = i             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 * 
 */
                (__pyx_v_table->vals[__pyx_v_k]) = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":1880
 *                         k = kh_put_int64(table, value, &ret)
 *                         table.vals[k] = i
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_int64(table)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;
              }
              __pyx_L35:;
            }
            __pyx_L31:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":1857
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L28;
          }
          __pyx_L28:;
        }
    }
  }
  __pyx_L7:;

  /* "pandas/_libs/hashtable_func_helper.pxi":1882
 *                         out[i] = 0
 * 
 *     kh_destroy_int64(table)             # <<<<<<<<<<<<<<
 *     return out
 * 
 */
  kh_destroy_int64(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":1883
 * 
 *     kh_destroy_int64(table)
 *     return out             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_out);
  __pyx_r = ((PyObject *)__pyx_v_out);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1813
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_int64(const int64_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated_int64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_out);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":1893
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_int64(const int64_t[:] arr, const int64_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_int64(__Pyx_memviewslice __pyx_v_arr, __Pyx_memviewslice __pyx_v_values) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  PyArrayObject *__pyx_v_result = 0;
  __pyx_t_5numpy_int64_t __pyx_v_val;
  kh_int64_t *__pyx_v_table;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyArrayObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ismember_int64", 1);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "pandas/_libs/hashtable_func_helper.pxi":1910
 *         Py_ssize_t i, n
 *         khiter_t k
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t] result
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1915
 *         int64_t val
 * 
 *         kh_int64_t *table = kh_init_int64()             # <<<<<<<<<<<<<<
 * 
 *     # construct the table
 */
  __pyx_v_table = kh_init_int64();

  /* "pandas/_libs/hashtable_func_helper.pxi":1918
 * 
 *     # construct the table
 *     n = len(values)             # <<<<<<<<<<<<<<
 *     kh_resize_int64(table, n)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":1919
 *     # construct the table
 *     n = len(values)
 *     kh_resize_int64(table, n)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  kh_resize_int64(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":1921
 *     kh_resize_int64(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":1922
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = (values[i])
 *             kh_put_int64(table, val, &ret)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":1923
 *     with nogil:
 *         for i in range(n):
 *             val = (values[i])             # <<<<<<<<<<<<<<
 *             kh_put_int64(table, val, &ret)
 * 
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_int64_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_4 * __pyx_v_values.strides[0]) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":1924
 *         for i in range(n):
 *             val = (values[i])
 *             kh_put_int64(table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *     # test membership
 */
          (void)(kh_put_int64(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret)));
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":1921
 *     kh_resize_int64(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1927
 * 
 *     # test membership
 *     n = len(arr)             # <<<<<<<<<<<<<<
 *     result = np.empty(n, dtype=np.uint8)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_arr); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":1928
 *     # test membership
 *     n = len(arr)
 *     result = np.empty(n, dtype=np.uint8)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_empty); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 1928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 1928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5)) __PYX_ERR(5, 1928, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(5, 1928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_uint8); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 1928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dtype, __pyx_t_9) < 0) __PYX_ERR(5, 1928, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, __pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 1928, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (!(likely(((__pyx_t_9) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_9, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 1928, __pyx_L1_error)
  __pyx_t_10 = ((PyArrayObject *)__pyx_t_9);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_11 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_10, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_11 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_13); Py_XDECREF(__pyx_t_14);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __pyx_t_12 = __pyx_t_13 = __pyx_t_14 = 0;
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(5, 1928, __pyx_L1_error)
  }
  __pyx_t_10 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_9);
  __pyx_t_9 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1930
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (arr[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":1931
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = (arr[i])
 *             k = kh_get_int64(table, val)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":1932
 *     with nogil:
 *         for i in range(n):
 *             val = (arr[i])             # <<<<<<<<<<<<<<
 *             k = kh_get_int64(table, val)
 *             result[i] = (k != table.n_buckets)
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_int64_t const  *) ( /* dim=0 */ (__pyx_v_arr.data + __pyx_t_4 * __pyx_v_arr.strides[0]) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":1933
 *         for i in range(n):
 *             val = (arr[i])
 *             k = kh_get_int64(table, val)             # <<<<<<<<<<<<<<
 *             result[i] = (k != table.n_buckets)
 * 
 */
          __pyx_v_k = kh_get_int64(__pyx_v_table, __pyx_v_val);

          /* "pandas/_libs/hashtable_func_helper.pxi":1934
 *             val = (arr[i])
 *             k = kh_get_int64(table, val)
 *             result[i] = (k != table.n_buckets)             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_int64(table)
 */
          __pyx_t_4 = __pyx_v_i;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_result.rcbuffer->pybuffer.buf, __pyx_t_4, __pyx_pybuffernd_result.diminfo[0].strides) = (__pyx_v_k != __pyx_v_table->n_buckets);
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":1930
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (arr[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L10;
        }
        __pyx_L10:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1936
 *             result[i] = (k != table.n_buckets)
 * 
 *     kh_destroy_int64(table)             # <<<<<<<<<<<<<<
 *     return result.view(np.bool_)
 * 
 */
  kh_destroy_int64(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":1937
 * 
 *     kh_destroy_int64(table)
 *     return result.view(np.bool_)             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_result), __pyx_n_s_view); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 1937, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 1937, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_bool_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 1937, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_11 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_11 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_6};
    __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_11, 1+__pyx_t_11);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 1937, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_r = __pyx_t_9;
  __pyx_t_9 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1893
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_int64(const int64_t[:] arr, const int64_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember_int64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":1946
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_int32(const int32_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_int32(__Pyx_memviewslice __pyx_v_values, int __pyx_v_dropna, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_int32 *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__63;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  kh_int32_t *__pyx_v_table;
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int32_t __pyx_v_val;
  int __pyx_v_ret;
  int __pyx_v_uses_mask;
  int __pyx_v_isna_entry;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_result_keys = NULL;
  __Pyx_memviewslice __pyx_v_result_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  khiter_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  khuint_t __pyx_t_14;
  khuint_t __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("value_count_int32", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1948
 * cdef value_count_int32(const int32_t[:] values, bint dropna, const uint8_t[:] mask=None):
 *     cdef:
 *         Py_ssize_t i = 0             # <<<<<<<<<<<<<<
 *         Py_ssize_t n = len(values)
 *         kh_int32_t *table
 */
  __pyx_v_i = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1949
 *     cdef:
 *         Py_ssize_t i = 0
 *         Py_ssize_t n = len(values)             # <<<<<<<<<<<<<<
 *         kh_int32_t *table
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":1957
 *         int32_t val
 * 
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1958
 * 
 *         int ret = 0
 *         bint uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint isna_entry = False
 * 
 */
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":1959
 *         int ret = 0
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False             # <<<<<<<<<<<<<<
 * 
 *     if uses_mask and not dropna:
 */
  __pyx_v_isna_entry = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1961
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  if (__pyx_v_uses_mask) {
  } else {
    __pyx_t_2 = __pyx_v_uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (!__pyx_v_dropna);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_2)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":1962
 * 
 *     if uses_mask and not dropna:
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")             # <<<<<<<<<<<<<<
 * 
 *     # we track the order in which keys are first seen (GH39009),
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_NotImplementedError, __pyx_tuple__41, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1962, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(5, 1962, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":1961
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1969
 *     #    result_keys remembers the original order of keys
 * 
 *     result_keys = Int32Vector()             # <<<<<<<<<<<<<<
 *     table = kh_init_int32()
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector)); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1969, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_result_keys = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1970
 * 
 *     result_keys = Int32Vector()
 *     table = kh_init_int32()             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_int32(table, n)
 */
  __pyx_v_table = kh_init_int32();

  /* "pandas/_libs/hashtable_func_helper.pxi":1972
 *     table = kh_init_int32()
 * 
 *     kh_resize_int32(table, n)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(n):
 */
  kh_resize_int32(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":1974
 *     kh_resize_int32(table, n)
 * 
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         val = (values[i])
 * 
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_5 = __pyx_t_1;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "pandas/_libs/hashtable_func_helper.pxi":1975
 * 
 *     for i in range(n):
 *         val = (values[i])             # <<<<<<<<<<<<<<
 * 
 *         if dropna:
 */
    __pyx_t_7 = __pyx_v_i;
    __pyx_v_val = (*((__pyx_t_5numpy_int32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

    /* "pandas/_libs/hashtable_func_helper.pxi":1977
 *         val = (values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    if (__pyx_v_dropna) {

      /* "pandas/_libs/hashtable_func_helper.pxi":1978
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
      if (__pyx_v_uses_mask) {

        /* "pandas/_libs/hashtable_func_helper.pxi":1979
 *         if dropna:
 *             if uses_mask:
 *                 isna_entry = mask[i]             # <<<<<<<<<<<<<<
 *             else:
 *                 isna_entry = is_nan_int32_t(val)
 */
        __pyx_t_7 = __pyx_v_i;
        __pyx_v_isna_entry = (*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) )));

        /* "pandas/_libs/hashtable_func_helper.pxi":1978
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
        goto __pyx_L9;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":1981
 *                 isna_entry = mask[i]
 *             else:
 *                 isna_entry = is_nan_int32_t(val)             # <<<<<<<<<<<<<<
 * 
 *         if not dropna or not isna_entry:
 */
      /*else*/ {
        __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_int32_t(__pyx_v_val); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 1981, __pyx_L1_error)
        __pyx_v_isna_entry = __pyx_t_2;
      }
      __pyx_L9:;

      /* "pandas/_libs/hashtable_func_helper.pxi":1977
 *         val = (values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":1983
 *                 isna_entry = is_nan_int32_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_int32(table, val)
 *             if k != table.n_buckets:
 */
    __pyx_t_3 = (!__pyx_v_dropna);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L11_bool_binop_done;
    }
    __pyx_t_3 = (!__pyx_v_isna_entry);
    __pyx_t_2 = __pyx_t_3;
    __pyx_L11_bool_binop_done:;
    if (__pyx_t_2) {

      /* "pandas/_libs/hashtable_func_helper.pxi":1984
 * 
 *         if not dropna or not isna_entry:
 *             k = kh_get_int32(table, val)             # <<<<<<<<<<<<<<
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1
 */
      __pyx_v_k = kh_get_int32(__pyx_v_table, __pyx_v_val);

      /* "pandas/_libs/hashtable_func_helper.pxi":1985
 *         if not dropna or not isna_entry:
 *             k = kh_get_int32(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
      __pyx_t_2 = (__pyx_v_k != __pyx_v_table->n_buckets);
      if (__pyx_t_2) {

        /* "pandas/_libs/hashtable_func_helper.pxi":1986
 *             k = kh_get_int32(table, val)
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 k = kh_put_int32(table, val, &ret)
 */
        __pyx_t_8 = __pyx_v_k;
        (__pyx_v_table->vals[__pyx_t_8]) = ((__pyx_v_table->vals[__pyx_t_8]) + 1);

        /* "pandas/_libs/hashtable_func_helper.pxi":1985
 *         if not dropna or not isna_entry:
 *             k = kh_get_int32(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
        goto __pyx_L13;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":1988
 *                 table.vals[k] += 1
 *             else:
 *                 k = kh_put_int32(table, val, &ret)             # <<<<<<<<<<<<<<
 *                 table.vals[k] = 1
 *                 result_keys.append(val)
 */
      /*else*/ {
        __pyx_v_k = kh_put_int32(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret));

        /* "pandas/_libs/hashtable_func_helper.pxi":1989
 *             else:
 *                 k = kh_put_int32(table, val, &ret)
 *                 table.vals[k] = 1             # <<<<<<<<<<<<<<
 *                 result_keys.append(val)
 * 
 */
        (__pyx_v_table->vals[__pyx_v_k]) = 1;

        /* "pandas/_libs/hashtable_func_helper.pxi":1990
 *                 k = kh_put_int32(table, val, &ret)
 *                 table.vals[k] = 1
 *                 result_keys.append(val)             # <<<<<<<<<<<<<<
 * 
 *     # collect counts in the order corresponding to result_keys:
 */
        ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_v_result_keys->__pyx_vtab)->append(__pyx_v_result_keys, __pyx_v_val); if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 1990, __pyx_L1_error)
      }
      __pyx_L13:;

      /* "pandas/_libs/hashtable_func_helper.pxi":1983
 *                 isna_entry = is_nan_int32_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_int32(table, val)
 *             if k != table.n_buckets:
 */
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":1994
 *     # collect counts in the order corresponding to result_keys:
 *     cdef:
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(table.size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_empty); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 1994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_v_table->size); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 1994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_4)) __PYX_ERR(5, 1994, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 1994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_np); if (unlikely(!__pyx_t_11)) __PYX_ERR(5, 1994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_int64); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 1994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_dtype, __pyx_t_12) < 0) __PYX_ERR(5, 1994, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_10, __pyx_t_4); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 1994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_12, PyBUF_WRITABLE); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(5, 1994, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_v_result_counts = __pyx_t_13;
  __pyx_t_13.memview = NULL;
  __pyx_t_13.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":1996
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)
 * 
 *     for i in range(table.size):             # <<<<<<<<<<<<<<
 *         k = kh_get_int32(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]
 */
  __pyx_t_14 = __pyx_v_table->size;
  __pyx_t_15 = __pyx_t_14;
  for (__pyx_t_1 = 0; __pyx_t_1 < __pyx_t_15; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "pandas/_libs/hashtable_func_helper.pxi":1997
 * 
 *     for i in range(table.size):
 *         k = kh_get_int32(table, result_keys.data.data[i])             # <<<<<<<<<<<<<<
 *         result_counts[i] = table.vals[k]
 * 
 */
    __pyx_v_k = kh_get_int32(__pyx_v_table, (__pyx_v_result_keys->data->data[__pyx_v_i]));

    /* "pandas/_libs/hashtable_func_helper.pxi":1998
 *     for i in range(table.size):
 *         k = kh_get_int32(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_int32(table)
 */
    __pyx_t_7 = __pyx_v_i;
    *((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_result_counts.data) + __pyx_t_7)) )) = (__pyx_v_table->vals[__pyx_v_k]);
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2000
 *         result_counts[i] = table.vals[k]
 * 
 *     kh_destroy_int32(table)             # <<<<<<<<<<<<<<
 * 
 *     return result_keys.to_array(), result_counts.base
 */
  kh_destroy_int32(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":2002
 *     kh_destroy_int32(table)
 * 
 *     return result_keys.to_array(), result_counts.base             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_12 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_v_result_keys->__pyx_vtab)->to_array(__pyx_v_result_keys, 0)); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 2002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_result_counts, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int64_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int64_t, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_base); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 2002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2002, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_12);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_12)) __PYX_ERR(5, 2002, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_10);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_10)) __PYX_ERR(5, 2002, __pyx_L1_error);
  __pyx_t_12 = 0;
  __pyx_t_10 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":1946
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_int32(const int32_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_13, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count_int32", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result_keys);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_result_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":2007
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_int32(const int32_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_int32(__Pyx_memviewslice __pyx_v_values, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_int32 *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__64;
  int __pyx_v_ret;
  __pyx_t_5numpy_int32_t __pyx_v_value;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  Py_ssize_t __pyx_v_first_na;
  khiter_t __pyx_v_k;
  kh_int32_t *__pyx_v_table;
  PyArrayObject *__pyx_v_out = 0;
  int __pyx_v_seen_na;
  int __pyx_v_uses_mask;
  int __pyx_v_seen_multiple_na;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_out;
  __Pyx_Buffer __pyx_pybuffer_out;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  khuint_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  size_t __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("duplicated_int32", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_out.pybuffer.buf = NULL;
  __pyx_pybuffer_out.refcount = 0;
  __pyx_pybuffernd_out.data = NULL;
  __pyx_pybuffernd_out.rcbuffer = &__pyx_pybuffer_out;

  /* "pandas/_libs/hashtable_func_helper.pxi":2009
 * cdef duplicated_int32(const int32_t[:] values, object keep='first', const uint8_t[:] mask=None):
 *     cdef:
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         int32_t value
 *         Py_ssize_t i, n = len(values), first_na = -1
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2011
 *         int ret = 0
 *         int32_t value
 *         Py_ssize_t i, n = len(values), first_na = -1             # <<<<<<<<<<<<<<
 *         khiter_t k
 *         kh_int32_t *table = kh_init_int32()
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;
  __pyx_v_first_na = -1L;

  /* "pandas/_libs/hashtable_func_helper.pxi":2013
 *         Py_ssize_t i, n = len(values), first_na = -1
 *         khiter_t k
 *         kh_int32_t *table = kh_init_int32()             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 */
  __pyx_v_table = kh_init_int32();

  /* "pandas/_libs/hashtable_func_helper.pxi":2014
 *         khiter_t k
 *         kh_int32_t *table = kh_init_int32()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')             # <<<<<<<<<<<<<<
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(5, 2014, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_n_u_bool) < 0) __PYX_ERR(5, 2014, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2014, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2014, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_out.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 1, __pyx_stack) == -1)) {
      __pyx_v_out = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_out.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(5, 2014, __pyx_L1_error)
    } else {__pyx_pybuffernd_out.diminfo[0].strides = __pyx_pybuffernd_out.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_out.diminfo[0].shape = __pyx_pybuffernd_out.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_out = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2015
 *         kh_int32_t *table = kh_init_int32()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint seen_multiple_na = False
 * 
 */
  __pyx_v_seen_na = 0;
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":2016
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_int32(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 */
  __pyx_v_seen_multiple_na = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2018
 *         bint seen_multiple_na = False
 * 
 *     kh_resize_int32(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))             # <<<<<<<<<<<<<<
 * 
 *     if keep not in ('last', 'first', False):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = kh_needed_n_buckets(__pyx_v_n);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2018, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_5, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2018, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(5, 2018, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_8) {
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_2 = __pyx_t_5;
  } else {
    __pyx_t_3 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2018, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_uint32(__pyx_t_2); if (unlikely((__pyx_t_7 == ((khuint_t)-1)) && PyErr_Occurred())) __PYX_ERR(5, 2018, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  kh_resize_int32(__pyx_v_table, __pyx_t_7);

  /* "pandas/_libs/hashtable_func_helper.pxi":2020
 *     kh_resize_int32(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  __Pyx_INCREF(__pyx_v_keep);
  __pyx_t_2 = __pyx_v_keep;
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_last, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2020, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_first, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2020, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, Py_False, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2020, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2020, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_8 = __pyx_t_9;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_9 = __pyx_t_8;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":2021
 * 
 *     if keep not in ('last', 'first', False):
 *         raise ValueError('keep must be either "first", "last" or False')             # <<<<<<<<<<<<<<
 * 
 *     if keep == "last":
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__43, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2021, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(5, 2021, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":2020
 *     kh_resize_int32(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2023
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_last, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2023, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":2024
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":2025
 *     if keep == "last":
 *         with nogil:
 *             for i in range(n - 1, -1, -1):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          for (__pyx_t_1 = (__pyx_v_n - 1); __pyx_t_1 > -1L; __pyx_t_1-=1) {
            __pyx_v_i = __pyx_t_1;

            /* "pandas/_libs/hashtable_func_helper.pxi":2026
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L14_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L14_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":2027
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":2028
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2027
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L16;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":2030
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":2031
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = (values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L16:;

              /* "pandas/_libs/hashtable_func_helper.pxi":2026
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L13;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":2033
 *                         seen_na = True
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_int32(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_int32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":2034
 *                 else:
 *                     value = (values[i])
 *                     kh_put_int32(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 *     elif keep == "first":
 */
              (void)(kh_put_int32(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":2035
 *                     value = (values[i])
 *                     kh_put_int32(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 *     elif keep == "first":
 *         with nogil:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L13:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":2024
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L10;
          }
          __pyx_L10:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":2023
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2036
 *                     kh_put_int32(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_first, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2036, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":2037
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":2038
 *     elif keep == "first":
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_11 = __pyx_t_1;
          for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
            __pyx_v_i = __pyx_t_12;

            /* "pandas/_libs/hashtable_func_helper.pxi":2039
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L23_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L23_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":2040
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":2041
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2040
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L25;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":2043
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":2044
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = (values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L25:;

              /* "pandas/_libs/hashtable_func_helper.pxi":2039
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L22;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":2046
 *                         seen_na = True
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_int32(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_int32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":2047
 *                 else:
 *                     value = (values[i])
 *                     kh_put_int32(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 * 
 */
              (void)(kh_put_int32(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":2048
 *                     value = (values[i])
 *                     kh_put_int32(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 * 
 *     else:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L22:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":2037
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L19;
          }
          __pyx_L19:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":2036
 *                     kh_put_int32(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2051
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
  /*else*/ {
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":2052
 *     else:
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_11 = __pyx_t_1;
          for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
            __pyx_v_i = __pyx_t_12;

            /* "pandas/_libs/hashtable_func_helper.pxi":2053
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L32_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L32_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":2054
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
              __pyx_t_9 = (!__pyx_v_seen_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":2055
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 *                         first_na = i             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                         out[i] = 0
 */
                __pyx_v_first_na = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":2056
 *                     if not seen_na:
 *                         first_na = i
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 */
                __pyx_v_seen_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2057
 *                         first_na = i
 *                         seen_na = True
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":2054
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":2058
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
              __pyx_t_9 = (!__pyx_v_seen_multiple_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":2059
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                         out[first_na] = 1
 *                         seen_multiple_na = True
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2060
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 *                         out[first_na] = 1             # <<<<<<<<<<<<<<
 *                         seen_multiple_na = True
 *                     else:
 */
                __pyx_t_10 = __pyx_v_first_na;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2061
 *                         out[i] = 1
 *                         out[first_na] = 1
 *                         seen_multiple_na = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = 1
 */
                __pyx_v_seen_multiple_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2058
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":2063
 *                         seen_multiple_na = True
 *                     else:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 * 
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;
              }
              __pyx_L34:;

              /* "pandas/_libs/hashtable_func_helper.pxi":2053
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
              goto __pyx_L31;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":2066
 * 
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_int32(table, value)
 *                     if k != table.n_buckets:
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_int32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":2067
 *                 else:
 *                     value = (values[i])
 *                     k = kh_get_int32(table, value)             # <<<<<<<<<<<<<<
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 */
              __pyx_v_k = kh_get_int32(__pyx_v_table, __pyx_v_value);

              /* "pandas/_libs/hashtable_func_helper.pxi":2068
 *                     value = (values[i])
 *                     k = kh_get_int32(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
              __pyx_t_9 = (__pyx_v_k != __pyx_v_table->n_buckets);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":2069
 *                     k = kh_get_int32(table, value)
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                     else:
 */
                __pyx_t_13 = (__pyx_v_table->vals[__pyx_v_k]);
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_13, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2070
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                     else:
 *                         k = kh_put_int32(table, value, &ret)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2068
 *                     value = (values[i])
 *                     k = kh_get_int32(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
                goto __pyx_L35;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":2072
 *                         out[i] = 1
 *                     else:
 *                         k = kh_put_int32(table, value, &ret)             # <<<<<<<<<<<<<<
 *                         table.vals[k] = i
 *                         out[i] = 0
 */
              /*else*/ {
                __pyx_v_k = kh_put_int32(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret));

                /* "pandas/_libs/hashtable_func_helper.pxi":2073
 *                     else:
 *                         k = kh_put_int32(table, value, &ret)
 *                         table.vals[k] = i             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 * 
 */
                (__pyx_v_table->vals[__pyx_v_k]) = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":2074
 *                         k = kh_put_int32(table, value, &ret)
 *                         table.vals[k] = i
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_int32(table)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;
              }
              __pyx_L35:;
            }
            __pyx_L31:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":2051
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L28;
          }
          __pyx_L28:;
        }
    }
  }
  __pyx_L7:;

  /* "pandas/_libs/hashtable_func_helper.pxi":2076
 *                         out[i] = 0
 * 
 *     kh_destroy_int32(table)             # <<<<<<<<<<<<<<
 *     return out
 * 
 */
  kh_destroy_int32(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":2077
 * 
 *     kh_destroy_int32(table)
 *     return out             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_out);
  __pyx_r = ((PyObject *)__pyx_v_out);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2007
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_int32(const int32_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated_int32", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_out);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":2087
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_int32(const int32_t[:] arr, const int32_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_int32(__Pyx_memviewslice __pyx_v_arr, __Pyx_memviewslice __pyx_v_values) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  PyArrayObject *__pyx_v_result = 0;
  __pyx_t_5numpy_int32_t __pyx_v_val;
  kh_int32_t *__pyx_v_table;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyArrayObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ismember_int32", 1);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "pandas/_libs/hashtable_func_helper.pxi":2104
 *         Py_ssize_t i, n
 *         khiter_t k
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t] result
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2109
 *         int32_t val
 * 
 *         kh_int32_t *table = kh_init_int32()             # <<<<<<<<<<<<<<
 * 
 *     # construct the table
 */
  __pyx_v_table = kh_init_int32();

  /* "pandas/_libs/hashtable_func_helper.pxi":2112
 * 
 *     # construct the table
 *     n = len(values)             # <<<<<<<<<<<<<<
 *     kh_resize_int32(table, n)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":2113
 *     # construct the table
 *     n = len(values)
 *     kh_resize_int32(table, n)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  kh_resize_int32(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":2115
 *     kh_resize_int32(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":2116
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = (values[i])
 *             kh_put_int32(table, val, &ret)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":2117
 *     with nogil:
 *         for i in range(n):
 *             val = (values[i])             # <<<<<<<<<<<<<<
 *             kh_put_int32(table, val, &ret)
 * 
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_int32_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_4 * __pyx_v_values.strides[0]) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":2118
 *         for i in range(n):
 *             val = (values[i])
 *             kh_put_int32(table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *     # test membership
 */
          (void)(kh_put_int32(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret)));
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2115
 *     kh_resize_int32(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2121
 * 
 *     # test membership
 *     n = len(arr)             # <<<<<<<<<<<<<<
 *     result = np.empty(n, dtype=np.uint8)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_arr); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":2122
 *     # test membership
 *     n = len(arr)
 *     result = np.empty(n, dtype=np.uint8)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_empty); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5)) __PYX_ERR(5, 2122, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(5, 2122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_uint8); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 2122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dtype, __pyx_t_9) < 0) __PYX_ERR(5, 2122, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, __pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 2122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (!(likely(((__pyx_t_9) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_9, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2122, __pyx_L1_error)
  __pyx_t_10 = ((PyArrayObject *)__pyx_t_9);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_11 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_10, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_11 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_13); Py_XDECREF(__pyx_t_14);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __pyx_t_12 = __pyx_t_13 = __pyx_t_14 = 0;
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(5, 2122, __pyx_L1_error)
  }
  __pyx_t_10 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_9);
  __pyx_t_9 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2124
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (arr[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":2125
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = (arr[i])
 *             k = kh_get_int32(table, val)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":2126
 *     with nogil:
 *         for i in range(n):
 *             val = (arr[i])             # <<<<<<<<<<<<<<
 *             k = kh_get_int32(table, val)
 *             result[i] = (k != table.n_buckets)
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_int32_t const  *) ( /* dim=0 */ (__pyx_v_arr.data + __pyx_t_4 * __pyx_v_arr.strides[0]) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":2127
 *         for i in range(n):
 *             val = (arr[i])
 *             k = kh_get_int32(table, val)             # <<<<<<<<<<<<<<
 *             result[i] = (k != table.n_buckets)
 * 
 */
          __pyx_v_k = kh_get_int32(__pyx_v_table, __pyx_v_val);

          /* "pandas/_libs/hashtable_func_helper.pxi":2128
 *             val = (arr[i])
 *             k = kh_get_int32(table, val)
 *             result[i] = (k != table.n_buckets)             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_int32(table)
 */
          __pyx_t_4 = __pyx_v_i;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_result.rcbuffer->pybuffer.buf, __pyx_t_4, __pyx_pybuffernd_result.diminfo[0].strides) = (__pyx_v_k != __pyx_v_table->n_buckets);
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2124
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (arr[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L10;
        }
        __pyx_L10:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2130
 *             result[i] = (k != table.n_buckets)
 * 
 *     kh_destroy_int32(table)             # <<<<<<<<<<<<<<
 *     return result.view(np.bool_)
 * 
 */
  kh_destroy_int32(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":2131
 * 
 *     kh_destroy_int32(table)
 *     return result.view(np.bool_)             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_result), __pyx_n_s_view); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_bool_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2131, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_11 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_11 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_6};
    __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_11, 1+__pyx_t_11);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 2131, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_r = __pyx_t_9;
  __pyx_t_9 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2087
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_int32(const int32_t[:] arr, const int32_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember_int32", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":2140
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_int16(const int16_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_int16(__Pyx_memviewslice __pyx_v_values, int __pyx_v_dropna, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_int16 *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__65;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  kh_int16_t *__pyx_v_table;
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int16_t __pyx_v_val;
  int __pyx_v_ret;
  int __pyx_v_uses_mask;
  int __pyx_v_isna_entry;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *__pyx_v_result_keys = NULL;
  __Pyx_memviewslice __pyx_v_result_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  khiter_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  khuint_t __pyx_t_14;
  khuint_t __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("value_count_int16", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2142
 * cdef value_count_int16(const int16_t[:] values, bint dropna, const uint8_t[:] mask=None):
 *     cdef:
 *         Py_ssize_t i = 0             # <<<<<<<<<<<<<<
 *         Py_ssize_t n = len(values)
 *         kh_int16_t *table
 */
  __pyx_v_i = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2143
 *     cdef:
 *         Py_ssize_t i = 0
 *         Py_ssize_t n = len(values)             # <<<<<<<<<<<<<<
 *         kh_int16_t *table
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":2151
 *         int16_t val
 * 
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2152
 * 
 *         int ret = 0
 *         bint uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint isna_entry = False
 * 
 */
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":2153
 *         int ret = 0
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False             # <<<<<<<<<<<<<<
 * 
 *     if uses_mask and not dropna:
 */
  __pyx_v_isna_entry = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2155
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  if (__pyx_v_uses_mask) {
  } else {
    __pyx_t_2 = __pyx_v_uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (!__pyx_v_dropna);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_2)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":2156
 * 
 *     if uses_mask and not dropna:
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")             # <<<<<<<<<<<<<<
 * 
 *     # we track the order in which keys are first seen (GH39009),
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_NotImplementedError, __pyx_tuple__41, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2156, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(5, 2156, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":2155
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2163
 *     #    result_keys remembers the original order of keys
 * 
 *     result_keys = Int16Vector()             # <<<<<<<<<<<<<<
 *     table = kh_init_int16()
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector)); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_result_keys = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2164
 * 
 *     result_keys = Int16Vector()
 *     table = kh_init_int16()             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_int16(table, n)
 */
  __pyx_v_table = kh_init_int16();

  /* "pandas/_libs/hashtable_func_helper.pxi":2166
 *     table = kh_init_int16()
 * 
 *     kh_resize_int16(table, n)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(n):
 */
  kh_resize_int16(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":2168
 *     kh_resize_int16(table, n)
 * 
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         val = (values[i])
 * 
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_5 = __pyx_t_1;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "pandas/_libs/hashtable_func_helper.pxi":2169
 * 
 *     for i in range(n):
 *         val = (values[i])             # <<<<<<<<<<<<<<
 * 
 *         if dropna:
 */
    __pyx_t_7 = __pyx_v_i;
    __pyx_v_val = (*((__pyx_t_5numpy_int16_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

    /* "pandas/_libs/hashtable_func_helper.pxi":2171
 *         val = (values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    if (__pyx_v_dropna) {

      /* "pandas/_libs/hashtable_func_helper.pxi":2172
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
      if (__pyx_v_uses_mask) {

        /* "pandas/_libs/hashtable_func_helper.pxi":2173
 *         if dropna:
 *             if uses_mask:
 *                 isna_entry = mask[i]             # <<<<<<<<<<<<<<
 *             else:
 *                 isna_entry = is_nan_int16_t(val)
 */
        __pyx_t_7 = __pyx_v_i;
        __pyx_v_isna_entry = (*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) )));

        /* "pandas/_libs/hashtable_func_helper.pxi":2172
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
        goto __pyx_L9;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2175
 *                 isna_entry = mask[i]
 *             else:
 *                 isna_entry = is_nan_int16_t(val)             # <<<<<<<<<<<<<<
 * 
 *         if not dropna or not isna_entry:
 */
      /*else*/ {
        __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_int16_t(__pyx_v_val); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2175, __pyx_L1_error)
        __pyx_v_isna_entry = __pyx_t_2;
      }
      __pyx_L9:;

      /* "pandas/_libs/hashtable_func_helper.pxi":2171
 *         val = (values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":2177
 *                 isna_entry = is_nan_int16_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_int16(table, val)
 *             if k != table.n_buckets:
 */
    __pyx_t_3 = (!__pyx_v_dropna);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L11_bool_binop_done;
    }
    __pyx_t_3 = (!__pyx_v_isna_entry);
    __pyx_t_2 = __pyx_t_3;
    __pyx_L11_bool_binop_done:;
    if (__pyx_t_2) {

      /* "pandas/_libs/hashtable_func_helper.pxi":2178
 * 
 *         if not dropna or not isna_entry:
 *             k = kh_get_int16(table, val)             # <<<<<<<<<<<<<<
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1
 */
      __pyx_v_k = kh_get_int16(__pyx_v_table, __pyx_v_val);

      /* "pandas/_libs/hashtable_func_helper.pxi":2179
 *         if not dropna or not isna_entry:
 *             k = kh_get_int16(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
      __pyx_t_2 = (__pyx_v_k != __pyx_v_table->n_buckets);
      if (__pyx_t_2) {

        /* "pandas/_libs/hashtable_func_helper.pxi":2180
 *             k = kh_get_int16(table, val)
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 k = kh_put_int16(table, val, &ret)
 */
        __pyx_t_8 = __pyx_v_k;
        (__pyx_v_table->vals[__pyx_t_8]) = ((__pyx_v_table->vals[__pyx_t_8]) + 1);

        /* "pandas/_libs/hashtable_func_helper.pxi":2179
 *         if not dropna or not isna_entry:
 *             k = kh_get_int16(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
        goto __pyx_L13;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2182
 *                 table.vals[k] += 1
 *             else:
 *                 k = kh_put_int16(table, val, &ret)             # <<<<<<<<<<<<<<
 *                 table.vals[k] = 1
 *                 result_keys.append(val)
 */
      /*else*/ {
        __pyx_v_k = kh_put_int16(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret));

        /* "pandas/_libs/hashtable_func_helper.pxi":2183
 *             else:
 *                 k = kh_put_int16(table, val, &ret)
 *                 table.vals[k] = 1             # <<<<<<<<<<<<<<
 *                 result_keys.append(val)
 * 
 */
        (__pyx_v_table->vals[__pyx_v_k]) = 1;

        /* "pandas/_libs/hashtable_func_helper.pxi":2184
 *                 k = kh_put_int16(table, val, &ret)
 *                 table.vals[k] = 1
 *                 result_keys.append(val)             # <<<<<<<<<<<<<<
 * 
 *     # collect counts in the order corresponding to result_keys:
 */
        ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int16Vector *)__pyx_v_result_keys->__pyx_vtab)->append(__pyx_v_result_keys, __pyx_v_val); if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2184, __pyx_L1_error)
      }
      __pyx_L13:;

      /* "pandas/_libs/hashtable_func_helper.pxi":2177
 *                 isna_entry = is_nan_int16_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_int16(table, val)
 *             if k != table.n_buckets:
 */
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2188
 *     # collect counts in the order corresponding to result_keys:
 *     cdef:
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(table.size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_empty); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 2188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_v_table->size); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 2188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_4)) __PYX_ERR(5, 2188, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_np); if (unlikely(!__pyx_t_11)) __PYX_ERR(5, 2188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_int64); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 2188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_dtype, __pyx_t_12) < 0) __PYX_ERR(5, 2188, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_10, __pyx_t_4); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 2188, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_12, PyBUF_WRITABLE); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(5, 2188, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_v_result_counts = __pyx_t_13;
  __pyx_t_13.memview = NULL;
  __pyx_t_13.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2190
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)
 * 
 *     for i in range(table.size):             # <<<<<<<<<<<<<<
 *         k = kh_get_int16(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]
 */
  __pyx_t_14 = __pyx_v_table->size;
  __pyx_t_15 = __pyx_t_14;
  for (__pyx_t_1 = 0; __pyx_t_1 < __pyx_t_15; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "pandas/_libs/hashtable_func_helper.pxi":2191
 * 
 *     for i in range(table.size):
 *         k = kh_get_int16(table, result_keys.data.data[i])             # <<<<<<<<<<<<<<
 *         result_counts[i] = table.vals[k]
 * 
 */
    __pyx_v_k = kh_get_int16(__pyx_v_table, (__pyx_v_result_keys->data->data[__pyx_v_i]));

    /* "pandas/_libs/hashtable_func_helper.pxi":2192
 *     for i in range(table.size):
 *         k = kh_get_int16(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_int16(table)
 */
    __pyx_t_7 = __pyx_v_i;
    *((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_result_counts.data) + __pyx_t_7)) )) = (__pyx_v_table->vals[__pyx_v_k]);
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2194
 *         result_counts[i] = table.vals[k]
 * 
 *     kh_destroy_int16(table)             # <<<<<<<<<<<<<<
 * 
 *     return result_keys.to_array(), result_counts.base
 */
  kh_destroy_int16(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":2196
 *     kh_destroy_int16(table)
 * 
 *     return result_keys.to_array(), result_counts.base             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_12 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int16Vector *)__pyx_v_result_keys->__pyx_vtab)->to_array(__pyx_v_result_keys, 0)); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 2196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_result_counts, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int64_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int64_t, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_base); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 2196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2196, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_12);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_12)) __PYX_ERR(5, 2196, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_10);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_10)) __PYX_ERR(5, 2196, __pyx_L1_error);
  __pyx_t_12 = 0;
  __pyx_t_10 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2140
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_int16(const int16_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_13, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count_int16", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result_keys);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_result_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":2201
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_int16(const int16_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_int16(__Pyx_memviewslice __pyx_v_values, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_int16 *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__66;
  int __pyx_v_ret;
  __pyx_t_5numpy_int16_t __pyx_v_value;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  Py_ssize_t __pyx_v_first_na;
  khiter_t __pyx_v_k;
  kh_int16_t *__pyx_v_table;
  PyArrayObject *__pyx_v_out = 0;
  int __pyx_v_seen_na;
  int __pyx_v_uses_mask;
  int __pyx_v_seen_multiple_na;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_out;
  __Pyx_Buffer __pyx_pybuffer_out;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  khuint_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  size_t __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("duplicated_int16", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_out.pybuffer.buf = NULL;
  __pyx_pybuffer_out.refcount = 0;
  __pyx_pybuffernd_out.data = NULL;
  __pyx_pybuffernd_out.rcbuffer = &__pyx_pybuffer_out;

  /* "pandas/_libs/hashtable_func_helper.pxi":2203
 * cdef duplicated_int16(const int16_t[:] values, object keep='first', const uint8_t[:] mask=None):
 *     cdef:
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         int16_t value
 *         Py_ssize_t i, n = len(values), first_na = -1
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2205
 *         int ret = 0
 *         int16_t value
 *         Py_ssize_t i, n = len(values), first_na = -1             # <<<<<<<<<<<<<<
 *         khiter_t k
 *         kh_int16_t *table = kh_init_int16()
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;
  __pyx_v_first_na = -1L;

  /* "pandas/_libs/hashtable_func_helper.pxi":2207
 *         Py_ssize_t i, n = len(values), first_na = -1
 *         khiter_t k
 *         kh_int16_t *table = kh_init_int16()             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 */
  __pyx_v_table = kh_init_int16();

  /* "pandas/_libs/hashtable_func_helper.pxi":2208
 *         khiter_t k
 *         kh_int16_t *table = kh_init_int16()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')             # <<<<<<<<<<<<<<
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(5, 2208, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_n_u_bool) < 0) __PYX_ERR(5, 2208, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2208, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_out.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 1, __pyx_stack) == -1)) {
      __pyx_v_out = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_out.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(5, 2208, __pyx_L1_error)
    } else {__pyx_pybuffernd_out.diminfo[0].strides = __pyx_pybuffernd_out.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_out.diminfo[0].shape = __pyx_pybuffernd_out.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_out = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2209
 *         kh_int16_t *table = kh_init_int16()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint seen_multiple_na = False
 * 
 */
  __pyx_v_seen_na = 0;
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":2210
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_int16(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 */
  __pyx_v_seen_multiple_na = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2212
 *         bint seen_multiple_na = False
 * 
 *     kh_resize_int16(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))             # <<<<<<<<<<<<<<
 * 
 *     if keep not in ('last', 'first', False):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = kh_needed_n_buckets(__pyx_v_n);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2212, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_5, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2212, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(5, 2212, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_8) {
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_2 = __pyx_t_5;
  } else {
    __pyx_t_3 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2212, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_uint32(__pyx_t_2); if (unlikely((__pyx_t_7 == ((khuint_t)-1)) && PyErr_Occurred())) __PYX_ERR(5, 2212, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  kh_resize_int16(__pyx_v_table, __pyx_t_7);

  /* "pandas/_libs/hashtable_func_helper.pxi":2214
 *     kh_resize_int16(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  __Pyx_INCREF(__pyx_v_keep);
  __pyx_t_2 = __pyx_v_keep;
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_last, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2214, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_first, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2214, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, Py_False, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2214, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2214, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_8 = __pyx_t_9;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_9 = __pyx_t_8;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":2215
 * 
 *     if keep not in ('last', 'first', False):
 *         raise ValueError('keep must be either "first", "last" or False')             # <<<<<<<<<<<<<<
 * 
 *     if keep == "last":
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__43, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2215, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(5, 2215, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":2214
 *     kh_resize_int16(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2217
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_last, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2217, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":2218
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":2219
 *     if keep == "last":
 *         with nogil:
 *             for i in range(n - 1, -1, -1):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          for (__pyx_t_1 = (__pyx_v_n - 1); __pyx_t_1 > -1L; __pyx_t_1-=1) {
            __pyx_v_i = __pyx_t_1;

            /* "pandas/_libs/hashtable_func_helper.pxi":2220
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L14_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L14_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":2221
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":2222
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2221
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L16;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":2224
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":2225
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = (values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L16:;

              /* "pandas/_libs/hashtable_func_helper.pxi":2220
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L13;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":2227
 *                         seen_na = True
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_int16(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_int16_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":2228
 *                 else:
 *                     value = (values[i])
 *                     kh_put_int16(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 *     elif keep == "first":
 */
              (void)(kh_put_int16(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":2229
 *                     value = (values[i])
 *                     kh_put_int16(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 *     elif keep == "first":
 *         with nogil:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L13:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":2218
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L10;
          }
          __pyx_L10:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":2217
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2230
 *                     kh_put_int16(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_first, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2230, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":2231
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":2232
 *     elif keep == "first":
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_11 = __pyx_t_1;
          for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
            __pyx_v_i = __pyx_t_12;

            /* "pandas/_libs/hashtable_func_helper.pxi":2233
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L23_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L23_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":2234
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":2235
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2234
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L25;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":2237
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":2238
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = (values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L25:;

              /* "pandas/_libs/hashtable_func_helper.pxi":2233
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L22;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":2240
 *                         seen_na = True
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_int16(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_int16_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":2241
 *                 else:
 *                     value = (values[i])
 *                     kh_put_int16(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 * 
 */
              (void)(kh_put_int16(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":2242
 *                     value = (values[i])
 *                     kh_put_int16(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 * 
 *     else:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L22:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":2231
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L19;
          }
          __pyx_L19:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":2230
 *                     kh_put_int16(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2245
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
  /*else*/ {
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":2246
 *     else:
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_11 = __pyx_t_1;
          for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
            __pyx_v_i = __pyx_t_12;

            /* "pandas/_libs/hashtable_func_helper.pxi":2247
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L32_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L32_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":2248
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
              __pyx_t_9 = (!__pyx_v_seen_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":2249
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 *                         first_na = i             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                         out[i] = 0
 */
                __pyx_v_first_na = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":2250
 *                     if not seen_na:
 *                         first_na = i
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 */
                __pyx_v_seen_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2251
 *                         first_na = i
 *                         seen_na = True
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":2248
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":2252
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
              __pyx_t_9 = (!__pyx_v_seen_multiple_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":2253
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                         out[first_na] = 1
 *                         seen_multiple_na = True
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2254
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 *                         out[first_na] = 1             # <<<<<<<<<<<<<<
 *                         seen_multiple_na = True
 *                     else:
 */
                __pyx_t_10 = __pyx_v_first_na;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2255
 *                         out[i] = 1
 *                         out[first_na] = 1
 *                         seen_multiple_na = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = 1
 */
                __pyx_v_seen_multiple_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2252
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":2257
 *                         seen_multiple_na = True
 *                     else:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 * 
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;
              }
              __pyx_L34:;

              /* "pandas/_libs/hashtable_func_helper.pxi":2247
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
              goto __pyx_L31;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":2260
 * 
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_int16(table, value)
 *                     if k != table.n_buckets:
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_int16_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":2261
 *                 else:
 *                     value = (values[i])
 *                     k = kh_get_int16(table, value)             # <<<<<<<<<<<<<<
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 */
              __pyx_v_k = kh_get_int16(__pyx_v_table, __pyx_v_value);

              /* "pandas/_libs/hashtable_func_helper.pxi":2262
 *                     value = (values[i])
 *                     k = kh_get_int16(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
              __pyx_t_9 = (__pyx_v_k != __pyx_v_table->n_buckets);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":2263
 *                     k = kh_get_int16(table, value)
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                     else:
 */
                __pyx_t_13 = (__pyx_v_table->vals[__pyx_v_k]);
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_13, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2264
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                     else:
 *                         k = kh_put_int16(table, value, &ret)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2262
 *                     value = (values[i])
 *                     k = kh_get_int16(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
                goto __pyx_L35;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":2266
 *                         out[i] = 1
 *                     else:
 *                         k = kh_put_int16(table, value, &ret)             # <<<<<<<<<<<<<<
 *                         table.vals[k] = i
 *                         out[i] = 0
 */
              /*else*/ {
                __pyx_v_k = kh_put_int16(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret));

                /* "pandas/_libs/hashtable_func_helper.pxi":2267
 *                     else:
 *                         k = kh_put_int16(table, value, &ret)
 *                         table.vals[k] = i             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 * 
 */
                (__pyx_v_table->vals[__pyx_v_k]) = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":2268
 *                         k = kh_put_int16(table, value, &ret)
 *                         table.vals[k] = i
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_int16(table)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;
              }
              __pyx_L35:;
            }
            __pyx_L31:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":2245
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L28;
          }
          __pyx_L28:;
        }
    }
  }
  __pyx_L7:;

  /* "pandas/_libs/hashtable_func_helper.pxi":2270
 *                         out[i] = 0
 * 
 *     kh_destroy_int16(table)             # <<<<<<<<<<<<<<
 *     return out
 * 
 */
  kh_destroy_int16(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":2271
 * 
 *     kh_destroy_int16(table)
 *     return out             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_out);
  __pyx_r = ((PyObject *)__pyx_v_out);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2201
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_int16(const int16_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated_int16", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_out);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":2281
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_int16(const int16_t[:] arr, const int16_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_int16(__Pyx_memviewslice __pyx_v_arr, __Pyx_memviewslice __pyx_v_values) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  PyArrayObject *__pyx_v_result = 0;
  __pyx_t_5numpy_int16_t __pyx_v_val;
  kh_int16_t *__pyx_v_table;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyArrayObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ismember_int16", 1);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "pandas/_libs/hashtable_func_helper.pxi":2298
 *         Py_ssize_t i, n
 *         khiter_t k
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t] result
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2303
 *         int16_t val
 * 
 *         kh_int16_t *table = kh_init_int16()             # <<<<<<<<<<<<<<
 * 
 *     # construct the table
 */
  __pyx_v_table = kh_init_int16();

  /* "pandas/_libs/hashtable_func_helper.pxi":2306
 * 
 *     # construct the table
 *     n = len(values)             # <<<<<<<<<<<<<<
 *     kh_resize_int16(table, n)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":2307
 *     # construct the table
 *     n = len(values)
 *     kh_resize_int16(table, n)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  kh_resize_int16(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":2309
 *     kh_resize_int16(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":2310
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = (values[i])
 *             kh_put_int16(table, val, &ret)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":2311
 *     with nogil:
 *         for i in range(n):
 *             val = (values[i])             # <<<<<<<<<<<<<<
 *             kh_put_int16(table, val, &ret)
 * 
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_int16_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_4 * __pyx_v_values.strides[0]) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":2312
 *         for i in range(n):
 *             val = (values[i])
 *             kh_put_int16(table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *     # test membership
 */
          (void)(kh_put_int16(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret)));
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2309
 *     kh_resize_int16(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2315
 * 
 *     # test membership
 *     n = len(arr)             # <<<<<<<<<<<<<<
 *     result = np.empty(n, dtype=np.uint8)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_arr); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":2316
 *     # test membership
 *     n = len(arr)
 *     result = np.empty(n, dtype=np.uint8)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_empty); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5)) __PYX_ERR(5, 2316, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(5, 2316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_uint8); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 2316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dtype, __pyx_t_9) < 0) __PYX_ERR(5, 2316, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, __pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 2316, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (!(likely(((__pyx_t_9) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_9, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2316, __pyx_L1_error)
  __pyx_t_10 = ((PyArrayObject *)__pyx_t_9);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_11 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_10, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_11 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_13); Py_XDECREF(__pyx_t_14);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __pyx_t_12 = __pyx_t_13 = __pyx_t_14 = 0;
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(5, 2316, __pyx_L1_error)
  }
  __pyx_t_10 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_9);
  __pyx_t_9 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2318
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (arr[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":2319
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = (arr[i])
 *             k = kh_get_int16(table, val)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":2320
 *     with nogil:
 *         for i in range(n):
 *             val = (arr[i])             # <<<<<<<<<<<<<<
 *             k = kh_get_int16(table, val)
 *             result[i] = (k != table.n_buckets)
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_int16_t const  *) ( /* dim=0 */ (__pyx_v_arr.data + __pyx_t_4 * __pyx_v_arr.strides[0]) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":2321
 *         for i in range(n):
 *             val = (arr[i])
 *             k = kh_get_int16(table, val)             # <<<<<<<<<<<<<<
 *             result[i] = (k != table.n_buckets)
 * 
 */
          __pyx_v_k = kh_get_int16(__pyx_v_table, __pyx_v_val);

          /* "pandas/_libs/hashtable_func_helper.pxi":2322
 *             val = (arr[i])
 *             k = kh_get_int16(table, val)
 *             result[i] = (k != table.n_buckets)             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_int16(table)
 */
          __pyx_t_4 = __pyx_v_i;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_result.rcbuffer->pybuffer.buf, __pyx_t_4, __pyx_pybuffernd_result.diminfo[0].strides) = (__pyx_v_k != __pyx_v_table->n_buckets);
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2318
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (arr[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L10;
        }
        __pyx_L10:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2324
 *             result[i] = (k != table.n_buckets)
 * 
 *     kh_destroy_int16(table)             # <<<<<<<<<<<<<<
 *     return result.view(np.bool_)
 * 
 */
  kh_destroy_int16(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":2325
 * 
 *     kh_destroy_int16(table)
 *     return result.view(np.bool_)             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_result), __pyx_n_s_view); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_bool_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2325, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_11 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_11 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_6};
    __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_11, 1+__pyx_t_11);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 2325, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_r = __pyx_t_9;
  __pyx_t_9 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2281
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_int16(const int16_t[:] arr, const int16_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember_int16", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":2334
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_int8(const int8_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_value_count_int8(__Pyx_memviewslice __pyx_v_values, int __pyx_v_dropna, struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_int8 *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__67;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  kh_int8_t *__pyx_v_table;
  khiter_t __pyx_v_k;
  __pyx_t_5numpy_int8_t __pyx_v_val;
  int __pyx_v_ret;
  int __pyx_v_uses_mask;
  int __pyx_v_isna_entry;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *__pyx_v_result_keys = NULL;
  __Pyx_memviewslice __pyx_v_result_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  Py_ssize_t __pyx_t_7;
  khiter_t __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  khuint_t __pyx_t_14;
  khuint_t __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("value_count_int8", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2336
 * cdef value_count_int8(const int8_t[:] values, bint dropna, const uint8_t[:] mask=None):
 *     cdef:
 *         Py_ssize_t i = 0             # <<<<<<<<<<<<<<
 *         Py_ssize_t n = len(values)
 *         kh_int8_t *table
 */
  __pyx_v_i = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2337
 *     cdef:
 *         Py_ssize_t i = 0
 *         Py_ssize_t n = len(values)             # <<<<<<<<<<<<<<
 *         kh_int8_t *table
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":2345
 *         int8_t val
 * 
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2346
 * 
 *         int ret = 0
 *         bint uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint isna_entry = False
 * 
 */
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":2347
 *         int ret = 0
 *         bint uses_mask = mask is not None
 *         bint isna_entry = False             # <<<<<<<<<<<<<<
 * 
 *     if uses_mask and not dropna:
 */
  __pyx_v_isna_entry = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2349
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  if (__pyx_v_uses_mask) {
  } else {
    __pyx_t_2 = __pyx_v_uses_mask;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = (!__pyx_v_dropna);
  __pyx_t_2 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (unlikely(__pyx_t_2)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":2350
 * 
 *     if uses_mask and not dropna:
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")             # <<<<<<<<<<<<<<
 * 
 *     # we track the order in which keys are first seen (GH39009),
 */
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_NotImplementedError, __pyx_tuple__41, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2350, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __PYX_ERR(5, 2350, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":2349
 *         bint isna_entry = False
 * 
 *     if uses_mask and not dropna:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2357
 *     #    result_keys remembers the original order of keys
 * 
 *     result_keys = Int8Vector()             # <<<<<<<<<<<<<<
 *     table = kh_init_int8()
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector)); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2357, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_v_result_keys = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2358
 * 
 *     result_keys = Int8Vector()
 *     table = kh_init_int8()             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_int8(table, n)
 */
  __pyx_v_table = kh_init_int8();

  /* "pandas/_libs/hashtable_func_helper.pxi":2360
 *     table = kh_init_int8()
 * 
 *     kh_resize_int8(table, n)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(n):
 */
  kh_resize_int8(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":2362
 *     kh_resize_int8(table, n)
 * 
 *     for i in range(n):             # <<<<<<<<<<<<<<
 *         val = (values[i])
 * 
 */
  __pyx_t_1 = __pyx_v_n;
  __pyx_t_5 = __pyx_t_1;
  for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
    __pyx_v_i = __pyx_t_6;

    /* "pandas/_libs/hashtable_func_helper.pxi":2363
 * 
 *     for i in range(n):
 *         val = (values[i])             # <<<<<<<<<<<<<<
 * 
 *         if dropna:
 */
    __pyx_t_7 = __pyx_v_i;
    __pyx_v_val = (*((__pyx_t_5numpy_int8_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_7 * __pyx_v_values.strides[0]) )));

    /* "pandas/_libs/hashtable_func_helper.pxi":2365
 *         val = (values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    if (__pyx_v_dropna) {

      /* "pandas/_libs/hashtable_func_helper.pxi":2366
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
      if (__pyx_v_uses_mask) {

        /* "pandas/_libs/hashtable_func_helper.pxi":2367
 *         if dropna:
 *             if uses_mask:
 *                 isna_entry = mask[i]             # <<<<<<<<<<<<<<
 *             else:
 *                 isna_entry = is_nan_int8_t(val)
 */
        __pyx_t_7 = __pyx_v_i;
        __pyx_v_isna_entry = (*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_7 * __pyx_v_mask.strides[0]) )));

        /* "pandas/_libs/hashtable_func_helper.pxi":2366
 * 
 *         if dropna:
 *             if uses_mask:             # <<<<<<<<<<<<<<
 *                 isna_entry = mask[i]
 *             else:
 */
        goto __pyx_L9;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2369
 *                 isna_entry = mask[i]
 *             else:
 *                 isna_entry = is_nan_int8_t(val)             # <<<<<<<<<<<<<<
 * 
 *         if not dropna or not isna_entry:
 */
      /*else*/ {
        __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_is_nan_int8_t(__pyx_v_val); if (unlikely(__pyx_t_2 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2369, __pyx_L1_error)
        __pyx_v_isna_entry = __pyx_t_2;
      }
      __pyx_L9:;

      /* "pandas/_libs/hashtable_func_helper.pxi":2365
 *         val = (values[i])
 * 
 *         if dropna:             # <<<<<<<<<<<<<<
 *             if uses_mask:
 *                 isna_entry = mask[i]
 */
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":2371
 *                 isna_entry = is_nan_int8_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_int8(table, val)
 *             if k != table.n_buckets:
 */
    __pyx_t_3 = (!__pyx_v_dropna);
    if (!__pyx_t_3) {
    } else {
      __pyx_t_2 = __pyx_t_3;
      goto __pyx_L11_bool_binop_done;
    }
    __pyx_t_3 = (!__pyx_v_isna_entry);
    __pyx_t_2 = __pyx_t_3;
    __pyx_L11_bool_binop_done:;
    if (__pyx_t_2) {

      /* "pandas/_libs/hashtable_func_helper.pxi":2372
 * 
 *         if not dropna or not isna_entry:
 *             k = kh_get_int8(table, val)             # <<<<<<<<<<<<<<
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1
 */
      __pyx_v_k = kh_get_int8(__pyx_v_table, __pyx_v_val);

      /* "pandas/_libs/hashtable_func_helper.pxi":2373
 *         if not dropna or not isna_entry:
 *             k = kh_get_int8(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
      __pyx_t_2 = (__pyx_v_k != __pyx_v_table->n_buckets);
      if (__pyx_t_2) {

        /* "pandas/_libs/hashtable_func_helper.pxi":2374
 *             k = kh_get_int8(table, val)
 *             if k != table.n_buckets:
 *                 table.vals[k] += 1             # <<<<<<<<<<<<<<
 *             else:
 *                 k = kh_put_int8(table, val, &ret)
 */
        __pyx_t_8 = __pyx_v_k;
        (__pyx_v_table->vals[__pyx_t_8]) = ((__pyx_v_table->vals[__pyx_t_8]) + 1);

        /* "pandas/_libs/hashtable_func_helper.pxi":2373
 *         if not dropna or not isna_entry:
 *             k = kh_get_int8(table, val)
 *             if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                 table.vals[k] += 1
 *             else:
 */
        goto __pyx_L13;
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2376
 *                 table.vals[k] += 1
 *             else:
 *                 k = kh_put_int8(table, val, &ret)             # <<<<<<<<<<<<<<
 *                 table.vals[k] = 1
 *                 result_keys.append(val)
 */
      /*else*/ {
        __pyx_v_k = kh_put_int8(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret));

        /* "pandas/_libs/hashtable_func_helper.pxi":2377
 *             else:
 *                 k = kh_put_int8(table, val, &ret)
 *                 table.vals[k] = 1             # <<<<<<<<<<<<<<
 *                 result_keys.append(val)
 * 
 */
        (__pyx_v_table->vals[__pyx_v_k]) = 1;

        /* "pandas/_libs/hashtable_func_helper.pxi":2378
 *                 k = kh_put_int8(table, val, &ret)
 *                 table.vals[k] = 1
 *                 result_keys.append(val)             # <<<<<<<<<<<<<<
 * 
 *     # collect counts in the order corresponding to result_keys:
 */
        ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int8Vector *)__pyx_v_result_keys->__pyx_vtab)->append(__pyx_v_result_keys, __pyx_v_val); if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2378, __pyx_L1_error)
      }
      __pyx_L13:;

      /* "pandas/_libs/hashtable_func_helper.pxi":2371
 *                 isna_entry = is_nan_int8_t(val)
 * 
 *         if not dropna or not isna_entry:             # <<<<<<<<<<<<<<
 *             k = kh_get_int8(table, val)
 *             if k != table.n_buckets:
 */
    }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2382
 *     # collect counts in the order corresponding to result_keys:
 *     cdef:
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)             # <<<<<<<<<<<<<<
 * 
 *     for i in range(table.size):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_empty); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 2382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_v_table->size); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = PyTuple_New(1); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 2382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_10, 0, __pyx_t_4)) __PYX_ERR(5, 2382, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GetModuleGlobalName(__pyx_t_11, __pyx_n_s_np); if (unlikely(!__pyx_t_11)) __PYX_ERR(5, 2382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_11);
  __pyx_t_12 = __Pyx_PyObject_GetAttrStr(__pyx_t_11, __pyx_n_s_int64); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 2382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_dtype, __pyx_t_12) < 0) __PYX_ERR(5, 2382, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_9, __pyx_t_10, __pyx_t_4); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 2382, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_12, PyBUF_WRITABLE); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(5, 2382, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_v_result_counts = __pyx_t_13;
  __pyx_t_13.memview = NULL;
  __pyx_t_13.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2384
 *         int64_t[::1] result_counts = np.empty(table.size, dtype=np.int64)
 * 
 *     for i in range(table.size):             # <<<<<<<<<<<<<<
 *         k = kh_get_int8(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]
 */
  __pyx_t_14 = __pyx_v_table->size;
  __pyx_t_15 = __pyx_t_14;
  for (__pyx_t_1 = 0; __pyx_t_1 < __pyx_t_15; __pyx_t_1+=1) {
    __pyx_v_i = __pyx_t_1;

    /* "pandas/_libs/hashtable_func_helper.pxi":2385
 * 
 *     for i in range(table.size):
 *         k = kh_get_int8(table, result_keys.data.data[i])             # <<<<<<<<<<<<<<
 *         result_counts[i] = table.vals[k]
 * 
 */
    __pyx_v_k = kh_get_int8(__pyx_v_table, (__pyx_v_result_keys->data->data[__pyx_v_i]));

    /* "pandas/_libs/hashtable_func_helper.pxi":2386
 *     for i in range(table.size):
 *         k = kh_get_int8(table, result_keys.data.data[i])
 *         result_counts[i] = table.vals[k]             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_int8(table)
 */
    __pyx_t_7 = __pyx_v_i;
    *((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_result_counts.data) + __pyx_t_7)) )) = (__pyx_v_table->vals[__pyx_v_k]);
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2388
 *         result_counts[i] = table.vals[k]
 * 
 *     kh_destroy_int8(table)             # <<<<<<<<<<<<<<
 * 
 *     return result_keys.to_array(), result_counts.base
 */
  kh_destroy_int8(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":2390
 *     kh_destroy_int8(table)
 * 
 *     return result_keys.to_array(), result_counts.base             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_12 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int8Vector *)__pyx_v_result_keys->__pyx_vtab)->to_array(__pyx_v_result_keys, 0)); if (unlikely(!__pyx_t_12)) __PYX_ERR(5, 2390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_v_result_counts, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int64_t, (int (*)(char *, PyObject *)) __pyx_memview_set_nn___pyx_t_5numpy_int64_t, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_10 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_base); if (unlikely(!__pyx_t_10)) __PYX_ERR(5, 2390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2390, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_12);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_12)) __PYX_ERR(5, 2390, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_10);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_10)) __PYX_ERR(5, 2390, __pyx_L1_error);
  __pyx_t_12 = 0;
  __pyx_t_10 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2334
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_int8(const int8_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_XDECREF(__pyx_t_12);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_13, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count_int8", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result_keys);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_result_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":2395
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_int8(const int8_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_duplicated_int8(__Pyx_memviewslice __pyx_v_values, struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_int8 *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__68;
  int __pyx_v_ret;
  __pyx_t_5numpy_int8_t __pyx_v_value;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  Py_ssize_t __pyx_v_first_na;
  khiter_t __pyx_v_k;
  kh_int8_t *__pyx_v_table;
  PyArrayObject *__pyx_v_out = 0;
  int __pyx_v_seen_na;
  int __pyx_v_uses_mask;
  int __pyx_v_seen_multiple_na;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_out;
  __Pyx_Buffer __pyx_pybuffer_out;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  khuint_t __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  Py_ssize_t __pyx_t_12;
  size_t __pyx_t_13;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("duplicated_int8", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_out.pybuffer.buf = NULL;
  __pyx_pybuffer_out.refcount = 0;
  __pyx_pybuffernd_out.data = NULL;
  __pyx_pybuffernd_out.rcbuffer = &__pyx_pybuffer_out;

  /* "pandas/_libs/hashtable_func_helper.pxi":2397
 * cdef duplicated_int8(const int8_t[:] values, object keep='first', const uint8_t[:] mask=None):
 *     cdef:
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         int8_t value
 *         Py_ssize_t i, n = len(values), first_na = -1
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2399
 *         int ret = 0
 *         int8_t value
 *         Py_ssize_t i, n = len(values), first_na = -1             # <<<<<<<<<<<<<<
 *         khiter_t k
 *         kh_int8_t *table = kh_init_int8()
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;
  __pyx_v_first_na = -1L;

  /* "pandas/_libs/hashtable_func_helper.pxi":2401
 *         Py_ssize_t i, n = len(values), first_na = -1
 *         khiter_t k
 *         kh_int8_t *table = kh_init_int8()             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 */
  __pyx_v_table = kh_init_int8();

  /* "pandas/_libs/hashtable_func_helper.pxi":2402
 *         khiter_t k
 *         kh_int8_t *table = kh_init_int8()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')             # <<<<<<<<<<<<<<
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_np); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2)) __PYX_ERR(5, 2402, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_n_u_bool) < 0) __PYX_ERR(5, 2402, __pyx_L1_error)
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2402, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2402, __pyx_L1_error)
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_out.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 1, __pyx_stack) == -1)) {
      __pyx_v_out = ((PyArrayObject *)Py_None); __Pyx_INCREF(Py_None); __pyx_pybuffernd_out.rcbuffer->pybuffer.buf = NULL;
      __PYX_ERR(5, 2402, __pyx_L1_error)
    } else {__pyx_pybuffernd_out.diminfo[0].strides = __pyx_pybuffernd_out.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_out.diminfo[0].shape = __pyx_pybuffernd_out.rcbuffer->pybuffer.shape[0];
    }
  }
  __pyx_t_6 = 0;
  __pyx_v_out = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2403
 *         kh_int8_t *table = kh_init_int8()
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None             # <<<<<<<<<<<<<<
 *         bint seen_multiple_na = False
 * 
 */
  __pyx_v_seen_na = 0;
  __pyx_v_uses_mask = (((PyObject *) __pyx_v_mask.memview) != Py_None);

  /* "pandas/_libs/hashtable_func_helper.pxi":2404
 *         ndarray[uint8_t, ndim=1, cast=True] out = np.empty(n, dtype='bool')
 *         bint seen_na = False, uses_mask = mask is not None
 *         bint seen_multiple_na = False             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_int8(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 */
  __pyx_v_seen_multiple_na = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2406
 *         bint seen_multiple_na = False
 * 
 *     kh_resize_int8(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))             # <<<<<<<<<<<<<<
 * 
 *     if keep not in ('last', 'first', False):
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = kh_needed_n_buckets(__pyx_v_n);
  __pyx_t_4 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2406, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_5, __pyx_t_4, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2406, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(5, 2406, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_8) {
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_2 = __pyx_t_5;
  } else {
    __pyx_t_3 = __Pyx_PyInt_From_npy_uint32(__pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2406, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = __pyx_t_3;
    __pyx_t_3 = 0;
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_7 = __Pyx_PyInt_As_npy_uint32(__pyx_t_2); if (unlikely((__pyx_t_7 == ((khuint_t)-1)) && PyErr_Occurred())) __PYX_ERR(5, 2406, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  kh_resize_int8(__pyx_v_table, __pyx_t_7);

  /* "pandas/_libs/hashtable_func_helper.pxi":2408
 *     kh_resize_int8(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  __Pyx_INCREF(__pyx_v_keep);
  __pyx_t_2 = __pyx_v_keep;
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_last, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2408, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_n_u_first, Py_NE)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2408, __pyx_L1_error)
  if (__pyx_t_9) {
  } else {
    __pyx_t_8 = __pyx_t_9;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_2, Py_False, Py_NE); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2408, __pyx_L1_error)
  __pyx_t_9 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2408, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_8 = __pyx_t_9;
  __pyx_L4_bool_binop_done:;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_9 = __pyx_t_8;
  if (unlikely(__pyx_t_9)) {

    /* "pandas/_libs/hashtable_func_helper.pxi":2409
 * 
 *     if keep not in ('last', 'first', False):
 *         raise ValueError('keep must be either "first", "last" or False')             # <<<<<<<<<<<<<<
 * 
 *     if keep == "last":
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__43, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2409, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(5, 2409, __pyx_L1_error)

    /* "pandas/_libs/hashtable_func_helper.pxi":2408
 *     kh_resize_int8(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     if keep not in ('last', 'first', False):             # <<<<<<<<<<<<<<
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 */
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2411
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_last, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2411, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":2412
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":2413
 *     if keep == "last":
 *         with nogil:
 *             for i in range(n - 1, -1, -1):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          for (__pyx_t_1 = (__pyx_v_n - 1); __pyx_t_1 > -1L; __pyx_t_1-=1) {
            __pyx_v_i = __pyx_t_1;

            /* "pandas/_libs/hashtable_func_helper.pxi":2414
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L14_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L14_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":2415
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":2416
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2415
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L16;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":2418
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":2419
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = (values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L16:;

              /* "pandas/_libs/hashtable_func_helper.pxi":2414
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L13;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":2421
 *                         seen_na = True
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_int8(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_int8_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":2422
 *                 else:
 *                     value = (values[i])
 *                     kh_put_int8(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 *     elif keep == "first":
 */
              (void)(kh_put_int8(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":2423
 *                     value = (values[i])
 *                     kh_put_int8(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 *     elif keep == "first":
 *         with nogil:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L13:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":2412
 * 
 *     if keep == "last":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n - 1, -1, -1):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L10;
          }
          __pyx_L10:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":2411
 *         raise ValueError('keep must be either "first", "last" or False')
 * 
 *     if keep == "last":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n - 1, -1, -1):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2424
 *                     kh_put_int8(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
  __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_v_keep, __pyx_n_u_first, Py_EQ)); if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2424, __pyx_L1_error)
  if (__pyx_t_9) {

    /* "pandas/_libs/hashtable_func_helper.pxi":2425
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":2426
 *     elif keep == "first":
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_11 = __pyx_t_1;
          for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
            __pyx_v_i = __pyx_t_12;

            /* "pandas/_libs/hashtable_func_helper.pxi":2427
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L23_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L23_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":2428
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
              if (__pyx_v_seen_na) {

                /* "pandas/_libs/hashtable_func_helper.pxi":2429
 *                 if uses_mask and mask[i]:
 *                     if seen_na:
 *                         out[i] = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = False
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2428
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if seen_na:             # <<<<<<<<<<<<<<
 *                         out[i] = True
 *                     else:
 */
                goto __pyx_L25;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":2431
 *                         out[i] = True
 *                     else:
 *                         out[i] = False             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":2432
 *                     else:
 *                         out[i] = False
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                 else:
 *                     value = (values[i])
 */
                __pyx_v_seen_na = 1;
              }
              __pyx_L25:;

              /* "pandas/_libs/hashtable_func_helper.pxi":2427
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if seen_na:
 *                         out[i] = True
 */
              goto __pyx_L22;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":2434
 *                         seen_na = True
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     kh_put_int8(table, value, &ret)
 *                     out[i] = ret == 0
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_int8_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":2435
 *                 else:
 *                     value = (values[i])
 *                     kh_put_int8(table, value, &ret)             # <<<<<<<<<<<<<<
 *                     out[i] = ret == 0
 * 
 */
              (void)(kh_put_int8(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret)));

              /* "pandas/_libs/hashtable_func_helper.pxi":2436
 *                     value = (values[i])
 *                     kh_put_int8(table, value, &ret)
 *                     out[i] = ret == 0             # <<<<<<<<<<<<<<
 * 
 *     else:
 */
              __pyx_t_10 = __pyx_v_i;
              *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = (__pyx_v_ret == 0);
            }
            __pyx_L22:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":2425
 *                     out[i] = ret == 0
 *     elif keep == "first":
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L19;
          }
          __pyx_L19:;
        }
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":2424
 *                     kh_put_int8(table, value, &ret)
 *                     out[i] = ret == 0
 *     elif keep == "first":             # <<<<<<<<<<<<<<
 *         with nogil:
 *             for i in range(n):
 */
    goto __pyx_L7;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2439
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
  /*else*/ {
    {
        #ifdef WITH_THREAD
        PyThreadState *_save;
        _save = NULL;
        Py_UNBLOCK_THREADS
        __Pyx_FastGIL_Remember();
        #endif
        /*try:*/ {

          /* "pandas/_libs/hashtable_func_helper.pxi":2440
 *     else:
 *         with nogil:
 *             for i in range(n):             # <<<<<<<<<<<<<<
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 */
          __pyx_t_1 = __pyx_v_n;
          __pyx_t_11 = __pyx_t_1;
          for (__pyx_t_12 = 0; __pyx_t_12 < __pyx_t_11; __pyx_t_12+=1) {
            __pyx_v_i = __pyx_t_12;

            /* "pandas/_libs/hashtable_func_helper.pxi":2441
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
            if (__pyx_v_uses_mask) {
            } else {
              __pyx_t_9 = __pyx_v_uses_mask;
              goto __pyx_L32_bool_binop_done;
            }
            __pyx_t_10 = __pyx_v_i;
            __pyx_t_8 = ((*((__pyx_t_5numpy_uint8_t const  *) ( /* dim=0 */ (__pyx_v_mask.data + __pyx_t_10 * __pyx_v_mask.strides[0]) ))) != 0);
            __pyx_t_9 = __pyx_t_8;
            __pyx_L32_bool_binop_done:;
            if (__pyx_t_9) {

              /* "pandas/_libs/hashtable_func_helper.pxi":2442
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
              __pyx_t_9 = (!__pyx_v_seen_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":2443
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:
 *                         first_na = i             # <<<<<<<<<<<<<<
 *                         seen_na = True
 *                         out[i] = 0
 */
                __pyx_v_first_na = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":2444
 *                     if not seen_na:
 *                         first_na = i
 *                         seen_na = True             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 */
                __pyx_v_seen_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2445
 *                         first_na = i
 *                         seen_na = True
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;

                /* "pandas/_libs/hashtable_func_helper.pxi":2442
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 *                     if not seen_na:             # <<<<<<<<<<<<<<
 *                         first_na = i
 *                         seen_na = True
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":2446
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
              __pyx_t_9 = (!__pyx_v_seen_multiple_na);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":2447
 *                         out[i] = 0
 *                     elif not seen_multiple_na:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                         out[first_na] = 1
 *                         seen_multiple_na = True
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2448
 *                     elif not seen_multiple_na:
 *                         out[i] = 1
 *                         out[first_na] = 1             # <<<<<<<<<<<<<<
 *                         seen_multiple_na = True
 *                     else:
 */
                __pyx_t_10 = __pyx_v_first_na;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2449
 *                         out[i] = 1
 *                         out[first_na] = 1
 *                         seen_multiple_na = True             # <<<<<<<<<<<<<<
 *                     else:
 *                         out[i] = 1
 */
                __pyx_v_seen_multiple_na = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2446
 *                         seen_na = True
 *                         out[i] = 0
 *                     elif not seen_multiple_na:             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                         out[first_na] = 1
 */
                goto __pyx_L34;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":2451
 *                         seen_multiple_na = True
 *                     else:
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 * 
 *                 else:
 */
              /*else*/ {
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;
              }
              __pyx_L34:;

              /* "pandas/_libs/hashtable_func_helper.pxi":2441
 *         with nogil:
 *             for i in range(n):
 *                 if uses_mask and mask[i]:             # <<<<<<<<<<<<<<
 *                     if not seen_na:
 *                         first_na = i
 */
              goto __pyx_L31;
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":2454
 * 
 *                 else:
 *                     value = (values[i])             # <<<<<<<<<<<<<<
 *                     k = kh_get_int8(table, value)
 *                     if k != table.n_buckets:
 */
            /*else*/ {
              __pyx_t_10 = __pyx_v_i;
              __pyx_v_value = (*((__pyx_t_5numpy_int8_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_10 * __pyx_v_values.strides[0]) )));

              /* "pandas/_libs/hashtable_func_helper.pxi":2455
 *                 else:
 *                     value = (values[i])
 *                     k = kh_get_int8(table, value)             # <<<<<<<<<<<<<<
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 */
              __pyx_v_k = kh_get_int8(__pyx_v_table, __pyx_v_value);

              /* "pandas/_libs/hashtable_func_helper.pxi":2456
 *                     value = (values[i])
 *                     k = kh_get_int8(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
              __pyx_t_9 = (__pyx_v_k != __pyx_v_table->n_buckets);
              if (__pyx_t_9) {

                /* "pandas/_libs/hashtable_func_helper.pxi":2457
 *                     k = kh_get_int8(table, value)
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1             # <<<<<<<<<<<<<<
 *                         out[i] = 1
 *                     else:
 */
                __pyx_t_13 = (__pyx_v_table->vals[__pyx_v_k]);
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_13, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2458
 *                     if k != table.n_buckets:
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1             # <<<<<<<<<<<<<<
 *                     else:
 *                         k = kh_put_int8(table, value, &ret)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 1;

                /* "pandas/_libs/hashtable_func_helper.pxi":2456
 *                     value = (values[i])
 *                     k = kh_get_int8(table, value)
 *                     if k != table.n_buckets:             # <<<<<<<<<<<<<<
 *                         out[table.vals[k]] = 1
 *                         out[i] = 1
 */
                goto __pyx_L35;
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":2460
 *                         out[i] = 1
 *                     else:
 *                         k = kh_put_int8(table, value, &ret)             # <<<<<<<<<<<<<<
 *                         table.vals[k] = i
 *                         out[i] = 0
 */
              /*else*/ {
                __pyx_v_k = kh_put_int8(__pyx_v_table, __pyx_v_value, (&__pyx_v_ret));

                /* "pandas/_libs/hashtable_func_helper.pxi":2461
 *                     else:
 *                         k = kh_put_int8(table, value, &ret)
 *                         table.vals[k] = i             # <<<<<<<<<<<<<<
 *                         out[i] = 0
 * 
 */
                (__pyx_v_table->vals[__pyx_v_k]) = __pyx_v_i;

                /* "pandas/_libs/hashtable_func_helper.pxi":2462
 *                         k = kh_put_int8(table, value, &ret)
 *                         table.vals[k] = i
 *                         out[i] = 0             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_int8(table)
 */
                __pyx_t_10 = __pyx_v_i;
                *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_out.rcbuffer->pybuffer.buf, __pyx_t_10, __pyx_pybuffernd_out.diminfo[0].strides) = 0;
              }
              __pyx_L35:;
            }
            __pyx_L31:;
          }
        }

        /* "pandas/_libs/hashtable_func_helper.pxi":2439
 * 
 *     else:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for i in range(n):
 *                 if uses_mask and mask[i]:
 */
        /*finally:*/ {
          /*normal exit:*/{
            #ifdef WITH_THREAD
            __Pyx_FastGIL_Forget();
            Py_BLOCK_THREADS
            #endif
            goto __pyx_L28;
          }
          __pyx_L28:;
        }
    }
  }
  __pyx_L7:;

  /* "pandas/_libs/hashtable_func_helper.pxi":2464
 *                         out[i] = 0
 * 
 *     kh_destroy_int8(table)             # <<<<<<<<<<<<<<
 *     return out
 * 
 */
  kh_destroy_int8(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":2465
 * 
 *     kh_destroy_int8(table)
 *     return out             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_out);
  __pyx_r = ((PyObject *)__pyx_v_out);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2395
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_int8(const int8_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated_int8", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_out.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_out);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":2475
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_int8(const int8_t[:] arr, const int8_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable_ismember_int8(__Pyx_memviewslice __pyx_v_arr, __Pyx_memviewslice __pyx_v_values) {
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  khiter_t __pyx_v_k;
  int __pyx_v_ret;
  PyArrayObject *__pyx_v_result = 0;
  __pyx_t_5numpy_int8_t __pyx_v_val;
  kh_int8_t *__pyx_v_table;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_result;
  __Pyx_Buffer __pyx_pybuffer_result;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  Py_ssize_t __pyx_t_3;
  Py_ssize_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyArrayObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ismember_int8", 1);
  __pyx_pybuffer_result.pybuffer.buf = NULL;
  __pyx_pybuffer_result.refcount = 0;
  __pyx_pybuffernd_result.data = NULL;
  __pyx_pybuffernd_result.rcbuffer = &__pyx_pybuffer_result;

  /* "pandas/_libs/hashtable_func_helper.pxi":2492
 *         Py_ssize_t i, n
 *         khiter_t k
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         ndarray[uint8_t] result
 * 
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2497
 *         int8_t val
 * 
 *         kh_int8_t *table = kh_init_int8()             # <<<<<<<<<<<<<<
 * 
 *     # construct the table
 */
  __pyx_v_table = kh_init_int8();

  /* "pandas/_libs/hashtable_func_helper.pxi":2500
 * 
 *     # construct the table
 *     n = len(values)             # <<<<<<<<<<<<<<
 *     kh_resize_int8(table, n)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_values); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":2501
 *     # construct the table
 *     n = len(values)
 *     kh_resize_int8(table, n)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  kh_resize_int8(__pyx_v_table, __pyx_v_n);

  /* "pandas/_libs/hashtable_func_helper.pxi":2503
 *     kh_resize_int8(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (values[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":2504
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = (values[i])
 *             kh_put_int8(table, val, &ret)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":2505
 *     with nogil:
 *         for i in range(n):
 *             val = (values[i])             # <<<<<<<<<<<<<<
 *             kh_put_int8(table, val, &ret)
 * 
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_int8_t const  *) ( /* dim=0 */ (__pyx_v_values.data + __pyx_t_4 * __pyx_v_values.strides[0]) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":2506
 *         for i in range(n):
 *             val = (values[i])
 *             kh_put_int8(table, val, &ret)             # <<<<<<<<<<<<<<
 * 
 *     # test membership
 */
          (void)(kh_put_int8(__pyx_v_table, __pyx_v_val, (&__pyx_v_ret)));
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2503
 *     kh_resize_int8(table, n)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (values[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L5:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2509
 * 
 *     # test membership
 *     n = len(arr)             # <<<<<<<<<<<<<<
 *     result = np.empty(n, dtype=np.uint8)
 * 
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_arr); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":2510
 *     # test membership
 *     n = len(arr)
 *     result = np.empty(n, dtype=np.uint8)             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_empty); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyInt_FromSsize_t(__pyx_v_n); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5)) __PYX_ERR(5, 2510, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_8, __pyx_n_s_np); if (unlikely(!__pyx_t_8)) __PYX_ERR(5, 2510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(__pyx_t_8, __pyx_n_s_uint8); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 2510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dtype, __pyx_t_9) < 0) __PYX_ERR(5, 2510, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
  __pyx_t_9 = __Pyx_PyObject_Call(__pyx_t_6, __pyx_t_7, __pyx_t_5); if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 2510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_9);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (!(likely(((__pyx_t_9) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_9, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2510, __pyx_L1_error)
  __pyx_t_10 = ((PyArrayObject *)__pyx_t_9);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
    __pyx_t_11 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_t_10, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_11 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_13, &__pyx_t_14);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_result.rcbuffer->pybuffer, (PyObject*)__pyx_v_result, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_13); Py_XDECREF(__pyx_t_14);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_13, __pyx_t_14);
      }
      __pyx_t_12 = __pyx_t_13 = __pyx_t_14 = 0;
    }
    __pyx_pybuffernd_result.diminfo[0].strides = __pyx_pybuffernd_result.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_result.diminfo[0].shape = __pyx_pybuffernd_result.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_11 < 0))) __PYX_ERR(5, 2510, __pyx_L1_error)
  }
  __pyx_t_10 = 0;
  __pyx_v_result = ((PyArrayObject *)__pyx_t_9);
  __pyx_t_9 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2512
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (arr[i])
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":2513
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             val = (arr[i])
 *             k = kh_get_int8(table, val)
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_2 = __pyx_t_1;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pandas/_libs/hashtable_func_helper.pxi":2514
 *     with nogil:
 *         for i in range(n):
 *             val = (arr[i])             # <<<<<<<<<<<<<<
 *             k = kh_get_int8(table, val)
 *             result[i] = (k != table.n_buckets)
 */
          __pyx_t_4 = __pyx_v_i;
          __pyx_v_val = (*((__pyx_t_5numpy_int8_t const  *) ( /* dim=0 */ (__pyx_v_arr.data + __pyx_t_4 * __pyx_v_arr.strides[0]) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":2515
 *         for i in range(n):
 *             val = (arr[i])
 *             k = kh_get_int8(table, val)             # <<<<<<<<<<<<<<
 *             result[i] = (k != table.n_buckets)
 * 
 */
          __pyx_v_k = kh_get_int8(__pyx_v_table, __pyx_v_val);

          /* "pandas/_libs/hashtable_func_helper.pxi":2516
 *             val = (arr[i])
 *             k = kh_get_int8(table, val)
 *             result[i] = (k != table.n_buckets)             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_int8(table)
 */
          __pyx_t_4 = __pyx_v_i;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_result.rcbuffer->pybuffer.buf, __pyx_t_4, __pyx_pybuffernd_result.diminfo[0].strides) = (__pyx_v_k != __pyx_v_table->n_buckets);
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2512
 *     result = np.empty(n, dtype=np.uint8)
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             val = (arr[i])
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L10;
        }
        __pyx_L10:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2518
 *             result[i] = (k != table.n_buckets)
 * 
 *     kh_destroy_int8(table)             # <<<<<<<<<<<<<<
 *     return result.view(np.bool_)
 * 
 */
  kh_destroy_int8(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":2519
 * 
 *     kh_destroy_int8(table)
 *     return result.view(np.bool_)             # <<<<<<<<<<<<<<
 * 
 * # ----------------------------------------------------------------------
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_result), __pyx_n_s_view); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_bool_2); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  __pyx_t_11 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_5))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_5);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_5);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_5, function);
      __pyx_t_11 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_6};
    __pyx_t_9 = __Pyx_PyObject_FastCall(__pyx_t_5, __pyx_callargs+1-__pyx_t_11, 1+__pyx_t_11);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_9)) __PYX_ERR(5, 2519, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_9);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __pyx_r = __pyx_t_9;
  __pyx_t_9 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2475
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef ismember_int8(const int8_t[:] arr, const int8_t[:] values):             # <<<<<<<<<<<<<<
 *     """
 *     Return boolean of values in arr on an
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember_int8", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_result.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":2532
 * 
 * 
 * cpdef value_count(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return value_count_object(values, dropna, mask=mask)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_7value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_7value_count = {"value_count", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_7value_count, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_7value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_signatures = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kwargs = 0;
  CYTHON_UNUSED PyObject *__pyx_v_defaults = 0;
  PyObject *__pyx_v__fused_sigindex = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fused_cpdef (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_signatures,&__pyx_n_s_args,&__pyx_n_s_kwargs,&__pyx_n_s_defaults,&__pyx_n_s_fused_sigindex,0};
    __pyx_defaults *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_self);
    values[4] = __Pyx_Arg_NewRef_VARARGS(__pyx_dynamic_args->__pyx_arg__fused_sigindex);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_signatures)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_args)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fused_cpdef", 0, 4, 5, 1); __PYX_ERR(5, 2532, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_kwargs)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fused_cpdef", 0, 4, 5, 2); __PYX_ERR(5, 2532, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_defaults)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fused_cpdef", 0, 4, 5, 3); __PYX_ERR(5, 2532, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_fused_sigindex);
          if (value) { values[4] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fused_cpdef") < 0)) __PYX_ERR(5, 2532, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_signatures = values[0];
    __pyx_v_args = values[1];
    __pyx_v_kwargs = values[2];
    __pyx_v_defaults = values[3];
    __pyx_v__fused_sigindex = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fused_cpdef", 0, 4, 5, __pyx_nargs); __PYX_ERR(5, 2532, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fused_cpdef", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_6value_count(__pyx_self, __pyx_v_signatures, __pyx_v_args, __pyx_v_kwargs, __pyx_v_defaults, __pyx_v__fused_sigindex);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_6value_count(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_signatures, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs, CYTHON_UNUSED PyObject *__pyx_v_defaults, PyObject *__pyx_v__fused_sigindex) {
  PyObject *__pyx_v_search_list = 0;
  PyObject *__pyx_v_sigindex_node = 0;
  PyObject *__pyx_v_dest_sig = NULL;
  PyTypeObject *__pyx_v_ndarray = 0;
  PyObject *__pyx_v_arg_as_memoryview = 0;
  __Pyx_memviewslice __pyx_v_memslice;
  Py_ssize_t __pyx_v_itemsize;
  int __pyx_v_dtype_signed;
  Py_UCS4 __pyx_v_kind;
  int __pyx_v___pyx_fused_dtype_int8__t_is_signed;
  int __pyx_v___pyx_fused_dtype_int16__t_is_signed;
  int __pyx_v___pyx_fused_dtype_int32__t_is_signed;
  int __pyx_v___pyx_fused_dtype_int64__t_is_signed;
  int __pyx_v___pyx_fused_dtype_uint8__t_is_signed;
  int __pyx_v___pyx_fused_dtype_uint16__t_is_signed;
  int __pyx_v___pyx_fused_dtype_uint32__t_is_signed;
  int __pyx_v___pyx_fused_dtype_uint64__t_is_signed;
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_v_dtype = NULL;
  PyObject *__pyx_v_arg_base = NULL;
  PyObject *__pyx_v_sig = NULL;
  PyObject *__pyx_v_sig_series = NULL;
  PyObject *__pyx_v_last_type = NULL;
  PyObject *__pyx_v_sig_type = NULL;
  PyObject *__pyx_v_sigindex_matches = NULL;
  PyObject *__pyx_v_sigindex_candidates = NULL;
  PyObject *__pyx_v_dst_type = NULL;
  PyObject *__pyx_v_found_matches = NULL;
  PyObject *__pyx_v_found_candidates = NULL;
  PyObject *__pyx_v_sn = NULL;
  PyObject *__pyx_v_type_match = NULL;
  PyObject *__pyx_v_candidates = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  long __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  __Pyx_memviewslice __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  Py_ssize_t __pyx_t_14;
  int __pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  Py_ssize_t __pyx_t_18;
  int __pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("value_count", 0);
  __Pyx_INCREF(__pyx_v_kwargs);
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, Py_None)) __PYX_ERR(5, 2532, __pyx_L1_error);
  __pyx_v_dest_sig = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_v_kwargs != Py_None);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_kwargs); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_t_4 = (!__pyx_t_3);
  __pyx_t_2 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {
    __Pyx_INCREF(Py_None);
    __Pyx_DECREF_SET(__pyx_v_kwargs, Py_None);
  }
  __pyx_t_1 = ((PyObject *)__Pyx_ImportNumPyArrayTypeIfAvailable()); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_ndarray = ((PyTypeObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_v_itemsize = -1L;
  __pyx_v___pyx_fused_dtype_int8__t_is_signed = (!(((__pyx_t_5numpy_int8_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_int16__t_is_signed = (!(((__pyx_t_5numpy_int16_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_int32__t_is_signed = (!(((__pyx_t_5numpy_int32_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_int64__t_is_signed = (!(((__pyx_t_5numpy_int64_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_uint8__t_is_signed = (!(((__pyx_t_5numpy_uint8_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_uint16__t_is_signed = (!(((__pyx_t_5numpy_uint16_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_uint32__t_is_signed = (!(((__pyx_t_5numpy_uint32_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_uint64__t_is_signed = (!(((__pyx_t_5numpy_uint64_t)-1L) > 0));
  if (unlikely(__pyx_v_args == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_PyTuple_GET_SIZE(((PyObject*)__pyx_v_args)); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_t_2 = (0 < __pyx_t_5);
  if (__pyx_t_2) {
    if (unlikely(__pyx_v_args == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(5, 2532, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_GetItemInt_Tuple(((PyObject*)__pyx_v_args), 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_arg = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L6;
  }
  __pyx_t_4 = (__pyx_v_kwargs != Py_None);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L7_bool_binop_done;
  }
  if (unlikely(__pyx_v_kwargs == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_t_4 = (__Pyx_PyDict_ContainsTF(__pyx_n_s_values, ((PyObject*)__pyx_v_kwargs), Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_4;
  __pyx_L7_bool_binop_done:;
  if (likely(__pyx_t_2)) {
    if (unlikely(__pyx_v_kwargs == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(5, 2532, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_PyDict_GetItem(((PyObject*)__pyx_v_kwargs), __pyx_n_s_values); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_arg = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L6;
  }
  /*else*/ {
    if (unlikely(__pyx_v_args == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(5, 2532, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_PyTuple_GET_SIZE(((PyObject*)__pyx_v_args)); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2532, __pyx_L1_error)
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_int_2);
    __Pyx_GIVEREF(__pyx_int_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_int_2)) __PYX_ERR(5, 2532, __pyx_L1_error);
    __Pyx_INCREF(__pyx_n_s_s);
    __Pyx_GIVEREF(__pyx_n_s_s);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_n_s_s)) __PYX_ERR(5, 2532, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Expected_at_least_d_argument_s_g, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_L6:;
  while (1) {
    __pyx_t_2 = (__pyx_v_ndarray != ((PyTypeObject*)Py_None));
    if (__pyx_t_2) {
      __pyx_t_2 = __Pyx_TypeCheck(__pyx_v_arg, __pyx_v_ndarray); 
      if (__pyx_t_2) {
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_dtype); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_v_dtype = __pyx_t_6;
        __pyx_t_6 = 0;
        goto __pyx_L12;
      }
      __pyx_t_2 = __pyx_memoryview_check(__pyx_v_arg); 
      if (__pyx_t_2) {
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_base); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_v_arg_base = __pyx_t_6;
        __pyx_t_6 = 0;
        __pyx_t_2 = __Pyx_TypeCheck(__pyx_v_arg_base, __pyx_v_ndarray); 
        if (__pyx_t_2) {
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg_base, __pyx_n_s_dtype); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_v_dtype = __pyx_t_6;
          __pyx_t_6 = 0;
          goto __pyx_L13;
        }
        /*else*/ {
          __Pyx_INCREF(Py_None);
          __pyx_v_dtype = Py_None;
        }
        __pyx_L13:;
        goto __pyx_L12;
      }
      /*else*/ {
        __Pyx_INCREF(Py_None);
        __pyx_v_dtype = Py_None;
      }
      __pyx_L12:;
      __pyx_v_itemsize = -1L;
      __pyx_t_2 = (__pyx_v_dtype != Py_None);
      if (__pyx_t_2) {
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtype, __pyx_n_s_itemsize); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_v_itemsize = __pyx_t_5;
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtype, __pyx_n_s_kind); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = __Pyx_PyObject_Ord(__pyx_t_6); if (unlikely(__pyx_t_7 == ((long)(long)(Py_UCS4)-1))) __PYX_ERR(5, 2532, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_v_kind = __pyx_t_7;
        __pyx_v_dtype_signed = (__pyx_v_kind == 0x69);
        switch (__pyx_v_kind) {
          case 0x69:
          case 0x75:
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_int8_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L16_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L16_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_int8__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L16_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int8_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_int16_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L20_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L20_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_int16__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L20_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int16_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_int32_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L24_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L24_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_int32__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L24_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_int64_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L28_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L28_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_int64__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L28_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_uint8_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L32_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L32_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_uint8__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L32_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint8_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_uint16_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L36_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L36_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_uint16__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L36_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint16_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_uint32_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L40_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L40_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_uint32__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L40_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_uint64_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L44_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L44_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_uint64__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L44_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          break;
          case 0x66:
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_float32_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L48_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          __pyx_t_2 = __pyx_t_4;
          __pyx_L48_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_float32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_float64_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L51_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          __pyx_t_2 = __pyx_t_4;
          __pyx_L51_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_float64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          break;
          case 99:
          __pyx_t_4 = ((sizeof(__pyx_t_double_complex)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L54_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          __pyx_t_2 = __pyx_t_4;
          __pyx_L54_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_kp_s_double_complex, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_float_complex)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L57_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          __pyx_t_2 = __pyx_t_4;
          __pyx_L57_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_kp_s_float_complex, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          break;
          case 79:
          break;
          default: break;
        }
      }
    }
    __pyx_t_2 = (__pyx_v_arg == Py_None);
    if (__pyx_t_2) {
      if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int8_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
      goto __pyx_L10_break;
    }
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      /*try:*/ {
        __pyx_t_6 = PyMemoryView_FromObject(__pyx_v_arg); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L60_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_v_arg_as_memoryview = ((PyObject*)__pyx_t_6);
        __pyx_t_6 = 0;
      }
      /*else:*/ {
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L71_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_int8_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L70_next_and;
        }
        __pyx_L71_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_int8_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L69_bool_binop_done;
        }
        __pyx_L70_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L69_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int8_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int8_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L77_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_int16_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L76_next_and;
        }
        __pyx_L77_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_int16_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L75_bool_binop_done;
        }
        __pyx_L76_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L75_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int16_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int16_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L83_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_int32_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L82_next_and;
        }
        __pyx_L83_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_int32_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L81_bool_binop_done;
        }
        __pyx_L82_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L81_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int32_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L89_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_int64_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L88_next_and;
        }
        __pyx_L89_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_int64_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L87_bool_binop_done;
        }
        __pyx_L88_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L87_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L95_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_uint8_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L94_next_and;
        }
        __pyx_L95_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_uint8_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L93_bool_binop_done;
        }
        __pyx_L94_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L93_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint8_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L101_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_uint16_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L100_next_and;
        }
        __pyx_L101_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_uint16_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L99_bool_binop_done;
        }
        __pyx_L100_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L99_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint16_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint16_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L107_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_uint32_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L106_next_and;
        }
        __pyx_L107_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_uint32_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L105_bool_binop_done;
        }
        __pyx_L106_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L105_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint32_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L113_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_uint64_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L112_next_and;
        }
        __pyx_L113_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_uint64_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L111_bool_binop_done;
        }
        __pyx_L112_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L111_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint64_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L119_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_float32_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L118_next_and;
        }
        __pyx_L119_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_float32_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L117_bool_binop_done;
        }
        __pyx_L118_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L117_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float32_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_float32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L125_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_float64_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L124_next_and;
        }
        __pyx_L125_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_float64_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L123_bool_binop_done;
        }
        __pyx_L124_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L123_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float64_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_float64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L131_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(void *)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L130_next_and;
        }
        __pyx_L131_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(void *)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L129_bool_binop_done;
        }
        __pyx_L130_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L129_bool_binop_done:;
        if (__pyx_t_2) {
          if ((CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION == 2)) {
            __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_object(__pyx_v_arg, 0); 
            __pyx_v_memslice = __pyx_t_12;
            goto __pyx_L133;
          }
          /*else*/ {
            __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_object(__pyx_v_arg_as_memoryview, 0); 
            __pyx_v_memslice = __pyx_t_12;
          }
          __pyx_L133:;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_object, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L138_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_double_complex)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L137_next_and;
        }
        __pyx_L138_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_double_complex)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L136_bool_binop_done;
        }
        __pyx_L137_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L136_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_double_complex(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_kp_s_double_complex, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L144_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_float_complex)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L143_next_and;
        }
        __pyx_L144_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_float_complex)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L142_bool_binop_done;
        }
        __pyx_L143_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L142_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_float_complex(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_kp_s_float_complex, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
      }
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L67_try_end;
      __pyx_L60_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_11 = __Pyx_PyErr_ExceptionMatches2(__pyx_builtin_ValueError, __pyx_builtin_TypeError);
      if (__pyx_t_11) {
        __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fused_cpdef", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_1, &__pyx_t_13) < 0) __PYX_ERR(5, 2532, __pyx_L62_except_error)
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_1);
        __Pyx_XGOTREF(__pyx_t_13);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        goto __pyx_L61_exception_handled;
      }
      goto __pyx_L62_except_error;
      __pyx_L62_except_error:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      goto __pyx_L1_error;
      __pyx_L65_try_break:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      goto __pyx_L10_break;
      __pyx_L61_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      __pyx_L67_try_end:;
    }
    if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, Py_None, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
    goto __pyx_L10_break;
  }
  __pyx_L10_break:;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v__fused_sigindex); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_t_4 = (!__pyx_t_2);
  if (__pyx_t_4) {
    __pyx_t_5 = 0;
    if (unlikely(__pyx_v_signatures == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(5, 2532, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_dict_iterator(((PyObject*)__pyx_v_signatures), 1, ((PyObject *)NULL), (&__pyx_t_14), (&__pyx_t_11)); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF(__pyx_t_13);
    __pyx_t_13 = __pyx_t_1;
    __pyx_t_1 = 0;
    while (1) {
      __pyx_t_15 = __Pyx_dict_iter_next(__pyx_t_13, __pyx_t_14, &__pyx_t_5, &__pyx_t_1, NULL, NULL, __pyx_t_11);
      if (unlikely(__pyx_t_15 == 0)) break;
      if (unlikely(__pyx_t_15 == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_sig, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_1 = __pyx_v__fused_sigindex;
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_sigindex_node, ((PyObject*)__pyx_t_1));
      __pyx_t_1 = 0;
      __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_v_sig, __pyx_n_s_strip); if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2532, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __pyx_t_17 = NULL;
      __pyx_t_15 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_16))) {
        __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_16);
        if (likely(__pyx_t_17)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
          __Pyx_INCREF(__pyx_t_17);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_16, function);
          __pyx_t_15 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_17, __pyx_kp_s__69};
        __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_16, __pyx_callargs+1-__pyx_t_15, 1+__pyx_t_15);
        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      }
      __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_split); if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2532, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      __pyx_t_15 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_16))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_16);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_16, function);
          __pyx_t_15 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_kp_s__70};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_16, __pyx_callargs+1-__pyx_t_15, 1+__pyx_t_15);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      }
      __pyx_t_16 = __Pyx_PySequence_ListKeepNew(__pyx_t_1); if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2532, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_18 = PyList_GET_SIZE(__pyx_t_16);
      if (unlikely(__pyx_t_18 < 1)) {
        __Pyx_RaiseNeedMoreValuesError(0+__pyx_t_18); __PYX_ERR(5, 2532, __pyx_L1_error)
      }
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_6 = PyList_GET_ITEM(__pyx_t_16, __pyx_t_18-1); 
      ((PyVarObject*)__pyx_t_16)->ob_size--;
      #else
      __pyx_t_6 = PySequence_ITEM(__pyx_t_16, __pyx_t_18-1); 
      #endif
      __Pyx_GOTREF(__pyx_t_6);
      #if !CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_17 = PySequence_GetSlice(__pyx_t_16, 0, __pyx_t_18-1); if (unlikely(!__pyx_t_17)) __PYX_ERR(5, 2532, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_DECREF(__pyx_t_16);
      __pyx_t_16 = __pyx_t_17; __pyx_t_17 = NULL;
      #else
      CYTHON_UNUSED_VAR(__pyx_t_17);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_sig_series, ((PyObject*)__pyx_t_16));
      __pyx_t_16 = 0;
      __Pyx_XDECREF_SET(__pyx_v_last_type, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_1 = __pyx_v_sig_series; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_18 = 0;
      for (;;) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
          #endif
          if (__pyx_t_18 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_6 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_18); __Pyx_INCREF(__pyx_t_6); __pyx_t_18++; if (unlikely((0 < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
        #else
        __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_18); __pyx_t_18++; if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
        __Pyx_XDECREF_SET(__pyx_v_sig_type, __pyx_t_6);
        __pyx_t_6 = 0;
        if (unlikely(__pyx_v_sigindex_node == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
          __PYX_ERR(5, 2532, __pyx_L1_error)
        }
        __pyx_t_4 = (__Pyx_PyDict_ContainsTF(__pyx_v_sig_type, __pyx_v_sigindex_node, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
        if (__pyx_t_4) {
          __pyx_t_6 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (unlikely(__pyx_v_sigindex_node == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            __PYX_ERR(5, 2532, __pyx_L1_error)
          }
          if (unlikely((PyDict_SetItem(__pyx_v_sigindex_node, __pyx_v_sig_type, __pyx_t_6) < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_DECREF_SET(__pyx_v_sigindex_node, __pyx_t_6);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          goto __pyx_L154;
        }
        /*else*/ {
          if (unlikely(__pyx_v_sigindex_node == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            __PYX_ERR(5, 2532, __pyx_L1_error)
          }
          __pyx_t_6 = __Pyx_PyDict_GetItem(__pyx_v_sigindex_node, __pyx_v_sig_type); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_16 = __pyx_t_6;
          __Pyx_INCREF(__pyx_t_16);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF_SET(__pyx_v_sigindex_node, ((PyObject*)__pyx_t_16));
          __pyx_t_16 = 0;
        }
        __pyx_L154:;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(__pyx_v_sigindex_node == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(5, 2532, __pyx_L1_error)
      }
      if (unlikely((PyDict_SetItem(__pyx_v_sigindex_node, __pyx_v_last_type, __pyx_v_sig) < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  }
  __pyx_t_13 = PyList_New(0); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_v_sigindex_matches = ((PyObject*)__pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = PyList_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_INCREF(__pyx_v__fused_sigindex);
  __Pyx_GIVEREF(__pyx_v__fused_sigindex);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_13, 0, __pyx_v__fused_sigindex)) __PYX_ERR(5, 2532, __pyx_L1_error);
  __pyx_v_sigindex_candidates = ((PyObject*)__pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __pyx_v_dest_sig; __Pyx_INCREF(__pyx_t_13);
  __pyx_t_14 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_13);
      #if !CYTHON_ASSUME_SAFE_MACROS
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
      #endif
      if (__pyx_t_14 >= __pyx_temp) break;
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_1 = PyList_GET_ITEM(__pyx_t_13, __pyx_t_14); __Pyx_INCREF(__pyx_t_1); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
    #else
    __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_13, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_dst_type, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_found_matches, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_found_candidates, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;
    __pyx_t_4 = (__pyx_v_dst_type == Py_None);
    if (__pyx_t_4) {
      __pyx_t_1 = __pyx_v_sigindex_matches; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_5 = 0;
      for (;;) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_16 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_16); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
        #else
        __pyx_t_16 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2532, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        #endif
        __Pyx_XDECREF_SET(__pyx_v_sn, __pyx_t_16);
        __pyx_t_16 = 0;
        if (unlikely(__pyx_v_sn == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "values");
          __PYX_ERR(5, 2532, __pyx_L1_error)
        }
        __pyx_t_16 = __Pyx_PyDict_Values(((PyObject*)__pyx_v_sn)); if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2532, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        __pyx_t_19 = __Pyx_PyList_Extend(__pyx_v_found_matches, __pyx_t_16); if (unlikely(__pyx_t_19 == ((int)-1))) __PYX_ERR(5, 2532, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __pyx_v_sigindex_candidates; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_5 = 0;
      for (;;) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_16 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_16); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
        #else
        __pyx_t_16 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2532, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        #endif
        __Pyx_XDECREF_SET(__pyx_v_sn, __pyx_t_16);
        __pyx_t_16 = 0;
        if (unlikely(__pyx_v_sn == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "values");
          __PYX_ERR(5, 2532, __pyx_L1_error)
        }
        __pyx_t_16 = __Pyx_PyDict_Values(((PyObject*)__pyx_v_sn)); if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2532, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        __pyx_t_19 = __Pyx_PyList_Extend(__pyx_v_found_candidates, __pyx_t_16); if (unlikely(__pyx_t_19 == ((int)-1))) __PYX_ERR(5, 2532, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L158;
    }
    /*else*/ {
      __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_sigindex_matches);
      __Pyx_GIVEREF(__pyx_v_sigindex_matches);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_sigindex_matches)) __PYX_ERR(5, 2532, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_sigindex_candidates);
      __Pyx_GIVEREF(__pyx_v_sigindex_candidates);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_sigindex_candidates)) __PYX_ERR(5, 2532, __pyx_L1_error);
      __pyx_t_16 = __pyx_t_1; __Pyx_INCREF(__pyx_t_16);
      __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      for (;;) {
        if (__pyx_t_5 >= 2) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_16, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_16, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
        __Pyx_XDECREF_SET(__pyx_v_search_list, ((PyObject*)__pyx_t_1));
        __pyx_t_1 = 0;
        if (unlikely(__pyx_v_search_list == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
          __PYX_ERR(5, 2532, __pyx_L1_error)
        }
        __pyx_t_1 = __pyx_v_search_list; __Pyx_INCREF(__pyx_t_1);
        __pyx_t_18 = 0;
        for (;;) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
            #endif
            if (__pyx_t_18 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_18); __Pyx_INCREF(__pyx_t_6); __pyx_t_18++; if (unlikely((0 < 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
          #else
          __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_18); __pyx_t_18++; if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
          __Pyx_XDECREF_SET(__pyx_v_sn, __pyx_t_6);
          __pyx_t_6 = 0;
          if (unlikely(__pyx_v_sn == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "get");
            __PYX_ERR(5, 2532, __pyx_L1_error)
          }
          __pyx_t_6 = __Pyx_PyDict_GetItemDefault(((PyObject*)__pyx_v_sn), __pyx_v_dst_type, Py_None); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2532, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_XDECREF_SET(__pyx_v_type_match, __pyx_t_6);
          __pyx_t_6 = 0;
          __pyx_t_4 = (__pyx_v_type_match != Py_None);
          if (__pyx_t_4) {
            __pyx_t_19 = __Pyx_PyList_Append(__pyx_v_found_matches, __pyx_v_type_match); if (unlikely(__pyx_t_19 == ((int)-1))) __PYX_ERR(5, 2532, __pyx_L1_error)
          }
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    }
    __pyx_L158:;
    __Pyx_INCREF(__pyx_v_found_matches);
    __Pyx_DECREF_SET(__pyx_v_sigindex_matches, __pyx_v_found_matches);
    __Pyx_INCREF(__pyx_v_found_candidates);
    __Pyx_DECREF_SET(__pyx_v_sigindex_candidates, __pyx_v_found_candidates);
    __pyx_t_2 = (PyList_GET_SIZE(__pyx_v_found_matches) != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_4 = __pyx_t_2;
      goto __pyx_L173_bool_binop_done;
    }
    __pyx_t_2 = (PyList_GET_SIZE(__pyx_v_found_candidates) != 0);
    __pyx_t_4 = __pyx_t_2;
    __pyx_L173_bool_binop_done:;
    __pyx_t_2 = (!__pyx_t_4);
    if (__pyx_t_2) {
      goto __pyx_L157_break;
    }
  }
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  goto __pyx_L175_for_end;
  __pyx_L157_break:;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  goto __pyx_L175_for_end;
  __pyx_L175_for_end:;
  __Pyx_INCREF(__pyx_v_sigindex_matches);
  __pyx_v_candidates = __pyx_v_sigindex_matches;
  __pyx_t_2 = (PyList_GET_SIZE(__pyx_v_candidates) != 0);
  __pyx_t_4 = (!__pyx_t_2);
  if (unlikely(__pyx_t_4)) {
    __pyx_t_13 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__71, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 2532, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_Raise(__pyx_t_13, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_t_14 = __Pyx_PyList_GET_SIZE(__pyx_v_candidates); if (unlikely(__pyx_t_14 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_t_4 = (__pyx_t_14 > 1);
  if (unlikely(__pyx_t_4)) {
    __pyx_t_13 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__72, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 2532, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_Raise(__pyx_t_13, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    if (unlikely(__pyx_v_signatures == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(5, 2532, __pyx_L1_error)
    }
    __pyx_t_13 = __Pyx_GetItemInt_List(__pyx_v_candidates, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 2532, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_16 = __Pyx_PyDict_GetItem(((PyObject*)__pyx_v_signatures), __pyx_t_13); if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2532, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_r = __pyx_t_16;
    __pyx_t_16 = 0;
    goto __pyx_L0;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fused_cpdef", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_search_list);
  __Pyx_XDECREF(__pyx_v_sigindex_node);
  __Pyx_XDECREF(__pyx_v_dest_sig);
  __Pyx_XDECREF((PyObject *)__pyx_v_ndarray);
  __Pyx_XDECREF(__pyx_v_arg_as_memoryview);
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XDECREF(__pyx_v_dtype);
  __Pyx_XDECREF(__pyx_v_arg_base);
  __Pyx_XDECREF(__pyx_v_sig);
  __Pyx_XDECREF(__pyx_v_sig_series);
  __Pyx_XDECREF(__pyx_v_last_type);
  __Pyx_XDECREF(__pyx_v_sig_type);
  __Pyx_XDECREF(__pyx_v_sigindex_matches);
  __Pyx_XDECREF(__pyx_v_sigindex_candidates);
  __Pyx_XDECREF(__pyx_v_dst_type);
  __Pyx_XDECREF(__pyx_v_found_matches);
  __Pyx_XDECREF(__pyx_v_found_candidates);
  __Pyx_XDECREF(__pyx_v_sn);
  __Pyx_XDECREF(__pyx_v_type_match);
  __Pyx_XDECREF(__pyx_v_candidates);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_21__pyx_fuse_0value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_7value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_0__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *__pyx_v_values, int __pyx_v_dropna, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_0__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__73;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_int8 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_0value_count", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int8_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2537
 * 
 *     elif htfunc_t is int8_t:
 *         return value_count_int8(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is int16_t:
 *         return value_count_int16(values, dropna, mask=mask)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int8_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2537, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 1;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_value_count_int8(__pyx_t_1, __pyx_v_dropna, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2537, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2532
 * 
 * 
 * cpdef value_count(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return value_count_object(values, dropna, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_21__pyx_fuse_0value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_0__pyx_mdef_6pandas_5_libs_9hashtable_21__pyx_fuse_0value_count = {"__pyx_fuse_0value_count", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_21__pyx_fuse_0value_count, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_21__pyx_fuse_0value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_0value_count (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_0value_count", 0, 2, 3, 1); __PYX_ERR(5, 2532, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_0value_count") < 0)) __PYX_ERR(5, 2532, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2532, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__73;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_0value_count", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2532, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_0value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_20__pyx_fuse_0value_count(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_20__pyx_fuse_0value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_0__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_0value_count", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int8_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2532, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_0__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_0value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_23__pyx_fuse_1value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_7value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_1__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *__pyx_v_values, int __pyx_v_dropna, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_1__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__74;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_int16 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_1value_count", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2539
 *         return value_count_int8(values, dropna, mask=mask)
 *     elif htfunc_t is int16_t:
 *         return value_count_int16(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is int32_t:
 *         return value_count_int32(values, dropna, mask=mask)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int16_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2539, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 1;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_value_count_int16(__pyx_t_1, __pyx_v_dropna, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2539, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2532
 * 
 * 
 * cpdef value_count(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return value_count_object(values, dropna, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_23__pyx_fuse_1value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_1__pyx_mdef_6pandas_5_libs_9hashtable_23__pyx_fuse_1value_count = {"__pyx_fuse_1value_count", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_23__pyx_fuse_1value_count, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_23__pyx_fuse_1value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_1value_count (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_1value_count", 0, 2, 3, 1); __PYX_ERR(5, 2532, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_1value_count") < 0)) __PYX_ERR(5, 2532, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2532, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__74;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_1value_count", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2532, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_1value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_22__pyx_fuse_1value_count(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_22__pyx_fuse_1value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_1__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_1value_count", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2532, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_1__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_1value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_25__pyx_fuse_2value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_7value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_2__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *__pyx_v_values, int __pyx_v_dropna, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_2__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__75;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_int32 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_2value_count", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2541
 *         return value_count_int16(values, dropna, mask=mask)
 *     elif htfunc_t is int32_t:
 *         return value_count_int32(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is int64_t:
 *         return value_count_int64(values, dropna, mask=mask)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int32_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2541, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 1;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_value_count_int32(__pyx_t_1, __pyx_v_dropna, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2541, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2532
 * 
 * 
 * cpdef value_count(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return value_count_object(values, dropna, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_25__pyx_fuse_2value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_2__pyx_mdef_6pandas_5_libs_9hashtable_25__pyx_fuse_2value_count = {"__pyx_fuse_2value_count", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_25__pyx_fuse_2value_count, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_25__pyx_fuse_2value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_2value_count (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_2value_count", 0, 2, 3, 1); __PYX_ERR(5, 2532, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_2value_count") < 0)) __PYX_ERR(5, 2532, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2532, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__75;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_2value_count", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2532, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_2value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_24__pyx_fuse_2value_count(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_24__pyx_fuse_2value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_2__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_2value_count", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2532, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_2__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_2value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_27__pyx_fuse_3value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_7value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_3__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *__pyx_v_values, int __pyx_v_dropna, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_3__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__76;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_int64 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_3value_count", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2543
 *         return value_count_int32(values, dropna, mask=mask)
 *     elif htfunc_t is int64_t:
 *         return value_count_int64(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 * 
 *     elif htfunc_t is uint8_t:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2543, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 1;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_value_count_int64(__pyx_t_1, __pyx_v_dropna, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2543, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2532
 * 
 * 
 * cpdef value_count(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return value_count_object(values, dropna, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_27__pyx_fuse_3value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_3__pyx_mdef_6pandas_5_libs_9hashtable_27__pyx_fuse_3value_count = {"__pyx_fuse_3value_count", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_27__pyx_fuse_3value_count, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_27__pyx_fuse_3value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_3value_count (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_3value_count", 0, 2, 3, 1); __PYX_ERR(5, 2532, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_3value_count") < 0)) __PYX_ERR(5, 2532, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2532, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__76;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_3value_count", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2532, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_3value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_26__pyx_fuse_3value_count(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_26__pyx_fuse_3value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_3__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_3value_count", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2532, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_3__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_3value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_29__pyx_fuse_4value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_7value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_4__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *__pyx_v_values, int __pyx_v_dropna, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_4__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__77;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_uint8 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_4value_count", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2546
 * 
 *     elif htfunc_t is uint8_t:
 *         return value_count_uint8(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is uint16_t:
 *         return value_count_uint16(values, dropna, mask=mask)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2546, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 1;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_value_count_uint8(__pyx_t_1, __pyx_v_dropna, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2546, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2532
 * 
 * 
 * cpdef value_count(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return value_count_object(values, dropna, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_29__pyx_fuse_4value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_4__pyx_mdef_6pandas_5_libs_9hashtable_29__pyx_fuse_4value_count = {"__pyx_fuse_4value_count", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_29__pyx_fuse_4value_count, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_29__pyx_fuse_4value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_4value_count (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_4value_count", 0, 2, 3, 1); __PYX_ERR(5, 2532, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_4value_count") < 0)) __PYX_ERR(5, 2532, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2532, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__77;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_4value_count", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2532, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_4value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_28__pyx_fuse_4value_count(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_28__pyx_fuse_4value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_4__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_4value_count", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2532, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_4__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_4value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_31__pyx_fuse_5value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_7value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_5__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *__pyx_v_values, int __pyx_v_dropna, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_5__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__78;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_uint16 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_5value_count", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint16_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2548
 *         return value_count_uint8(values, dropna, mask=mask)
 *     elif htfunc_t is uint16_t:
 *         return value_count_uint16(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is uint32_t:
 *         return value_count_uint32(values, dropna, mask=mask)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint16_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2548, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 1;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_value_count_uint16(__pyx_t_1, __pyx_v_dropna, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2548, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2532
 * 
 * 
 * cpdef value_count(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return value_count_object(values, dropna, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_31__pyx_fuse_5value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_5__pyx_mdef_6pandas_5_libs_9hashtable_31__pyx_fuse_5value_count = {"__pyx_fuse_5value_count", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_31__pyx_fuse_5value_count, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_31__pyx_fuse_5value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_5value_count (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_5value_count", 0, 2, 3, 1); __PYX_ERR(5, 2532, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_5value_count") < 0)) __PYX_ERR(5, 2532, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2532, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__78;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_5value_count", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2532, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_5value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_30__pyx_fuse_5value_count(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_30__pyx_fuse_5value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_5__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_5value_count", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint16_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2532, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_5__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_5value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_33__pyx_fuse_6value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_7value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_6__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *__pyx_v_values, int __pyx_v_dropna, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_6__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__79;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_uint32 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_6value_count", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2550
 *         return value_count_uint16(values, dropna, mask=mask)
 *     elif htfunc_t is uint32_t:
 *         return value_count_uint32(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is uint64_t:
 *         return value_count_uint64(values, dropna, mask=mask)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint32_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2550, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 1;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_value_count_uint32(__pyx_t_1, __pyx_v_dropna, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2550, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2532
 * 
 * 
 * cpdef value_count(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return value_count_object(values, dropna, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_33__pyx_fuse_6value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_6__pyx_mdef_6pandas_5_libs_9hashtable_33__pyx_fuse_6value_count = {"__pyx_fuse_6value_count", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_33__pyx_fuse_6value_count, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_33__pyx_fuse_6value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_6value_count (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_6value_count", 0, 2, 3, 1); __PYX_ERR(5, 2532, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_6value_count") < 0)) __PYX_ERR(5, 2532, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2532, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__79;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_6value_count", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2532, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_6value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_32__pyx_fuse_6value_count(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_32__pyx_fuse_6value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_6__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_6value_count", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2532, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_6__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_6value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_35__pyx_fuse_7value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_7value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_7__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *__pyx_v_values, int __pyx_v_dropna, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_7__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__80;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_uint64 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_7value_count", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2552
 *         return value_count_uint32(values, dropna, mask=mask)
 *     elif htfunc_t is uint64_t:
 *         return value_count_uint64(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 * 
 *     elif htfunc_t is float64_t:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint64_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2552, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 1;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_value_count_uint64(__pyx_t_1, __pyx_v_dropna, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2552, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2532
 * 
 * 
 * cpdef value_count(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return value_count_object(values, dropna, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_35__pyx_fuse_7value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_7__pyx_mdef_6pandas_5_libs_9hashtable_35__pyx_fuse_7value_count = {"__pyx_fuse_7value_count", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_35__pyx_fuse_7value_count, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_35__pyx_fuse_7value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_7value_count (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_7value_count", 0, 2, 3, 1); __PYX_ERR(5, 2532, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_7value_count") < 0)) __PYX_ERR(5, 2532, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2532, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__80;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_7value_count", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2532, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_7value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_34__pyx_fuse_7value_count(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_34__pyx_fuse_7value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_7__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_7value_count", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2532, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_7__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_7value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_37__pyx_fuse_8value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_7value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_8__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *__pyx_v_values, int __pyx_v_dropna, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_8__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__81;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_float32 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_8value_count", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2557
 *         return value_count_float64(values, dropna, mask=mask)
 *     elif htfunc_t is float32_t:
 *         return value_count_float32(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 * 
 *     elif htfunc_t is complex128_t:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float32_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2557, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 1;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_value_count_float32(__pyx_t_1, __pyx_v_dropna, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2532
 * 
 * 
 * cpdef value_count(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return value_count_object(values, dropna, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_37__pyx_fuse_8value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_8__pyx_mdef_6pandas_5_libs_9hashtable_37__pyx_fuse_8value_count = {"__pyx_fuse_8value_count", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_37__pyx_fuse_8value_count, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_37__pyx_fuse_8value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_8value_count (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_8value_count", 0, 2, 3, 1); __PYX_ERR(5, 2532, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_8value_count") < 0)) __PYX_ERR(5, 2532, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2532, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__81;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_8value_count", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2532, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_8value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_36__pyx_fuse_8value_count(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_36__pyx_fuse_8value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_8__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_8value_count", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2532, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_8__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_8value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_39__pyx_fuse_9value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_7value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_9__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *__pyx_v_values, int __pyx_v_dropna, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_9__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__82;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_float64 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_9value_count", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2555
 * 
 *     elif htfunc_t is float64_t:
 *         return value_count_float64(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is float32_t:
 *         return value_count_float32(values, dropna, mask=mask)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float64_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2555, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 1;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_value_count_float64(__pyx_t_1, __pyx_v_dropna, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2555, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2532
 * 
 * 
 * cpdef value_count(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return value_count_object(values, dropna, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_39__pyx_fuse_9value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_9__pyx_mdef_6pandas_5_libs_9hashtable_39__pyx_fuse_9value_count = {"__pyx_fuse_9value_count", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_39__pyx_fuse_9value_count, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_39__pyx_fuse_9value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_9value_count (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_9value_count", 0, 2, 3, 1); __PYX_ERR(5, 2532, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_9value_count") < 0)) __PYX_ERR(5, 2532, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2532, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__82;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_9value_count", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2532, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_9value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_38__pyx_fuse_9value_count(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_38__pyx_fuse_9value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_9__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_9value_count", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2532, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_9__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_9value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_41__pyx_fuse_10value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_7value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_10__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *__pyx_v_values, int __pyx_v_dropna, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_10__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__83;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_object __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_10value_count", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2534
 * cpdef value_count(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 *     if htfunc_t is object:
 *         return value_count_object(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 * 
 *     elif htfunc_t is int8_t:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_value_count_object(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2534, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2532
 * 
 * 
 * cpdef value_count(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return value_count_object(values, dropna, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_41__pyx_fuse_10value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_10__pyx_mdef_6pandas_5_libs_9hashtable_41__pyx_fuse_10value_count = {"__pyx_fuse_10value_count", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_41__pyx_fuse_10value_count, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_41__pyx_fuse_10value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_10value_count (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_10value_count", 0, 2, 3, 1); __PYX_ERR(5, 2532, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_10value_count") < 0)) __PYX_ERR(5, 2532, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2532, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__83;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_10value_count", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2532, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_10value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_40__pyx_fuse_10value_count(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_40__pyx_fuse_10value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_10__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_10value_count", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2532, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_10__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_10value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_43__pyx_fuse_11value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_7value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_11__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *__pyx_v_values, int __pyx_v_dropna, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_11__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__84;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_complex128 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_11value_count", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo___pyx_t_double_complex, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2560
 * 
 *     elif htfunc_t is complex128_t:
 *         return value_count_complex128(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is complex64_t:
 *         return value_count_complex64(values, dropna, mask=mask)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_double_complex__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2560, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 1;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_value_count_complex128(__pyx_t_1, __pyx_v_dropna, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2560, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2532
 * 
 * 
 * cpdef value_count(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return value_count_object(values, dropna, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_43__pyx_fuse_11value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_11__pyx_mdef_6pandas_5_libs_9hashtable_43__pyx_fuse_11value_count = {"__pyx_fuse_11value_count", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_43__pyx_fuse_11value_count, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_43__pyx_fuse_11value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_11value_count (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_11value_count", 0, 2, 3, 1); __PYX_ERR(5, 2532, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_11value_count") < 0)) __PYX_ERR(5, 2532, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2532, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__84;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_11value_count", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2532, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_11value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_42__pyx_fuse_11value_count(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_42__pyx_fuse_11value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_11__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_11value_count", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo___pyx_t_double_complex, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2532, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_11__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_11value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_45__pyx_fuse_12value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_7value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_12__pyx_f_6pandas_5_libs_9hashtable_value_count(PyArrayObject *__pyx_v_values, int __pyx_v_dropna, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_12__pyx_opt_args_6pandas_5_libs_9hashtable_value_count *__pyx_optional_args) {
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__85;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_value_count_complex64 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_12value_count", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_mask = __pyx_optional_args->mask;
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo___pyx_t_float_complex, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2562
 *         return value_count_complex128(values, dropna, mask=mask)
 *     elif htfunc_t is complex64_t:
 *         return value_count_complex64(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 * 
 *     else:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_float_complex__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2562, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 1;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_value_count_complex64(__pyx_t_1, __pyx_v_dropna, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2532
 * 
 * 
 * cpdef value_count(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return value_count_object(values, dropna, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_45__pyx_fuse_12value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_12__pyx_mdef_6pandas_5_libs_9hashtable_45__pyx_fuse_12value_count = {"__pyx_fuse_12value_count", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_45__pyx_fuse_12value_count, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_45__pyx_fuse_12value_count(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_12value_count (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_12value_count", 0, 2, 3, 1); __PYX_ERR(5, 2532, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_12value_count") < 0)) __PYX_ERR(5, 2532, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2532, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2532, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__85;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_12value_count", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2532, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_12value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_44__pyx_fuse_12value_count(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_44__pyx_fuse_12value_count(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_12__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_12value_count", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo___pyx_t_float_complex, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2532, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_12__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_12value_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":2568
 * 
 * 
 * cpdef duplicated(ndarray[htfunc_t] values, object keep="first", const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return duplicated_object(values, keep, mask=mask)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_9duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_9duplicated = {"duplicated", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_9duplicated, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_9duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_signatures = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kwargs = 0;
  CYTHON_UNUSED PyObject *__pyx_v_defaults = 0;
  PyObject *__pyx_v__fused_sigindex = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fused_cpdef (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_signatures,&__pyx_n_s_args,&__pyx_n_s_kwargs,&__pyx_n_s_defaults,&__pyx_n_s_fused_sigindex,0};
    __pyx_defaults1 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_self);
    values[4] = __Pyx_Arg_NewRef_VARARGS(__pyx_dynamic_args->__pyx_arg__fused_sigindex);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_signatures)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_args)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fused_cpdef", 0, 4, 5, 1); __PYX_ERR(5, 2568, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_kwargs)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fused_cpdef", 0, 4, 5, 2); __PYX_ERR(5, 2568, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_defaults)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fused_cpdef", 0, 4, 5, 3); __PYX_ERR(5, 2568, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_fused_sigindex);
          if (value) { values[4] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fused_cpdef") < 0)) __PYX_ERR(5, 2568, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_signatures = values[0];
    __pyx_v_args = values[1];
    __pyx_v_kwargs = values[2];
    __pyx_v_defaults = values[3];
    __pyx_v__fused_sigindex = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fused_cpdef", 0, 4, 5, __pyx_nargs); __PYX_ERR(5, 2568, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fused_cpdef", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_8duplicated(__pyx_self, __pyx_v_signatures, __pyx_v_args, __pyx_v_kwargs, __pyx_v_defaults, __pyx_v__fused_sigindex);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_8duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_signatures, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs, CYTHON_UNUSED PyObject *__pyx_v_defaults, PyObject *__pyx_v__fused_sigindex) {
  PyObject *__pyx_v_search_list = 0;
  PyObject *__pyx_v_sigindex_node = 0;
  PyObject *__pyx_v_dest_sig = NULL;
  PyTypeObject *__pyx_v_ndarray = 0;
  PyObject *__pyx_v_arg_as_memoryview = 0;
  __Pyx_memviewslice __pyx_v_memslice;
  Py_ssize_t __pyx_v_itemsize;
  int __pyx_v_dtype_signed;
  Py_UCS4 __pyx_v_kind;
  int __pyx_v___pyx_fused_dtype_int8__t_is_signed;
  int __pyx_v___pyx_fused_dtype_int16__t_is_signed;
  int __pyx_v___pyx_fused_dtype_int32__t_is_signed;
  int __pyx_v___pyx_fused_dtype_int64__t_is_signed;
  int __pyx_v___pyx_fused_dtype_uint8__t_is_signed;
  int __pyx_v___pyx_fused_dtype_uint16__t_is_signed;
  int __pyx_v___pyx_fused_dtype_uint32__t_is_signed;
  int __pyx_v___pyx_fused_dtype_uint64__t_is_signed;
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_v_dtype = NULL;
  PyObject *__pyx_v_arg_base = NULL;
  PyObject *__pyx_v_sig = NULL;
  PyObject *__pyx_v_sig_series = NULL;
  PyObject *__pyx_v_last_type = NULL;
  PyObject *__pyx_v_sig_type = NULL;
  PyObject *__pyx_v_sigindex_matches = NULL;
  PyObject *__pyx_v_sigindex_candidates = NULL;
  PyObject *__pyx_v_dst_type = NULL;
  PyObject *__pyx_v_found_matches = NULL;
  PyObject *__pyx_v_found_candidates = NULL;
  PyObject *__pyx_v_sn = NULL;
  PyObject *__pyx_v_type_match = NULL;
  PyObject *__pyx_v_candidates = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  long __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  __Pyx_memviewslice __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  Py_ssize_t __pyx_t_14;
  int __pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  Py_ssize_t __pyx_t_18;
  int __pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("duplicated", 0);
  __Pyx_INCREF(__pyx_v_kwargs);
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, Py_None)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __pyx_v_dest_sig = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_v_kwargs != Py_None);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_kwargs); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_t_4 = (!__pyx_t_3);
  __pyx_t_2 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {
    __Pyx_INCREF(Py_None);
    __Pyx_DECREF_SET(__pyx_v_kwargs, Py_None);
  }
  __pyx_t_1 = ((PyObject *)__Pyx_ImportNumPyArrayTypeIfAvailable()); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_ndarray = ((PyTypeObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_v_itemsize = -1L;
  __pyx_v___pyx_fused_dtype_int8__t_is_signed = (!(((__pyx_t_5numpy_int8_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_int16__t_is_signed = (!(((__pyx_t_5numpy_int16_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_int32__t_is_signed = (!(((__pyx_t_5numpy_int32_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_int64__t_is_signed = (!(((__pyx_t_5numpy_int64_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_uint8__t_is_signed = (!(((__pyx_t_5numpy_uint8_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_uint16__t_is_signed = (!(((__pyx_t_5numpy_uint16_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_uint32__t_is_signed = (!(((__pyx_t_5numpy_uint32_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_uint64__t_is_signed = (!(((__pyx_t_5numpy_uint64_t)-1L) > 0));
  if (unlikely(__pyx_v_args == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_PyTuple_GET_SIZE(((PyObject*)__pyx_v_args)); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_t_2 = (0 < __pyx_t_5);
  if (__pyx_t_2) {
    if (unlikely(__pyx_v_args == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(5, 2568, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_GetItemInt_Tuple(((PyObject*)__pyx_v_args), 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_arg = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L6;
  }
  __pyx_t_4 = (__pyx_v_kwargs != Py_None);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L7_bool_binop_done;
  }
  if (unlikely(__pyx_v_kwargs == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_t_4 = (__Pyx_PyDict_ContainsTF(__pyx_n_s_values, ((PyObject*)__pyx_v_kwargs), Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_4;
  __pyx_L7_bool_binop_done:;
  if (likely(__pyx_t_2)) {
    if (unlikely(__pyx_v_kwargs == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(5, 2568, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_PyDict_GetItem(((PyObject*)__pyx_v_kwargs), __pyx_n_s_values); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_arg = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L6;
  }
  /*else*/ {
    if (unlikely(__pyx_v_args == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(5, 2568, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_PyTuple_GET_SIZE(((PyObject*)__pyx_v_args)); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2568, __pyx_L1_error)
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_int_1);
    __Pyx_GIVEREF(__pyx_int_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_int_1)) __PYX_ERR(5, 2568, __pyx_L1_error);
    __Pyx_INCREF(__pyx_kp_s__86);
    __Pyx_GIVEREF(__pyx_kp_s__86);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_kp_s__86)) __PYX_ERR(5, 2568, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Expected_at_least_d_argument_s_g, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_L6:;
  while (1) {
    __pyx_t_2 = (__pyx_v_ndarray != ((PyTypeObject*)Py_None));
    if (__pyx_t_2) {
      __pyx_t_2 = __Pyx_TypeCheck(__pyx_v_arg, __pyx_v_ndarray); 
      if (__pyx_t_2) {
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_dtype); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_v_dtype = __pyx_t_6;
        __pyx_t_6 = 0;
        goto __pyx_L12;
      }
      __pyx_t_2 = __pyx_memoryview_check(__pyx_v_arg); 
      if (__pyx_t_2) {
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_base); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_v_arg_base = __pyx_t_6;
        __pyx_t_6 = 0;
        __pyx_t_2 = __Pyx_TypeCheck(__pyx_v_arg_base, __pyx_v_ndarray); 
        if (__pyx_t_2) {
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg_base, __pyx_n_s_dtype); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_v_dtype = __pyx_t_6;
          __pyx_t_6 = 0;
          goto __pyx_L13;
        }
        /*else*/ {
          __Pyx_INCREF(Py_None);
          __pyx_v_dtype = Py_None;
        }
        __pyx_L13:;
        goto __pyx_L12;
      }
      /*else*/ {
        __Pyx_INCREF(Py_None);
        __pyx_v_dtype = Py_None;
      }
      __pyx_L12:;
      __pyx_v_itemsize = -1L;
      __pyx_t_2 = (__pyx_v_dtype != Py_None);
      if (__pyx_t_2) {
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtype, __pyx_n_s_itemsize); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_v_itemsize = __pyx_t_5;
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtype, __pyx_n_s_kind); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = __Pyx_PyObject_Ord(__pyx_t_6); if (unlikely(__pyx_t_7 == ((long)(long)(Py_UCS4)-1))) __PYX_ERR(5, 2568, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_v_kind = __pyx_t_7;
        __pyx_v_dtype_signed = (__pyx_v_kind == 0x69);
        switch (__pyx_v_kind) {
          case 0x69:
          case 0x75:
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_int8_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L16_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L16_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_int8__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L16_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int8_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_int16_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L20_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L20_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_int16__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L20_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int16_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_int32_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L24_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L24_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_int32__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L24_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_int64_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L28_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L28_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_int64__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L28_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_uint8_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L32_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L32_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_uint8__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L32_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint8_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_uint16_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L36_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L36_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_uint16__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L36_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint16_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_uint32_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L40_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L40_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_uint32__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L40_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_uint64_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L44_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L44_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_uint64__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L44_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          break;
          case 0x66:
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_float32_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L48_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          __pyx_t_2 = __pyx_t_4;
          __pyx_L48_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_float32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_float64_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L51_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          __pyx_t_2 = __pyx_t_4;
          __pyx_L51_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_float64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          break;
          case 99:
          __pyx_t_4 = ((sizeof(__pyx_t_double_complex)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L54_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          __pyx_t_2 = __pyx_t_4;
          __pyx_L54_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_kp_s_double_complex, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_float_complex)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L57_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          __pyx_t_2 = __pyx_t_4;
          __pyx_L57_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_kp_s_float_complex, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          break;
          case 79:
          break;
          default: break;
        }
      }
    }
    __pyx_t_2 = (__pyx_v_arg == Py_None);
    if (__pyx_t_2) {
      if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int8_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
      goto __pyx_L10_break;
    }
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      /*try:*/ {
        __pyx_t_6 = PyMemoryView_FromObject(__pyx_v_arg); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L60_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_v_arg_as_memoryview = ((PyObject*)__pyx_t_6);
        __pyx_t_6 = 0;
      }
      /*else:*/ {
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L71_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_int8_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L70_next_and;
        }
        __pyx_L71_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_int8_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L69_bool_binop_done;
        }
        __pyx_L70_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L69_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int8_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int8_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L77_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_int16_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L76_next_and;
        }
        __pyx_L77_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_int16_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L75_bool_binop_done;
        }
        __pyx_L76_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L75_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int16_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int16_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L83_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_int32_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L82_next_and;
        }
        __pyx_L83_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_int32_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L81_bool_binop_done;
        }
        __pyx_L82_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L81_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int32_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L89_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_int64_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L88_next_and;
        }
        __pyx_L89_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_int64_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L87_bool_binop_done;
        }
        __pyx_L88_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L87_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L95_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_uint8_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L94_next_and;
        }
        __pyx_L95_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_uint8_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L93_bool_binop_done;
        }
        __pyx_L94_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L93_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint8_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L101_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_uint16_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L100_next_and;
        }
        __pyx_L101_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_uint16_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L99_bool_binop_done;
        }
        __pyx_L100_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L99_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint16_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint16_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L107_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_uint32_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L106_next_and;
        }
        __pyx_L107_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_uint32_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L105_bool_binop_done;
        }
        __pyx_L106_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L105_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint32_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L113_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_uint64_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L112_next_and;
        }
        __pyx_L113_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_uint64_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L111_bool_binop_done;
        }
        __pyx_L112_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L111_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint64_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L119_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_float32_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L118_next_and;
        }
        __pyx_L119_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_float32_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L117_bool_binop_done;
        }
        __pyx_L118_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L117_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float32_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_float32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L125_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_float64_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L124_next_and;
        }
        __pyx_L125_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_float64_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L123_bool_binop_done;
        }
        __pyx_L124_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L123_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float64_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_float64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L131_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(void *)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L130_next_and;
        }
        __pyx_L131_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(void *)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L129_bool_binop_done;
        }
        __pyx_L130_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L129_bool_binop_done:;
        if (__pyx_t_2) {
          if ((CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION == 2)) {
            __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_object(__pyx_v_arg, 0); 
            __pyx_v_memslice = __pyx_t_12;
            goto __pyx_L133;
          }
          /*else*/ {
            __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_object(__pyx_v_arg_as_memoryview, 0); 
            __pyx_v_memslice = __pyx_t_12;
          }
          __pyx_L133:;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_object, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L138_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_double_complex)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L137_next_and;
        }
        __pyx_L138_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_double_complex)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L136_bool_binop_done;
        }
        __pyx_L137_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L136_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_double_complex(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_kp_s_double_complex, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L144_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_float_complex)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L143_next_and;
        }
        __pyx_L144_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_float_complex)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L142_bool_binop_done;
        }
        __pyx_L143_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L142_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_float_complex(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_kp_s_float_complex, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
      }
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L67_try_end;
      __pyx_L60_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_11 = __Pyx_PyErr_ExceptionMatches2(__pyx_builtin_ValueError, __pyx_builtin_TypeError);
      if (__pyx_t_11) {
        __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fused_cpdef", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_1, &__pyx_t_13) < 0) __PYX_ERR(5, 2568, __pyx_L62_except_error)
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_1);
        __Pyx_XGOTREF(__pyx_t_13);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        goto __pyx_L61_exception_handled;
      }
      goto __pyx_L62_except_error;
      __pyx_L62_except_error:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      goto __pyx_L1_error;
      __pyx_L65_try_break:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      goto __pyx_L10_break;
      __pyx_L61_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      __pyx_L67_try_end:;
    }
    if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, Py_None, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
    goto __pyx_L10_break;
  }
  __pyx_L10_break:;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v__fused_sigindex); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_t_4 = (!__pyx_t_2);
  if (__pyx_t_4) {
    __pyx_t_5 = 0;
    if (unlikely(__pyx_v_signatures == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(5, 2568, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_dict_iterator(((PyObject*)__pyx_v_signatures), 1, ((PyObject *)NULL), (&__pyx_t_14), (&__pyx_t_11)); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF(__pyx_t_13);
    __pyx_t_13 = __pyx_t_1;
    __pyx_t_1 = 0;
    while (1) {
      __pyx_t_15 = __Pyx_dict_iter_next(__pyx_t_13, __pyx_t_14, &__pyx_t_5, &__pyx_t_1, NULL, NULL, __pyx_t_11);
      if (unlikely(__pyx_t_15 == 0)) break;
      if (unlikely(__pyx_t_15 == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_sig, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_1 = __pyx_v__fused_sigindex;
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_sigindex_node, ((PyObject*)__pyx_t_1));
      __pyx_t_1 = 0;
      __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_v_sig, __pyx_n_s_strip); if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2568, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __pyx_t_17 = NULL;
      __pyx_t_15 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_16))) {
        __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_16);
        if (likely(__pyx_t_17)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
          __Pyx_INCREF(__pyx_t_17);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_16, function);
          __pyx_t_15 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_17, __pyx_kp_s__69};
        __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_16, __pyx_callargs+1-__pyx_t_15, 1+__pyx_t_15);
        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      }
      __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_split); if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2568, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      __pyx_t_15 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_16))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_16);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_16, function);
          __pyx_t_15 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_kp_s__70};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_16, __pyx_callargs+1-__pyx_t_15, 1+__pyx_t_15);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      }
      __pyx_t_16 = __Pyx_PySequence_ListKeepNew(__pyx_t_1); if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2568, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_18 = PyList_GET_SIZE(__pyx_t_16);
      if (unlikely(__pyx_t_18 < 1)) {
        __Pyx_RaiseNeedMoreValuesError(0+__pyx_t_18); __PYX_ERR(5, 2568, __pyx_L1_error)
      }
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_6 = PyList_GET_ITEM(__pyx_t_16, __pyx_t_18-1); 
      ((PyVarObject*)__pyx_t_16)->ob_size--;
      #else
      __pyx_t_6 = PySequence_ITEM(__pyx_t_16, __pyx_t_18-1); 
      #endif
      __Pyx_GOTREF(__pyx_t_6);
      #if !CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_17 = PySequence_GetSlice(__pyx_t_16, 0, __pyx_t_18-1); if (unlikely(!__pyx_t_17)) __PYX_ERR(5, 2568, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_DECREF(__pyx_t_16);
      __pyx_t_16 = __pyx_t_17; __pyx_t_17 = NULL;
      #else
      CYTHON_UNUSED_VAR(__pyx_t_17);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_sig_series, ((PyObject*)__pyx_t_16));
      __pyx_t_16 = 0;
      __Pyx_XDECREF_SET(__pyx_v_last_type, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_1 = __pyx_v_sig_series; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_18 = 0;
      for (;;) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
          #endif
          if (__pyx_t_18 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_6 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_18); __Pyx_INCREF(__pyx_t_6); __pyx_t_18++; if (unlikely((0 < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
        #else
        __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_18); __pyx_t_18++; if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
        __Pyx_XDECREF_SET(__pyx_v_sig_type, __pyx_t_6);
        __pyx_t_6 = 0;
        if (unlikely(__pyx_v_sigindex_node == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
          __PYX_ERR(5, 2568, __pyx_L1_error)
        }
        __pyx_t_4 = (__Pyx_PyDict_ContainsTF(__pyx_v_sig_type, __pyx_v_sigindex_node, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
        if (__pyx_t_4) {
          __pyx_t_6 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (unlikely(__pyx_v_sigindex_node == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            __PYX_ERR(5, 2568, __pyx_L1_error)
          }
          if (unlikely((PyDict_SetItem(__pyx_v_sigindex_node, __pyx_v_sig_type, __pyx_t_6) < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_DECREF_SET(__pyx_v_sigindex_node, __pyx_t_6);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          goto __pyx_L154;
        }
        /*else*/ {
          if (unlikely(__pyx_v_sigindex_node == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            __PYX_ERR(5, 2568, __pyx_L1_error)
          }
          __pyx_t_6 = __Pyx_PyDict_GetItem(__pyx_v_sigindex_node, __pyx_v_sig_type); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_16 = __pyx_t_6;
          __Pyx_INCREF(__pyx_t_16);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF_SET(__pyx_v_sigindex_node, ((PyObject*)__pyx_t_16));
          __pyx_t_16 = 0;
        }
        __pyx_L154:;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(__pyx_v_sigindex_node == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(5, 2568, __pyx_L1_error)
      }
      if (unlikely((PyDict_SetItem(__pyx_v_sigindex_node, __pyx_v_last_type, __pyx_v_sig) < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  }
  __pyx_t_13 = PyList_New(0); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_v_sigindex_matches = ((PyObject*)__pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = PyList_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_INCREF(__pyx_v__fused_sigindex);
  __Pyx_GIVEREF(__pyx_v__fused_sigindex);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_13, 0, __pyx_v__fused_sigindex)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __pyx_v_sigindex_candidates = ((PyObject*)__pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __pyx_v_dest_sig; __Pyx_INCREF(__pyx_t_13);
  __pyx_t_14 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_13);
      #if !CYTHON_ASSUME_SAFE_MACROS
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
      #endif
      if (__pyx_t_14 >= __pyx_temp) break;
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_1 = PyList_GET_ITEM(__pyx_t_13, __pyx_t_14); __Pyx_INCREF(__pyx_t_1); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
    #else
    __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_13, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_dst_type, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_found_matches, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_found_candidates, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;
    __pyx_t_4 = (__pyx_v_dst_type == Py_None);
    if (__pyx_t_4) {
      __pyx_t_1 = __pyx_v_sigindex_matches; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_5 = 0;
      for (;;) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_16 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_16); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
        #else
        __pyx_t_16 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2568, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        #endif
        __Pyx_XDECREF_SET(__pyx_v_sn, __pyx_t_16);
        __pyx_t_16 = 0;
        if (unlikely(__pyx_v_sn == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "values");
          __PYX_ERR(5, 2568, __pyx_L1_error)
        }
        __pyx_t_16 = __Pyx_PyDict_Values(((PyObject*)__pyx_v_sn)); if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2568, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        __pyx_t_19 = __Pyx_PyList_Extend(__pyx_v_found_matches, __pyx_t_16); if (unlikely(__pyx_t_19 == ((int)-1))) __PYX_ERR(5, 2568, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __pyx_v_sigindex_candidates; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_5 = 0;
      for (;;) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_16 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_16); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
        #else
        __pyx_t_16 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2568, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        #endif
        __Pyx_XDECREF_SET(__pyx_v_sn, __pyx_t_16);
        __pyx_t_16 = 0;
        if (unlikely(__pyx_v_sn == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "values");
          __PYX_ERR(5, 2568, __pyx_L1_error)
        }
        __pyx_t_16 = __Pyx_PyDict_Values(((PyObject*)__pyx_v_sn)); if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2568, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        __pyx_t_19 = __Pyx_PyList_Extend(__pyx_v_found_candidates, __pyx_t_16); if (unlikely(__pyx_t_19 == ((int)-1))) __PYX_ERR(5, 2568, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L158;
    }
    /*else*/ {
      __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_sigindex_matches);
      __Pyx_GIVEREF(__pyx_v_sigindex_matches);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_sigindex_matches)) __PYX_ERR(5, 2568, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_sigindex_candidates);
      __Pyx_GIVEREF(__pyx_v_sigindex_candidates);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_sigindex_candidates)) __PYX_ERR(5, 2568, __pyx_L1_error);
      __pyx_t_16 = __pyx_t_1; __Pyx_INCREF(__pyx_t_16);
      __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      for (;;) {
        if (__pyx_t_5 >= 2) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_16, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_16, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
        __Pyx_XDECREF_SET(__pyx_v_search_list, ((PyObject*)__pyx_t_1));
        __pyx_t_1 = 0;
        if (unlikely(__pyx_v_search_list == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
          __PYX_ERR(5, 2568, __pyx_L1_error)
        }
        __pyx_t_1 = __pyx_v_search_list; __Pyx_INCREF(__pyx_t_1);
        __pyx_t_18 = 0;
        for (;;) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
            #endif
            if (__pyx_t_18 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_18); __Pyx_INCREF(__pyx_t_6); __pyx_t_18++; if (unlikely((0 < 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
          #else
          __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_18); __pyx_t_18++; if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
          __Pyx_XDECREF_SET(__pyx_v_sn, __pyx_t_6);
          __pyx_t_6 = 0;
          if (unlikely(__pyx_v_sn == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "get");
            __PYX_ERR(5, 2568, __pyx_L1_error)
          }
          __pyx_t_6 = __Pyx_PyDict_GetItemDefault(((PyObject*)__pyx_v_sn), __pyx_v_dst_type, Py_None); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2568, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_XDECREF_SET(__pyx_v_type_match, __pyx_t_6);
          __pyx_t_6 = 0;
          __pyx_t_4 = (__pyx_v_type_match != Py_None);
          if (__pyx_t_4) {
            __pyx_t_19 = __Pyx_PyList_Append(__pyx_v_found_matches, __pyx_v_type_match); if (unlikely(__pyx_t_19 == ((int)-1))) __PYX_ERR(5, 2568, __pyx_L1_error)
          }
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    }
    __pyx_L158:;
    __Pyx_INCREF(__pyx_v_found_matches);
    __Pyx_DECREF_SET(__pyx_v_sigindex_matches, __pyx_v_found_matches);
    __Pyx_INCREF(__pyx_v_found_candidates);
    __Pyx_DECREF_SET(__pyx_v_sigindex_candidates, __pyx_v_found_candidates);
    __pyx_t_2 = (PyList_GET_SIZE(__pyx_v_found_matches) != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_4 = __pyx_t_2;
      goto __pyx_L173_bool_binop_done;
    }
    __pyx_t_2 = (PyList_GET_SIZE(__pyx_v_found_candidates) != 0);
    __pyx_t_4 = __pyx_t_2;
    __pyx_L173_bool_binop_done:;
    __pyx_t_2 = (!__pyx_t_4);
    if (__pyx_t_2) {
      goto __pyx_L157_break;
    }
  }
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  goto __pyx_L175_for_end;
  __pyx_L157_break:;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  goto __pyx_L175_for_end;
  __pyx_L175_for_end:;
  __Pyx_INCREF(__pyx_v_sigindex_matches);
  __pyx_v_candidates = __pyx_v_sigindex_matches;
  __pyx_t_2 = (PyList_GET_SIZE(__pyx_v_candidates) != 0);
  __pyx_t_4 = (!__pyx_t_2);
  if (unlikely(__pyx_t_4)) {
    __pyx_t_13 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__71, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 2568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_Raise(__pyx_t_13, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_t_14 = __Pyx_PyList_GET_SIZE(__pyx_v_candidates); if (unlikely(__pyx_t_14 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_t_4 = (__pyx_t_14 > 1);
  if (unlikely(__pyx_t_4)) {
    __pyx_t_13 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__72, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 2568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_Raise(__pyx_t_13, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    if (unlikely(__pyx_v_signatures == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(5, 2568, __pyx_L1_error)
    }
    __pyx_t_13 = __Pyx_GetItemInt_List(__pyx_v_candidates, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 2568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_16 = __Pyx_PyDict_GetItem(((PyObject*)__pyx_v_signatures), __pyx_t_13); if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2568, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_r = __pyx_t_16;
    __pyx_t_16 = 0;
    goto __pyx_L0;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fused_cpdef", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_search_list);
  __Pyx_XDECREF(__pyx_v_sigindex_node);
  __Pyx_XDECREF(__pyx_v_dest_sig);
  __Pyx_XDECREF((PyObject *)__pyx_v_ndarray);
  __Pyx_XDECREF(__pyx_v_arg_as_memoryview);
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XDECREF(__pyx_v_dtype);
  __Pyx_XDECREF(__pyx_v_arg_base);
  __Pyx_XDECREF(__pyx_v_sig);
  __Pyx_XDECREF(__pyx_v_sig_series);
  __Pyx_XDECREF(__pyx_v_last_type);
  __Pyx_XDECREF(__pyx_v_sig_type);
  __Pyx_XDECREF(__pyx_v_sigindex_matches);
  __Pyx_XDECREF(__pyx_v_sigindex_candidates);
  __Pyx_XDECREF(__pyx_v_dst_type);
  __Pyx_XDECREF(__pyx_v_found_matches);
  __Pyx_XDECREF(__pyx_v_found_candidates);
  __Pyx_XDECREF(__pyx_v_sn);
  __Pyx_XDECREF(__pyx_v_type_match);
  __Pyx_XDECREF(__pyx_v_candidates);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_49__pyx_fuse_0duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_9duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_0__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_0__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__87;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_int8 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_0duplicated", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int8_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2573
 * 
 *     elif htfunc_t is int8_t:
 *         return duplicated_int8(values, keep, mask=mask)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is int16_t:
 *         return duplicated_int16(values, keep, mask=mask)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int8_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2573, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 2;
  __pyx_t_3.keep = __pyx_v_keep;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_duplicated_int8(__pyx_t_1, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2573, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2568
 * 
 * 
 * cpdef duplicated(ndarray[htfunc_t] values, object keep="first", const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return duplicated_object(values, keep, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_49__pyx_fuse_0duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_0__pyx_mdef_6pandas_5_libs_9hashtable_49__pyx_fuse_0duplicated = {"__pyx_fuse_0duplicated", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_49__pyx_fuse_0duplicated, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_49__pyx_fuse_0duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  PyObject *__pyx_v_keep = 0;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_0duplicated (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_keep,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_n_u_first));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_keep);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_0duplicated") < 0)) __PYX_ERR(5, 2568, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_keep = values[1];
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2568, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__87;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_0duplicated", 0, 1, 3, __pyx_nargs); __PYX_ERR(5, 2568, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_0duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_48__pyx_fuse_0duplicated(__pyx_self, __pyx_v_values, __pyx_v_keep, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_48__pyx_fuse_0duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_0__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_0duplicated", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int8_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2568, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.keep = __pyx_v_keep;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_0__pyx_f_6pandas_5_libs_9hashtable_duplicated(((PyArrayObject *)__pyx_v_values), 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_0duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_51__pyx_fuse_1duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_9duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_1__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_1__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__88;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_int16 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_1duplicated", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2575
 *         return duplicated_int8(values, keep, mask=mask)
 *     elif htfunc_t is int16_t:
 *         return duplicated_int16(values, keep, mask=mask)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is int32_t:
 *         return duplicated_int32(values, keep, mask=mask)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int16_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2575, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 2;
  __pyx_t_3.keep = __pyx_v_keep;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_duplicated_int16(__pyx_t_1, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2575, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2568
 * 
 * 
 * cpdef duplicated(ndarray[htfunc_t] values, object keep="first", const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return duplicated_object(values, keep, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_51__pyx_fuse_1duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_1__pyx_mdef_6pandas_5_libs_9hashtable_51__pyx_fuse_1duplicated = {"__pyx_fuse_1duplicated", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_51__pyx_fuse_1duplicated, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_51__pyx_fuse_1duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  PyObject *__pyx_v_keep = 0;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_1duplicated (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_keep,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_n_u_first));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_keep);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_1duplicated") < 0)) __PYX_ERR(5, 2568, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_keep = values[1];
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2568, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__88;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_1duplicated", 0, 1, 3, __pyx_nargs); __PYX_ERR(5, 2568, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_1duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_50__pyx_fuse_1duplicated(__pyx_self, __pyx_v_values, __pyx_v_keep, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_50__pyx_fuse_1duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_1__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_1duplicated", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2568, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.keep = __pyx_v_keep;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_1__pyx_f_6pandas_5_libs_9hashtable_duplicated(((PyArrayObject *)__pyx_v_values), 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_1duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_53__pyx_fuse_2duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_9duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_2__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_2__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__89;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_int32 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_2duplicated", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2577
 *         return duplicated_int16(values, keep, mask=mask)
 *     elif htfunc_t is int32_t:
 *         return duplicated_int32(values, keep, mask=mask)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is int64_t:
 *         return duplicated_int64(values, keep, mask=mask)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int32_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2577, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 2;
  __pyx_t_3.keep = __pyx_v_keep;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_duplicated_int32(__pyx_t_1, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2577, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2568
 * 
 * 
 * cpdef duplicated(ndarray[htfunc_t] values, object keep="first", const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return duplicated_object(values, keep, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_53__pyx_fuse_2duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_2__pyx_mdef_6pandas_5_libs_9hashtable_53__pyx_fuse_2duplicated = {"__pyx_fuse_2duplicated", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_53__pyx_fuse_2duplicated, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_53__pyx_fuse_2duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  PyObject *__pyx_v_keep = 0;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_2duplicated (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_keep,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_n_u_first));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_keep);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_2duplicated") < 0)) __PYX_ERR(5, 2568, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_keep = values[1];
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2568, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__89;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_2duplicated", 0, 1, 3, __pyx_nargs); __PYX_ERR(5, 2568, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_2duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_52__pyx_fuse_2duplicated(__pyx_self, __pyx_v_values, __pyx_v_keep, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_52__pyx_fuse_2duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_2__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_2duplicated", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2568, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.keep = __pyx_v_keep;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_2__pyx_f_6pandas_5_libs_9hashtable_duplicated(((PyArrayObject *)__pyx_v_values), 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_2duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_55__pyx_fuse_3duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_9duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_3__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_3__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__90;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_int64 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_3duplicated", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2579
 *         return duplicated_int32(values, keep, mask=mask)
 *     elif htfunc_t is int64_t:
 *         return duplicated_int64(values, keep, mask=mask)             # <<<<<<<<<<<<<<
 * 
 *     elif htfunc_t is uint8_t:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2579, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 2;
  __pyx_t_3.keep = __pyx_v_keep;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_duplicated_int64(__pyx_t_1, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2579, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2568
 * 
 * 
 * cpdef duplicated(ndarray[htfunc_t] values, object keep="first", const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return duplicated_object(values, keep, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_55__pyx_fuse_3duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_3__pyx_mdef_6pandas_5_libs_9hashtable_55__pyx_fuse_3duplicated = {"__pyx_fuse_3duplicated", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_55__pyx_fuse_3duplicated, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_55__pyx_fuse_3duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  PyObject *__pyx_v_keep = 0;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_3duplicated (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_keep,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_n_u_first));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_keep);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_3duplicated") < 0)) __PYX_ERR(5, 2568, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_keep = values[1];
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2568, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__90;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_3duplicated", 0, 1, 3, __pyx_nargs); __PYX_ERR(5, 2568, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_3duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_54__pyx_fuse_3duplicated(__pyx_self, __pyx_v_values, __pyx_v_keep, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_54__pyx_fuse_3duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_3__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_3duplicated", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2568, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.keep = __pyx_v_keep;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_3__pyx_f_6pandas_5_libs_9hashtable_duplicated(((PyArrayObject *)__pyx_v_values), 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_3duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_57__pyx_fuse_4duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_9duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_4__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_4__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__91;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_uint8 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_4duplicated", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2582
 * 
 *     elif htfunc_t is uint8_t:
 *         return duplicated_uint8(values, keep, mask=mask)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is uint16_t:
 *         return duplicated_uint16(values, keep, mask=mask)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2582, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 2;
  __pyx_t_3.keep = __pyx_v_keep;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_duplicated_uint8(__pyx_t_1, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2568
 * 
 * 
 * cpdef duplicated(ndarray[htfunc_t] values, object keep="first", const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return duplicated_object(values, keep, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_57__pyx_fuse_4duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_4__pyx_mdef_6pandas_5_libs_9hashtable_57__pyx_fuse_4duplicated = {"__pyx_fuse_4duplicated", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_57__pyx_fuse_4duplicated, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_57__pyx_fuse_4duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  PyObject *__pyx_v_keep = 0;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_4duplicated (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_keep,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_n_u_first));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_keep);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_4duplicated") < 0)) __PYX_ERR(5, 2568, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_keep = values[1];
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2568, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__91;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_4duplicated", 0, 1, 3, __pyx_nargs); __PYX_ERR(5, 2568, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_4duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_56__pyx_fuse_4duplicated(__pyx_self, __pyx_v_values, __pyx_v_keep, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_56__pyx_fuse_4duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_4__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_4duplicated", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2568, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.keep = __pyx_v_keep;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_4__pyx_f_6pandas_5_libs_9hashtable_duplicated(((PyArrayObject *)__pyx_v_values), 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_4duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_59__pyx_fuse_5duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_9duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_5__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_5__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__92;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_uint16 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_5duplicated", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint16_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2584
 *         return duplicated_uint8(values, keep, mask=mask)
 *     elif htfunc_t is uint16_t:
 *         return duplicated_uint16(values, keep, mask=mask)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is uint32_t:
 *         return duplicated_uint32(values, keep, mask=mask)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint16_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2584, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 2;
  __pyx_t_3.keep = __pyx_v_keep;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_duplicated_uint16(__pyx_t_1, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2584, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2568
 * 
 * 
 * cpdef duplicated(ndarray[htfunc_t] values, object keep="first", const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return duplicated_object(values, keep, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_59__pyx_fuse_5duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_5__pyx_mdef_6pandas_5_libs_9hashtable_59__pyx_fuse_5duplicated = {"__pyx_fuse_5duplicated", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_59__pyx_fuse_5duplicated, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_59__pyx_fuse_5duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  PyObject *__pyx_v_keep = 0;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_5duplicated (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_keep,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_n_u_first));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_keep);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_5duplicated") < 0)) __PYX_ERR(5, 2568, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_keep = values[1];
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2568, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__92;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_5duplicated", 0, 1, 3, __pyx_nargs); __PYX_ERR(5, 2568, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_5duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_58__pyx_fuse_5duplicated(__pyx_self, __pyx_v_values, __pyx_v_keep, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_58__pyx_fuse_5duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_5__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_5duplicated", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint16_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2568, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.keep = __pyx_v_keep;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_5__pyx_f_6pandas_5_libs_9hashtable_duplicated(((PyArrayObject *)__pyx_v_values), 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_5duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_61__pyx_fuse_6duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_9duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_6__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_6__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__93;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_uint32 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_6duplicated", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2586
 *         return duplicated_uint16(values, keep, mask=mask)
 *     elif htfunc_t is uint32_t:
 *         return duplicated_uint32(values, keep, mask=mask)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is uint64_t:
 *         return duplicated_uint64(values, keep, mask=mask)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint32_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2586, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 2;
  __pyx_t_3.keep = __pyx_v_keep;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_duplicated_uint32(__pyx_t_1, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2568
 * 
 * 
 * cpdef duplicated(ndarray[htfunc_t] values, object keep="first", const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return duplicated_object(values, keep, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_61__pyx_fuse_6duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_6__pyx_mdef_6pandas_5_libs_9hashtable_61__pyx_fuse_6duplicated = {"__pyx_fuse_6duplicated", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_61__pyx_fuse_6duplicated, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_61__pyx_fuse_6duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  PyObject *__pyx_v_keep = 0;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_6duplicated (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_keep,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_n_u_first));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_keep);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_6duplicated") < 0)) __PYX_ERR(5, 2568, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_keep = values[1];
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2568, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__93;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_6duplicated", 0, 1, 3, __pyx_nargs); __PYX_ERR(5, 2568, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_6duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_60__pyx_fuse_6duplicated(__pyx_self, __pyx_v_values, __pyx_v_keep, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_60__pyx_fuse_6duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_6__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_6duplicated", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2568, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.keep = __pyx_v_keep;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_6__pyx_f_6pandas_5_libs_9hashtable_duplicated(((PyArrayObject *)__pyx_v_values), 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_6duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_63__pyx_fuse_7duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_9duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_7__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_7__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__94;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_uint64 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_7duplicated", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2588
 *         return duplicated_uint32(values, keep, mask=mask)
 *     elif htfunc_t is uint64_t:
 *         return duplicated_uint64(values, keep, mask=mask)             # <<<<<<<<<<<<<<
 * 
 *     elif htfunc_t is float64_t:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint64_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2588, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 2;
  __pyx_t_3.keep = __pyx_v_keep;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_duplicated_uint64(__pyx_t_1, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2588, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2568
 * 
 * 
 * cpdef duplicated(ndarray[htfunc_t] values, object keep="first", const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return duplicated_object(values, keep, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_63__pyx_fuse_7duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_7__pyx_mdef_6pandas_5_libs_9hashtable_63__pyx_fuse_7duplicated = {"__pyx_fuse_7duplicated", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_63__pyx_fuse_7duplicated, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_63__pyx_fuse_7duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  PyObject *__pyx_v_keep = 0;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_7duplicated (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_keep,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_n_u_first));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_keep);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_7duplicated") < 0)) __PYX_ERR(5, 2568, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_keep = values[1];
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2568, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__94;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_7duplicated", 0, 1, 3, __pyx_nargs); __PYX_ERR(5, 2568, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_7duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_62__pyx_fuse_7duplicated(__pyx_self, __pyx_v_values, __pyx_v_keep, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_62__pyx_fuse_7duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_7__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_7duplicated", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2568, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.keep = __pyx_v_keep;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_7__pyx_f_6pandas_5_libs_9hashtable_duplicated(((PyArrayObject *)__pyx_v_values), 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_7duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_65__pyx_fuse_8duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_9duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_8__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_8__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__95;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_float32 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_8duplicated", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2593
 *         return duplicated_float64(values, keep, mask=mask)
 *     elif htfunc_t is float32_t:
 *         return duplicated_float32(values, keep, mask=mask)             # <<<<<<<<<<<<<<
 * 
 *     elif htfunc_t is complex128_t:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float32_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2593, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 2;
  __pyx_t_3.keep = __pyx_v_keep;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_duplicated_float32(__pyx_t_1, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2593, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2568
 * 
 * 
 * cpdef duplicated(ndarray[htfunc_t] values, object keep="first", const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return duplicated_object(values, keep, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_65__pyx_fuse_8duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_8__pyx_mdef_6pandas_5_libs_9hashtable_65__pyx_fuse_8duplicated = {"__pyx_fuse_8duplicated", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_65__pyx_fuse_8duplicated, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_65__pyx_fuse_8duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  PyObject *__pyx_v_keep = 0;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_8duplicated (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_keep,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_n_u_first));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_keep);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_8duplicated") < 0)) __PYX_ERR(5, 2568, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_keep = values[1];
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2568, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__95;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_8duplicated", 0, 1, 3, __pyx_nargs); __PYX_ERR(5, 2568, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_8duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_64__pyx_fuse_8duplicated(__pyx_self, __pyx_v_values, __pyx_v_keep, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_64__pyx_fuse_8duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_8__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_8duplicated", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2568, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.keep = __pyx_v_keep;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_8__pyx_f_6pandas_5_libs_9hashtable_duplicated(((PyArrayObject *)__pyx_v_values), 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_8duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_67__pyx_fuse_9duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_9duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_9__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_9__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__96;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_float64 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_9duplicated", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2591
 * 
 *     elif htfunc_t is float64_t:
 *         return duplicated_float64(values, keep, mask=mask)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is float32_t:
 *         return duplicated_float32(values, keep, mask=mask)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float64_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2591, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 2;
  __pyx_t_3.keep = __pyx_v_keep;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_duplicated_float64(__pyx_t_1, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2591, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2568
 * 
 * 
 * cpdef duplicated(ndarray[htfunc_t] values, object keep="first", const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return duplicated_object(values, keep, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_67__pyx_fuse_9duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_9__pyx_mdef_6pandas_5_libs_9hashtable_67__pyx_fuse_9duplicated = {"__pyx_fuse_9duplicated", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_67__pyx_fuse_9duplicated, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_67__pyx_fuse_9duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  PyObject *__pyx_v_keep = 0;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_9duplicated (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_keep,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_n_u_first));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_keep);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_9duplicated") < 0)) __PYX_ERR(5, 2568, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_keep = values[1];
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2568, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__96;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_9duplicated", 0, 1, 3, __pyx_nargs); __PYX_ERR(5, 2568, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_9duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_66__pyx_fuse_9duplicated(__pyx_self, __pyx_v_values, __pyx_v_keep, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_66__pyx_fuse_9duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_9__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_9duplicated", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2568, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.keep = __pyx_v_keep;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_9__pyx_f_6pandas_5_libs_9hashtable_duplicated(((PyArrayObject *)__pyx_v_values), 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_9duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_69__pyx_fuse_10duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_9duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_10__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_10__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__97;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_object __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_10duplicated", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2570
 * cpdef duplicated(ndarray[htfunc_t] values, object keep="first", const uint8_t[:] mask=None):
 *     if htfunc_t is object:
 *         return duplicated_object(values, keep, mask=mask)             # <<<<<<<<<<<<<<
 * 
 *     elif htfunc_t is int8_t:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.keep = __pyx_v_keep;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_duplicated_object(((PyArrayObject *)__pyx_v_values), &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2570, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2568
 * 
 * 
 * cpdef duplicated(ndarray[htfunc_t] values, object keep="first", const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return duplicated_object(values, keep, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_69__pyx_fuse_10duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_10__pyx_mdef_6pandas_5_libs_9hashtable_69__pyx_fuse_10duplicated = {"__pyx_fuse_10duplicated", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_69__pyx_fuse_10duplicated, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_69__pyx_fuse_10duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  PyObject *__pyx_v_keep = 0;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_10duplicated (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_keep,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_n_u_first));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_keep);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_10duplicated") < 0)) __PYX_ERR(5, 2568, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_keep = values[1];
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2568, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__97;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_10duplicated", 0, 1, 3, __pyx_nargs); __PYX_ERR(5, 2568, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_10duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_68__pyx_fuse_10duplicated(__pyx_self, __pyx_v_values, __pyx_v_keep, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_68__pyx_fuse_10duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_10__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_10duplicated", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2568, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.keep = __pyx_v_keep;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_10__pyx_f_6pandas_5_libs_9hashtable_duplicated(((PyArrayObject *)__pyx_v_values), 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_10duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_71__pyx_fuse_11duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_9duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_11__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_11__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__98;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_complex128 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_11duplicated", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo___pyx_t_double_complex, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2596
 * 
 *     elif htfunc_t is complex128_t:
 *         return duplicated_complex128(values, keep, mask=mask)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is complex64_t:
 *         return duplicated_complex64(values, keep, mask=mask)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_double_complex__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2596, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 2;
  __pyx_t_3.keep = __pyx_v_keep;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_duplicated_complex128(__pyx_t_1, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2596, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2568
 * 
 * 
 * cpdef duplicated(ndarray[htfunc_t] values, object keep="first", const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return duplicated_object(values, keep, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_71__pyx_fuse_11duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_11__pyx_mdef_6pandas_5_libs_9hashtable_71__pyx_fuse_11duplicated = {"__pyx_fuse_11duplicated", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_71__pyx_fuse_11duplicated, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_71__pyx_fuse_11duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  PyObject *__pyx_v_keep = 0;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_11duplicated (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_keep,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_n_u_first));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_keep);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_11duplicated") < 0)) __PYX_ERR(5, 2568, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_keep = values[1];
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2568, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__98;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_11duplicated", 0, 1, 3, __pyx_nargs); __PYX_ERR(5, 2568, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_11duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_70__pyx_fuse_11duplicated(__pyx_self, __pyx_v_values, __pyx_v_keep, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_70__pyx_fuse_11duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_11__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_11duplicated", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo___pyx_t_double_complex, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2568, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.keep = __pyx_v_keep;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_11__pyx_f_6pandas_5_libs_9hashtable_duplicated(((PyArrayObject *)__pyx_v_values), 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_11duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_73__pyx_fuse_12duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_9duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_12__pyx_f_6pandas_5_libs_9hashtable_duplicated(PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_fuse_12__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated *__pyx_optional_args) {
  PyObject *__pyx_v_keep = ((PyObject *)__pyx_n_u_first);
  __Pyx_memviewslice __pyx_v_mask = __pyx_k__99;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_opt_args_6pandas_5_libs_9hashtable_duplicated_complex64 __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_12duplicated", 1);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_keep = __pyx_optional_args->keep;
      if (__pyx_optional_args->__pyx_n > 1) {
        __pyx_v_mask = __pyx_optional_args->mask;
      }
    }
  }
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo___pyx_t_float_complex, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2598
 *         return duplicated_complex128(values, keep, mask=mask)
 *     elif htfunc_t is complex64_t:
 *         return duplicated_complex64(values, keep, mask=mask)             # <<<<<<<<<<<<<<
 * 
 *     else:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_float_complex__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2598, __pyx_L1_error)
  __pyx_t_3.__pyx_n = 2;
  __pyx_t_3.keep = __pyx_v_keep;
  __pyx_t_3.mask = __pyx_v_mask;
  __pyx_t_2 = __pyx_f_6pandas_5_libs_9hashtable_duplicated_complex64(__pyx_t_1, &__pyx_t_3); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2598, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2568
 * 
 * 
 * cpdef duplicated(ndarray[htfunc_t] values, object keep="first", const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return duplicated_object(values, keep, mask=mask)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __Pyx_XDECREF(__pyx_t_2);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_73__pyx_fuse_12duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_12__pyx_mdef_6pandas_5_libs_9hashtable_73__pyx_fuse_12duplicated = {"__pyx_fuse_12duplicated", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_73__pyx_fuse_12duplicated, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_73__pyx_fuse_12duplicated(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  PyObject *__pyx_v_keep = 0;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_12duplicated (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_keep,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_VARARGS(((PyObject *)__pyx_n_u_first));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_keep);
          if (value) { values[1] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2568, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_12duplicated") < 0)) __PYX_ERR(5, 2568, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_keep = values[1];
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2568, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_k__99;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_12duplicated", 0, 1, 3, __pyx_nargs); __PYX_ERR(5, 2568, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_12duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_72__pyx_fuse_12duplicated(__pyx_self, __pyx_v_values, __pyx_v_keep, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_72__pyx_fuse_12duplicated(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_keep, __Pyx_memviewslice __pyx_v_mask) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_12__pyx_opt_args_6pandas_5_libs_9hashtable_duplicated __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_12duplicated", 1);
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo___pyx_t_float_complex, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(!__pyx_v_mask.memview)) { __Pyx_RaiseUnboundLocalError("mask"); __PYX_ERR(5, 2568, __pyx_L1_error) }
  __pyx_t_2.__pyx_n = 2;
  __pyx_t_2.keep = __pyx_v_keep;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_12__pyx_f_6pandas_5_libs_9hashtable_duplicated(((PyArrayObject *)__pyx_v_values), 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_12duplicated", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":2604
 * 
 * 
 * cpdef ismember(ndarray[htfunc_t] arr, ndarray[htfunc_t] values):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return ismember_object(arr, values)
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_11ismember = {"ismember", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_11ismember, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_signatures = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kwargs = 0;
  CYTHON_UNUSED PyObject *__pyx_v_defaults = 0;
  PyObject *__pyx_v__fused_sigindex = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fused_cpdef (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_signatures,&__pyx_n_s_args,&__pyx_n_s_kwargs,&__pyx_n_s_defaults,&__pyx_n_s_fused_sigindex,0};
    __pyx_defaults2 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults2, __pyx_self);
    values[4] = __Pyx_Arg_NewRef_VARARGS(__pyx_dynamic_args->__pyx_arg__fused_sigindex);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_signatures)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_args)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fused_cpdef", 0, 4, 5, 1); __PYX_ERR(5, 2604, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_kwargs)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fused_cpdef", 0, 4, 5, 2); __PYX_ERR(5, 2604, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_defaults)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fused_cpdef", 0, 4, 5, 3); __PYX_ERR(5, 2604, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_fused_sigindex);
          if (value) { values[4] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fused_cpdef") < 0)) __PYX_ERR(5, 2604, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_signatures = values[0];
    __pyx_v_args = values[1];
    __pyx_v_kwargs = values[2];
    __pyx_v_defaults = values[3];
    __pyx_v__fused_sigindex = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fused_cpdef", 0, 4, 5, __pyx_nargs); __PYX_ERR(5, 2604, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fused_cpdef", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_10ismember(__pyx_self, __pyx_v_signatures, __pyx_v_args, __pyx_v_kwargs, __pyx_v_defaults, __pyx_v__fused_sigindex);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_10ismember(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_signatures, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs, CYTHON_UNUSED PyObject *__pyx_v_defaults, PyObject *__pyx_v__fused_sigindex) {
  PyObject *__pyx_v_search_list = 0;
  PyObject *__pyx_v_sigindex_node = 0;
  PyObject *__pyx_v_dest_sig = NULL;
  PyTypeObject *__pyx_v_ndarray = 0;
  PyObject *__pyx_v_arg_as_memoryview = 0;
  __Pyx_memviewslice __pyx_v_memslice;
  Py_ssize_t __pyx_v_itemsize;
  int __pyx_v_dtype_signed;
  Py_UCS4 __pyx_v_kind;
  int __pyx_v___pyx_fused_dtype_int8__t_is_signed;
  int __pyx_v___pyx_fused_dtype_int16__t_is_signed;
  int __pyx_v___pyx_fused_dtype_int32__t_is_signed;
  int __pyx_v___pyx_fused_dtype_int64__t_is_signed;
  int __pyx_v___pyx_fused_dtype_uint8__t_is_signed;
  int __pyx_v___pyx_fused_dtype_uint16__t_is_signed;
  int __pyx_v___pyx_fused_dtype_uint32__t_is_signed;
  int __pyx_v___pyx_fused_dtype_uint64__t_is_signed;
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_v_dtype = NULL;
  PyObject *__pyx_v_arg_base = NULL;
  PyObject *__pyx_v_sig = NULL;
  PyObject *__pyx_v_sig_series = NULL;
  PyObject *__pyx_v_last_type = NULL;
  PyObject *__pyx_v_sig_type = NULL;
  PyObject *__pyx_v_sigindex_matches = NULL;
  PyObject *__pyx_v_sigindex_candidates = NULL;
  PyObject *__pyx_v_dst_type = NULL;
  PyObject *__pyx_v_found_matches = NULL;
  PyObject *__pyx_v_found_candidates = NULL;
  PyObject *__pyx_v_sn = NULL;
  PyObject *__pyx_v_type_match = NULL;
  PyObject *__pyx_v_candidates = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  long __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  __Pyx_memviewslice __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  Py_ssize_t __pyx_t_14;
  int __pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  Py_ssize_t __pyx_t_18;
  int __pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("ismember", 0);
  __Pyx_INCREF(__pyx_v_kwargs);
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, Py_None)) __PYX_ERR(5, 2604, __pyx_L1_error);
  __pyx_v_dest_sig = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_v_kwargs != Py_None);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_kwargs); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_t_4 = (!__pyx_t_3);
  __pyx_t_2 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {
    __Pyx_INCREF(Py_None);
    __Pyx_DECREF_SET(__pyx_v_kwargs, Py_None);
  }
  __pyx_t_1 = ((PyObject *)__Pyx_ImportNumPyArrayTypeIfAvailable()); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_ndarray = ((PyTypeObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_v_itemsize = -1L;
  __pyx_v___pyx_fused_dtype_int8__t_is_signed = (!(((__pyx_t_5numpy_int8_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_int16__t_is_signed = (!(((__pyx_t_5numpy_int16_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_int32__t_is_signed = (!(((__pyx_t_5numpy_int32_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_int64__t_is_signed = (!(((__pyx_t_5numpy_int64_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_uint8__t_is_signed = (!(((__pyx_t_5numpy_uint8_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_uint16__t_is_signed = (!(((__pyx_t_5numpy_uint16_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_uint32__t_is_signed = (!(((__pyx_t_5numpy_uint32_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_uint64__t_is_signed = (!(((__pyx_t_5numpy_uint64_t)-1L) > 0));
  if (unlikely(__pyx_v_args == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_PyTuple_GET_SIZE(((PyObject*)__pyx_v_args)); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_t_2 = (0 < __pyx_t_5);
  if (__pyx_t_2) {
    if (unlikely(__pyx_v_args == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(5, 2604, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_GetItemInt_Tuple(((PyObject*)__pyx_v_args), 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_arg = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L6;
  }
  __pyx_t_4 = (__pyx_v_kwargs != Py_None);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L7_bool_binop_done;
  }
  if (unlikely(__pyx_v_kwargs == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_t_4 = (__Pyx_PyDict_ContainsTF(__pyx_n_s_arr, ((PyObject*)__pyx_v_kwargs), Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_4;
  __pyx_L7_bool_binop_done:;
  if (likely(__pyx_t_2)) {
    if (unlikely(__pyx_v_kwargs == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(5, 2604, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_PyDict_GetItem(((PyObject*)__pyx_v_kwargs), __pyx_n_s_arr); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_arg = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L6;
  }
  /*else*/ {
    if (unlikely(__pyx_v_args == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(5, 2604, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_PyTuple_GET_SIZE(((PyObject*)__pyx_v_args)); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2604, __pyx_L1_error)
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_int_2);
    __Pyx_GIVEREF(__pyx_int_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_int_2)) __PYX_ERR(5, 2604, __pyx_L1_error);
    __Pyx_INCREF(__pyx_n_s_s);
    __Pyx_GIVEREF(__pyx_n_s_s);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_n_s_s)) __PYX_ERR(5, 2604, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Expected_at_least_d_argument_s_g, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_L6:;
  while (1) {
    __pyx_t_2 = (__pyx_v_ndarray != ((PyTypeObject*)Py_None));
    if (__pyx_t_2) {
      __pyx_t_2 = __Pyx_TypeCheck(__pyx_v_arg, __pyx_v_ndarray); 
      if (__pyx_t_2) {
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_dtype); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_v_dtype = __pyx_t_6;
        __pyx_t_6 = 0;
        goto __pyx_L12;
      }
      __pyx_t_2 = __pyx_memoryview_check(__pyx_v_arg); 
      if (__pyx_t_2) {
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_base); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_v_arg_base = __pyx_t_6;
        __pyx_t_6 = 0;
        __pyx_t_2 = __Pyx_TypeCheck(__pyx_v_arg_base, __pyx_v_ndarray); 
        if (__pyx_t_2) {
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg_base, __pyx_n_s_dtype); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_v_dtype = __pyx_t_6;
          __pyx_t_6 = 0;
          goto __pyx_L13;
        }
        /*else*/ {
          __Pyx_INCREF(Py_None);
          __pyx_v_dtype = Py_None;
        }
        __pyx_L13:;
        goto __pyx_L12;
      }
      /*else*/ {
        __Pyx_INCREF(Py_None);
        __pyx_v_dtype = Py_None;
      }
      __pyx_L12:;
      __pyx_v_itemsize = -1L;
      __pyx_t_2 = (__pyx_v_dtype != Py_None);
      if (__pyx_t_2) {
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtype, __pyx_n_s_itemsize); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_v_itemsize = __pyx_t_5;
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtype, __pyx_n_s_kind); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = __Pyx_PyObject_Ord(__pyx_t_6); if (unlikely(__pyx_t_7 == ((long)(long)(Py_UCS4)-1))) __PYX_ERR(5, 2604, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_v_kind = __pyx_t_7;
        __pyx_v_dtype_signed = (__pyx_v_kind == 0x69);
        switch (__pyx_v_kind) {
          case 0x69:
          case 0x75:
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_int8_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L16_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L16_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_int8__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L16_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int8_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_int16_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L20_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L20_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_int16__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L20_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int16_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_int32_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L24_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L24_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_int32__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L24_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_int64_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L28_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L28_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_int64__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L28_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_uint8_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L32_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L32_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_uint8__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L32_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint8_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_uint16_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L36_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L36_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_uint16__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L36_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint16_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_uint32_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L40_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L40_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_uint32__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L40_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_uint64_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L44_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L44_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_uint64__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L44_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          break;
          case 0x66:
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_float32_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L48_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          __pyx_t_2 = __pyx_t_4;
          __pyx_L48_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_float32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_float64_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L51_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          __pyx_t_2 = __pyx_t_4;
          __pyx_L51_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_float64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          break;
          case 99:
          __pyx_t_4 = ((sizeof(__pyx_t_double_complex)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L54_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          __pyx_t_2 = __pyx_t_4;
          __pyx_L54_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_kp_s_double_complex, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_float_complex)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L57_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          __pyx_t_2 = __pyx_t_4;
          __pyx_L57_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_kp_s_float_complex, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          break;
          case 79:
          break;
          default: break;
        }
      }
    }
    __pyx_t_2 = (__pyx_v_arg == Py_None);
    if (__pyx_t_2) {
      if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int8_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
      goto __pyx_L10_break;
    }
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      /*try:*/ {
        __pyx_t_6 = PyMemoryView_FromObject(__pyx_v_arg); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L60_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_v_arg_as_memoryview = ((PyObject*)__pyx_t_6);
        __pyx_t_6 = 0;
      }
      /*else:*/ {
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L71_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_int8_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L70_next_and;
        }
        __pyx_L71_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_int8_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L69_bool_binop_done;
        }
        __pyx_L70_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L69_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int8_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int8_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L77_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_int16_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L76_next_and;
        }
        __pyx_L77_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_int16_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L75_bool_binop_done;
        }
        __pyx_L76_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L75_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int16_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int16_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L83_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_int32_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L82_next_and;
        }
        __pyx_L83_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_int32_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L81_bool_binop_done;
        }
        __pyx_L82_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L81_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int32_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L89_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_int64_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L88_next_and;
        }
        __pyx_L89_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_int64_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L87_bool_binop_done;
        }
        __pyx_L88_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L87_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L95_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_uint8_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L94_next_and;
        }
        __pyx_L95_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_uint8_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L93_bool_binop_done;
        }
        __pyx_L94_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L93_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint8_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L101_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_uint16_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L100_next_and;
        }
        __pyx_L101_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_uint16_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L99_bool_binop_done;
        }
        __pyx_L100_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L99_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint16_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint16_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L107_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_uint32_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L106_next_and;
        }
        __pyx_L107_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_uint32_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L105_bool_binop_done;
        }
        __pyx_L106_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L105_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint32_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L113_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_uint64_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L112_next_and;
        }
        __pyx_L113_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_uint64_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L111_bool_binop_done;
        }
        __pyx_L112_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L111_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint64_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L119_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_float32_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L118_next_and;
        }
        __pyx_L119_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_float32_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L117_bool_binop_done;
        }
        __pyx_L118_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L117_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float32_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_float32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L125_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_float64_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L124_next_and;
        }
        __pyx_L125_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_float64_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L123_bool_binop_done;
        }
        __pyx_L124_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L123_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float64_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_float64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L131_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(void *)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L130_next_and;
        }
        __pyx_L131_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(void *)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L129_bool_binop_done;
        }
        __pyx_L130_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L129_bool_binop_done:;
        if (__pyx_t_2) {
          if ((CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION == 2)) {
            __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_object(__pyx_v_arg, 0); 
            __pyx_v_memslice = __pyx_t_12;
            goto __pyx_L133;
          }
          /*else*/ {
            __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_object(__pyx_v_arg_as_memoryview, 0); 
            __pyx_v_memslice = __pyx_t_12;
          }
          __pyx_L133:;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_object, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L138_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_double_complex)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L137_next_and;
        }
        __pyx_L138_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_double_complex)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L136_bool_binop_done;
        }
        __pyx_L137_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L136_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_double_complex(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_kp_s_double_complex, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L144_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_float_complex)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L143_next_and;
        }
        __pyx_L144_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_float_complex)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L142_bool_binop_done;
        }
        __pyx_L143_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L142_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_float_complex(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_kp_s_float_complex, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
      }
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L67_try_end;
      __pyx_L60_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_11 = __Pyx_PyErr_ExceptionMatches2(__pyx_builtin_ValueError, __pyx_builtin_TypeError);
      if (__pyx_t_11) {
        __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fused_cpdef", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_1, &__pyx_t_13) < 0) __PYX_ERR(5, 2604, __pyx_L62_except_error)
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_1);
        __Pyx_XGOTREF(__pyx_t_13);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        goto __pyx_L61_exception_handled;
      }
      goto __pyx_L62_except_error;
      __pyx_L62_except_error:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      goto __pyx_L1_error;
      __pyx_L65_try_break:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      goto __pyx_L10_break;
      __pyx_L61_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      __pyx_L67_try_end:;
    }
    if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, Py_None, long, 1, __Pyx_PyInt_From_long, 1, 0, 1) < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
    goto __pyx_L10_break;
  }
  __pyx_L10_break:;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v__fused_sigindex); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_t_4 = (!__pyx_t_2);
  if (__pyx_t_4) {
    __pyx_t_5 = 0;
    if (unlikely(__pyx_v_signatures == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(5, 2604, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_dict_iterator(((PyObject*)__pyx_v_signatures), 1, ((PyObject *)NULL), (&__pyx_t_14), (&__pyx_t_11)); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF(__pyx_t_13);
    __pyx_t_13 = __pyx_t_1;
    __pyx_t_1 = 0;
    while (1) {
      __pyx_t_15 = __Pyx_dict_iter_next(__pyx_t_13, __pyx_t_14, &__pyx_t_5, &__pyx_t_1, NULL, NULL, __pyx_t_11);
      if (unlikely(__pyx_t_15 == 0)) break;
      if (unlikely(__pyx_t_15 == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_sig, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_1 = __pyx_v__fused_sigindex;
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_sigindex_node, ((PyObject*)__pyx_t_1));
      __pyx_t_1 = 0;
      __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_v_sig, __pyx_n_s_strip); if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2604, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __pyx_t_17 = NULL;
      __pyx_t_15 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_16))) {
        __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_16);
        if (likely(__pyx_t_17)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
          __Pyx_INCREF(__pyx_t_17);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_16, function);
          __pyx_t_15 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_17, __pyx_kp_s__69};
        __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_16, __pyx_callargs+1-__pyx_t_15, 1+__pyx_t_15);
        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      }
      __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_split); if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2604, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      __pyx_t_15 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_16))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_16);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_16, function);
          __pyx_t_15 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_kp_s__70};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_16, __pyx_callargs+1-__pyx_t_15, 1+__pyx_t_15);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      }
      __pyx_t_16 = __Pyx_PySequence_ListKeepNew(__pyx_t_1); if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2604, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_18 = PyList_GET_SIZE(__pyx_t_16);
      if (unlikely(__pyx_t_18 < 1)) {
        __Pyx_RaiseNeedMoreValuesError(0+__pyx_t_18); __PYX_ERR(5, 2604, __pyx_L1_error)
      }
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_6 = PyList_GET_ITEM(__pyx_t_16, __pyx_t_18-1); 
      ((PyVarObject*)__pyx_t_16)->ob_size--;
      #else
      __pyx_t_6 = PySequence_ITEM(__pyx_t_16, __pyx_t_18-1); 
      #endif
      __Pyx_GOTREF(__pyx_t_6);
      #if !CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_17 = PySequence_GetSlice(__pyx_t_16, 0, __pyx_t_18-1); if (unlikely(!__pyx_t_17)) __PYX_ERR(5, 2604, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_DECREF(__pyx_t_16);
      __pyx_t_16 = __pyx_t_17; __pyx_t_17 = NULL;
      #else
      CYTHON_UNUSED_VAR(__pyx_t_17);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_sig_series, ((PyObject*)__pyx_t_16));
      __pyx_t_16 = 0;
      __Pyx_XDECREF_SET(__pyx_v_last_type, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_1 = __pyx_v_sig_series; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_18 = 0;
      for (;;) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
          #endif
          if (__pyx_t_18 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_6 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_18); __Pyx_INCREF(__pyx_t_6); __pyx_t_18++; if (unlikely((0 < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
        #else
        __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_18); __pyx_t_18++; if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
        __Pyx_XDECREF_SET(__pyx_v_sig_type, __pyx_t_6);
        __pyx_t_6 = 0;
        if (unlikely(__pyx_v_sigindex_node == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
          __PYX_ERR(5, 2604, __pyx_L1_error)
        }
        __pyx_t_4 = (__Pyx_PyDict_ContainsTF(__pyx_v_sig_type, __pyx_v_sigindex_node, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
        if (__pyx_t_4) {
          __pyx_t_6 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (unlikely(__pyx_v_sigindex_node == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            __PYX_ERR(5, 2604, __pyx_L1_error)
          }
          if (unlikely((PyDict_SetItem(__pyx_v_sigindex_node, __pyx_v_sig_type, __pyx_t_6) < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_DECREF_SET(__pyx_v_sigindex_node, __pyx_t_6);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          goto __pyx_L154;
        }
        /*else*/ {
          if (unlikely(__pyx_v_sigindex_node == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            __PYX_ERR(5, 2604, __pyx_L1_error)
          }
          __pyx_t_6 = __Pyx_PyDict_GetItem(__pyx_v_sigindex_node, __pyx_v_sig_type); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_16 = __pyx_t_6;
          __Pyx_INCREF(__pyx_t_16);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF_SET(__pyx_v_sigindex_node, ((PyObject*)__pyx_t_16));
          __pyx_t_16 = 0;
        }
        __pyx_L154:;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(__pyx_v_sigindex_node == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(5, 2604, __pyx_L1_error)
      }
      if (unlikely((PyDict_SetItem(__pyx_v_sigindex_node, __pyx_v_last_type, __pyx_v_sig) < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  }
  __pyx_t_13 = PyList_New(0); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_v_sigindex_matches = ((PyObject*)__pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = PyList_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_INCREF(__pyx_v__fused_sigindex);
  __Pyx_GIVEREF(__pyx_v__fused_sigindex);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_13, 0, __pyx_v__fused_sigindex)) __PYX_ERR(5, 2604, __pyx_L1_error);
  __pyx_v_sigindex_candidates = ((PyObject*)__pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __pyx_v_dest_sig; __Pyx_INCREF(__pyx_t_13);
  __pyx_t_14 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_13);
      #if !CYTHON_ASSUME_SAFE_MACROS
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
      #endif
      if (__pyx_t_14 >= __pyx_temp) break;
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_1 = PyList_GET_ITEM(__pyx_t_13, __pyx_t_14); __Pyx_INCREF(__pyx_t_1); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
    #else
    __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_13, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_dst_type, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_found_matches, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_found_candidates, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;
    __pyx_t_4 = (__pyx_v_dst_type == Py_None);
    if (__pyx_t_4) {
      __pyx_t_1 = __pyx_v_sigindex_matches; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_5 = 0;
      for (;;) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_16 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_16); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
        #else
        __pyx_t_16 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2604, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        #endif
        __Pyx_XDECREF_SET(__pyx_v_sn, __pyx_t_16);
        __pyx_t_16 = 0;
        if (unlikely(__pyx_v_sn == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "values");
          __PYX_ERR(5, 2604, __pyx_L1_error)
        }
        __pyx_t_16 = __Pyx_PyDict_Values(((PyObject*)__pyx_v_sn)); if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2604, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        __pyx_t_19 = __Pyx_PyList_Extend(__pyx_v_found_matches, __pyx_t_16); if (unlikely(__pyx_t_19 == ((int)-1))) __PYX_ERR(5, 2604, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __pyx_v_sigindex_candidates; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_5 = 0;
      for (;;) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_16 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_16); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
        #else
        __pyx_t_16 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2604, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        #endif
        __Pyx_XDECREF_SET(__pyx_v_sn, __pyx_t_16);
        __pyx_t_16 = 0;
        if (unlikely(__pyx_v_sn == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "values");
          __PYX_ERR(5, 2604, __pyx_L1_error)
        }
        __pyx_t_16 = __Pyx_PyDict_Values(((PyObject*)__pyx_v_sn)); if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2604, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        __pyx_t_19 = __Pyx_PyList_Extend(__pyx_v_found_candidates, __pyx_t_16); if (unlikely(__pyx_t_19 == ((int)-1))) __PYX_ERR(5, 2604, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L158;
    }
    /*else*/ {
      __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_sigindex_matches);
      __Pyx_GIVEREF(__pyx_v_sigindex_matches);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_sigindex_matches)) __PYX_ERR(5, 2604, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_sigindex_candidates);
      __Pyx_GIVEREF(__pyx_v_sigindex_candidates);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_sigindex_candidates)) __PYX_ERR(5, 2604, __pyx_L1_error);
      __pyx_t_16 = __pyx_t_1; __Pyx_INCREF(__pyx_t_16);
      __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      for (;;) {
        if (__pyx_t_5 >= 2) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_16, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_16, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
        __Pyx_XDECREF_SET(__pyx_v_search_list, ((PyObject*)__pyx_t_1));
        __pyx_t_1 = 0;
        if (unlikely(__pyx_v_search_list == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
          __PYX_ERR(5, 2604, __pyx_L1_error)
        }
        __pyx_t_1 = __pyx_v_search_list; __Pyx_INCREF(__pyx_t_1);
        __pyx_t_18 = 0;
        for (;;) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
            #endif
            if (__pyx_t_18 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_18); __Pyx_INCREF(__pyx_t_6); __pyx_t_18++; if (unlikely((0 < 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
          #else
          __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_18); __pyx_t_18++; if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
          __Pyx_XDECREF_SET(__pyx_v_sn, __pyx_t_6);
          __pyx_t_6 = 0;
          if (unlikely(__pyx_v_sn == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "get");
            __PYX_ERR(5, 2604, __pyx_L1_error)
          }
          __pyx_t_6 = __Pyx_PyDict_GetItemDefault(((PyObject*)__pyx_v_sn), __pyx_v_dst_type, Py_None); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2604, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_XDECREF_SET(__pyx_v_type_match, __pyx_t_6);
          __pyx_t_6 = 0;
          __pyx_t_4 = (__pyx_v_type_match != Py_None);
          if (__pyx_t_4) {
            __pyx_t_19 = __Pyx_PyList_Append(__pyx_v_found_matches, __pyx_v_type_match); if (unlikely(__pyx_t_19 == ((int)-1))) __PYX_ERR(5, 2604, __pyx_L1_error)
          }
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    }
    __pyx_L158:;
    __Pyx_INCREF(__pyx_v_found_matches);
    __Pyx_DECREF_SET(__pyx_v_sigindex_matches, __pyx_v_found_matches);
    __Pyx_INCREF(__pyx_v_found_candidates);
    __Pyx_DECREF_SET(__pyx_v_sigindex_candidates, __pyx_v_found_candidates);
    __pyx_t_2 = (PyList_GET_SIZE(__pyx_v_found_matches) != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_4 = __pyx_t_2;
      goto __pyx_L173_bool_binop_done;
    }
    __pyx_t_2 = (PyList_GET_SIZE(__pyx_v_found_candidates) != 0);
    __pyx_t_4 = __pyx_t_2;
    __pyx_L173_bool_binop_done:;
    __pyx_t_2 = (!__pyx_t_4);
    if (__pyx_t_2) {
      goto __pyx_L157_break;
    }
  }
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  goto __pyx_L175_for_end;
  __pyx_L157_break:;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  goto __pyx_L175_for_end;
  __pyx_L175_for_end:;
  __Pyx_INCREF(__pyx_v_sigindex_matches);
  __pyx_v_candidates = __pyx_v_sigindex_matches;
  __pyx_t_2 = (PyList_GET_SIZE(__pyx_v_candidates) != 0);
  __pyx_t_4 = (!__pyx_t_2);
  if (unlikely(__pyx_t_4)) {
    __pyx_t_13 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__71, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 2604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_Raise(__pyx_t_13, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_t_14 = __Pyx_PyList_GET_SIZE(__pyx_v_candidates); if (unlikely(__pyx_t_14 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_t_4 = (__pyx_t_14 > 1);
  if (unlikely(__pyx_t_4)) {
    __pyx_t_13 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__72, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 2604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_Raise(__pyx_t_13, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    if (unlikely(__pyx_v_signatures == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(5, 2604, __pyx_L1_error)
    }
    __pyx_t_13 = __Pyx_GetItemInt_List(__pyx_v_candidates, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 2604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_t_16 = __Pyx_PyDict_GetItem(((PyObject*)__pyx_v_signatures), __pyx_t_13); if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2604, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_16);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __pyx_r = __pyx_t_16;
    __pyx_t_16 = 0;
    goto __pyx_L0;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fused_cpdef", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_search_list);
  __Pyx_XDECREF(__pyx_v_sigindex_node);
  __Pyx_XDECREF(__pyx_v_dest_sig);
  __Pyx_XDECREF((PyObject *)__pyx_v_ndarray);
  __Pyx_XDECREF(__pyx_v_arg_as_memoryview);
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XDECREF(__pyx_v_dtype);
  __Pyx_XDECREF(__pyx_v_arg_base);
  __Pyx_XDECREF(__pyx_v_sig);
  __Pyx_XDECREF(__pyx_v_sig_series);
  __Pyx_XDECREF(__pyx_v_last_type);
  __Pyx_XDECREF(__pyx_v_sig_type);
  __Pyx_XDECREF(__pyx_v_sigindex_matches);
  __Pyx_XDECREF(__pyx_v_sigindex_candidates);
  __Pyx_XDECREF(__pyx_v_dst_type);
  __Pyx_XDECREF(__pyx_v_found_matches);
  __Pyx_XDECREF(__pyx_v_found_candidates);
  __Pyx_XDECREF(__pyx_v_sn);
  __Pyx_XDECREF(__pyx_v_type_match);
  __Pyx_XDECREF(__pyx_v_candidates);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_77__pyx_fuse_0ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_0__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_0ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int8_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int8_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2609
 * 
 *     elif htfunc_t is int8_t:
 *         return ismember_int8(arr, values)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is int16_t:
 *         return ismember_int16(arr, values)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int8_t__const__(((PyObject *)__pyx_v_arr), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2609, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int8_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(5, 2609, __pyx_L1_error)
  __pyx_t_3 = __pyx_f_6pandas_5_libs_9hashtable_ismember_int8(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2609, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2604
 * 
 * 
 * cpdef ismember(ndarray[htfunc_t] arr, ndarray[htfunc_t] values):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return ismember_object(arr, values)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_77__pyx_fuse_0ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_0__pyx_mdef_6pandas_5_libs_9hashtable_77__pyx_fuse_0ismember = {"__pyx_fuse_0ismember", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_77__pyx_fuse_0ismember, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_77__pyx_fuse_0ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_arr = 0;
  PyArrayObject *__pyx_v_values = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_0ismember (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_arr,&__pyx_n_s_values,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_arr)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_0ismember", 1, 2, 2, 1); __PYX_ERR(5, 2604, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_0ismember") < 0)) __PYX_ERR(5, 2604, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
      values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
    }
    __pyx_v_arr = ((PyArrayObject *)values[0]);
    __pyx_v_values = ((PyArrayObject *)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_0ismember", 1, 2, 2, __pyx_nargs); __PYX_ERR(5, 2604, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_0ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_arr), __pyx_ptype_5numpy_ndarray, 1, "arr", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_76__pyx_fuse_0ismember(__pyx_self, __pyx_v_arr, __pyx_v_values);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_76__pyx_fuse_0ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_0ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int8_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int8_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_fuse_0__pyx_f_6pandas_5_libs_9hashtable_ismember(((PyArrayObject *)__pyx_v_arr), ((PyArrayObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_0ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_79__pyx_fuse_1ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_1__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_1ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2611
 *         return ismember_int8(arr, values)
 *     elif htfunc_t is int16_t:
 *         return ismember_int16(arr, values)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is int32_t:
 *         return ismember_int32(arr, values)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int16_t__const__(((PyObject *)__pyx_v_arr), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2611, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int16_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(5, 2611, __pyx_L1_error)
  __pyx_t_3 = __pyx_f_6pandas_5_libs_9hashtable_ismember_int16(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2604
 * 
 * 
 * cpdef ismember(ndarray[htfunc_t] arr, ndarray[htfunc_t] values):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return ismember_object(arr, values)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_79__pyx_fuse_1ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_1__pyx_mdef_6pandas_5_libs_9hashtable_79__pyx_fuse_1ismember = {"__pyx_fuse_1ismember", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_79__pyx_fuse_1ismember, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_79__pyx_fuse_1ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_arr = 0;
  PyArrayObject *__pyx_v_values = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_1ismember (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_arr,&__pyx_n_s_values,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_arr)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_1ismember", 1, 2, 2, 1); __PYX_ERR(5, 2604, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_1ismember") < 0)) __PYX_ERR(5, 2604, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
      values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
    }
    __pyx_v_arr = ((PyArrayObject *)values[0]);
    __pyx_v_values = ((PyArrayObject *)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_1ismember", 1, 2, 2, __pyx_nargs); __PYX_ERR(5, 2604, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_1ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_arr), __pyx_ptype_5numpy_ndarray, 1, "arr", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_78__pyx_fuse_1ismember(__pyx_self, __pyx_v_arr, __pyx_v_values);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_78__pyx_fuse_1ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_1ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_fuse_1__pyx_f_6pandas_5_libs_9hashtable_ismember(((PyArrayObject *)__pyx_v_arr), ((PyArrayObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_1ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_81__pyx_fuse_2ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_2__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_2ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2613
 *         return ismember_int16(arr, values)
 *     elif htfunc_t is int32_t:
 *         return ismember_int32(arr, values)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is int64_t:
 *         return ismember_int64(arr, values)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int32_t__const__(((PyObject *)__pyx_v_arr), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2613, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int32_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(5, 2613, __pyx_L1_error)
  __pyx_t_3 = __pyx_f_6pandas_5_libs_9hashtable_ismember_int32(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2613, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2604
 * 
 * 
 * cpdef ismember(ndarray[htfunc_t] arr, ndarray[htfunc_t] values):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return ismember_object(arr, values)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_81__pyx_fuse_2ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_2__pyx_mdef_6pandas_5_libs_9hashtable_81__pyx_fuse_2ismember = {"__pyx_fuse_2ismember", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_81__pyx_fuse_2ismember, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_81__pyx_fuse_2ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_arr = 0;
  PyArrayObject *__pyx_v_values = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_2ismember (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_arr,&__pyx_n_s_values,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_arr)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_2ismember", 1, 2, 2, 1); __PYX_ERR(5, 2604, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_2ismember") < 0)) __PYX_ERR(5, 2604, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
      values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
    }
    __pyx_v_arr = ((PyArrayObject *)values[0]);
    __pyx_v_values = ((PyArrayObject *)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_2ismember", 1, 2, 2, __pyx_nargs); __PYX_ERR(5, 2604, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_2ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_arr), __pyx_ptype_5numpy_ndarray, 1, "arr", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_80__pyx_fuse_2ismember(__pyx_self, __pyx_v_arr, __pyx_v_values);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_80__pyx_fuse_2ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_2ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_fuse_2__pyx_f_6pandas_5_libs_9hashtable_ismember(((PyArrayObject *)__pyx_v_arr), ((PyArrayObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_2ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_83__pyx_fuse_3ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_3__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_3ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2615
 *         return ismember_int32(arr, values)
 *     elif htfunc_t is int64_t:
 *         return ismember_int64(arr, values)             # <<<<<<<<<<<<<<
 * 
 *     elif htfunc_t is uint8_t:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t__const__(((PyObject *)__pyx_v_arr), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2615, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(5, 2615, __pyx_L1_error)
  __pyx_t_3 = __pyx_f_6pandas_5_libs_9hashtable_ismember_int64(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2615, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2604
 * 
 * 
 * cpdef ismember(ndarray[htfunc_t] arr, ndarray[htfunc_t] values):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return ismember_object(arr, values)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_83__pyx_fuse_3ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_3__pyx_mdef_6pandas_5_libs_9hashtable_83__pyx_fuse_3ismember = {"__pyx_fuse_3ismember", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_83__pyx_fuse_3ismember, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_83__pyx_fuse_3ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_arr = 0;
  PyArrayObject *__pyx_v_values = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_3ismember (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_arr,&__pyx_n_s_values,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_arr)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_3ismember", 1, 2, 2, 1); __PYX_ERR(5, 2604, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_3ismember") < 0)) __PYX_ERR(5, 2604, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
      values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
    }
    __pyx_v_arr = ((PyArrayObject *)values[0]);
    __pyx_v_values = ((PyArrayObject *)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_3ismember", 1, 2, 2, __pyx_nargs); __PYX_ERR(5, 2604, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_3ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_arr), __pyx_ptype_5numpy_ndarray, 1, "arr", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_82__pyx_fuse_3ismember(__pyx_self, __pyx_v_arr, __pyx_v_values);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_82__pyx_fuse_3ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_3ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_fuse_3__pyx_f_6pandas_5_libs_9hashtable_ismember(((PyArrayObject *)__pyx_v_arr), ((PyArrayObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_3ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_85__pyx_fuse_4ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_4__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_4ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2618
 * 
 *     elif htfunc_t is uint8_t:
 *         return ismember_uint8(arr, values)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is uint16_t:
 *         return ismember_uint16(arr, values)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(((PyObject *)__pyx_v_arr), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2618, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(5, 2618, __pyx_L1_error)
  __pyx_t_3 = __pyx_f_6pandas_5_libs_9hashtable_ismember_uint8(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2618, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2604
 * 
 * 
 * cpdef ismember(ndarray[htfunc_t] arr, ndarray[htfunc_t] values):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return ismember_object(arr, values)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_85__pyx_fuse_4ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_4__pyx_mdef_6pandas_5_libs_9hashtable_85__pyx_fuse_4ismember = {"__pyx_fuse_4ismember", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_85__pyx_fuse_4ismember, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_85__pyx_fuse_4ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_arr = 0;
  PyArrayObject *__pyx_v_values = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_4ismember (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_arr,&__pyx_n_s_values,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_arr)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_4ismember", 1, 2, 2, 1); __PYX_ERR(5, 2604, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_4ismember") < 0)) __PYX_ERR(5, 2604, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
      values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
    }
    __pyx_v_arr = ((PyArrayObject *)values[0]);
    __pyx_v_values = ((PyArrayObject *)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_4ismember", 1, 2, 2, __pyx_nargs); __PYX_ERR(5, 2604, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_4ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_arr), __pyx_ptype_5numpy_ndarray, 1, "arr", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_84__pyx_fuse_4ismember(__pyx_self, __pyx_v_arr, __pyx_v_values);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_84__pyx_fuse_4ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_4ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_fuse_4__pyx_f_6pandas_5_libs_9hashtable_ismember(((PyArrayObject *)__pyx_v_arr), ((PyArrayObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_4ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_87__pyx_fuse_5ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_5__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_5ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint16_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint16_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2620
 *         return ismember_uint8(arr, values)
 *     elif htfunc_t is uint16_t:
 *         return ismember_uint16(arr, values)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is uint32_t:
 *         return ismember_uint32(arr, values)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint16_t__const__(((PyObject *)__pyx_v_arr), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2620, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint16_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(5, 2620, __pyx_L1_error)
  __pyx_t_3 = __pyx_f_6pandas_5_libs_9hashtable_ismember_uint16(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2620, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2604
 * 
 * 
 * cpdef ismember(ndarray[htfunc_t] arr, ndarray[htfunc_t] values):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return ismember_object(arr, values)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_87__pyx_fuse_5ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_5__pyx_mdef_6pandas_5_libs_9hashtable_87__pyx_fuse_5ismember = {"__pyx_fuse_5ismember", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_87__pyx_fuse_5ismember, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_87__pyx_fuse_5ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_arr = 0;
  PyArrayObject *__pyx_v_values = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_5ismember (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_arr,&__pyx_n_s_values,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_arr)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_5ismember", 1, 2, 2, 1); __PYX_ERR(5, 2604, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_5ismember") < 0)) __PYX_ERR(5, 2604, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
      values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
    }
    __pyx_v_arr = ((PyArrayObject *)values[0]);
    __pyx_v_values = ((PyArrayObject *)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_5ismember", 1, 2, 2, __pyx_nargs); __PYX_ERR(5, 2604, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_5ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_arr), __pyx_ptype_5numpy_ndarray, 1, "arr", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_86__pyx_fuse_5ismember(__pyx_self, __pyx_v_arr, __pyx_v_values);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_86__pyx_fuse_5ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_5ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint16_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint16_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_fuse_5__pyx_f_6pandas_5_libs_9hashtable_ismember(((PyArrayObject *)__pyx_v_arr), ((PyArrayObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_5ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_89__pyx_fuse_6ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_6__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_6ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2622
 *         return ismember_uint16(arr, values)
 *     elif htfunc_t is uint32_t:
 *         return ismember_uint32(arr, values)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is uint64_t:
 *         return ismember_uint64(arr, values)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint32_t__const__(((PyObject *)__pyx_v_arr), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2622, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint32_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(5, 2622, __pyx_L1_error)
  __pyx_t_3 = __pyx_f_6pandas_5_libs_9hashtable_ismember_uint32(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2622, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2604
 * 
 * 
 * cpdef ismember(ndarray[htfunc_t] arr, ndarray[htfunc_t] values):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return ismember_object(arr, values)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_89__pyx_fuse_6ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_6__pyx_mdef_6pandas_5_libs_9hashtable_89__pyx_fuse_6ismember = {"__pyx_fuse_6ismember", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_89__pyx_fuse_6ismember, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_89__pyx_fuse_6ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_arr = 0;
  PyArrayObject *__pyx_v_values = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_6ismember (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_arr,&__pyx_n_s_values,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_arr)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_6ismember", 1, 2, 2, 1); __PYX_ERR(5, 2604, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_6ismember") < 0)) __PYX_ERR(5, 2604, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
      values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
    }
    __pyx_v_arr = ((PyArrayObject *)values[0]);
    __pyx_v_values = ((PyArrayObject *)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_6ismember", 1, 2, 2, __pyx_nargs); __PYX_ERR(5, 2604, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_6ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_arr), __pyx_ptype_5numpy_ndarray, 1, "arr", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_88__pyx_fuse_6ismember(__pyx_self, __pyx_v_arr, __pyx_v_values);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_88__pyx_fuse_6ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_6ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_fuse_6__pyx_f_6pandas_5_libs_9hashtable_ismember(((PyArrayObject *)__pyx_v_arr), ((PyArrayObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_6ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_91__pyx_fuse_7ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_7__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_7ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2624
 *         return ismember_uint32(arr, values)
 *     elif htfunc_t is uint64_t:
 *         return ismember_uint64(arr, values)             # <<<<<<<<<<<<<<
 * 
 *     elif htfunc_t is float64_t:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint64_t__const__(((PyObject *)__pyx_v_arr), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2624, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint64_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(5, 2624, __pyx_L1_error)
  __pyx_t_3 = __pyx_f_6pandas_5_libs_9hashtable_ismember_uint64(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2624, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2604
 * 
 * 
 * cpdef ismember(ndarray[htfunc_t] arr, ndarray[htfunc_t] values):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return ismember_object(arr, values)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_91__pyx_fuse_7ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_7__pyx_mdef_6pandas_5_libs_9hashtable_91__pyx_fuse_7ismember = {"__pyx_fuse_7ismember", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_91__pyx_fuse_7ismember, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_91__pyx_fuse_7ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_arr = 0;
  PyArrayObject *__pyx_v_values = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_7ismember (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_arr,&__pyx_n_s_values,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_arr)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_7ismember", 1, 2, 2, 1); __PYX_ERR(5, 2604, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_7ismember") < 0)) __PYX_ERR(5, 2604, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
      values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
    }
    __pyx_v_arr = ((PyArrayObject *)values[0]);
    __pyx_v_values = ((PyArrayObject *)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_7ismember", 1, 2, 2, __pyx_nargs); __PYX_ERR(5, 2604, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_7ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_arr), __pyx_ptype_5numpy_ndarray, 1, "arr", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_90__pyx_fuse_7ismember(__pyx_self, __pyx_v_arr, __pyx_v_values);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_90__pyx_fuse_7ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_7ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_fuse_7__pyx_f_6pandas_5_libs_9hashtable_ismember(((PyArrayObject *)__pyx_v_arr), ((PyArrayObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_7ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_93__pyx_fuse_8ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_8__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_8ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2629
 *         return ismember_float64(arr, values)
 *     elif htfunc_t is float32_t:
 *         return ismember_float32(arr, values)             # <<<<<<<<<<<<<<
 * 
 *     elif htfunc_t is complex128_t:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float32_t__const__(((PyObject *)__pyx_v_arr), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2629, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float32_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(5, 2629, __pyx_L1_error)
  __pyx_t_3 = __pyx_f_6pandas_5_libs_9hashtable_ismember_float32(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2629, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2604
 * 
 * 
 * cpdef ismember(ndarray[htfunc_t] arr, ndarray[htfunc_t] values):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return ismember_object(arr, values)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_93__pyx_fuse_8ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_8__pyx_mdef_6pandas_5_libs_9hashtable_93__pyx_fuse_8ismember = {"__pyx_fuse_8ismember", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_93__pyx_fuse_8ismember, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_93__pyx_fuse_8ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_arr = 0;
  PyArrayObject *__pyx_v_values = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_8ismember (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_arr,&__pyx_n_s_values,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_arr)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_8ismember", 1, 2, 2, 1); __PYX_ERR(5, 2604, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_8ismember") < 0)) __PYX_ERR(5, 2604, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
      values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
    }
    __pyx_v_arr = ((PyArrayObject *)values[0]);
    __pyx_v_values = ((PyArrayObject *)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_8ismember", 1, 2, 2, __pyx_nargs); __PYX_ERR(5, 2604, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_8ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_arr), __pyx_ptype_5numpy_ndarray, 1, "arr", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_92__pyx_fuse_8ismember(__pyx_self, __pyx_v_arr, __pyx_v_values);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_92__pyx_fuse_8ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_8ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_fuse_8__pyx_f_6pandas_5_libs_9hashtable_ismember(((PyArrayObject *)__pyx_v_arr), ((PyArrayObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_8ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_95__pyx_fuse_9ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_9__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_9ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2627
 * 
 *     elif htfunc_t is float64_t:
 *         return ismember_float64(arr, values)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is float32_t:
 *         return ismember_float32(arr, values)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float64_t__const__(((PyObject *)__pyx_v_arr), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2627, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float64_t__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(5, 2627, __pyx_L1_error)
  __pyx_t_3 = __pyx_f_6pandas_5_libs_9hashtable_ismember_float64(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2627, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2604
 * 
 * 
 * cpdef ismember(ndarray[htfunc_t] arr, ndarray[htfunc_t] values):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return ismember_object(arr, values)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_95__pyx_fuse_9ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_9__pyx_mdef_6pandas_5_libs_9hashtable_95__pyx_fuse_9ismember = {"__pyx_fuse_9ismember", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_95__pyx_fuse_9ismember, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_95__pyx_fuse_9ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_arr = 0;
  PyArrayObject *__pyx_v_values = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_9ismember (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_arr,&__pyx_n_s_values,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_arr)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_9ismember", 1, 2, 2, 1); __PYX_ERR(5, 2604, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_9ismember") < 0)) __PYX_ERR(5, 2604, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
      values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
    }
    __pyx_v_arr = ((PyArrayObject *)values[0]);
    __pyx_v_values = ((PyArrayObject *)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_9ismember", 1, 2, 2, __pyx_nargs); __PYX_ERR(5, 2604, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_9ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_arr), __pyx_ptype_5numpy_ndarray, 1, "arr", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_94__pyx_fuse_9ismember(__pyx_self, __pyx_v_arr, __pyx_v_values);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_94__pyx_fuse_9ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_9ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_fuse_9__pyx_f_6pandas_5_libs_9hashtable_ismember(((PyArrayObject *)__pyx_v_arr), ((PyArrayObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_9ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_97__pyx_fuse_10ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_10__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_10ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2606
 * cpdef ismember(ndarray[htfunc_t] arr, ndarray[htfunc_t] values):
 *     if htfunc_t is object:
 *         return ismember_object(arr, values)             # <<<<<<<<<<<<<<
 * 
 *     elif htfunc_t is int8_t:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable_ismember_object(((PyArrayObject *)__pyx_v_arr), ((PyArrayObject *)__pyx_v_values)); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2604
 * 
 * 
 * cpdef ismember(ndarray[htfunc_t] arr, ndarray[htfunc_t] values):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return ismember_object(arr, values)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_97__pyx_fuse_10ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_10__pyx_mdef_6pandas_5_libs_9hashtable_97__pyx_fuse_10ismember = {"__pyx_fuse_10ismember", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_97__pyx_fuse_10ismember, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_97__pyx_fuse_10ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_arr = 0;
  PyArrayObject *__pyx_v_values = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_10ismember (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_arr,&__pyx_n_s_values,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_arr)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_10ismember", 1, 2, 2, 1); __PYX_ERR(5, 2604, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_10ismember") < 0)) __PYX_ERR(5, 2604, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
      values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
    }
    __pyx_v_arr = ((PyArrayObject *)values[0]);
    __pyx_v_values = ((PyArrayObject *)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_10ismember", 1, 2, 2, __pyx_nargs); __PYX_ERR(5, 2604, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_10ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_arr), __pyx_ptype_5numpy_ndarray, 1, "arr", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_96__pyx_fuse_10ismember(__pyx_self, __pyx_v_arr, __pyx_v_values);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_96__pyx_fuse_10ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_10ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_fuse_10__pyx_f_6pandas_5_libs_9hashtable_ismember(((PyArrayObject *)__pyx_v_arr), ((PyArrayObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_10ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_99__pyx_fuse_11ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_11__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_11ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo___pyx_t_double_complex, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo___pyx_t_double_complex, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2632
 * 
 *     elif htfunc_t is complex128_t:
 *         return ismember_complex128(arr, values)             # <<<<<<<<<<<<<<
 *     elif htfunc_t is complex64_t:
 *         return ismember_complex64(arr, values)
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_double_complex__const__(((PyObject *)__pyx_v_arr), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2632, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_double_complex__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(5, 2632, __pyx_L1_error)
  __pyx_t_3 = __pyx_f_6pandas_5_libs_9hashtable_ismember_complex128(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2604
 * 
 * 
 * cpdef ismember(ndarray[htfunc_t] arr, ndarray[htfunc_t] values):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return ismember_object(arr, values)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_99__pyx_fuse_11ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_11__pyx_mdef_6pandas_5_libs_9hashtable_99__pyx_fuse_11ismember = {"__pyx_fuse_11ismember", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_99__pyx_fuse_11ismember, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_99__pyx_fuse_11ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_arr = 0;
  PyArrayObject *__pyx_v_values = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_11ismember (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_arr,&__pyx_n_s_values,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_arr)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_11ismember", 1, 2, 2, 1); __PYX_ERR(5, 2604, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_11ismember") < 0)) __PYX_ERR(5, 2604, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
      values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
    }
    __pyx_v_arr = ((PyArrayObject *)values[0]);
    __pyx_v_values = ((PyArrayObject *)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_11ismember", 1, 2, 2, __pyx_nargs); __PYX_ERR(5, 2604, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_11ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_arr), __pyx_ptype_5numpy_ndarray, 1, "arr", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_98__pyx_fuse_11ismember(__pyx_self, __pyx_v_arr, __pyx_v_values);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_98__pyx_fuse_11ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_11ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo___pyx_t_double_complex, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo___pyx_t_double_complex, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_fuse_11__pyx_f_6pandas_5_libs_9hashtable_ismember(((PyArrayObject *)__pyx_v_arr), ((PyArrayObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_11ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_101__pyx_fuse_12ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_11ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_fuse_12__pyx_f_6pandas_5_libs_9hashtable_ismember(PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values, CYTHON_UNUSED int __pyx_skip_dispatch) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_memviewslice __pyx_t_1 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_2 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_12ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo___pyx_t_float_complex, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo___pyx_t_float_complex, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2634
 *         return ismember_complex128(arr, values)
 *     elif htfunc_t is complex64_t:
 *         return ismember_complex64(arr, values)             # <<<<<<<<<<<<<<
 * 
 *     else:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_float_complex__const__(((PyObject *)__pyx_v_arr), 0); if (unlikely(!__pyx_t_1.memview)) __PYX_ERR(5, 2634, __pyx_L1_error)
  __pyx_t_2 = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_float_complex__const__(((PyObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_2.memview)) __PYX_ERR(5, 2634, __pyx_L1_error)
  __pyx_t_3 = __pyx_f_6pandas_5_libs_9hashtable_ismember_complex64(__pyx_t_1, __pyx_t_2); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2634, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __pyx_t_1.memview = NULL; __pyx_t_1.data = NULL;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __pyx_t_2.memview = NULL; __pyx_t_2.data = NULL;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2604
 * 
 * 
 * cpdef ismember(ndarray[htfunc_t] arr, ndarray[htfunc_t] values):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return ismember_object(arr, values)
 */

  /* function exit code */
  __pyx_L1_error:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_1, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_2, 1);
  __Pyx_XDECREF(__pyx_t_3);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_101__pyx_fuse_12ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_12__pyx_mdef_6pandas_5_libs_9hashtable_101__pyx_fuse_12ismember = {"__pyx_fuse_12ismember", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_101__pyx_fuse_12ismember, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_101__pyx_fuse_12ismember(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_arr = 0;
  PyArrayObject *__pyx_v_values = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[2] = {0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fuse_12ismember (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_arr,&__pyx_n_s_values,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_arr)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2604, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fuse_12ismember", 1, 2, 2, 1); __PYX_ERR(5, 2604, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fuse_12ismember") < 0)) __PYX_ERR(5, 2604, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 2)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
      values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
    }
    __pyx_v_arr = ((PyArrayObject *)values[0]);
    __pyx_v_values = ((PyArrayObject *)values[1]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fuse_12ismember", 1, 2, 2, __pyx_nargs); __PYX_ERR(5, 2604, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_12ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_arr), __pyx_ptype_5numpy_ndarray, 1, "arr", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_100__pyx_fuse_12ismember(__pyx_self, __pyx_v_arr, __pyx_v_values);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_100__pyx_fuse_12ismember(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_values) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_12ismember", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo___pyx_t_float_complex, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo___pyx_t_float_complex, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_fuse_12__pyx_f_6pandas_5_libs_9hashtable_ismember(((PyArrayObject *)__pyx_v_arr), ((PyArrayObject *)__pyx_v_values), 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fuse_12ismember", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_13mode = {"mode", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13mode, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_13mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_signatures = 0;
  PyObject *__pyx_v_args = 0;
  PyObject *__pyx_v_kwargs = 0;
  CYTHON_UNUSED PyObject *__pyx_v_defaults = 0;
  PyObject *__pyx_v__fused_sigindex = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[5] = {0,0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_fused_cpdef (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_signatures,&__pyx_n_s_args,&__pyx_n_s_kwargs,&__pyx_n_s_defaults,&__pyx_n_s_fused_sigindex,0};
    __pyx_defaults3 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults3, __pyx_self);
    values[4] = __Pyx_Arg_NewRef_VARARGS(__pyx_dynamic_args->__pyx_arg__fused_sigindex);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_signatures)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_args)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fused_cpdef", 0, 4, 5, 1); __PYX_ERR(5, 2640, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_kwargs)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fused_cpdef", 0, 4, 5, 2); __PYX_ERR(5, 2640, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (likely((values[3] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_defaults)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[3]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_fused_cpdef", 0, 4, 5, 3); __PYX_ERR(5, 2640, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  4:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_fused_sigindex);
          if (value) { values[4] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_fused_cpdef") < 0)) __PYX_ERR(5, 2640, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  5: values[4] = __Pyx_Arg_VARARGS(__pyx_args, 4);
        CYTHON_FALLTHROUGH;
        case  4: values[3] = __Pyx_Arg_VARARGS(__pyx_args, 3);
        values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_signatures = values[0];
    __pyx_v_args = values[1];
    __pyx_v_kwargs = values[2];
    __pyx_v_defaults = values[3];
    __pyx_v__fused_sigindex = values[4];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_fused_cpdef", 0, 4, 5, __pyx_nargs); __PYX_ERR(5, 2640, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fused_cpdef", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_12mode(__pyx_self, __pyx_v_signatures, __pyx_v_args, __pyx_v_kwargs, __pyx_v_defaults, __pyx_v__fused_sigindex);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_12mode(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v_signatures, PyObject *__pyx_v_args, PyObject *__pyx_v_kwargs, CYTHON_UNUSED PyObject *__pyx_v_defaults, PyObject *__pyx_v__fused_sigindex) {
  PyObject *__pyx_v_search_list = 0;
  PyObject *__pyx_v_sigindex_node = 0;
  PyObject *__pyx_v_dest_sig = NULL;
  PyTypeObject *__pyx_v_ndarray = 0;
  PyObject *__pyx_v_arg_as_memoryview = 0;
  __Pyx_memviewslice __pyx_v_memslice;
  Py_ssize_t __pyx_v_itemsize;
  int __pyx_v_dtype_signed;
  Py_UCS4 __pyx_v_kind;
  int __pyx_v___pyx_fused_dtype_int8__t_is_signed;
  int __pyx_v___pyx_fused_dtype_int16__t_is_signed;
  int __pyx_v___pyx_fused_dtype_int32__t_is_signed;
  int __pyx_v___pyx_fused_dtype_int64__t_is_signed;
  int __pyx_v___pyx_fused_dtype_uint8__t_is_signed;
  int __pyx_v___pyx_fused_dtype_uint16__t_is_signed;
  int __pyx_v___pyx_fused_dtype_uint32__t_is_signed;
  int __pyx_v___pyx_fused_dtype_uint64__t_is_signed;
  PyObject *__pyx_v_arg = NULL;
  PyObject *__pyx_v_dtype = NULL;
  PyObject *__pyx_v_arg_base = NULL;
  PyObject *__pyx_v_sig = NULL;
  PyObject *__pyx_v_sig_series = NULL;
  PyObject *__pyx_v_last_type = NULL;
  PyObject *__pyx_v_sig_type = NULL;
  PyObject *__pyx_v_sigindex_matches = NULL;
  PyObject *__pyx_v_sigindex_candidates = NULL;
  PyObject *__pyx_v_dst_type = NULL;
  PyObject *__pyx_v_found_matches = NULL;
  PyObject *__pyx_v_found_candidates = NULL;
  PyObject *__pyx_v_sn = NULL;
  PyObject *__pyx_v_type_match = NULL;
  PyObject *__pyx_v_candidates = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  long __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  __Pyx_memviewslice __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  Py_ssize_t __pyx_t_14;
  int __pyx_t_15;
  PyObject *__pyx_t_16 = NULL;
  PyObject *__pyx_t_17 = NULL;
  Py_ssize_t __pyx_t_18;
  int __pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("mode", 0);
  __Pyx_INCREF(__pyx_v_kwargs);
  __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, Py_None)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_v_dest_sig = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_3 = (__pyx_v_kwargs != Py_None);
  if (__pyx_t_3) {
  } else {
    __pyx_t_2 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_v_kwargs); if (unlikely((__pyx_t_3 < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
  __pyx_t_4 = (!__pyx_t_3);
  __pyx_t_2 = __pyx_t_4;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_2) {
    __Pyx_INCREF(Py_None);
    __Pyx_DECREF_SET(__pyx_v_kwargs, Py_None);
  }
  __pyx_t_1 = ((PyObject *)__Pyx_ImportNumPyArrayTypeIfAvailable()); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_ndarray = ((PyTypeObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_v_itemsize = -1L;
  __pyx_v___pyx_fused_dtype_int8__t_is_signed = (!(((__pyx_t_5numpy_int8_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_int16__t_is_signed = (!(((__pyx_t_5numpy_int16_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_int32__t_is_signed = (!(((__pyx_t_5numpy_int32_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_int64__t_is_signed = (!(((__pyx_t_5numpy_int64_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_uint8__t_is_signed = (!(((__pyx_t_5numpy_uint8_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_uint16__t_is_signed = (!(((__pyx_t_5numpy_uint16_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_uint32__t_is_signed = (!(((__pyx_t_5numpy_uint32_t)-1L) > 0));
  __pyx_v___pyx_fused_dtype_uint64__t_is_signed = (!(((__pyx_t_5numpy_uint64_t)-1L) > 0));
  if (unlikely(__pyx_v_args == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(5, 2640, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_PyTuple_GET_SIZE(((PyObject*)__pyx_v_args)); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2640, __pyx_L1_error)
  __pyx_t_2 = (0 < __pyx_t_5);
  if (__pyx_t_2) {
    if (unlikely(__pyx_v_args == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(5, 2640, __pyx_L1_error)
    }
    __pyx_t_1 = PyTuple_GET_ITEM(((PyObject*)__pyx_v_args), 0);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v_arg = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L6;
  }
  __pyx_t_4 = (__pyx_v_kwargs != Py_None);
  if (__pyx_t_4) {
  } else {
    __pyx_t_2 = __pyx_t_4;
    goto __pyx_L7_bool_binop_done;
  }
  if (unlikely(__pyx_v_kwargs == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    __PYX_ERR(5, 2640, __pyx_L1_error)
  }
  __pyx_t_4 = (__Pyx_PyDict_ContainsTF(__pyx_n_s_values, ((PyObject*)__pyx_v_kwargs), Py_EQ)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
  __pyx_t_2 = __pyx_t_4;
  __pyx_L7_bool_binop_done:;
  if (likely(__pyx_t_2)) {
    if (unlikely(__pyx_v_kwargs == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(5, 2640, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_PyDict_GetItem(((PyObject*)__pyx_v_kwargs), __pyx_n_s_values); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_v_arg = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L6;
  }
  /*else*/ {
    if (unlikely(__pyx_v_args == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(5, 2640, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_PyTuple_GET_SIZE(((PyObject*)__pyx_v_args)); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2640, __pyx_L1_error)
    __pyx_t_1 = PyInt_FromSsize_t(__pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = PyTuple_New(3); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_int_2);
    __Pyx_GIVEREF(__pyx_int_2);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_int_2)) __PYX_ERR(5, 2640, __pyx_L1_error);
    __Pyx_INCREF(__pyx_n_s_s);
    __Pyx_GIVEREF(__pyx_n_s_s);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_n_s_s)) __PYX_ERR(5, 2640, __pyx_L1_error);
    __Pyx_GIVEREF(__pyx_t_1);
    if (__Pyx_PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error);
    __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Expected_at_least_d_argument_s_g, __pyx_t_6); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = __Pyx_PyObject_CallOneArg(__pyx_builtin_TypeError, __pyx_t_1); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __PYX_ERR(5, 2640, __pyx_L1_error)
  }
  __pyx_L6:;
  while (1) {
    __pyx_t_2 = (__pyx_v_ndarray != ((PyTypeObject*)Py_None));
    if (__pyx_t_2) {
      __pyx_t_2 = __Pyx_TypeCheck(__pyx_v_arg, __pyx_v_ndarray); 
      if (__pyx_t_2) {
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_dtype); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_v_dtype = __pyx_t_6;
        __pyx_t_6 = 0;
        goto __pyx_L12;
      }
      __pyx_t_2 = __pyx_memoryview_check(__pyx_v_arg); 
      if (__pyx_t_2) {
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_base); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_v_arg_base = __pyx_t_6;
        __pyx_t_6 = 0;
        __pyx_t_2 = __Pyx_TypeCheck(__pyx_v_arg_base, __pyx_v_ndarray); 
        if (__pyx_t_2) {
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg_base, __pyx_n_s_dtype); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_v_dtype = __pyx_t_6;
          __pyx_t_6 = 0;
          goto __pyx_L13;
        }
        /*else*/ {
          __Pyx_INCREF(Py_None);
          __pyx_v_dtype = Py_None;
        }
        __pyx_L13:;
        goto __pyx_L12;
      }
      /*else*/ {
        __Pyx_INCREF(Py_None);
        __pyx_v_dtype = Py_None;
      }
      __pyx_L12:;
      __pyx_v_itemsize = -1L;
      __pyx_t_2 = (__pyx_v_dtype != Py_None);
      if (__pyx_t_2) {
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtype, __pyx_n_s_itemsize); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_v_itemsize = __pyx_t_5;
        __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_dtype, __pyx_n_s_kind); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_t_7 = __Pyx_PyObject_Ord(__pyx_t_6); if (unlikely(__pyx_t_7 == ((long)(long)(Py_UCS4)-1))) __PYX_ERR(5, 2640, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
        __pyx_v_kind = __pyx_t_7;
        __pyx_v_dtype_signed = (__pyx_v_kind == 0x69);
        switch (__pyx_v_kind) {
          case 0x69:
          case 0x75:
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_int8_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L16_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L16_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_int8__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L16_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int8_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_int16_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L20_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L20_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_int16__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L20_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int16_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_int32_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L24_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L24_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_int32__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L24_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_int64_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L28_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L28_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_int64__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L28_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_uint8_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L32_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L32_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_uint8__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L32_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint8_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_uint16_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L36_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L36_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_uint16__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L36_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint16_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_uint32_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L40_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L40_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_uint32__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L40_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_uint64_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L44_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L44_bool_binop_done;
          }
          __pyx_t_4 = (!(__pyx_v___pyx_fused_dtype_uint64__t_is_signed ^ __pyx_v_dtype_signed));
          __pyx_t_2 = __pyx_t_4;
          __pyx_L44_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          break;
          case 0x66:
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_float32_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L48_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          __pyx_t_2 = __pyx_t_4;
          __pyx_L48_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_float32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_5numpy_float64_t)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L51_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          __pyx_t_2 = __pyx_t_4;
          __pyx_L51_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_float64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          break;
          case 99:
          __pyx_t_4 = ((sizeof(__pyx_t_double_complex)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L54_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          __pyx_t_2 = __pyx_t_4;
          __pyx_L54_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_kp_s_double_complex, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          __pyx_t_4 = ((sizeof(__pyx_t_float_complex)) == __pyx_v_itemsize);
          if (__pyx_t_4) {
          } else {
            __pyx_t_2 = __pyx_t_4;
            goto __pyx_L57_bool_binop_done;
          }
          __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_v_arg, __pyx_n_s_ndim); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_5 = __Pyx_PyIndex_AsSsize_t(__pyx_t_6); if (unlikely((__pyx_t_5 == (Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __pyx_t_4 = (((Py_ssize_t)__pyx_t_5) == 1);
          __pyx_t_2 = __pyx_t_4;
          __pyx_L57_bool_binop_done:;
          if (__pyx_t_2) {
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_kp_s_float_complex, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
            goto __pyx_L10_break;
          }
          break;
          case 79:
          break;
          default: break;
        }
      }
    }
    __pyx_t_2 = (__pyx_v_arg == Py_None);
    if (__pyx_t_2) {
      if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int8_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
      goto __pyx_L10_break;
    }
    {
      __Pyx_PyThreadState_declare
      __Pyx_PyThreadState_assign
      __Pyx_ExceptionSave(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      __Pyx_XGOTREF(__pyx_t_8);
      __Pyx_XGOTREF(__pyx_t_9);
      __Pyx_XGOTREF(__pyx_t_10);
      /*try:*/ {
        __pyx_t_6 = PyMemoryView_FromObject(__pyx_v_arg); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L60_error)
        __Pyx_GOTREF(__pyx_t_6);
        __pyx_v_arg_as_memoryview = ((PyObject*)__pyx_t_6);
        __pyx_t_6 = 0;
      }
      /*else:*/ {
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L71_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_int8_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L70_next_and;
        }
        __pyx_L71_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_int8_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L69_bool_binop_done;
        }
        __pyx_L70_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L69_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int8_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int8_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L77_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_int16_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L76_next_and;
        }
        __pyx_L77_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_int16_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L75_bool_binop_done;
        }
        __pyx_L76_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L75_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int16_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int16_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L83_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_int32_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L82_next_and;
        }
        __pyx_L83_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_int32_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L81_bool_binop_done;
        }
        __pyx_L82_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L81_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int32_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L89_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_int64_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L88_next_and;
        }
        __pyx_L89_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_int64_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L87_bool_binop_done;
        }
        __pyx_L88_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L87_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_int64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L95_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_uint8_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L94_next_and;
        }
        __pyx_L95_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_uint8_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L93_bool_binop_done;
        }
        __pyx_L94_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L93_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint8_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L101_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_uint16_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L100_next_and;
        }
        __pyx_L101_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_uint16_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L99_bool_binop_done;
        }
        __pyx_L100_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L99_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint16_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint16_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L107_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_uint32_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L106_next_and;
        }
        __pyx_L107_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_uint32_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L105_bool_binop_done;
        }
        __pyx_L106_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L105_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint32_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L113_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_uint64_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L112_next_and;
        }
        __pyx_L113_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_uint64_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L111_bool_binop_done;
        }
        __pyx_L112_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L111_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint64_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_uint64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L119_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_float32_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L118_next_and;
        }
        __pyx_L119_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_float32_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L117_bool_binop_done;
        }
        __pyx_L118_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L117_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float32_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_float32_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L125_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_5numpy_float64_t)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L124_next_and;
        }
        __pyx_L125_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_5numpy_float64_t)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L123_bool_binop_done;
        }
        __pyx_L124_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L123_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float64_t(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_float64_t, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L131_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(void *)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L130_next_and;
        }
        __pyx_L131_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(void *)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L129_bool_binop_done;
        }
        __pyx_L130_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L129_bool_binop_done:;
        if (__pyx_t_2) {
          if ((CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION == 2)) {
            __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_object(__pyx_v_arg, 0); 
            __pyx_v_memslice = __pyx_t_12;
            goto __pyx_L133;
          }
          /*else*/ {
            __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_object(__pyx_v_arg_as_memoryview, 0); 
            __pyx_v_memslice = __pyx_t_12;
          }
          __pyx_L133:;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_n_s_object, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L138_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_double_complex)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L137_next_and;
        }
        __pyx_L138_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_double_complex)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L136_bool_binop_done;
        }
        __pyx_L137_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L136_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_double_complex(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_kp_s_double_complex, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
        __pyx_t_4 = (__pyx_v_itemsize == -1L);
        if (!__pyx_t_4) {
          goto __pyx_L144_next_or;
        } else {
        }
        __pyx_t_5 = __Pyx_PyMemoryView_Get_itemsize(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_5 == (sizeof(__pyx_t_float_complex)));
        if (!__pyx_t_4) {
        } else {
          goto __pyx_L143_next_and;
        }
        __pyx_L144_next_or:;
        __pyx_t_4 = (__pyx_v_itemsize == (sizeof(__pyx_t_float_complex)));
        if (__pyx_t_4) {
        } else {
          __pyx_t_2 = __pyx_t_4;
          goto __pyx_L142_bool_binop_done;
        }
        __pyx_L143_next_and:;
        __pyx_t_11 = __Pyx_PyMemoryView_Get_ndim(__pyx_v_arg_as_memoryview); if (unlikely(__pyx_t_11 == ((int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __pyx_t_4 = (__pyx_t_11 == 1);
        __pyx_t_2 = __pyx_t_4;
        __pyx_L142_bool_binop_done:;
        if (__pyx_t_2) {
          __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_float_complex(__pyx_v_arg_as_memoryview, 0); 
          __pyx_v_memslice = __pyx_t_12;
          __pyx_t_2 = (__pyx_v_memslice.memview != 0);
          if (__pyx_t_2) {
            __PYX_XCLEAR_MEMVIEW((&__pyx_v_memslice), 1); 
            if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, __pyx_kp_s_float_complex, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L62_except_error)
            goto __pyx_L65_try_break;
          }
          /*else*/ {
            PyErr_Clear(); 
          }
        }
      }
      __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
      __Pyx_XDECREF(__pyx_t_9); __pyx_t_9 = 0;
      __Pyx_XDECREF(__pyx_t_10); __pyx_t_10 = 0;
      goto __pyx_L67_try_end;
      __pyx_L60_error:;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_11 = __Pyx_PyErr_ExceptionMatches2(__pyx_builtin_ValueError, __pyx_builtin_TypeError);
      if (__pyx_t_11) {
        __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fused_cpdef", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_6, &__pyx_t_1, &__pyx_t_13) < 0) __PYX_ERR(5, 2640, __pyx_L62_except_error)
        __Pyx_XGOTREF(__pyx_t_6);
        __Pyx_XGOTREF(__pyx_t_1);
        __Pyx_XGOTREF(__pyx_t_13);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_XDECREF(__pyx_t_13); __pyx_t_13 = 0;
        goto __pyx_L61_exception_handled;
      }
      goto __pyx_L62_except_error;
      __pyx_L62_except_error:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      goto __pyx_L1_error;
      __pyx_L65_try_break:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      goto __pyx_L10_break;
      __pyx_L61_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_8);
      __Pyx_XGIVEREF(__pyx_t_9);
      __Pyx_XGIVEREF(__pyx_t_10);
      __Pyx_ExceptionReset(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      __pyx_L67_try_end:;
    }
    if (unlikely((__Pyx_SetItemInt(__pyx_v_dest_sig, 0, Py_None, long, 1, __Pyx_PyInt_From_long, 1, 0, 0) < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
    goto __pyx_L10_break;
  }
  __pyx_L10_break:;
  __pyx_t_2 = __Pyx_PyObject_IsTrue(__pyx_v__fused_sigindex); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
  __pyx_t_4 = (!__pyx_t_2);
  if (__pyx_t_4) {
    __pyx_t_5 = 0;
    if (unlikely(__pyx_v_signatures == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(5, 2640, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_dict_iterator(((PyObject*)__pyx_v_signatures), 1, ((PyObject *)NULL), (&__pyx_t_14), (&__pyx_t_11)); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF(__pyx_t_13);
    __pyx_t_13 = __pyx_t_1;
    __pyx_t_1 = 0;
    while (1) {
      __pyx_t_15 = __Pyx_dict_iter_next(__pyx_t_13, __pyx_t_14, &__pyx_t_5, &__pyx_t_1, NULL, NULL, __pyx_t_11);
      if (unlikely(__pyx_t_15 == 0)) break;
      if (unlikely(__pyx_t_15 == -1)) __PYX_ERR(5, 2640, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_sig, __pyx_t_1);
      __pyx_t_1 = 0;
      __pyx_t_1 = __pyx_v__fused_sigindex;
      __Pyx_INCREF(__pyx_t_1);
      __Pyx_XDECREF_SET(__pyx_v_sigindex_node, ((PyObject*)__pyx_t_1));
      __pyx_t_1 = 0;
      __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_v_sig, __pyx_n_s_strip); if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2640, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __pyx_t_17 = NULL;
      __pyx_t_15 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_16))) {
        __pyx_t_17 = PyMethod_GET_SELF(__pyx_t_16);
        if (likely(__pyx_t_17)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
          __Pyx_INCREF(__pyx_t_17);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_16, function);
          __pyx_t_15 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_17, __pyx_kp_s__69};
        __pyx_t_6 = __Pyx_PyObject_FastCall(__pyx_t_16, __pyx_callargs+1-__pyx_t_15, 1+__pyx_t_15);
        __Pyx_XDECREF(__pyx_t_17); __pyx_t_17 = 0;
        if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      }
      __pyx_t_16 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_split); if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2640, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      __pyx_t_6 = NULL;
      __pyx_t_15 = 0;
      #if CYTHON_UNPACK_METHODS
      if (likely(PyMethod_Check(__pyx_t_16))) {
        __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_16);
        if (likely(__pyx_t_6)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_16);
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_16, function);
          __pyx_t_15 = 1;
        }
      }
      #endif
      {
        PyObject *__pyx_callargs[2] = {__pyx_t_6, __pyx_kp_s__70};
        __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_16, __pyx_callargs+1-__pyx_t_15, 1+__pyx_t_15);
        __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
        if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      }
      __pyx_t_16 = __Pyx_PySequence_ListKeepNew(__pyx_t_1); if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2640, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_16);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_18 = PyList_GET_SIZE(__pyx_t_16);
      if (unlikely(__pyx_t_18 < 1)) {
        __Pyx_RaiseNeedMoreValuesError(0+__pyx_t_18); __PYX_ERR(5, 2640, __pyx_L1_error)
      }
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_6 = PyList_GET_ITEM(__pyx_t_16, __pyx_t_18-1); 
      ((PyVarObject*)__pyx_t_16)->ob_size--;
      #else
      __pyx_t_6 = PySequence_ITEM(__pyx_t_16, __pyx_t_18-1); 
      #endif
      __Pyx_GOTREF(__pyx_t_6);
      #if !CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_17 = PySequence_GetSlice(__pyx_t_16, 0, __pyx_t_18-1); if (unlikely(!__pyx_t_17)) __PYX_ERR(5, 2640, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_17);
      __Pyx_DECREF(__pyx_t_16);
      __pyx_t_16 = __pyx_t_17; __pyx_t_17 = NULL;
      #else
      CYTHON_UNUSED_VAR(__pyx_t_17);
      #endif
      __Pyx_XDECREF_SET(__pyx_v_sig_series, ((PyObject*)__pyx_t_16));
      __pyx_t_16 = 0;
      __Pyx_XDECREF_SET(__pyx_v_last_type, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_1 = __pyx_v_sig_series; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_18 = 0;
      for (;;) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
          #endif
          if (__pyx_t_18 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_6 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_18); __Pyx_INCREF(__pyx_t_6); __pyx_t_18++; if (unlikely((0 < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
        #else
        __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_18); __pyx_t_18++; if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_6);
        #endif
        __Pyx_XDECREF_SET(__pyx_v_sig_type, __pyx_t_6);
        __pyx_t_6 = 0;
        if (unlikely(__pyx_v_sigindex_node == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
          __PYX_ERR(5, 2640, __pyx_L1_error)
        }
        __pyx_t_4 = (__Pyx_PyDict_ContainsTF(__pyx_v_sig_type, __pyx_v_sigindex_node, Py_NE)); if (unlikely((__pyx_t_4 < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
        if (__pyx_t_4) {
          __pyx_t_6 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          if (unlikely(__pyx_v_sigindex_node == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            __PYX_ERR(5, 2640, __pyx_L1_error)
          }
          if (unlikely((PyDict_SetItem(__pyx_v_sigindex_node, __pyx_v_sig_type, __pyx_t_6) < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_INCREF(__pyx_t_6);
          __Pyx_DECREF_SET(__pyx_v_sigindex_node, __pyx_t_6);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          goto __pyx_L154;
        }
        /*else*/ {
          if (unlikely(__pyx_v_sigindex_node == Py_None)) {
            PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
            __PYX_ERR(5, 2640, __pyx_L1_error)
          }
          __pyx_t_6 = __Pyx_PyDict_GetItem(__pyx_v_sigindex_node, __pyx_v_sig_type); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __pyx_t_16 = __pyx_t_6;
          __Pyx_INCREF(__pyx_t_16);
          __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
          __Pyx_DECREF_SET(__pyx_v_sigindex_node, ((PyObject*)__pyx_t_16));
          __pyx_t_16 = 0;
        }
        __pyx_L154:;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(__pyx_v_sigindex_node == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(5, 2640, __pyx_L1_error)
      }
      if (unlikely((PyDict_SetItem(__pyx_v_sigindex_node, __pyx_v_last_type, __pyx_v_sig) < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
    }
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  }
  __pyx_t_13 = PyList_New(0); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_v_sigindex_matches = ((PyObject*)__pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = PyList_New(1); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_INCREF(__pyx_v__fused_sigindex);
  __Pyx_GIVEREF(__pyx_v__fused_sigindex);
  if (__Pyx_PyList_SET_ITEM(__pyx_t_13, 0, __pyx_v__fused_sigindex)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_v_sigindex_candidates = ((PyObject*)__pyx_t_13);
  __pyx_t_13 = 0;
  __pyx_t_13 = __pyx_v_dest_sig; __Pyx_INCREF(__pyx_t_13);
  __pyx_t_14 = 0;
  for (;;) {
    {
      Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_13);
      #if !CYTHON_ASSUME_SAFE_MACROS
      if (unlikely((__pyx_temp < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
      #endif
      if (__pyx_t_14 >= __pyx_temp) break;
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    __pyx_t_1 = PyList_GET_ITEM(__pyx_t_13, __pyx_t_14); __Pyx_INCREF(__pyx_t_1); __pyx_t_14++; if (unlikely((0 < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
    #else
    __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_13, __pyx_t_14); __pyx_t_14++; if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_dst_type, __pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_found_matches, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;
    __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_XDECREF_SET(__pyx_v_found_candidates, ((PyObject*)__pyx_t_1));
    __pyx_t_1 = 0;
    __pyx_t_4 = (__pyx_v_dst_type == Py_None);
    if (__pyx_t_4) {
      __pyx_t_1 = __pyx_v_sigindex_matches; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_5 = 0;
      for (;;) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_16 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_16); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
        #else
        __pyx_t_16 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2640, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        #endif
        __Pyx_XDECREF_SET(__pyx_v_sn, __pyx_t_16);
        __pyx_t_16 = 0;
        if (unlikely(__pyx_v_sn == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "values");
          __PYX_ERR(5, 2640, __pyx_L1_error)
        }
        __pyx_t_16 = __Pyx_PyDict_Values(((PyObject*)__pyx_v_sn)); if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2640, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        __pyx_t_19 = __Pyx_PyList_Extend(__pyx_v_found_matches, __pyx_t_16); if (unlikely(__pyx_t_19 == ((int)-1))) __PYX_ERR(5, 2640, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __pyx_v_sigindex_candidates; __Pyx_INCREF(__pyx_t_1);
      __pyx_t_5 = 0;
      for (;;) {
        {
          Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
          #if !CYTHON_ASSUME_SAFE_MACROS
          if (unlikely((__pyx_temp < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
          #endif
          if (__pyx_t_5 >= __pyx_temp) break;
        }
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_16 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_16); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
        #else
        __pyx_t_16 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2640, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        #endif
        __Pyx_XDECREF_SET(__pyx_v_sn, __pyx_t_16);
        __pyx_t_16 = 0;
        if (unlikely(__pyx_v_sn == Py_None)) {
          PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "values");
          __PYX_ERR(5, 2640, __pyx_L1_error)
        }
        __pyx_t_16 = __Pyx_PyDict_Values(((PyObject*)__pyx_v_sn)); if (unlikely(!__pyx_t_16)) __PYX_ERR(5, 2640, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_16);
        __pyx_t_19 = __Pyx_PyList_Extend(__pyx_v_found_candidates, __pyx_t_16); if (unlikely(__pyx_t_19 == ((int)-1))) __PYX_ERR(5, 2640, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
      }
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L158;
    }
    /*else*/ {
      __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_INCREF(__pyx_v_sigindex_matches);
      __Pyx_GIVEREF(__pyx_v_sigindex_matches);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_sigindex_matches)) __PYX_ERR(5, 2640, __pyx_L1_error);
      __Pyx_INCREF(__pyx_v_sigindex_candidates);
      __Pyx_GIVEREF(__pyx_v_sigindex_candidates);
      if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_v_sigindex_candidates)) __PYX_ERR(5, 2640, __pyx_L1_error);
      __pyx_t_16 = __pyx_t_1; __Pyx_INCREF(__pyx_t_16);
      __pyx_t_5 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      for (;;) {
        if (__pyx_t_5 >= 2) break;
        #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        __pyx_t_1 = PyTuple_GET_ITEM(__pyx_t_16, __pyx_t_5); __Pyx_INCREF(__pyx_t_1); __pyx_t_5++; if (unlikely((0 < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
        #else
        __pyx_t_1 = __Pyx_PySequence_ITEM(__pyx_t_16, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_1);
        #endif
        __Pyx_XDECREF_SET(__pyx_v_search_list, ((PyObject*)__pyx_t_1));
        __pyx_t_1 = 0;
        if (unlikely(__pyx_v_search_list == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
          __PYX_ERR(5, 2640, __pyx_L1_error)
        }
        __pyx_t_1 = __pyx_v_search_list; __Pyx_INCREF(__pyx_t_1);
        __pyx_t_18 = 0;
        for (;;) {
          {
            Py_ssize_t __pyx_temp = __Pyx_PyList_GET_SIZE(__pyx_t_1);
            #if !CYTHON_ASSUME_SAFE_MACROS
            if (unlikely((__pyx_temp < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
            #endif
            if (__pyx_t_18 >= __pyx_temp) break;
          }
          #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
          __pyx_t_6 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_18); __Pyx_INCREF(__pyx_t_6); __pyx_t_18++; if (unlikely((0 < 0))) __PYX_ERR(5, 2640, __pyx_L1_error)
          #else
          __pyx_t_6 = __Pyx_PySequence_ITEM(__pyx_t_1, __pyx_t_18); __pyx_t_18++; if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          #endif
          __Pyx_XDECREF_SET(__pyx_v_sn, __pyx_t_6);
          __pyx_t_6 = 0;
          if (unlikely(__pyx_v_sn == Py_None)) {
            PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "get");
            __PYX_ERR(5, 2640, __pyx_L1_error)
          }
          __pyx_t_6 = __Pyx_PyDict_GetItemDefault(((PyObject*)__pyx_v_sn), __pyx_v_dst_type, Py_None); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2640, __pyx_L1_error)
          __Pyx_GOTREF(__pyx_t_6);
          __Pyx_XDECREF_SET(__pyx_v_type_match, __pyx_t_6);
          __pyx_t_6 = 0;
          __pyx_t_4 = (__pyx_v_type_match != Py_None);
          if (__pyx_t_4) {
            __pyx_t_19 = __Pyx_PyList_Append(__pyx_v_found_matches, __pyx_v_type_match); if (unlikely(__pyx_t_19 == ((int)-1))) __PYX_ERR(5, 2640, __pyx_L1_error)
          }
        }
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      }
      __Pyx_DECREF(__pyx_t_16); __pyx_t_16 = 0;
    }
    __pyx_L158:;
    __Pyx_INCREF(__pyx_v_found_matches);
    __Pyx_DECREF_SET(__pyx_v_sigindex_matches, __pyx_v_found_matches);
    __Pyx_INCREF(__pyx_v_found_candidates);
    __Pyx_DECREF_SET(__pyx_v_sigindex_candidates, __pyx_v_found_candidates);
    __pyx_t_2 = (PyList_GET_SIZE(__pyx_v_found_matches) != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_4 = __pyx_t_2;
      goto __pyx_L173_bool_binop_done;
    }
    __pyx_t_2 = (PyList_GET_SIZE(__pyx_v_found_candidates) != 0);
    __pyx_t_4 = __pyx_t_2;
    __pyx_L173_bool_binop_done:;
    __pyx_t_2 = (!__pyx_t_4);
    if (__pyx_t_2) {
      goto __pyx_L157_break;
    }
  }
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  goto __pyx_L175_for_end;
  __pyx_L157_break:;
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  goto __pyx_L175_for_end;
  __pyx_L175_for_end:;
  __Pyx_INCREF(__pyx_v_sigindex_matches);
  __pyx_v_candidates = __pyx_v_sigindex_matches;
  __pyx_t_2 = (PyList_GET_SIZE(__pyx_v_candidates) != 0);
  __pyx_t_4 = (!__pyx_t_2);
  if (unlikely(__pyx_t_4)) {
    __pyx_t_13 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__71, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 2640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_Raise(__pyx_t_13, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __PYX_ERR(5, 2640, __pyx_L1_error)
  }
  __pyx_t_14 = __Pyx_PyList_GET_SIZE(__pyx_v_candidates); if (unlikely(__pyx_t_14 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2640, __pyx_L1_error)
  __pyx_t_4 = (__pyx_t_14 > 1);
  if (unlikely(__pyx_t_4)) {
    __pyx_t_13 = __Pyx_PyObject_Call(__pyx_builtin_TypeError, __pyx_tuple__72, NULL); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 2640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __Pyx_Raise(__pyx_t_13, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
    __PYX_ERR(5, 2640, __pyx_L1_error)
  }
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    if (unlikely(__pyx_v_signatures == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(5, 2640, __pyx_L1_error)
    }
    __pyx_t_13 = __Pyx_PyDict_GetItem(((PyObject*)__pyx_v_signatures), PyList_GET_ITEM(__pyx_v_candidates, 0)); if (unlikely(!__pyx_t_13)) __PYX_ERR(5, 2640, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_13);
    __pyx_r = __pyx_t_13;
    __pyx_t_13 = 0;
    goto __pyx_L0;
  }

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_XDECREF(__pyx_t_16);
  __Pyx_XDECREF(__pyx_t_17);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_fused_cpdef", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_search_list);
  __Pyx_XDECREF(__pyx_v_sigindex_node);
  __Pyx_XDECREF(__pyx_v_dest_sig);
  __Pyx_XDECREF((PyObject *)__pyx_v_ndarray);
  __Pyx_XDECREF(__pyx_v_arg_as_memoryview);
  __Pyx_XDECREF(__pyx_v_arg);
  __Pyx_XDECREF(__pyx_v_dtype);
  __Pyx_XDECREF(__pyx_v_arg_base);
  __Pyx_XDECREF(__pyx_v_sig);
  __Pyx_XDECREF(__pyx_v_sig_series);
  __Pyx_XDECREF(__pyx_v_last_type);
  __Pyx_XDECREF(__pyx_v_sig_type);
  __Pyx_XDECREF(__pyx_v_sigindex_matches);
  __Pyx_XDECREF(__pyx_v_sigindex_candidates);
  __Pyx_XDECREF(__pyx_v_dst_type);
  __Pyx_XDECREF(__pyx_v_found_matches);
  __Pyx_XDECREF(__pyx_v_found_candidates);
  __Pyx_XDECREF(__pyx_v_sn);
  __Pyx_XDECREF(__pyx_v_type_match);
  __Pyx_XDECREF(__pyx_v_candidates);
  __Pyx_XDECREF(__pyx_v_kwargs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_158__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_memoryview_fromslice(__Pyx_CyFunction_Defaults(__pyx_defaults17, __pyx_self)->__pyx_arg_mask, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_fuse_0__pyx_pw_6pandas_5_libs_9hashtable_105mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_0__pyx_mdef_6pandas_5_libs_9hashtable_105mode = {"__pyx_fuse_0mode", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_fuse_0__pyx_pw_6pandas_5_libs_9hashtable_105mode, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_fuse_0__pyx_pw_6pandas_5_libs_9hashtable_105mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mode (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    __pyx_defaults17 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults17, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, 1); __PYX_ERR(5, 2640, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "mode") < 0)) __PYX_ERR(5, 2640, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2642, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2642, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_dynamic_args->__pyx_arg_mask;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2640, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2642, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_104mode(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_104mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  PyArrayObject *__pyx_v_keys = 0;
  PyArrayObject *__pyx_v_modes = 0;
  __Pyx_memviewslice __pyx_v_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_v_count;
  __pyx_t_5numpy_int64_t __pyx_v_max_count;
  Py_ssize_t __pyx_v_nkeys;
  Py_ssize_t __pyx_v_k;
  Py_ssize_t __pyx_v_j;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_keys;
  __Pyx_Buffer __pyx_pybuffer_keys;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_modes;
  __Pyx_Buffer __pyx_pybuffer_modes;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_0__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyArrayObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  Py_ssize_t __pyx_t_13;
  PyArrayObject *__pyx_t_14 = NULL;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_t_18;
  Py_ssize_t __pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_0mode", 1);
  __pyx_pybuffer_keys.pybuffer.buf = NULL;
  __pyx_pybuffer_keys.refcount = 0;
  __pyx_pybuffernd_keys.data = NULL;
  __pyx_pybuffernd_keys.rcbuffer = &__pyx_pybuffer_keys;
  __pyx_pybuffer_modes.pybuffer.buf = NULL;
  __pyx_pybuffer_modes.refcount = 0;
  __pyx_pybuffernd_modes.data = NULL;
  __pyx_pybuffernd_modes.rcbuffer = &__pyx_pybuffer_modes;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int8_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2650
 * 
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1             # <<<<<<<<<<<<<<
 *         Py_ssize_t nkeys, k, j = 0
 * 
 */
  __pyx_v_max_count = -1LL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2651
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1
 *         Py_ssize_t nkeys, k, j = 0             # <<<<<<<<<<<<<<
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 */
  __pyx_v_j = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2653
 *         Py_ssize_t nkeys, k, j = 0
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 *     nkeys = len(keys)
 * 
 */
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_0__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(5, 2653, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2653, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_4, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_t_8, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int8_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_v_keys, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int8_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_10); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_12);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
      __pyx_t_10 = __pyx_t_11 = __pyx_t_12 = 0;
    }
    __pyx_pybuffernd_keys.diminfo[0].strides = __pyx_pybuffernd_keys.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_keys.diminfo[0].shape = __pyx_pybuffernd_keys.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2653, __pyx_L1_error)
  }
  __pyx_t_8 = 0;
  __pyx_v_keys = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_v_counts = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2654
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 *     nkeys = len(keys)             # <<<<<<<<<<<<<<
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)
 */
  __pyx_t_13 = PyObject_Length(((PyObject *)__pyx_v_keys)); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2654, __pyx_L1_error)
  __pyx_v_nkeys = __pyx_t_13;

  /* "pandas/_libs/hashtable_func_helper.pxi":2656
 *     nkeys = len(keys)
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)             # <<<<<<<<<<<<<<
 * 
 *     if htfunc_t is not object:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_empty); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_nkeys); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_values), __pyx_n_s_dtype); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_5) < 0) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2656, __pyx_L1_error)
  __pyx_t_14 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_t_14, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_v_modes, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_11, __pyx_t_10);
      }
      __pyx_t_12 = __pyx_t_11 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_modes.diminfo[0].strides = __pyx_pybuffernd_modes.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_modes.diminfo[0].shape = __pyx_pybuffernd_modes.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2656, __pyx_L1_error)
  }
  __pyx_t_14 = 0;
  __pyx_v_modes = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":2660
 *     if htfunc_t is not object:
 *         with nogil:
 *             for k in range(nkeys):             # <<<<<<<<<<<<<<
 *                 count = counts[k]
 *                 if count == max_count:
 */
        __pyx_t_13 = __pyx_v_nkeys;
        __pyx_t_15 = __pyx_t_13;
        for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
          __pyx_v_k = __pyx_t_16;

          /* "pandas/_libs/hashtable_func_helper.pxi":2661
 *         with nogil:
 *             for k in range(nkeys):
 *                 count = counts[k]             # <<<<<<<<<<<<<<
 *                 if count == max_count:
 *                     j += 1
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_v_count = (*((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_counts.data) + __pyx_t_17)) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
          __pyx_t_18 = (__pyx_v_count == __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2663
 *                 count = counts[k]
 *                 if count == max_count:
 *                     j += 1             # <<<<<<<<<<<<<<
 *                 elif count > max_count:
 *                     max_count = count
 */
            __pyx_v_j = (__pyx_v_j + 1);

            /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
          __pyx_t_18 = (__pyx_v_count > __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2665
 *                     j += 1
 *                 elif count > max_count:
 *                     max_count = count             # <<<<<<<<<<<<<<
 *                     j = 0
 *                 else:
 */
            __pyx_v_max_count = __pyx_v_count;

            /* "pandas/_libs/hashtable_func_helper.pxi":2666
 *                 elif count > max_count:
 *                     max_count = count
 *                     j = 0             # <<<<<<<<<<<<<<
 *                 else:
 *                     continue
 */
            __pyx_v_j = 0;

            /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2668
 *                     j = 0
 *                 else:
 *                     continue             # <<<<<<<<<<<<<<
 * 
 *                 modes[j] = keys[k]
 */
          /*else*/ {
            goto __pyx_L8_continue;
          }
          __pyx_L10:;

          /* "pandas/_libs/hashtable_func_helper.pxi":2670
 *                     continue
 * 
 *                 modes[j] = keys[k]             # <<<<<<<<<<<<<<
 *     else:
 *         for k in range(nkeys):
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_t_19 = __pyx_v_j;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_int8_t *, __pyx_pybuffernd_modes.rcbuffer->pybuffer.buf, __pyx_t_19, __pyx_pybuffernd_modes.diminfo[0].strides) = (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_int8_t *, __pyx_pybuffernd_keys.rcbuffer->pybuffer.buf, __pyx_t_17, __pyx_pybuffernd_keys.diminfo[0].strides));
          __pyx_L8_continue:;
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L7;
        }
        __pyx_L7:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2684
 *             modes[j] = keys[k]
 * 
 *     return modes[:j + 1]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyInt_FromSsize_t((__pyx_v_j + 1)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PySlice_New(Py_None, __pyx_t_5, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_modes), __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_keys);
  __Pyx_XDECREF((PyObject *)__pyx_v_modes);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_160__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_memoryview_fromslice(__Pyx_CyFunction_Defaults(__pyx_defaults18, __pyx_self)->__pyx_arg_mask, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_fuse_1__pyx_pw_6pandas_5_libs_9hashtable_107mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_1__pyx_mdef_6pandas_5_libs_9hashtable_107mode = {"__pyx_fuse_1mode", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_fuse_1__pyx_pw_6pandas_5_libs_9hashtable_107mode, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_fuse_1__pyx_pw_6pandas_5_libs_9hashtable_107mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mode (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    __pyx_defaults18 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults18, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, 1); __PYX_ERR(5, 2640, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "mode") < 0)) __PYX_ERR(5, 2640, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2642, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2642, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_dynamic_args->__pyx_arg_mask;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2640, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2642, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_106mode(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_106mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  PyArrayObject *__pyx_v_keys = 0;
  PyArrayObject *__pyx_v_modes = 0;
  __Pyx_memviewslice __pyx_v_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_v_count;
  __pyx_t_5numpy_int64_t __pyx_v_max_count;
  Py_ssize_t __pyx_v_nkeys;
  Py_ssize_t __pyx_v_k;
  Py_ssize_t __pyx_v_j;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_keys;
  __Pyx_Buffer __pyx_pybuffer_keys;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_modes;
  __Pyx_Buffer __pyx_pybuffer_modes;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_1__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyArrayObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  Py_ssize_t __pyx_t_13;
  PyArrayObject *__pyx_t_14 = NULL;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_t_18;
  Py_ssize_t __pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_1mode", 1);
  __pyx_pybuffer_keys.pybuffer.buf = NULL;
  __pyx_pybuffer_keys.refcount = 0;
  __pyx_pybuffernd_keys.data = NULL;
  __pyx_pybuffernd_keys.rcbuffer = &__pyx_pybuffer_keys;
  __pyx_pybuffer_modes.pybuffer.buf = NULL;
  __pyx_pybuffer_modes.refcount = 0;
  __pyx_pybuffernd_modes.data = NULL;
  __pyx_pybuffernd_modes.rcbuffer = &__pyx_pybuffer_modes;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2650
 * 
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1             # <<<<<<<<<<<<<<
 *         Py_ssize_t nkeys, k, j = 0
 * 
 */
  __pyx_v_max_count = -1LL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2651
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1
 *         Py_ssize_t nkeys, k, j = 0             # <<<<<<<<<<<<<<
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 */
  __pyx_v_j = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2653
 *         Py_ssize_t nkeys, k, j = 0
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 *     nkeys = len(keys)
 * 
 */
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_1__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(5, 2653, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2653, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_4, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_t_8, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_v_keys, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_10); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_12);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
      __pyx_t_10 = __pyx_t_11 = __pyx_t_12 = 0;
    }
    __pyx_pybuffernd_keys.diminfo[0].strides = __pyx_pybuffernd_keys.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_keys.diminfo[0].shape = __pyx_pybuffernd_keys.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2653, __pyx_L1_error)
  }
  __pyx_t_8 = 0;
  __pyx_v_keys = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_v_counts = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2654
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 *     nkeys = len(keys)             # <<<<<<<<<<<<<<
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)
 */
  __pyx_t_13 = PyObject_Length(((PyObject *)__pyx_v_keys)); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2654, __pyx_L1_error)
  __pyx_v_nkeys = __pyx_t_13;

  /* "pandas/_libs/hashtable_func_helper.pxi":2656
 *     nkeys = len(keys)
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)             # <<<<<<<<<<<<<<
 * 
 *     if htfunc_t is not object:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_empty); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_nkeys); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_values), __pyx_n_s_dtype); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_5) < 0) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2656, __pyx_L1_error)
  __pyx_t_14 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_t_14, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_v_modes, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_11, __pyx_t_10);
      }
      __pyx_t_12 = __pyx_t_11 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_modes.diminfo[0].strides = __pyx_pybuffernd_modes.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_modes.diminfo[0].shape = __pyx_pybuffernd_modes.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2656, __pyx_L1_error)
  }
  __pyx_t_14 = 0;
  __pyx_v_modes = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":2660
 *     if htfunc_t is not object:
 *         with nogil:
 *             for k in range(nkeys):             # <<<<<<<<<<<<<<
 *                 count = counts[k]
 *                 if count == max_count:
 */
        __pyx_t_13 = __pyx_v_nkeys;
        __pyx_t_15 = __pyx_t_13;
        for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
          __pyx_v_k = __pyx_t_16;

          /* "pandas/_libs/hashtable_func_helper.pxi":2661
 *         with nogil:
 *             for k in range(nkeys):
 *                 count = counts[k]             # <<<<<<<<<<<<<<
 *                 if count == max_count:
 *                     j += 1
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_v_count = (*((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_counts.data) + __pyx_t_17)) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
          __pyx_t_18 = (__pyx_v_count == __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2663
 *                 count = counts[k]
 *                 if count == max_count:
 *                     j += 1             # <<<<<<<<<<<<<<
 *                 elif count > max_count:
 *                     max_count = count
 */
            __pyx_v_j = (__pyx_v_j + 1);

            /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
          __pyx_t_18 = (__pyx_v_count > __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2665
 *                     j += 1
 *                 elif count > max_count:
 *                     max_count = count             # <<<<<<<<<<<<<<
 *                     j = 0
 *                 else:
 */
            __pyx_v_max_count = __pyx_v_count;

            /* "pandas/_libs/hashtable_func_helper.pxi":2666
 *                 elif count > max_count:
 *                     max_count = count
 *                     j = 0             # <<<<<<<<<<<<<<
 *                 else:
 *                     continue
 */
            __pyx_v_j = 0;

            /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2668
 *                     j = 0
 *                 else:
 *                     continue             # <<<<<<<<<<<<<<
 * 
 *                 modes[j] = keys[k]
 */
          /*else*/ {
            goto __pyx_L8_continue;
          }
          __pyx_L10:;

          /* "pandas/_libs/hashtable_func_helper.pxi":2670
 *                     continue
 * 
 *                 modes[j] = keys[k]             # <<<<<<<<<<<<<<
 *     else:
 *         for k in range(nkeys):
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_t_19 = __pyx_v_j;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_int16_t *, __pyx_pybuffernd_modes.rcbuffer->pybuffer.buf, __pyx_t_19, __pyx_pybuffernd_modes.diminfo[0].strides) = (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_int16_t *, __pyx_pybuffernd_keys.rcbuffer->pybuffer.buf, __pyx_t_17, __pyx_pybuffernd_keys.diminfo[0].strides));
          __pyx_L8_continue:;
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L7;
        }
        __pyx_L7:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2684
 *             modes[j] = keys[k]
 * 
 *     return modes[:j + 1]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyInt_FromSsize_t((__pyx_v_j + 1)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PySlice_New(Py_None, __pyx_t_5, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_modes), __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_keys);
  __Pyx_XDECREF((PyObject *)__pyx_v_modes);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_162__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_memoryview_fromslice(__Pyx_CyFunction_Defaults(__pyx_defaults19, __pyx_self)->__pyx_arg_mask, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_fuse_2__pyx_pw_6pandas_5_libs_9hashtable_109mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_2__pyx_mdef_6pandas_5_libs_9hashtable_109mode = {"__pyx_fuse_2mode", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_fuse_2__pyx_pw_6pandas_5_libs_9hashtable_109mode, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_fuse_2__pyx_pw_6pandas_5_libs_9hashtable_109mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mode (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    __pyx_defaults19 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults19, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, 1); __PYX_ERR(5, 2640, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "mode") < 0)) __PYX_ERR(5, 2640, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2642, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2642, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_dynamic_args->__pyx_arg_mask;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2640, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2642, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_108mode(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_108mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  PyArrayObject *__pyx_v_keys = 0;
  PyArrayObject *__pyx_v_modes = 0;
  __Pyx_memviewslice __pyx_v_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_v_count;
  __pyx_t_5numpy_int64_t __pyx_v_max_count;
  Py_ssize_t __pyx_v_nkeys;
  Py_ssize_t __pyx_v_k;
  Py_ssize_t __pyx_v_j;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_keys;
  __Pyx_Buffer __pyx_pybuffer_keys;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_modes;
  __Pyx_Buffer __pyx_pybuffer_modes;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_2__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyArrayObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  Py_ssize_t __pyx_t_13;
  PyArrayObject *__pyx_t_14 = NULL;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_t_18;
  Py_ssize_t __pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_2mode", 1);
  __pyx_pybuffer_keys.pybuffer.buf = NULL;
  __pyx_pybuffer_keys.refcount = 0;
  __pyx_pybuffernd_keys.data = NULL;
  __pyx_pybuffernd_keys.rcbuffer = &__pyx_pybuffer_keys;
  __pyx_pybuffer_modes.pybuffer.buf = NULL;
  __pyx_pybuffer_modes.refcount = 0;
  __pyx_pybuffernd_modes.data = NULL;
  __pyx_pybuffernd_modes.rcbuffer = &__pyx_pybuffer_modes;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2650
 * 
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1             # <<<<<<<<<<<<<<
 *         Py_ssize_t nkeys, k, j = 0
 * 
 */
  __pyx_v_max_count = -1LL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2651
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1
 *         Py_ssize_t nkeys, k, j = 0             # <<<<<<<<<<<<<<
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 */
  __pyx_v_j = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2653
 *         Py_ssize_t nkeys, k, j = 0
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 *     nkeys = len(keys)
 * 
 */
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_2__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(5, 2653, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2653, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_4, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_t_8, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_v_keys, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_10); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_12);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
      __pyx_t_10 = __pyx_t_11 = __pyx_t_12 = 0;
    }
    __pyx_pybuffernd_keys.diminfo[0].strides = __pyx_pybuffernd_keys.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_keys.diminfo[0].shape = __pyx_pybuffernd_keys.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2653, __pyx_L1_error)
  }
  __pyx_t_8 = 0;
  __pyx_v_keys = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_v_counts = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2654
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 *     nkeys = len(keys)             # <<<<<<<<<<<<<<
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)
 */
  __pyx_t_13 = PyObject_Length(((PyObject *)__pyx_v_keys)); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2654, __pyx_L1_error)
  __pyx_v_nkeys = __pyx_t_13;

  /* "pandas/_libs/hashtable_func_helper.pxi":2656
 *     nkeys = len(keys)
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)             # <<<<<<<<<<<<<<
 * 
 *     if htfunc_t is not object:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_empty); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_nkeys); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_values), __pyx_n_s_dtype); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_5) < 0) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2656, __pyx_L1_error)
  __pyx_t_14 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_t_14, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_v_modes, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_11, __pyx_t_10);
      }
      __pyx_t_12 = __pyx_t_11 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_modes.diminfo[0].strides = __pyx_pybuffernd_modes.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_modes.diminfo[0].shape = __pyx_pybuffernd_modes.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2656, __pyx_L1_error)
  }
  __pyx_t_14 = 0;
  __pyx_v_modes = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":2660
 *     if htfunc_t is not object:
 *         with nogil:
 *             for k in range(nkeys):             # <<<<<<<<<<<<<<
 *                 count = counts[k]
 *                 if count == max_count:
 */
        __pyx_t_13 = __pyx_v_nkeys;
        __pyx_t_15 = __pyx_t_13;
        for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
          __pyx_v_k = __pyx_t_16;

          /* "pandas/_libs/hashtable_func_helper.pxi":2661
 *         with nogil:
 *             for k in range(nkeys):
 *                 count = counts[k]             # <<<<<<<<<<<<<<
 *                 if count == max_count:
 *                     j += 1
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_v_count = (*((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_counts.data) + __pyx_t_17)) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
          __pyx_t_18 = (__pyx_v_count == __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2663
 *                 count = counts[k]
 *                 if count == max_count:
 *                     j += 1             # <<<<<<<<<<<<<<
 *                 elif count > max_count:
 *                     max_count = count
 */
            __pyx_v_j = (__pyx_v_j + 1);

            /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
          __pyx_t_18 = (__pyx_v_count > __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2665
 *                     j += 1
 *                 elif count > max_count:
 *                     max_count = count             # <<<<<<<<<<<<<<
 *                     j = 0
 *                 else:
 */
            __pyx_v_max_count = __pyx_v_count;

            /* "pandas/_libs/hashtable_func_helper.pxi":2666
 *                 elif count > max_count:
 *                     max_count = count
 *                     j = 0             # <<<<<<<<<<<<<<
 *                 else:
 *                     continue
 */
            __pyx_v_j = 0;

            /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2668
 *                     j = 0
 *                 else:
 *                     continue             # <<<<<<<<<<<<<<
 * 
 *                 modes[j] = keys[k]
 */
          /*else*/ {
            goto __pyx_L8_continue;
          }
          __pyx_L10:;

          /* "pandas/_libs/hashtable_func_helper.pxi":2670
 *                     continue
 * 
 *                 modes[j] = keys[k]             # <<<<<<<<<<<<<<
 *     else:
 *         for k in range(nkeys):
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_t_19 = __pyx_v_j;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_int32_t *, __pyx_pybuffernd_modes.rcbuffer->pybuffer.buf, __pyx_t_19, __pyx_pybuffernd_modes.diminfo[0].strides) = (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_int32_t *, __pyx_pybuffernd_keys.rcbuffer->pybuffer.buf, __pyx_t_17, __pyx_pybuffernd_keys.diminfo[0].strides));
          __pyx_L8_continue:;
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L7;
        }
        __pyx_L7:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2684
 *             modes[j] = keys[k]
 * 
 *     return modes[:j + 1]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyInt_FromSsize_t((__pyx_v_j + 1)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PySlice_New(Py_None, __pyx_t_5, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_modes), __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_keys);
  __Pyx_XDECREF((PyObject *)__pyx_v_modes);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_164__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_memoryview_fromslice(__Pyx_CyFunction_Defaults(__pyx_defaults20, __pyx_self)->__pyx_arg_mask, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_fuse_3__pyx_pw_6pandas_5_libs_9hashtable_111mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_3__pyx_mdef_6pandas_5_libs_9hashtable_111mode = {"__pyx_fuse_3mode", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_fuse_3__pyx_pw_6pandas_5_libs_9hashtable_111mode, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_fuse_3__pyx_pw_6pandas_5_libs_9hashtable_111mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mode (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    __pyx_defaults20 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults20, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, 1); __PYX_ERR(5, 2640, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "mode") < 0)) __PYX_ERR(5, 2640, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2642, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2642, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_dynamic_args->__pyx_arg_mask;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2640, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2642, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_110mode(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_110mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  PyArrayObject *__pyx_v_keys = 0;
  PyArrayObject *__pyx_v_modes = 0;
  __Pyx_memviewslice __pyx_v_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_v_count;
  __pyx_t_5numpy_int64_t __pyx_v_max_count;
  Py_ssize_t __pyx_v_nkeys;
  Py_ssize_t __pyx_v_k;
  Py_ssize_t __pyx_v_j;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_keys;
  __Pyx_Buffer __pyx_pybuffer_keys;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_modes;
  __Pyx_Buffer __pyx_pybuffer_modes;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_3__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyArrayObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  Py_ssize_t __pyx_t_13;
  PyArrayObject *__pyx_t_14 = NULL;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_t_18;
  Py_ssize_t __pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_3mode", 1);
  __pyx_pybuffer_keys.pybuffer.buf = NULL;
  __pyx_pybuffer_keys.refcount = 0;
  __pyx_pybuffernd_keys.data = NULL;
  __pyx_pybuffernd_keys.rcbuffer = &__pyx_pybuffer_keys;
  __pyx_pybuffer_modes.pybuffer.buf = NULL;
  __pyx_pybuffer_modes.refcount = 0;
  __pyx_pybuffernd_modes.data = NULL;
  __pyx_pybuffernd_modes.rcbuffer = &__pyx_pybuffer_modes;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2650
 * 
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1             # <<<<<<<<<<<<<<
 *         Py_ssize_t nkeys, k, j = 0
 * 
 */
  __pyx_v_max_count = -1LL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2651
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1
 *         Py_ssize_t nkeys, k, j = 0             # <<<<<<<<<<<<<<
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 */
  __pyx_v_j = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2653
 *         Py_ssize_t nkeys, k, j = 0
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 *     nkeys = len(keys)
 * 
 */
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_3__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(5, 2653, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2653, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_4, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_t_8, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_v_keys, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_10); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_12);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
      __pyx_t_10 = __pyx_t_11 = __pyx_t_12 = 0;
    }
    __pyx_pybuffernd_keys.diminfo[0].strides = __pyx_pybuffernd_keys.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_keys.diminfo[0].shape = __pyx_pybuffernd_keys.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2653, __pyx_L1_error)
  }
  __pyx_t_8 = 0;
  __pyx_v_keys = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_v_counts = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2654
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 *     nkeys = len(keys)             # <<<<<<<<<<<<<<
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)
 */
  __pyx_t_13 = PyObject_Length(((PyObject *)__pyx_v_keys)); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2654, __pyx_L1_error)
  __pyx_v_nkeys = __pyx_t_13;

  /* "pandas/_libs/hashtable_func_helper.pxi":2656
 *     nkeys = len(keys)
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)             # <<<<<<<<<<<<<<
 * 
 *     if htfunc_t is not object:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_empty); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_nkeys); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_values), __pyx_n_s_dtype); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_5) < 0) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2656, __pyx_L1_error)
  __pyx_t_14 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_t_14, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_v_modes, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_11, __pyx_t_10);
      }
      __pyx_t_12 = __pyx_t_11 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_modes.diminfo[0].strides = __pyx_pybuffernd_modes.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_modes.diminfo[0].shape = __pyx_pybuffernd_modes.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2656, __pyx_L1_error)
  }
  __pyx_t_14 = 0;
  __pyx_v_modes = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":2660
 *     if htfunc_t is not object:
 *         with nogil:
 *             for k in range(nkeys):             # <<<<<<<<<<<<<<
 *                 count = counts[k]
 *                 if count == max_count:
 */
        __pyx_t_13 = __pyx_v_nkeys;
        __pyx_t_15 = __pyx_t_13;
        for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
          __pyx_v_k = __pyx_t_16;

          /* "pandas/_libs/hashtable_func_helper.pxi":2661
 *         with nogil:
 *             for k in range(nkeys):
 *                 count = counts[k]             # <<<<<<<<<<<<<<
 *                 if count == max_count:
 *                     j += 1
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_v_count = (*((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_counts.data) + __pyx_t_17)) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
          __pyx_t_18 = (__pyx_v_count == __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2663
 *                 count = counts[k]
 *                 if count == max_count:
 *                     j += 1             # <<<<<<<<<<<<<<
 *                 elif count > max_count:
 *                     max_count = count
 */
            __pyx_v_j = (__pyx_v_j + 1);

            /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
          __pyx_t_18 = (__pyx_v_count > __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2665
 *                     j += 1
 *                 elif count > max_count:
 *                     max_count = count             # <<<<<<<<<<<<<<
 *                     j = 0
 *                 else:
 */
            __pyx_v_max_count = __pyx_v_count;

            /* "pandas/_libs/hashtable_func_helper.pxi":2666
 *                 elif count > max_count:
 *                     max_count = count
 *                     j = 0             # <<<<<<<<<<<<<<
 *                 else:
 *                     continue
 */
            __pyx_v_j = 0;

            /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2668
 *                     j = 0
 *                 else:
 *                     continue             # <<<<<<<<<<<<<<
 * 
 *                 modes[j] = keys[k]
 */
          /*else*/ {
            goto __pyx_L8_continue;
          }
          __pyx_L10:;

          /* "pandas/_libs/hashtable_func_helper.pxi":2670
 *                     continue
 * 
 *                 modes[j] = keys[k]             # <<<<<<<<<<<<<<
 *     else:
 *         for k in range(nkeys):
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_t_19 = __pyx_v_j;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_int64_t *, __pyx_pybuffernd_modes.rcbuffer->pybuffer.buf, __pyx_t_19, __pyx_pybuffernd_modes.diminfo[0].strides) = (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_int64_t *, __pyx_pybuffernd_keys.rcbuffer->pybuffer.buf, __pyx_t_17, __pyx_pybuffernd_keys.diminfo[0].strides));
          __pyx_L8_continue:;
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L7;
        }
        __pyx_L7:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2684
 *             modes[j] = keys[k]
 * 
 *     return modes[:j + 1]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyInt_FromSsize_t((__pyx_v_j + 1)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PySlice_New(Py_None, __pyx_t_5, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_modes), __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_keys);
  __Pyx_XDECREF((PyObject *)__pyx_v_modes);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_166__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_memoryview_fromslice(__Pyx_CyFunction_Defaults(__pyx_defaults21, __pyx_self)->__pyx_arg_mask, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_fuse_4__pyx_pw_6pandas_5_libs_9hashtable_113mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_4__pyx_mdef_6pandas_5_libs_9hashtable_113mode = {"__pyx_fuse_4mode", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_fuse_4__pyx_pw_6pandas_5_libs_9hashtable_113mode, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_fuse_4__pyx_pw_6pandas_5_libs_9hashtable_113mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mode (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    __pyx_defaults21 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults21, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, 1); __PYX_ERR(5, 2640, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "mode") < 0)) __PYX_ERR(5, 2640, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2642, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2642, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_dynamic_args->__pyx_arg_mask;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2640, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2642, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_112mode(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_112mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  PyArrayObject *__pyx_v_keys = 0;
  PyArrayObject *__pyx_v_modes = 0;
  __Pyx_memviewslice __pyx_v_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_v_count;
  __pyx_t_5numpy_int64_t __pyx_v_max_count;
  Py_ssize_t __pyx_v_nkeys;
  Py_ssize_t __pyx_v_k;
  Py_ssize_t __pyx_v_j;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_keys;
  __Pyx_Buffer __pyx_pybuffer_keys;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_modes;
  __Pyx_Buffer __pyx_pybuffer_modes;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_4__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyArrayObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  Py_ssize_t __pyx_t_13;
  PyArrayObject *__pyx_t_14 = NULL;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_t_18;
  Py_ssize_t __pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_4mode", 1);
  __pyx_pybuffer_keys.pybuffer.buf = NULL;
  __pyx_pybuffer_keys.refcount = 0;
  __pyx_pybuffernd_keys.data = NULL;
  __pyx_pybuffernd_keys.rcbuffer = &__pyx_pybuffer_keys;
  __pyx_pybuffer_modes.pybuffer.buf = NULL;
  __pyx_pybuffer_modes.refcount = 0;
  __pyx_pybuffernd_modes.data = NULL;
  __pyx_pybuffernd_modes.rcbuffer = &__pyx_pybuffer_modes;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2650
 * 
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1             # <<<<<<<<<<<<<<
 *         Py_ssize_t nkeys, k, j = 0
 * 
 */
  __pyx_v_max_count = -1LL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2651
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1
 *         Py_ssize_t nkeys, k, j = 0             # <<<<<<<<<<<<<<
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 */
  __pyx_v_j = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2653
 *         Py_ssize_t nkeys, k, j = 0
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 *     nkeys = len(keys)
 * 
 */
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_4__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(5, 2653, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2653, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_4, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_t_8, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_v_keys, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_10); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_12);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
      __pyx_t_10 = __pyx_t_11 = __pyx_t_12 = 0;
    }
    __pyx_pybuffernd_keys.diminfo[0].strides = __pyx_pybuffernd_keys.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_keys.diminfo[0].shape = __pyx_pybuffernd_keys.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2653, __pyx_L1_error)
  }
  __pyx_t_8 = 0;
  __pyx_v_keys = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_v_counts = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2654
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 *     nkeys = len(keys)             # <<<<<<<<<<<<<<
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)
 */
  __pyx_t_13 = PyObject_Length(((PyObject *)__pyx_v_keys)); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2654, __pyx_L1_error)
  __pyx_v_nkeys = __pyx_t_13;

  /* "pandas/_libs/hashtable_func_helper.pxi":2656
 *     nkeys = len(keys)
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)             # <<<<<<<<<<<<<<
 * 
 *     if htfunc_t is not object:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_empty); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_nkeys); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_values), __pyx_n_s_dtype); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_5) < 0) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2656, __pyx_L1_error)
  __pyx_t_14 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_t_14, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_v_modes, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_11, __pyx_t_10);
      }
      __pyx_t_12 = __pyx_t_11 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_modes.diminfo[0].strides = __pyx_pybuffernd_modes.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_modes.diminfo[0].shape = __pyx_pybuffernd_modes.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2656, __pyx_L1_error)
  }
  __pyx_t_14 = 0;
  __pyx_v_modes = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":2660
 *     if htfunc_t is not object:
 *         with nogil:
 *             for k in range(nkeys):             # <<<<<<<<<<<<<<
 *                 count = counts[k]
 *                 if count == max_count:
 */
        __pyx_t_13 = __pyx_v_nkeys;
        __pyx_t_15 = __pyx_t_13;
        for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
          __pyx_v_k = __pyx_t_16;

          /* "pandas/_libs/hashtable_func_helper.pxi":2661
 *         with nogil:
 *             for k in range(nkeys):
 *                 count = counts[k]             # <<<<<<<<<<<<<<
 *                 if count == max_count:
 *                     j += 1
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_v_count = (*((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_counts.data) + __pyx_t_17)) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
          __pyx_t_18 = (__pyx_v_count == __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2663
 *                 count = counts[k]
 *                 if count == max_count:
 *                     j += 1             # <<<<<<<<<<<<<<
 *                 elif count > max_count:
 *                     max_count = count
 */
            __pyx_v_j = (__pyx_v_j + 1);

            /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
          __pyx_t_18 = (__pyx_v_count > __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2665
 *                     j += 1
 *                 elif count > max_count:
 *                     max_count = count             # <<<<<<<<<<<<<<
 *                     j = 0
 *                 else:
 */
            __pyx_v_max_count = __pyx_v_count;

            /* "pandas/_libs/hashtable_func_helper.pxi":2666
 *                 elif count > max_count:
 *                     max_count = count
 *                     j = 0             # <<<<<<<<<<<<<<
 *                 else:
 *                     continue
 */
            __pyx_v_j = 0;

            /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2668
 *                     j = 0
 *                 else:
 *                     continue             # <<<<<<<<<<<<<<
 * 
 *                 modes[j] = keys[k]
 */
          /*else*/ {
            goto __pyx_L8_continue;
          }
          __pyx_L10:;

          /* "pandas/_libs/hashtable_func_helper.pxi":2670
 *                     continue
 * 
 *                 modes[j] = keys[k]             # <<<<<<<<<<<<<<
 *     else:
 *         for k in range(nkeys):
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_t_19 = __pyx_v_j;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_modes.rcbuffer->pybuffer.buf, __pyx_t_19, __pyx_pybuffernd_modes.diminfo[0].strides) = (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint8_t *, __pyx_pybuffernd_keys.rcbuffer->pybuffer.buf, __pyx_t_17, __pyx_pybuffernd_keys.diminfo[0].strides));
          __pyx_L8_continue:;
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L7;
        }
        __pyx_L7:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2684
 *             modes[j] = keys[k]
 * 
 *     return modes[:j + 1]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyInt_FromSsize_t((__pyx_v_j + 1)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PySlice_New(Py_None, __pyx_t_5, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_modes), __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_keys);
  __Pyx_XDECREF((PyObject *)__pyx_v_modes);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_168__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_memoryview_fromslice(__Pyx_CyFunction_Defaults(__pyx_defaults22, __pyx_self)->__pyx_arg_mask, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_fuse_5__pyx_pw_6pandas_5_libs_9hashtable_115mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_5__pyx_mdef_6pandas_5_libs_9hashtable_115mode = {"__pyx_fuse_5mode", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_fuse_5__pyx_pw_6pandas_5_libs_9hashtable_115mode, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_fuse_5__pyx_pw_6pandas_5_libs_9hashtable_115mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mode (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    __pyx_defaults22 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults22, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, 1); __PYX_ERR(5, 2640, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "mode") < 0)) __PYX_ERR(5, 2640, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2642, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2642, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_dynamic_args->__pyx_arg_mask;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2640, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2642, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_114mode(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_114mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  PyArrayObject *__pyx_v_keys = 0;
  PyArrayObject *__pyx_v_modes = 0;
  __Pyx_memviewslice __pyx_v_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_v_count;
  __pyx_t_5numpy_int64_t __pyx_v_max_count;
  Py_ssize_t __pyx_v_nkeys;
  Py_ssize_t __pyx_v_k;
  Py_ssize_t __pyx_v_j;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_keys;
  __Pyx_Buffer __pyx_pybuffer_keys;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_modes;
  __Pyx_Buffer __pyx_pybuffer_modes;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_5__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyArrayObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  Py_ssize_t __pyx_t_13;
  PyArrayObject *__pyx_t_14 = NULL;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_t_18;
  Py_ssize_t __pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_5mode", 1);
  __pyx_pybuffer_keys.pybuffer.buf = NULL;
  __pyx_pybuffer_keys.refcount = 0;
  __pyx_pybuffernd_keys.data = NULL;
  __pyx_pybuffernd_keys.rcbuffer = &__pyx_pybuffer_keys;
  __pyx_pybuffer_modes.pybuffer.buf = NULL;
  __pyx_pybuffer_modes.refcount = 0;
  __pyx_pybuffernd_modes.data = NULL;
  __pyx_pybuffernd_modes.rcbuffer = &__pyx_pybuffer_modes;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint16_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2650
 * 
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1             # <<<<<<<<<<<<<<
 *         Py_ssize_t nkeys, k, j = 0
 * 
 */
  __pyx_v_max_count = -1LL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2651
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1
 *         Py_ssize_t nkeys, k, j = 0             # <<<<<<<<<<<<<<
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 */
  __pyx_v_j = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2653
 *         Py_ssize_t nkeys, k, j = 0
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 *     nkeys = len(keys)
 * 
 */
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_5__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(5, 2653, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2653, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_4, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_t_8, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint16_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_v_keys, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint16_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_10); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_12);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
      __pyx_t_10 = __pyx_t_11 = __pyx_t_12 = 0;
    }
    __pyx_pybuffernd_keys.diminfo[0].strides = __pyx_pybuffernd_keys.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_keys.diminfo[0].shape = __pyx_pybuffernd_keys.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2653, __pyx_L1_error)
  }
  __pyx_t_8 = 0;
  __pyx_v_keys = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_v_counts = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2654
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 *     nkeys = len(keys)             # <<<<<<<<<<<<<<
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)
 */
  __pyx_t_13 = PyObject_Length(((PyObject *)__pyx_v_keys)); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2654, __pyx_L1_error)
  __pyx_v_nkeys = __pyx_t_13;

  /* "pandas/_libs/hashtable_func_helper.pxi":2656
 *     nkeys = len(keys)
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)             # <<<<<<<<<<<<<<
 * 
 *     if htfunc_t is not object:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_empty); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_nkeys); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_values), __pyx_n_s_dtype); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_5) < 0) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2656, __pyx_L1_error)
  __pyx_t_14 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_t_14, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint16_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_v_modes, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint16_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_11, __pyx_t_10);
      }
      __pyx_t_12 = __pyx_t_11 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_modes.diminfo[0].strides = __pyx_pybuffernd_modes.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_modes.diminfo[0].shape = __pyx_pybuffernd_modes.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2656, __pyx_L1_error)
  }
  __pyx_t_14 = 0;
  __pyx_v_modes = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":2660
 *     if htfunc_t is not object:
 *         with nogil:
 *             for k in range(nkeys):             # <<<<<<<<<<<<<<
 *                 count = counts[k]
 *                 if count == max_count:
 */
        __pyx_t_13 = __pyx_v_nkeys;
        __pyx_t_15 = __pyx_t_13;
        for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
          __pyx_v_k = __pyx_t_16;

          /* "pandas/_libs/hashtable_func_helper.pxi":2661
 *         with nogil:
 *             for k in range(nkeys):
 *                 count = counts[k]             # <<<<<<<<<<<<<<
 *                 if count == max_count:
 *                     j += 1
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_v_count = (*((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_counts.data) + __pyx_t_17)) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
          __pyx_t_18 = (__pyx_v_count == __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2663
 *                 count = counts[k]
 *                 if count == max_count:
 *                     j += 1             # <<<<<<<<<<<<<<
 *                 elif count > max_count:
 *                     max_count = count
 */
            __pyx_v_j = (__pyx_v_j + 1);

            /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
          __pyx_t_18 = (__pyx_v_count > __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2665
 *                     j += 1
 *                 elif count > max_count:
 *                     max_count = count             # <<<<<<<<<<<<<<
 *                     j = 0
 *                 else:
 */
            __pyx_v_max_count = __pyx_v_count;

            /* "pandas/_libs/hashtable_func_helper.pxi":2666
 *                 elif count > max_count:
 *                     max_count = count
 *                     j = 0             # <<<<<<<<<<<<<<
 *                 else:
 *                     continue
 */
            __pyx_v_j = 0;

            /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2668
 *                     j = 0
 *                 else:
 *                     continue             # <<<<<<<<<<<<<<
 * 
 *                 modes[j] = keys[k]
 */
          /*else*/ {
            goto __pyx_L8_continue;
          }
          __pyx_L10:;

          /* "pandas/_libs/hashtable_func_helper.pxi":2670
 *                     continue
 * 
 *                 modes[j] = keys[k]             # <<<<<<<<<<<<<<
 *     else:
 *         for k in range(nkeys):
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_t_19 = __pyx_v_j;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint16_t *, __pyx_pybuffernd_modes.rcbuffer->pybuffer.buf, __pyx_t_19, __pyx_pybuffernd_modes.diminfo[0].strides) = (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint16_t *, __pyx_pybuffernd_keys.rcbuffer->pybuffer.buf, __pyx_t_17, __pyx_pybuffernd_keys.diminfo[0].strides));
          __pyx_L8_continue:;
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L7;
        }
        __pyx_L7:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2684
 *             modes[j] = keys[k]
 * 
 *     return modes[:j + 1]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyInt_FromSsize_t((__pyx_v_j + 1)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PySlice_New(Py_None, __pyx_t_5, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_modes), __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_keys);
  __Pyx_XDECREF((PyObject *)__pyx_v_modes);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_170__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_memoryview_fromslice(__Pyx_CyFunction_Defaults(__pyx_defaults23, __pyx_self)->__pyx_arg_mask, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_fuse_6__pyx_pw_6pandas_5_libs_9hashtable_117mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_6__pyx_mdef_6pandas_5_libs_9hashtable_117mode = {"__pyx_fuse_6mode", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_fuse_6__pyx_pw_6pandas_5_libs_9hashtable_117mode, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_fuse_6__pyx_pw_6pandas_5_libs_9hashtable_117mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mode (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    __pyx_defaults23 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults23, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, 1); __PYX_ERR(5, 2640, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "mode") < 0)) __PYX_ERR(5, 2640, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2642, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2642, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_dynamic_args->__pyx_arg_mask;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2640, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2642, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_116mode(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_116mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  PyArrayObject *__pyx_v_keys = 0;
  PyArrayObject *__pyx_v_modes = 0;
  __Pyx_memviewslice __pyx_v_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_v_count;
  __pyx_t_5numpy_int64_t __pyx_v_max_count;
  Py_ssize_t __pyx_v_nkeys;
  Py_ssize_t __pyx_v_k;
  Py_ssize_t __pyx_v_j;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_keys;
  __Pyx_Buffer __pyx_pybuffer_keys;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_modes;
  __Pyx_Buffer __pyx_pybuffer_modes;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_6__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyArrayObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  Py_ssize_t __pyx_t_13;
  PyArrayObject *__pyx_t_14 = NULL;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_t_18;
  Py_ssize_t __pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_6mode", 1);
  __pyx_pybuffer_keys.pybuffer.buf = NULL;
  __pyx_pybuffer_keys.refcount = 0;
  __pyx_pybuffernd_keys.data = NULL;
  __pyx_pybuffernd_keys.rcbuffer = &__pyx_pybuffer_keys;
  __pyx_pybuffer_modes.pybuffer.buf = NULL;
  __pyx_pybuffer_modes.refcount = 0;
  __pyx_pybuffernd_modes.data = NULL;
  __pyx_pybuffernd_modes.rcbuffer = &__pyx_pybuffer_modes;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2650
 * 
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1             # <<<<<<<<<<<<<<
 *         Py_ssize_t nkeys, k, j = 0
 * 
 */
  __pyx_v_max_count = -1LL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2651
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1
 *         Py_ssize_t nkeys, k, j = 0             # <<<<<<<<<<<<<<
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 */
  __pyx_v_j = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2653
 *         Py_ssize_t nkeys, k, j = 0
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 *     nkeys = len(keys)
 * 
 */
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_6__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(5, 2653, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2653, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_4, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_t_8, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_v_keys, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_10); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_12);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
      __pyx_t_10 = __pyx_t_11 = __pyx_t_12 = 0;
    }
    __pyx_pybuffernd_keys.diminfo[0].strides = __pyx_pybuffernd_keys.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_keys.diminfo[0].shape = __pyx_pybuffernd_keys.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2653, __pyx_L1_error)
  }
  __pyx_t_8 = 0;
  __pyx_v_keys = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_v_counts = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2654
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 *     nkeys = len(keys)             # <<<<<<<<<<<<<<
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)
 */
  __pyx_t_13 = PyObject_Length(((PyObject *)__pyx_v_keys)); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2654, __pyx_L1_error)
  __pyx_v_nkeys = __pyx_t_13;

  /* "pandas/_libs/hashtable_func_helper.pxi":2656
 *     nkeys = len(keys)
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)             # <<<<<<<<<<<<<<
 * 
 *     if htfunc_t is not object:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_empty); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_nkeys); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_values), __pyx_n_s_dtype); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_5) < 0) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2656, __pyx_L1_error)
  __pyx_t_14 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_t_14, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint32_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_v_modes, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint32_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_11, __pyx_t_10);
      }
      __pyx_t_12 = __pyx_t_11 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_modes.diminfo[0].strides = __pyx_pybuffernd_modes.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_modes.diminfo[0].shape = __pyx_pybuffernd_modes.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2656, __pyx_L1_error)
  }
  __pyx_t_14 = 0;
  __pyx_v_modes = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":2660
 *     if htfunc_t is not object:
 *         with nogil:
 *             for k in range(nkeys):             # <<<<<<<<<<<<<<
 *                 count = counts[k]
 *                 if count == max_count:
 */
        __pyx_t_13 = __pyx_v_nkeys;
        __pyx_t_15 = __pyx_t_13;
        for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
          __pyx_v_k = __pyx_t_16;

          /* "pandas/_libs/hashtable_func_helper.pxi":2661
 *         with nogil:
 *             for k in range(nkeys):
 *                 count = counts[k]             # <<<<<<<<<<<<<<
 *                 if count == max_count:
 *                     j += 1
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_v_count = (*((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_counts.data) + __pyx_t_17)) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
          __pyx_t_18 = (__pyx_v_count == __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2663
 *                 count = counts[k]
 *                 if count == max_count:
 *                     j += 1             # <<<<<<<<<<<<<<
 *                 elif count > max_count:
 *                     max_count = count
 */
            __pyx_v_j = (__pyx_v_j + 1);

            /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
          __pyx_t_18 = (__pyx_v_count > __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2665
 *                     j += 1
 *                 elif count > max_count:
 *                     max_count = count             # <<<<<<<<<<<<<<
 *                     j = 0
 *                 else:
 */
            __pyx_v_max_count = __pyx_v_count;

            /* "pandas/_libs/hashtable_func_helper.pxi":2666
 *                 elif count > max_count:
 *                     max_count = count
 *                     j = 0             # <<<<<<<<<<<<<<
 *                 else:
 *                     continue
 */
            __pyx_v_j = 0;

            /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2668
 *                     j = 0
 *                 else:
 *                     continue             # <<<<<<<<<<<<<<
 * 
 *                 modes[j] = keys[k]
 */
          /*else*/ {
            goto __pyx_L8_continue;
          }
          __pyx_L10:;

          /* "pandas/_libs/hashtable_func_helper.pxi":2670
 *                     continue
 * 
 *                 modes[j] = keys[k]             # <<<<<<<<<<<<<<
 *     else:
 *         for k in range(nkeys):
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_t_19 = __pyx_v_j;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint32_t *, __pyx_pybuffernd_modes.rcbuffer->pybuffer.buf, __pyx_t_19, __pyx_pybuffernd_modes.diminfo[0].strides) = (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint32_t *, __pyx_pybuffernd_keys.rcbuffer->pybuffer.buf, __pyx_t_17, __pyx_pybuffernd_keys.diminfo[0].strides));
          __pyx_L8_continue:;
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L7;
        }
        __pyx_L7:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2684
 *             modes[j] = keys[k]
 * 
 *     return modes[:j + 1]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyInt_FromSsize_t((__pyx_v_j + 1)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PySlice_New(Py_None, __pyx_t_5, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_modes), __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_keys);
  __Pyx_XDECREF((PyObject *)__pyx_v_modes);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_172__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_memoryview_fromslice(__Pyx_CyFunction_Defaults(__pyx_defaults24, __pyx_self)->__pyx_arg_mask, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_fuse_7__pyx_pw_6pandas_5_libs_9hashtable_119mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_7__pyx_mdef_6pandas_5_libs_9hashtable_119mode = {"__pyx_fuse_7mode", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_fuse_7__pyx_pw_6pandas_5_libs_9hashtable_119mode, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_fuse_7__pyx_pw_6pandas_5_libs_9hashtable_119mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mode (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    __pyx_defaults24 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults24, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, 1); __PYX_ERR(5, 2640, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "mode") < 0)) __PYX_ERR(5, 2640, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2642, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2642, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_dynamic_args->__pyx_arg_mask;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2640, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2642, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_118mode(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_118mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  PyArrayObject *__pyx_v_keys = 0;
  PyArrayObject *__pyx_v_modes = 0;
  __Pyx_memviewslice __pyx_v_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_v_count;
  __pyx_t_5numpy_int64_t __pyx_v_max_count;
  Py_ssize_t __pyx_v_nkeys;
  Py_ssize_t __pyx_v_k;
  Py_ssize_t __pyx_v_j;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_keys;
  __Pyx_Buffer __pyx_pybuffer_keys;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_modes;
  __Pyx_Buffer __pyx_pybuffer_modes;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_7__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyArrayObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  Py_ssize_t __pyx_t_13;
  PyArrayObject *__pyx_t_14 = NULL;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_t_18;
  Py_ssize_t __pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_7mode", 1);
  __pyx_pybuffer_keys.pybuffer.buf = NULL;
  __pyx_pybuffer_keys.refcount = 0;
  __pyx_pybuffernd_keys.data = NULL;
  __pyx_pybuffernd_keys.rcbuffer = &__pyx_pybuffer_keys;
  __pyx_pybuffer_modes.pybuffer.buf = NULL;
  __pyx_pybuffer_modes.refcount = 0;
  __pyx_pybuffernd_modes.data = NULL;
  __pyx_pybuffernd_modes.rcbuffer = &__pyx_pybuffer_modes;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2650
 * 
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1             # <<<<<<<<<<<<<<
 *         Py_ssize_t nkeys, k, j = 0
 * 
 */
  __pyx_v_max_count = -1LL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2651
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1
 *         Py_ssize_t nkeys, k, j = 0             # <<<<<<<<<<<<<<
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 */
  __pyx_v_j = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2653
 *         Py_ssize_t nkeys, k, j = 0
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 *     nkeys = len(keys)
 * 
 */
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_7__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(5, 2653, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2653, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_4, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_t_8, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_v_keys, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_10); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_12);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
      __pyx_t_10 = __pyx_t_11 = __pyx_t_12 = 0;
    }
    __pyx_pybuffernd_keys.diminfo[0].strides = __pyx_pybuffernd_keys.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_keys.diminfo[0].shape = __pyx_pybuffernd_keys.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2653, __pyx_L1_error)
  }
  __pyx_t_8 = 0;
  __pyx_v_keys = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_v_counts = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2654
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 *     nkeys = len(keys)             # <<<<<<<<<<<<<<
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)
 */
  __pyx_t_13 = PyObject_Length(((PyObject *)__pyx_v_keys)); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2654, __pyx_L1_error)
  __pyx_v_nkeys = __pyx_t_13;

  /* "pandas/_libs/hashtable_func_helper.pxi":2656
 *     nkeys = len(keys)
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)             # <<<<<<<<<<<<<<
 * 
 *     if htfunc_t is not object:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_empty); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_nkeys); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_values), __pyx_n_s_dtype); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_5) < 0) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2656, __pyx_L1_error)
  __pyx_t_14 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_t_14, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint64_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_v_modes, &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint64_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_11, __pyx_t_10);
      }
      __pyx_t_12 = __pyx_t_11 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_modes.diminfo[0].strides = __pyx_pybuffernd_modes.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_modes.diminfo[0].shape = __pyx_pybuffernd_modes.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2656, __pyx_L1_error)
  }
  __pyx_t_14 = 0;
  __pyx_v_modes = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":2660
 *     if htfunc_t is not object:
 *         with nogil:
 *             for k in range(nkeys):             # <<<<<<<<<<<<<<
 *                 count = counts[k]
 *                 if count == max_count:
 */
        __pyx_t_13 = __pyx_v_nkeys;
        __pyx_t_15 = __pyx_t_13;
        for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
          __pyx_v_k = __pyx_t_16;

          /* "pandas/_libs/hashtable_func_helper.pxi":2661
 *         with nogil:
 *             for k in range(nkeys):
 *                 count = counts[k]             # <<<<<<<<<<<<<<
 *                 if count == max_count:
 *                     j += 1
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_v_count = (*((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_counts.data) + __pyx_t_17)) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
          __pyx_t_18 = (__pyx_v_count == __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2663
 *                 count = counts[k]
 *                 if count == max_count:
 *                     j += 1             # <<<<<<<<<<<<<<
 *                 elif count > max_count:
 *                     max_count = count
 */
            __pyx_v_j = (__pyx_v_j + 1);

            /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
          __pyx_t_18 = (__pyx_v_count > __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2665
 *                     j += 1
 *                 elif count > max_count:
 *                     max_count = count             # <<<<<<<<<<<<<<
 *                     j = 0
 *                 else:
 */
            __pyx_v_max_count = __pyx_v_count;

            /* "pandas/_libs/hashtable_func_helper.pxi":2666
 *                 elif count > max_count:
 *                     max_count = count
 *                     j = 0             # <<<<<<<<<<<<<<
 *                 else:
 *                     continue
 */
            __pyx_v_j = 0;

            /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2668
 *                     j = 0
 *                 else:
 *                     continue             # <<<<<<<<<<<<<<
 * 
 *                 modes[j] = keys[k]
 */
          /*else*/ {
            goto __pyx_L8_continue;
          }
          __pyx_L10:;

          /* "pandas/_libs/hashtable_func_helper.pxi":2670
 *                     continue
 * 
 *                 modes[j] = keys[k]             # <<<<<<<<<<<<<<
 *     else:
 *         for k in range(nkeys):
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_t_19 = __pyx_v_j;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint64_t *, __pyx_pybuffernd_modes.rcbuffer->pybuffer.buf, __pyx_t_19, __pyx_pybuffernd_modes.diminfo[0].strides) = (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_uint64_t *, __pyx_pybuffernd_keys.rcbuffer->pybuffer.buf, __pyx_t_17, __pyx_pybuffernd_keys.diminfo[0].strides));
          __pyx_L8_continue:;
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L7;
        }
        __pyx_L7:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2684
 *             modes[j] = keys[k]
 * 
 *     return modes[:j + 1]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyInt_FromSsize_t((__pyx_v_j + 1)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PySlice_New(Py_None, __pyx_t_5, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_modes), __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_keys);
  __Pyx_XDECREF((PyObject *)__pyx_v_modes);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_174__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_memoryview_fromslice(__Pyx_CyFunction_Defaults(__pyx_defaults25, __pyx_self)->__pyx_arg_mask, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_fuse_8__pyx_pw_6pandas_5_libs_9hashtable_121mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_8__pyx_mdef_6pandas_5_libs_9hashtable_121mode = {"__pyx_fuse_8mode", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_fuse_8__pyx_pw_6pandas_5_libs_9hashtable_121mode, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_fuse_8__pyx_pw_6pandas_5_libs_9hashtable_121mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mode (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    __pyx_defaults25 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults25, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, 1); __PYX_ERR(5, 2640, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "mode") < 0)) __PYX_ERR(5, 2640, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2642, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2642, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_dynamic_args->__pyx_arg_mask;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2640, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2642, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_120mode(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_120mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  PyArrayObject *__pyx_v_keys = 0;
  PyArrayObject *__pyx_v_modes = 0;
  __Pyx_memviewslice __pyx_v_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_v_count;
  __pyx_t_5numpy_int64_t __pyx_v_max_count;
  Py_ssize_t __pyx_v_nkeys;
  Py_ssize_t __pyx_v_k;
  Py_ssize_t __pyx_v_j;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_keys;
  __Pyx_Buffer __pyx_pybuffer_keys;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_modes;
  __Pyx_Buffer __pyx_pybuffer_modes;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_8__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyArrayObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  Py_ssize_t __pyx_t_13;
  PyArrayObject *__pyx_t_14 = NULL;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_t_18;
  Py_ssize_t __pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_8mode", 1);
  __pyx_pybuffer_keys.pybuffer.buf = NULL;
  __pyx_pybuffer_keys.refcount = 0;
  __pyx_pybuffernd_keys.data = NULL;
  __pyx_pybuffernd_keys.rcbuffer = &__pyx_pybuffer_keys;
  __pyx_pybuffer_modes.pybuffer.buf = NULL;
  __pyx_pybuffer_modes.refcount = 0;
  __pyx_pybuffernd_modes.data = NULL;
  __pyx_pybuffernd_modes.rcbuffer = &__pyx_pybuffer_modes;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2650
 * 
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1             # <<<<<<<<<<<<<<
 *         Py_ssize_t nkeys, k, j = 0
 * 
 */
  __pyx_v_max_count = -1LL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2651
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1
 *         Py_ssize_t nkeys, k, j = 0             # <<<<<<<<<<<<<<
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 */
  __pyx_v_j = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2653
 *         Py_ssize_t nkeys, k, j = 0
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 *     nkeys = len(keys)
 * 
 */
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_8__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(5, 2653, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2653, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_4, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_t_8, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_v_keys, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_10); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_12);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
      __pyx_t_10 = __pyx_t_11 = __pyx_t_12 = 0;
    }
    __pyx_pybuffernd_keys.diminfo[0].strides = __pyx_pybuffernd_keys.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_keys.diminfo[0].shape = __pyx_pybuffernd_keys.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2653, __pyx_L1_error)
  }
  __pyx_t_8 = 0;
  __pyx_v_keys = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_v_counts = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2654
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 *     nkeys = len(keys)             # <<<<<<<<<<<<<<
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)
 */
  __pyx_t_13 = PyObject_Length(((PyObject *)__pyx_v_keys)); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2654, __pyx_L1_error)
  __pyx_v_nkeys = __pyx_t_13;

  /* "pandas/_libs/hashtable_func_helper.pxi":2656
 *     nkeys = len(keys)
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)             # <<<<<<<<<<<<<<
 * 
 *     if htfunc_t is not object:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_empty); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_nkeys); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_values), __pyx_n_s_dtype); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_5) < 0) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2656, __pyx_L1_error)
  __pyx_t_14 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_t_14, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_v_modes, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_11, __pyx_t_10);
      }
      __pyx_t_12 = __pyx_t_11 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_modes.diminfo[0].strides = __pyx_pybuffernd_modes.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_modes.diminfo[0].shape = __pyx_pybuffernd_modes.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2656, __pyx_L1_error)
  }
  __pyx_t_14 = 0;
  __pyx_v_modes = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":2660
 *     if htfunc_t is not object:
 *         with nogil:
 *             for k in range(nkeys):             # <<<<<<<<<<<<<<
 *                 count = counts[k]
 *                 if count == max_count:
 */
        __pyx_t_13 = __pyx_v_nkeys;
        __pyx_t_15 = __pyx_t_13;
        for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
          __pyx_v_k = __pyx_t_16;

          /* "pandas/_libs/hashtable_func_helper.pxi":2661
 *         with nogil:
 *             for k in range(nkeys):
 *                 count = counts[k]             # <<<<<<<<<<<<<<
 *                 if count == max_count:
 *                     j += 1
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_v_count = (*((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_counts.data) + __pyx_t_17)) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
          __pyx_t_18 = (__pyx_v_count == __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2663
 *                 count = counts[k]
 *                 if count == max_count:
 *                     j += 1             # <<<<<<<<<<<<<<
 *                 elif count > max_count:
 *                     max_count = count
 */
            __pyx_v_j = (__pyx_v_j + 1);

            /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
          __pyx_t_18 = (__pyx_v_count > __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2665
 *                     j += 1
 *                 elif count > max_count:
 *                     max_count = count             # <<<<<<<<<<<<<<
 *                     j = 0
 *                 else:
 */
            __pyx_v_max_count = __pyx_v_count;

            /* "pandas/_libs/hashtable_func_helper.pxi":2666
 *                 elif count > max_count:
 *                     max_count = count
 *                     j = 0             # <<<<<<<<<<<<<<
 *                 else:
 *                     continue
 */
            __pyx_v_j = 0;

            /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2668
 *                     j = 0
 *                 else:
 *                     continue             # <<<<<<<<<<<<<<
 * 
 *                 modes[j] = keys[k]
 */
          /*else*/ {
            goto __pyx_L8_continue;
          }
          __pyx_L10:;

          /* "pandas/_libs/hashtable_func_helper.pxi":2670
 *                     continue
 * 
 *                 modes[j] = keys[k]             # <<<<<<<<<<<<<<
 *     else:
 *         for k in range(nkeys):
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_t_19 = __pyx_v_j;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_float32_t *, __pyx_pybuffernd_modes.rcbuffer->pybuffer.buf, __pyx_t_19, __pyx_pybuffernd_modes.diminfo[0].strides) = (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_float32_t *, __pyx_pybuffernd_keys.rcbuffer->pybuffer.buf, __pyx_t_17, __pyx_pybuffernd_keys.diminfo[0].strides));
          __pyx_L8_continue:;
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L7;
        }
        __pyx_L7:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2684
 *             modes[j] = keys[k]
 * 
 *     return modes[:j + 1]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyInt_FromSsize_t((__pyx_v_j + 1)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PySlice_New(Py_None, __pyx_t_5, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_modes), __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_keys);
  __Pyx_XDECREF((PyObject *)__pyx_v_modes);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_176__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_memoryview_fromslice(__Pyx_CyFunction_Defaults(__pyx_defaults26, __pyx_self)->__pyx_arg_mask, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_fuse_9__pyx_pw_6pandas_5_libs_9hashtable_123mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_9__pyx_mdef_6pandas_5_libs_9hashtable_123mode = {"__pyx_fuse_9mode", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_fuse_9__pyx_pw_6pandas_5_libs_9hashtable_123mode, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_fuse_9__pyx_pw_6pandas_5_libs_9hashtable_123mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mode (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    __pyx_defaults26 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults26, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, 1); __PYX_ERR(5, 2640, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "mode") < 0)) __PYX_ERR(5, 2640, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2642, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2642, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_dynamic_args->__pyx_arg_mask;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2640, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2642, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_122mode(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_122mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  PyArrayObject *__pyx_v_keys = 0;
  PyArrayObject *__pyx_v_modes = 0;
  __Pyx_memviewslice __pyx_v_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_v_count;
  __pyx_t_5numpy_int64_t __pyx_v_max_count;
  Py_ssize_t __pyx_v_nkeys;
  Py_ssize_t __pyx_v_k;
  Py_ssize_t __pyx_v_j;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_keys;
  __Pyx_Buffer __pyx_pybuffer_keys;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_modes;
  __Pyx_Buffer __pyx_pybuffer_modes;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_9__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyArrayObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  Py_ssize_t __pyx_t_13;
  PyArrayObject *__pyx_t_14 = NULL;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_t_18;
  Py_ssize_t __pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_9mode", 1);
  __pyx_pybuffer_keys.pybuffer.buf = NULL;
  __pyx_pybuffer_keys.refcount = 0;
  __pyx_pybuffernd_keys.data = NULL;
  __pyx_pybuffernd_keys.rcbuffer = &__pyx_pybuffer_keys;
  __pyx_pybuffer_modes.pybuffer.buf = NULL;
  __pyx_pybuffer_modes.refcount = 0;
  __pyx_pybuffernd_modes.data = NULL;
  __pyx_pybuffernd_modes.rcbuffer = &__pyx_pybuffer_modes;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2650
 * 
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1             # <<<<<<<<<<<<<<
 *         Py_ssize_t nkeys, k, j = 0
 * 
 */
  __pyx_v_max_count = -1LL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2651
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1
 *         Py_ssize_t nkeys, k, j = 0             # <<<<<<<<<<<<<<
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 */
  __pyx_v_j = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2653
 *         Py_ssize_t nkeys, k, j = 0
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 *     nkeys = len(keys)
 * 
 */
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_9__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(5, 2653, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2653, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_4, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_t_8, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_v_keys, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_10); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_12);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
      __pyx_t_10 = __pyx_t_11 = __pyx_t_12 = 0;
    }
    __pyx_pybuffernd_keys.diminfo[0].strides = __pyx_pybuffernd_keys.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_keys.diminfo[0].shape = __pyx_pybuffernd_keys.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2653, __pyx_L1_error)
  }
  __pyx_t_8 = 0;
  __pyx_v_keys = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_v_counts = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2654
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 *     nkeys = len(keys)             # <<<<<<<<<<<<<<
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)
 */
  __pyx_t_13 = PyObject_Length(((PyObject *)__pyx_v_keys)); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2654, __pyx_L1_error)
  __pyx_v_nkeys = __pyx_t_13;

  /* "pandas/_libs/hashtable_func_helper.pxi":2656
 *     nkeys = len(keys)
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)             # <<<<<<<<<<<<<<
 * 
 *     if htfunc_t is not object:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_empty); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_nkeys); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_values), __pyx_n_s_dtype); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_5) < 0) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2656, __pyx_L1_error)
  __pyx_t_14 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_t_14, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_v_modes, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_11, __pyx_t_10);
      }
      __pyx_t_12 = __pyx_t_11 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_modes.diminfo[0].strides = __pyx_pybuffernd_modes.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_modes.diminfo[0].shape = __pyx_pybuffernd_modes.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2656, __pyx_L1_error)
  }
  __pyx_t_14 = 0;
  __pyx_v_modes = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":2660
 *     if htfunc_t is not object:
 *         with nogil:
 *             for k in range(nkeys):             # <<<<<<<<<<<<<<
 *                 count = counts[k]
 *                 if count == max_count:
 */
        __pyx_t_13 = __pyx_v_nkeys;
        __pyx_t_15 = __pyx_t_13;
        for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
          __pyx_v_k = __pyx_t_16;

          /* "pandas/_libs/hashtable_func_helper.pxi":2661
 *         with nogil:
 *             for k in range(nkeys):
 *                 count = counts[k]             # <<<<<<<<<<<<<<
 *                 if count == max_count:
 *                     j += 1
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_v_count = (*((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_counts.data) + __pyx_t_17)) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
          __pyx_t_18 = (__pyx_v_count == __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2663
 *                 count = counts[k]
 *                 if count == max_count:
 *                     j += 1             # <<<<<<<<<<<<<<
 *                 elif count > max_count:
 *                     max_count = count
 */
            __pyx_v_j = (__pyx_v_j + 1);

            /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
          __pyx_t_18 = (__pyx_v_count > __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2665
 *                     j += 1
 *                 elif count > max_count:
 *                     max_count = count             # <<<<<<<<<<<<<<
 *                     j = 0
 *                 else:
 */
            __pyx_v_max_count = __pyx_v_count;

            /* "pandas/_libs/hashtable_func_helper.pxi":2666
 *                 elif count > max_count:
 *                     max_count = count
 *                     j = 0             # <<<<<<<<<<<<<<
 *                 else:
 *                     continue
 */
            __pyx_v_j = 0;

            /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2668
 *                     j = 0
 *                 else:
 *                     continue             # <<<<<<<<<<<<<<
 * 
 *                 modes[j] = keys[k]
 */
          /*else*/ {
            goto __pyx_L8_continue;
          }
          __pyx_L10:;

          /* "pandas/_libs/hashtable_func_helper.pxi":2670
 *                     continue
 * 
 *                 modes[j] = keys[k]             # <<<<<<<<<<<<<<
 *     else:
 *         for k in range(nkeys):
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_t_19 = __pyx_v_j;
          *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_float64_t *, __pyx_pybuffernd_modes.rcbuffer->pybuffer.buf, __pyx_t_19, __pyx_pybuffernd_modes.diminfo[0].strides) = (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_float64_t *, __pyx_pybuffernd_keys.rcbuffer->pybuffer.buf, __pyx_t_17, __pyx_pybuffernd_keys.diminfo[0].strides));
          __pyx_L8_continue:;
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L7;
        }
        __pyx_L7:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2684
 *             modes[j] = keys[k]
 * 
 *     return modes[:j + 1]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyInt_FromSsize_t((__pyx_v_j + 1)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PySlice_New(Py_None, __pyx_t_5, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_modes), __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_keys);
  __Pyx_XDECREF((PyObject *)__pyx_v_modes);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_178__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_memoryview_fromslice(__Pyx_CyFunction_Defaults(__pyx_defaults27, __pyx_self)->__pyx_arg_mask, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_fuse_10__pyx_pw_6pandas_5_libs_9hashtable_125mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_10__pyx_mdef_6pandas_5_libs_9hashtable_125mode = {"__pyx_fuse_10mode", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_fuse_10__pyx_pw_6pandas_5_libs_9hashtable_125mode, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_fuse_10__pyx_pw_6pandas_5_libs_9hashtable_125mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mode (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    __pyx_defaults27 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults27, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, 1); __PYX_ERR(5, 2640, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "mode") < 0)) __PYX_ERR(5, 2640, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2642, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2642, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_dynamic_args->__pyx_arg_mask;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2640, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2642, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_124mode(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_124mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  PyArrayObject *__pyx_v_keys = 0;
  PyArrayObject *__pyx_v_modes = 0;
  __Pyx_memviewslice __pyx_v_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_v_count;
  __pyx_t_5numpy_int64_t __pyx_v_max_count;
  Py_ssize_t __pyx_v_nkeys;
  Py_ssize_t __pyx_v_k;
  Py_ssize_t __pyx_v_j;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_keys;
  __Pyx_Buffer __pyx_pybuffer_keys;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_modes;
  __Pyx_Buffer __pyx_pybuffer_modes;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_10__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyArrayObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  Py_ssize_t __pyx_t_13;
  PyArrayObject *__pyx_t_14 = NULL;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_t_18;
  PyObject **__pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_10mode", 1);
  __pyx_pybuffer_keys.pybuffer.buf = NULL;
  __pyx_pybuffer_keys.refcount = 0;
  __pyx_pybuffernd_keys.data = NULL;
  __pyx_pybuffernd_keys.rcbuffer = &__pyx_pybuffer_keys;
  __pyx_pybuffer_modes.pybuffer.buf = NULL;
  __pyx_pybuffer_modes.refcount = 0;
  __pyx_pybuffernd_modes.data = NULL;
  __pyx_pybuffernd_modes.rcbuffer = &__pyx_pybuffer_modes;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2650
 * 
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1             # <<<<<<<<<<<<<<
 *         Py_ssize_t nkeys, k, j = 0
 * 
 */
  __pyx_v_max_count = -1LL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2651
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1
 *         Py_ssize_t nkeys, k, j = 0             # <<<<<<<<<<<<<<
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 */
  __pyx_v_j = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2653
 *         Py_ssize_t nkeys, k, j = 0
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 *     nkeys = len(keys)
 * 
 */
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_10__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(5, 2653, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2653, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_4, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_t_8, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_v_keys, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_10); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_12);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
      __pyx_t_10 = __pyx_t_11 = __pyx_t_12 = 0;
    }
    __pyx_pybuffernd_keys.diminfo[0].strides = __pyx_pybuffernd_keys.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_keys.diminfo[0].shape = __pyx_pybuffernd_keys.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2653, __pyx_L1_error)
  }
  __pyx_t_8 = 0;
  __pyx_v_keys = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_v_counts = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2654
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 *     nkeys = len(keys)             # <<<<<<<<<<<<<<
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)
 */
  __pyx_t_13 = PyObject_Length(((PyObject *)__pyx_v_keys)); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2654, __pyx_L1_error)
  __pyx_v_nkeys = __pyx_t_13;

  /* "pandas/_libs/hashtable_func_helper.pxi":2656
 *     nkeys = len(keys)
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)             # <<<<<<<<<<<<<<
 * 
 *     if htfunc_t is not object:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_empty); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_nkeys); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_values), __pyx_n_s_dtype); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_5) < 0) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2656, __pyx_L1_error)
  __pyx_t_14 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_t_14, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_v_modes, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_11, __pyx_t_10);
      }
      __pyx_t_12 = __pyx_t_11 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_modes.diminfo[0].strides = __pyx_pybuffernd_modes.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_modes.diminfo[0].shape = __pyx_pybuffernd_modes.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2656, __pyx_L1_error)
  }
  __pyx_t_14 = 0;
  __pyx_v_modes = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2672
 *                 modes[j] = keys[k]
 *     else:
 *         for k in range(nkeys):             # <<<<<<<<<<<<<<
 *             count = counts[k]
 *             if count == max_count:
 */
  __pyx_t_13 = __pyx_v_nkeys;
  __pyx_t_15 = __pyx_t_13;
  for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
    __pyx_v_k = __pyx_t_16;

    /* "pandas/_libs/hashtable_func_helper.pxi":2673
 *     else:
 *         for k in range(nkeys):
 *             count = counts[k]             # <<<<<<<<<<<<<<
 *             if count == max_count:
 *                 j += 1
 */
    __pyx_t_17 = __pyx_v_k;
    __pyx_v_count = (*((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_counts.data) + __pyx_t_17)) )));

    /* "pandas/_libs/hashtable_func_helper.pxi":2674
 *         for k in range(nkeys):
 *             count = counts[k]
 *             if count == max_count:             # <<<<<<<<<<<<<<
 *                 j += 1
 *             elif count > max_count:
 */
    __pyx_t_18 = (__pyx_v_count == __pyx_v_max_count);
    if (__pyx_t_18) {

      /* "pandas/_libs/hashtable_func_helper.pxi":2675
 *             count = counts[k]
 *             if count == max_count:
 *                 j += 1             # <<<<<<<<<<<<<<
 *             elif count > max_count:
 *                 max_count = count
 */
      __pyx_v_j = (__pyx_v_j + 1);

      /* "pandas/_libs/hashtable_func_helper.pxi":2674
 *         for k in range(nkeys):
 *             count = counts[k]
 *             if count == max_count:             # <<<<<<<<<<<<<<
 *                 j += 1
 *             elif count > max_count:
 */
      goto __pyx_L7;
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":2676
 *             if count == max_count:
 *                 j += 1
 *             elif count > max_count:             # <<<<<<<<<<<<<<
 *                 max_count = count
 *                 j = 0
 */
    __pyx_t_18 = (__pyx_v_count > __pyx_v_max_count);
    if (__pyx_t_18) {

      /* "pandas/_libs/hashtable_func_helper.pxi":2677
 *                 j += 1
 *             elif count > max_count:
 *                 max_count = count             # <<<<<<<<<<<<<<
 *                 j = 0
 *             else:
 */
      __pyx_v_max_count = __pyx_v_count;

      /* "pandas/_libs/hashtable_func_helper.pxi":2678
 *             elif count > max_count:
 *                 max_count = count
 *                 j = 0             # <<<<<<<<<<<<<<
 *             else:
 *                 continue
 */
      __pyx_v_j = 0;

      /* "pandas/_libs/hashtable_func_helper.pxi":2676
 *             if count == max_count:
 *                 j += 1
 *             elif count > max_count:             # <<<<<<<<<<<<<<
 *                 max_count = count
 *                 j = 0
 */
      goto __pyx_L7;
    }

    /* "pandas/_libs/hashtable_func_helper.pxi":2680
 *                 j = 0
 *             else:
 *                 continue             # <<<<<<<<<<<<<<
 * 
 *             modes[j] = keys[k]
 */
    /*else*/ {
      goto __pyx_L5_continue;
    }
    __pyx_L7:;

    /* "pandas/_libs/hashtable_func_helper.pxi":2682
 *                 continue
 * 
 *             modes[j] = keys[k]             # <<<<<<<<<<<<<<
 * 
 *     return modes[:j + 1]
 */
    __pyx_t_17 = __pyx_v_k;
    __pyx_t_5 = (PyObject *) *__Pyx_BufPtrStrided1d(PyObject **, __pyx_pybuffernd_keys.rcbuffer->pybuffer.buf, __pyx_t_17, __pyx_pybuffernd_keys.diminfo[0].strides);
    if (unlikely(__pyx_t_5 == NULL)) __pyx_t_5 = Py_None;
    __Pyx_INCREF((PyObject*)__pyx_t_5);
    __pyx_t_17 = __pyx_v_j;
    __pyx_t_19 = __Pyx_BufPtrStrided1d(PyObject **, __pyx_pybuffernd_modes.rcbuffer->pybuffer.buf, __pyx_t_17, __pyx_pybuffernd_modes.diminfo[0].strides);
    __Pyx_XGOTREF(*__pyx_t_19);
    __Pyx_INCREF(__pyx_t_5); __Pyx_XDECREF(*__pyx_t_19);
    *__pyx_t_19 = __pyx_t_5;
    __Pyx_XGIVEREF(*__pyx_t_19);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_L5_continue:;
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2684
 *             modes[j] = keys[k]
 * 
 *     return modes[:j + 1]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyInt_FromSsize_t((__pyx_v_j + 1)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PySlice_New(Py_None, __pyx_t_5, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_modes), __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_keys);
  __Pyx_XDECREF((PyObject *)__pyx_v_modes);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_180__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_memoryview_fromslice(__Pyx_CyFunction_Defaults(__pyx_defaults28, __pyx_self)->__pyx_arg_mask, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_fuse_11__pyx_pw_6pandas_5_libs_9hashtable_127mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_11__pyx_mdef_6pandas_5_libs_9hashtable_127mode = {"__pyx_fuse_11mode", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_fuse_11__pyx_pw_6pandas_5_libs_9hashtable_127mode, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_fuse_11__pyx_pw_6pandas_5_libs_9hashtable_127mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mode (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    __pyx_defaults28 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults28, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, 1); __PYX_ERR(5, 2640, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "mode") < 0)) __PYX_ERR(5, 2640, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2642, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2642, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_dynamic_args->__pyx_arg_mask;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2640, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2642, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_126mode(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_126mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  PyArrayObject *__pyx_v_keys = 0;
  PyArrayObject *__pyx_v_modes = 0;
  __Pyx_memviewslice __pyx_v_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_v_count;
  __pyx_t_5numpy_int64_t __pyx_v_max_count;
  Py_ssize_t __pyx_v_nkeys;
  Py_ssize_t __pyx_v_k;
  Py_ssize_t __pyx_v_j;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_keys;
  __Pyx_Buffer __pyx_pybuffer_keys;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_modes;
  __Pyx_Buffer __pyx_pybuffer_modes;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_11__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyArrayObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  Py_ssize_t __pyx_t_13;
  PyArrayObject *__pyx_t_14 = NULL;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_t_18;
  Py_ssize_t __pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_11mode", 1);
  __pyx_pybuffer_keys.pybuffer.buf = NULL;
  __pyx_pybuffer_keys.refcount = 0;
  __pyx_pybuffernd_keys.data = NULL;
  __pyx_pybuffernd_keys.rcbuffer = &__pyx_pybuffer_keys;
  __pyx_pybuffer_modes.pybuffer.buf = NULL;
  __pyx_pybuffer_modes.refcount = 0;
  __pyx_pybuffernd_modes.data = NULL;
  __pyx_pybuffernd_modes.rcbuffer = &__pyx_pybuffer_modes;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo___pyx_t_double_complex, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2650
 * 
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1             # <<<<<<<<<<<<<<
 *         Py_ssize_t nkeys, k, j = 0
 * 
 */
  __pyx_v_max_count = -1LL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2651
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1
 *         Py_ssize_t nkeys, k, j = 0             # <<<<<<<<<<<<<<
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 */
  __pyx_v_j = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2653
 *         Py_ssize_t nkeys, k, j = 0
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 *     nkeys = len(keys)
 * 
 */
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_11__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(5, 2653, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2653, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_4, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_t_8, &__Pyx_TypeInfo___pyx_t_double_complex, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_v_keys, &__Pyx_TypeInfo___pyx_t_double_complex, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_10); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_12);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
      __pyx_t_10 = __pyx_t_11 = __pyx_t_12 = 0;
    }
    __pyx_pybuffernd_keys.diminfo[0].strides = __pyx_pybuffernd_keys.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_keys.diminfo[0].shape = __pyx_pybuffernd_keys.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2653, __pyx_L1_error)
  }
  __pyx_t_8 = 0;
  __pyx_v_keys = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_v_counts = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2654
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 *     nkeys = len(keys)             # <<<<<<<<<<<<<<
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)
 */
  __pyx_t_13 = PyObject_Length(((PyObject *)__pyx_v_keys)); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2654, __pyx_L1_error)
  __pyx_v_nkeys = __pyx_t_13;

  /* "pandas/_libs/hashtable_func_helper.pxi":2656
 *     nkeys = len(keys)
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)             # <<<<<<<<<<<<<<
 * 
 *     if htfunc_t is not object:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_empty); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_nkeys); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_values), __pyx_n_s_dtype); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_5) < 0) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2656, __pyx_L1_error)
  __pyx_t_14 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_t_14, &__Pyx_TypeInfo___pyx_t_double_complex, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_v_modes, &__Pyx_TypeInfo___pyx_t_double_complex, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_11, __pyx_t_10);
      }
      __pyx_t_12 = __pyx_t_11 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_modes.diminfo[0].strides = __pyx_pybuffernd_modes.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_modes.diminfo[0].shape = __pyx_pybuffernd_modes.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2656, __pyx_L1_error)
  }
  __pyx_t_14 = 0;
  __pyx_v_modes = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":2660
 *     if htfunc_t is not object:
 *         with nogil:
 *             for k in range(nkeys):             # <<<<<<<<<<<<<<
 *                 count = counts[k]
 *                 if count == max_count:
 */
        __pyx_t_13 = __pyx_v_nkeys;
        __pyx_t_15 = __pyx_t_13;
        for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
          __pyx_v_k = __pyx_t_16;

          /* "pandas/_libs/hashtable_func_helper.pxi":2661
 *         with nogil:
 *             for k in range(nkeys):
 *                 count = counts[k]             # <<<<<<<<<<<<<<
 *                 if count == max_count:
 *                     j += 1
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_v_count = (*((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_counts.data) + __pyx_t_17)) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
          __pyx_t_18 = (__pyx_v_count == __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2663
 *                 count = counts[k]
 *                 if count == max_count:
 *                     j += 1             # <<<<<<<<<<<<<<
 *                 elif count > max_count:
 *                     max_count = count
 */
            __pyx_v_j = (__pyx_v_j + 1);

            /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
          __pyx_t_18 = (__pyx_v_count > __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2665
 *                     j += 1
 *                 elif count > max_count:
 *                     max_count = count             # <<<<<<<<<<<<<<
 *                     j = 0
 *                 else:
 */
            __pyx_v_max_count = __pyx_v_count;

            /* "pandas/_libs/hashtable_func_helper.pxi":2666
 *                 elif count > max_count:
 *                     max_count = count
 *                     j = 0             # <<<<<<<<<<<<<<
 *                 else:
 *                     continue
 */
            __pyx_v_j = 0;

            /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2668
 *                     j = 0
 *                 else:
 *                     continue             # <<<<<<<<<<<<<<
 * 
 *                 modes[j] = keys[k]
 */
          /*else*/ {
            goto __pyx_L8_continue;
          }
          __pyx_L10:;

          /* "pandas/_libs/hashtable_func_helper.pxi":2670
 *                     continue
 * 
 *                 modes[j] = keys[k]             # <<<<<<<<<<<<<<
 *     else:
 *         for k in range(nkeys):
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_t_19 = __pyx_v_j;
          *__Pyx_BufPtrStrided1d(__pyx_t_double_complex *, __pyx_pybuffernd_modes.rcbuffer->pybuffer.buf, __pyx_t_19, __pyx_pybuffernd_modes.diminfo[0].strides) = (*__Pyx_BufPtrStrided1d(__pyx_t_double_complex *, __pyx_pybuffernd_keys.rcbuffer->pybuffer.buf, __pyx_t_17, __pyx_pybuffernd_keys.diminfo[0].strides));
          __pyx_L8_continue:;
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L7;
        }
        __pyx_L7:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2684
 *             modes[j] = keys[k]
 * 
 *     return modes[:j + 1]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyInt_FromSsize_t((__pyx_v_j + 1)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PySlice_New(Py_None, __pyx_t_5, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_modes), __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_keys);
  __Pyx_XDECREF((PyObject *)__pyx_v_modes);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_182__defaults__(CYTHON_UNUSED PyObject *__pyx_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__defaults__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_memoryview_fromslice(__Pyx_CyFunction_Defaults(__pyx_defaults29, __pyx_self)->__pyx_arg_mask, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_2);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_1, 1, Py_None)) __PYX_ERR(5, 2640, __pyx_L1_error);
  __pyx_t_2 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pandas._libs.hashtable.__defaults__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_fuse_12__pyx_pw_6pandas_5_libs_9hashtable_129mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_fuse_12__pyx_mdef_6pandas_5_libs_9hashtable_129mode = {"__pyx_fuse_12mode", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_fuse_12__pyx_pw_6pandas_5_libs_9hashtable_129mode, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_fuse_12__pyx_pw_6pandas_5_libs_9hashtable_129mode(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_values = 0;
  int __pyx_v_dropna;
  __Pyx_memviewslice __pyx_v_mask = { 0, 0, { 0 }, { 0 }, { 0 } };
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("mode (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_dropna,&__pyx_n_s_mask,0};
    __pyx_defaults29 *__pyx_dynamic_args = __Pyx_CyFunction_Defaults(__pyx_defaults29, __pyx_self);
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_dropna)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, 1); __PYX_ERR(5, 2640, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[2] = __Pyx_Arg_NewRef_VARARGS(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2640, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "mode") < 0)) __PYX_ERR(5, 2640, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_VARARGS(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_VARARGS(__pyx_args, 1);
        values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_dropna = __Pyx_PyObject_IsTrue(values[1]); if (unlikely((__pyx_v_dropna == (int)-1) && PyErr_Occurred())) __PYX_ERR(5, 2642, __pyx_L3_error)
    if (values[2]) {
      __pyx_v_mask = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(values[2], 0); if (unlikely(!__pyx_v_mask.memview)) __PYX_ERR(5, 2642, __pyx_L3_error)
    } else {
      __pyx_v_mask = __pyx_dynamic_args->__pyx_arg_mask;
      __PYX_INC_MEMVIEW(&__pyx_v_mask, 1);
    }
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("mode", 0, 2, 3, __pyx_nargs); __PYX_ERR(5, 2640, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(5, 2642, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_128mode(__pyx_self, __pyx_v_values, __pyx_v_dropna, __pyx_v_mask);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_mask, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_128mode(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_values, int __pyx_v_dropna, __Pyx_memviewslice __pyx_v_mask) {
  PyArrayObject *__pyx_v_keys = 0;
  PyArrayObject *__pyx_v_modes = 0;
  __Pyx_memviewslice __pyx_v_counts = { 0, 0, { 0 }, { 0 }, { 0 } };
  __pyx_t_5numpy_int64_t __pyx_v_count;
  __pyx_t_5numpy_int64_t __pyx_v_max_count;
  Py_ssize_t __pyx_v_nkeys;
  Py_ssize_t __pyx_v_k;
  Py_ssize_t __pyx_v_j;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_keys;
  __Pyx_Buffer __pyx_pybuffer_keys;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_modes;
  __Pyx_Buffer __pyx_pybuffer_modes;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_fuse_12__pyx_opt_args_6pandas_5_libs_9hashtable_value_count __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  __Pyx_memviewslice __pyx_t_7 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyArrayObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  Py_ssize_t __pyx_t_13;
  PyArrayObject *__pyx_t_14 = NULL;
  Py_ssize_t __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_t_18;
  Py_ssize_t __pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_fuse_12mode", 1);
  __pyx_pybuffer_keys.pybuffer.buf = NULL;
  __pyx_pybuffer_keys.refcount = 0;
  __pyx_pybuffernd_keys.data = NULL;
  __pyx_pybuffernd_keys.rcbuffer = &__pyx_pybuffer_keys;
  __pyx_pybuffer_modes.pybuffer.buf = NULL;
  __pyx_pybuffer_modes.refcount = 0;
  __pyx_pybuffernd_modes.data = NULL;
  __pyx_pybuffernd_modes.rcbuffer = &__pyx_pybuffer_modes;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo___pyx_t_float_complex, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable_func_helper.pxi":2650
 * 
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1             # <<<<<<<<<<<<<<
 *         Py_ssize_t nkeys, k, j = 0
 * 
 */
  __pyx_v_max_count = -1LL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2651
 *         int64_t[::1] counts
 *         int64_t count, max_count = -1
 *         Py_ssize_t nkeys, k, j = 0             # <<<<<<<<<<<<<<
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 */
  __pyx_v_j = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2653
 *         Py_ssize_t nkeys, k, j = 0
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)             # <<<<<<<<<<<<<<
 *     nkeys = len(keys)
 * 
 */
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.mask = __pyx_v_mask;
  __pyx_t_1 = __pyx_fuse_12__pyx_f_6pandas_5_libs_9hashtable_value_count(((PyArrayObject *)__pyx_v_values), __pyx_v_dropna, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    Py_ssize_t size = __Pyx_PySequence_SIZE(sequence);
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      __PYX_ERR(5, 2653, __pyx_L1_error)
    }
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_3 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_t_4);
    #else
    __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_5 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2653, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_GetIterNextFunc(__pyx_t_5);
    index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_4);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    __PYX_ERR(5, 2653, __pyx_L1_error)
    __pyx_L4_unpacking_done:;
  }
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2653, __pyx_L1_error)
  __pyx_t_7 = __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(__pyx_t_4, PyBUF_WRITABLE); if (unlikely(!__pyx_t_7.memview)) __PYX_ERR(5, 2653, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_8 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_t_8, &__Pyx_TypeInfo___pyx_t_float_complex, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_keys.rcbuffer->pybuffer, (PyObject*)__pyx_v_keys, &__Pyx_TypeInfo___pyx_t_float_complex, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_10); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_12);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
      __pyx_t_10 = __pyx_t_11 = __pyx_t_12 = 0;
    }
    __pyx_pybuffernd_keys.diminfo[0].strides = __pyx_pybuffernd_keys.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_keys.diminfo[0].shape = __pyx_pybuffernd_keys.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2653, __pyx_L1_error)
  }
  __pyx_t_8 = 0;
  __pyx_v_keys = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_v_counts = __pyx_t_7;
  __pyx_t_7.memview = NULL;
  __pyx_t_7.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2654
 * 
 *     keys, counts = value_count(values, dropna, mask=mask)
 *     nkeys = len(keys)             # <<<<<<<<<<<<<<
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)
 */
  __pyx_t_13 = PyObject_Length(((PyObject *)__pyx_v_keys)); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(5, 2654, __pyx_L1_error)
  __pyx_v_nkeys = __pyx_t_13;

  /* "pandas/_libs/hashtable_func_helper.pxi":2656
 *     nkeys = len(keys)
 * 
 *     modes = np.empty(nkeys, dtype=values.dtype)             # <<<<<<<<<<<<<<
 * 
 *     if htfunc_t is not object:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_1, __pyx_n_s_np); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_empty); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_nkeys); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error);
  __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_values), __pyx_n_s_dtype); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_t_5) < 0) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2656, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2656, __pyx_L1_error)
  __pyx_t_14 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_t_14, &__Pyx_TypeInfo___pyx_t_float_complex, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_modes.rcbuffer->pybuffer, (PyObject*)__pyx_v_modes, &__Pyx_TypeInfo___pyx_t_float_complex, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_11, __pyx_t_10);
      }
      __pyx_t_12 = __pyx_t_11 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_modes.diminfo[0].strides = __pyx_pybuffernd_modes.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_modes.diminfo[0].shape = __pyx_pybuffernd_modes.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_9 < 0))) __PYX_ERR(5, 2656, __pyx_L1_error)
  }
  __pyx_t_14 = 0;
  __pyx_v_modes = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":2660
 *     if htfunc_t is not object:
 *         with nogil:
 *             for k in range(nkeys):             # <<<<<<<<<<<<<<
 *                 count = counts[k]
 *                 if count == max_count:
 */
        __pyx_t_13 = __pyx_v_nkeys;
        __pyx_t_15 = __pyx_t_13;
        for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
          __pyx_v_k = __pyx_t_16;

          /* "pandas/_libs/hashtable_func_helper.pxi":2661
 *         with nogil:
 *             for k in range(nkeys):
 *                 count = counts[k]             # <<<<<<<<<<<<<<
 *                 if count == max_count:
 *                     j += 1
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_v_count = (*((__pyx_t_5numpy_int64_t *) ( /* dim=0 */ ((char *) (((__pyx_t_5numpy_int64_t *) __pyx_v_counts.data) + __pyx_t_17)) )));

          /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
          __pyx_t_18 = (__pyx_v_count == __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2663
 *                 count = counts[k]
 *                 if count == max_count:
 *                     j += 1             # <<<<<<<<<<<<<<
 *                 elif count > max_count:
 *                     max_count = count
 */
            __pyx_v_j = (__pyx_v_j + 1);

            /* "pandas/_libs/hashtable_func_helper.pxi":2662
 *             for k in range(nkeys):
 *                 count = counts[k]
 *                 if count == max_count:             # <<<<<<<<<<<<<<
 *                     j += 1
 *                 elif count > max_count:
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
          __pyx_t_18 = (__pyx_v_count > __pyx_v_max_count);
          if (__pyx_t_18) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2665
 *                     j += 1
 *                 elif count > max_count:
 *                     max_count = count             # <<<<<<<<<<<<<<
 *                     j = 0
 *                 else:
 */
            __pyx_v_max_count = __pyx_v_count;

            /* "pandas/_libs/hashtable_func_helper.pxi":2666
 *                 elif count > max_count:
 *                     max_count = count
 *                     j = 0             # <<<<<<<<<<<<<<
 *                 else:
 *                     continue
 */
            __pyx_v_j = 0;

            /* "pandas/_libs/hashtable_func_helper.pxi":2664
 *                 if count == max_count:
 *                     j += 1
 *                 elif count > max_count:             # <<<<<<<<<<<<<<
 *                     max_count = count
 *                     j = 0
 */
            goto __pyx_L10;
          }

          /* "pandas/_libs/hashtable_func_helper.pxi":2668
 *                     j = 0
 *                 else:
 *                     continue             # <<<<<<<<<<<<<<
 * 
 *                 modes[j] = keys[k]
 */
          /*else*/ {
            goto __pyx_L8_continue;
          }
          __pyx_L10:;

          /* "pandas/_libs/hashtable_func_helper.pxi":2670
 *                     continue
 * 
 *                 modes[j] = keys[k]             # <<<<<<<<<<<<<<
 *     else:
 *         for k in range(nkeys):
 */
          __pyx_t_17 = __pyx_v_k;
          __pyx_t_19 = __pyx_v_j;
          *__Pyx_BufPtrStrided1d(__pyx_t_float_complex *, __pyx_pybuffernd_modes.rcbuffer->pybuffer.buf, __pyx_t_19, __pyx_pybuffernd_modes.diminfo[0].strides) = (*__Pyx_BufPtrStrided1d(__pyx_t_float_complex *, __pyx_pybuffernd_keys.rcbuffer->pybuffer.buf, __pyx_t_17, __pyx_pybuffernd_keys.diminfo[0].strides));
          __pyx_L8_continue:;
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2659
 * 
 *     if htfunc_t is not object:
 *         with nogil:             # <<<<<<<<<<<<<<
 *             for k in range(nkeys):
 *                 count = counts[k]
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L7;
        }
        __pyx_L7:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2684
 *             modes[j] = keys[k]
 * 
 *     return modes[:j + 1]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyInt_FromSsize_t((__pyx_v_j + 1)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PySlice_New(Py_None, __pyx_t_5, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_modes), __pyx_t_1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_7, 1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.mode", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_keys.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_modes.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_keys);
  __Pyx_XDECREF((PyObject *)__pyx_v_modes);
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_counts, 1);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":2688
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def _unique_label_indices_int64(const int64_t[:] labels) -> ndarray:
 */

/* Python wrapper */
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_15_unique_label_indices_int64(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_14_unique_label_indices_int64, "\n    Indices of the first occurrences of the unique labels\n    *excluding* -1. equivalent to:\n        np.unique(labels, return_index=True)[1]\n    ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_15_unique_label_indices_int64 = {"_unique_label_indices_int64", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15_unique_label_indices_int64, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14_unique_label_indices_int64};
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_15_unique_label_indices_int64(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_labels = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyArrayObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_unique_label_indices_int64 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_labels,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_labels)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2688, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_unique_label_indices_int64") < 0)) __PYX_ERR(5, 2688, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_labels = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t__const__(values[0], 0); if (unlikely(!__pyx_v_labels.memview)) __PYX_ERR(5, 2690, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_unique_label_indices_int64", 1, 1, 1, __pyx_nargs); __PYX_ERR(5, 2688, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_labels, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable._unique_label_indices_int64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_14_unique_label_indices_int64(__pyx_self, __pyx_v_labels);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_labels, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_14_unique_label_indices_int64(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_labels) {
  int __pyx_v_ret;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  kh_int64_t *__pyx_v_table;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *__pyx_v_idx = 0;
  PyArrayObject *__pyx_v_arr = 0;
  struct __pyx_t_6pandas_5_libs_9hashtable_Int64VectorData *__pyx_v_ud;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  struct __pyx_t_6pandas_5_libs_9hashtable_Int64VectorData *__pyx_t_3;
  khuint_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyArrayObject *__pyx_t_17 = NULL;
  npy_intp __pyx_t_18;
  int __pyx_t_19;
  __pyx_t_5numpy_int64_t __pyx_t_20;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_unique_label_indices_int64", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;

  /* "pandas/_libs/hashtable_func_helper.pxi":2697
 *     """
 *     cdef:
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         Py_ssize_t i, n = len(labels)
 *         kh_int64_t *table = kh_init_int64()
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2698
 *     cdef:
 *         int ret = 0
 *         Py_ssize_t i, n = len(labels)             # <<<<<<<<<<<<<<
 *         kh_int64_t *table = kh_init_int64()
 *         Int64Vector idx = Int64Vector()
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_labels); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":2699
 *         int ret = 0
 *         Py_ssize_t i, n = len(labels)
 *         kh_int64_t *table = kh_init_int64()             # <<<<<<<<<<<<<<
 *         Int64Vector idx = Int64Vector()
 *         ndarray[int64_t, ndim=1] arr
 */
  __pyx_v_table = kh_init_int64();

  /* "pandas/_libs/hashtable_func_helper.pxi":2700
 *         Py_ssize_t i, n = len(labels)
 *         kh_int64_t *table = kh_init_int64()
 *         Int64Vector idx = Int64Vector()             # <<<<<<<<<<<<<<
 *         ndarray[int64_t, ndim=1] arr
 *         Int64VectorData *ud = idx.data
 */
  __pyx_t_2 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector)); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2700, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_idx = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2702
 *         Int64Vector idx = Int64Vector()
 *         ndarray[int64_t, ndim=1] arr
 *         Int64VectorData *ud = idx.data             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_int64(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 */
  __pyx_t_3 = __pyx_v_idx->data;
  __pyx_v_ud = __pyx_t_3;

  /* "pandas/_libs/hashtable_func_helper.pxi":2704
 *         Int64VectorData *ud = idx.data
 * 
 *     kh_resize_int64(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = kh_needed_n_buckets(__pyx_v_n);
  __pyx_t_6 = __Pyx_PyInt_From_npy_uint32(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2704, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyObject_RichCompare(__pyx_t_2, __pyx_t_6, Py_LT); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2704, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(5, 2704, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_8) {
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_5 = __pyx_t_2;
  } else {
    __pyx_t_7 = __Pyx_PyInt_From_npy_uint32(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2704, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_5 = __pyx_t_7;
    __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_npy_uint32(__pyx_t_5); if (unlikely((__pyx_t_4 == ((khuint_t)-1)) && PyErr_Occurred())) __PYX_ERR(5, 2704, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  kh_resize_int64(__pyx_v_table, __pyx_t_4);

  /* "pandas/_libs/hashtable_func_helper.pxi":2706
 *     kh_resize_int64(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             kh_put_int64(table, labels[i], &ret)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":2707
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             kh_put_int64(table, labels[i], &ret)
 *             if ret != 0:
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_9 = __pyx_t_1;
        for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
          __pyx_v_i = __pyx_t_10;

          /* "pandas/_libs/hashtable_func_helper.pxi":2708
 *     with nogil:
 *         for i in range(n):
 *             kh_put_int64(table, labels[i], &ret)             # <<<<<<<<<<<<<<
 *             if ret != 0:
 *                 if needs_resize(ud):
 */
          __pyx_t_11 = __pyx_v_i;
          (void)(kh_put_int64(__pyx_v_table, (*((__pyx_t_5numpy_int64_t const  *) ( /* dim=0 */ (__pyx_v_labels.data + __pyx_t_11 * __pyx_v_labels.strides[0]) ))), (&__pyx_v_ret)));

          /* "pandas/_libs/hashtable_func_helper.pxi":2709
 *         for i in range(n):
 *             kh_put_int64(table, labels[i], &ret)
 *             if ret != 0:             # <<<<<<<<<<<<<<
 *                 if needs_resize(ud):
 *                     with gil:
 */
          __pyx_t_8 = (__pyx_v_ret != 0);
          if (__pyx_t_8) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2710
 *             kh_put_int64(table, labels[i], &ret)
 *             if ret != 0:
 *                 if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                     with gil:
 *                         idx.resize()
 */
            __pyx_t_8 = __pyx_fuse_0__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_8 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(5, 2710, __pyx_L4_error)
            if (__pyx_t_8) {

              /* "pandas/_libs/hashtable_func_helper.pxi":2711
 *             if ret != 0:
 *                 if needs_resize(ud):
 *                     with gil:             # <<<<<<<<<<<<<<
 *                         idx.resize()
 *                 append_data_int64(ud, i)
 */
              {
                  #ifdef WITH_THREAD
                  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                  #endif
                  /*try:*/ {

                    /* "pandas/_libs/hashtable_func_helper.pxi":2712
 *                 if needs_resize(ud):
 *                     with gil:
 *                         idx.resize()             # <<<<<<<<<<<<<<
 *                 append_data_int64(ud, i)
 * 
 */
                    __pyx_t_5 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_v_idx->__pyx_vtab)->resize(__pyx_v_idx); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2712, __pyx_L13_error)
                    __Pyx_GOTREF(__pyx_t_5);
                    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                  }

                  /* "pandas/_libs/hashtable_func_helper.pxi":2711
 *             if ret != 0:
 *                 if needs_resize(ud):
 *                     with gil:             # <<<<<<<<<<<<<<
 *                         idx.resize()
 *                 append_data_int64(ud, i)
 */
                  /*finally:*/ {
                    /*normal exit:*/{
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L14;
                    }
                    __pyx_L13_error: {
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L4_error;
                    }
                    __pyx_L14:;
                  }
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":2710
 *             kh_put_int64(table, labels[i], &ret)
 *             if ret != 0:
 *                 if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                     with gil:
 *                         idx.resize()
 */
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":2713
 *                     with gil:
 *                         idx.resize()
 *                 append_data_int64(ud, i)             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_int64(table)
 */
            __pyx_f_6pandas_5_libs_9hashtable_append_data_int64(__pyx_v_ud, __pyx_v_i); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(5, 2713, __pyx_L4_error)

            /* "pandas/_libs/hashtable_func_helper.pxi":2709
 *         for i in range(n):
 *             kh_put_int64(table, labels[i], &ret)
 *             if ret != 0:             # <<<<<<<<<<<<<<
 *                 if needs_resize(ud):
 *                     with gil:
 */
          }
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2706
 *     kh_resize_int64(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             kh_put_int64(table, labels[i], &ret)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2715
 *                 append_data_int64(ud, i)
 * 
 *     kh_destroy_int64(table)             # <<<<<<<<<<<<<<
 * 
 *     arr = idx.to_array()
 */
  kh_destroy_int64(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":2717
 *     kh_destroy_int64(table)
 * 
 *     arr = idx.to_array()             # <<<<<<<<<<<<<<
 *     arr = arr[np.asarray(labels)[arr].argsort()]
 * 
 */
  __pyx_t_5 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int64Vector *)__pyx_v_idx->__pyx_vtab)->to_array(__pyx_v_idx, 0)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2717, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __pyx_t_12 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)((PyArrayObject *)__pyx_t_5), &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_12 < 0)) {
      PyErr_Fetch(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_13); Py_XDECREF(__pyx_t_14); Py_XDECREF(__pyx_t_15);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_13, __pyx_t_14, __pyx_t_15);
      }
      __pyx_t_13 = __pyx_t_14 = __pyx_t_15 = 0;
    }
    __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(5, 2717, __pyx_L1_error)
  }
  __pyx_v_arr = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2718
 * 
 *     arr = idx.to_array()
 *     arr = arr[np.asarray(labels)[arr].argsort()]             # <<<<<<<<<<<<<<
 * 
 *     return arr[1:] if arr.size != 0 and labels[arr[0]] == -1 else arr
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_asarray); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __pyx_memoryview_fromslice(__pyx_v_labels, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int64_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_16 = NULL;
  __pyx_t_12 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_16)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_16);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_12 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_16, __pyx_t_7};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_12, 1+__pyx_t_12);
    __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2718, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_2, ((PyObject *)__pyx_v_arr)); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_argsort); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  __pyx_t_12 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_12 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_12, 0+__pyx_t_12);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2718, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_arr), __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2718, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2718, __pyx_L1_error)
  __pyx_t_17 = ((PyArrayObject *)__pyx_t_2);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __pyx_t_12 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_t_17, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_12 < 0)) {
      PyErr_Fetch(&__pyx_t_15, &__pyx_t_14, &__pyx_t_13);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_15); Py_XDECREF(__pyx_t_14); Py_XDECREF(__pyx_t_13);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_15, __pyx_t_14, __pyx_t_13);
      }
      __pyx_t_15 = __pyx_t_14 = __pyx_t_13 = 0;
    }
    __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(5, 2718, __pyx_L1_error)
  }
  __pyx_t_17 = 0;
  __Pyx_DECREF_SET(__pyx_v_arr, ((PyArrayObject *)__pyx_t_2));
  __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2720
 *     arr = arr[np.asarray(labels)[arr].argsort()]
 * 
 *     return arr[1:] if arr.size != 0 and labels[arr[0]] == -1 else arr             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_18 = __pyx_f_5numpy_7ndarray_4size_size(((PyArrayObject *)__pyx_v_arr)); if (unlikely(__pyx_t_18 == ((npy_intp)-1) && PyErr_Occurred())) __PYX_ERR(5, 2720, __pyx_L1_error)
  __pyx_t_19 = (__pyx_t_18 != 0);
  if (__pyx_t_19) {
  } else {
    __pyx_t_8 = __pyx_t_19;
    goto __pyx_L15_bool_binop_done;
  }
  __pyx_t_11 = 0;
  __pyx_t_20 = (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_int64_t *, __pyx_pybuffernd_arr.rcbuffer->pybuffer.buf, __pyx_t_11, __pyx_pybuffernd_arr.diminfo[0].strides));
  __pyx_t_19 = ((*((__pyx_t_5numpy_int64_t const  *) ( /* dim=0 */ (__pyx_v_labels.data + __pyx_t_20 * __pyx_v_labels.strides[0]) ))) == -1LL);
  __pyx_t_8 = __pyx_t_19;
  __pyx_L15_bool_binop_done:;
  if (__pyx_t_8) {
    __pyx_t_5 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_arr), __pyx_slice__100); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2720, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2720, __pyx_L1_error)
    __pyx_t_2 = __pyx_t_5;
    __pyx_t_5 = 0;
  } else {
    __Pyx_INCREF((PyObject *)__pyx_v_arr);
    __pyx_t_2 = ((PyObject *)__pyx_v_arr);
  }
  __pyx_r = ((PyArrayObject *)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2688
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def _unique_label_indices_int64(const int64_t[:] labels) -> ndarray:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_16);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable._unique_label_indices_int64", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_idx);
  __Pyx_XDECREF((PyObject *)__pyx_v_arr);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable_func_helper.pxi":2723
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def _unique_label_indices_int32(const int32_t[:] labels) -> ndarray:
 */

/* Python wrapper */
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_17_unique_label_indices_int32(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_16_unique_label_indices_int32, "\n    Indices of the first occurrences of the unique labels\n    *excluding* -1. equivalent to:\n        np.unique(labels, return_index=True)[1]\n    ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_17_unique_label_indices_int32 = {"_unique_label_indices_int32", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17_unique_label_indices_int32, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16_unique_label_indices_int32};
static PyArrayObject *__pyx_pw_6pandas_5_libs_9hashtable_17_unique_label_indices_int32(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  __Pyx_memviewslice __pyx_v_labels = { 0, 0, { 0 }, { 0 }, { 0 } };
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyArrayObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_unique_label_indices_int32 (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_labels,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_labels)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(5, 2723, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "_unique_label_indices_int32") < 0)) __PYX_ERR(5, 2723, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v_labels = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int32_t__const__(values[0], 0); if (unlikely(!__pyx_v_labels.memview)) __PYX_ERR(5, 2725, __pyx_L3_error)
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_unique_label_indices_int32", 1, 1, 1, __pyx_nargs); __PYX_ERR(5, 2723, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_labels, 1);
  __Pyx_AddTraceback("pandas._libs.hashtable._unique_label_indices_int32", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16_unique_label_indices_int32(__pyx_self, __pyx_v_labels);

  /* function exit code */
  __PYX_XCLEAR_MEMVIEW(&__pyx_v_labels, 1);
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyArrayObject *__pyx_pf_6pandas_5_libs_9hashtable_16_unique_label_indices_int32(CYTHON_UNUSED PyObject *__pyx_self, __Pyx_memviewslice __pyx_v_labels) {
  int __pyx_v_ret;
  Py_ssize_t __pyx_v_i;
  Py_ssize_t __pyx_v_n;
  kh_int32_t *__pyx_v_table;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *__pyx_v_idx = 0;
  PyArrayObject *__pyx_v_arr = 0;
  __pyx_t_6pandas_5_libs_9hashtable_Int32VectorData *__pyx_v_ud;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  PyArrayObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Py_ssize_t __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  __pyx_t_6pandas_5_libs_9hashtable_Int32VectorData *__pyx_t_3;
  khuint_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  Py_ssize_t __pyx_t_9;
  Py_ssize_t __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  int __pyx_t_12;
  PyObject *__pyx_t_13 = NULL;
  PyObject *__pyx_t_14 = NULL;
  PyObject *__pyx_t_15 = NULL;
  PyObject *__pyx_t_16 = NULL;
  PyArrayObject *__pyx_t_17 = NULL;
  npy_intp __pyx_t_18;
  int __pyx_t_19;
  Py_ssize_t __pyx_t_20;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_unique_label_indices_int32", 1);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;

  /* "pandas/_libs/hashtable_func_helper.pxi":2732
 *     """
 *     cdef:
 *         int ret = 0             # <<<<<<<<<<<<<<
 *         Py_ssize_t i, n = len(labels)
 *         kh_int32_t *table = kh_init_int32()
 */
  __pyx_v_ret = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2733
 *     cdef:
 *         int ret = 0
 *         Py_ssize_t i, n = len(labels)             # <<<<<<<<<<<<<<
 *         kh_int32_t *table = kh_init_int32()
 *         Int32Vector idx = Int32Vector()
 */
  __pyx_t_1 = __Pyx_MemoryView_Len(__pyx_v_labels); 
  __pyx_v_n = __pyx_t_1;

  /* "pandas/_libs/hashtable_func_helper.pxi":2734
 *         int ret = 0
 *         Py_ssize_t i, n = len(labels)
 *         kh_int32_t *table = kh_init_int32()             # <<<<<<<<<<<<<<
 *         Int32Vector idx = Int32Vector()
 *         ndarray[int32_t, ndim=1] arr
 */
  __pyx_v_table = kh_init_int32();

  /* "pandas/_libs/hashtable_func_helper.pxi":2735
 *         Py_ssize_t i, n = len(labels)
 *         kh_int32_t *table = kh_init_int32()
 *         Int32Vector idx = Int32Vector()             # <<<<<<<<<<<<<<
 *         ndarray[int32_t, ndim=1] arr
 *         Int32VectorData *ud = idx.data
 */
  __pyx_t_2 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector)); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2735, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_idx = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2737
 *         Int32Vector idx = Int32Vector()
 *         ndarray[int32_t, ndim=1] arr
 *         Int32VectorData *ud = idx.data             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_int32(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 */
  __pyx_t_3 = __pyx_v_idx->data;
  __pyx_v_ud = __pyx_t_3;

  /* "pandas/_libs/hashtable_func_helper.pxi":2739
 *         Int32VectorData *ud = idx.data
 * 
 *     kh_resize_int32(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))             # <<<<<<<<<<<<<<
 * 
 *     with nogil:
 */
  __Pyx_GetModuleGlobalName(__pyx_t_2, __pyx_n_s_SIZE_HINT_LIMIT); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = kh_needed_n_buckets(__pyx_v_n);
  __pyx_t_6 = __Pyx_PyInt_From_npy_uint32(__pyx_t_4); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyObject_RichCompare(__pyx_t_2, __pyx_t_6, Py_LT); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2739, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_8 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely((__pyx_t_8 < 0))) __PYX_ERR(5, 2739, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__pyx_t_8) {
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_5 = __pyx_t_2;
  } else {
    __pyx_t_7 = __Pyx_PyInt_From_npy_uint32(__pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2739, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_5 = __pyx_t_7;
    __pyx_t_7 = 0;
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyInt_As_npy_uint32(__pyx_t_5); if (unlikely((__pyx_t_4 == ((khuint_t)-1)) && PyErr_Occurred())) __PYX_ERR(5, 2739, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  kh_resize_int32(__pyx_v_table, __pyx_t_4);

  /* "pandas/_libs/hashtable_func_helper.pxi":2741
 *     kh_resize_int32(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             kh_put_int32(table, labels[i], &ret)
 */
  {
      #ifdef WITH_THREAD
      PyThreadState *_save;
      _save = NULL;
      Py_UNBLOCK_THREADS
      __Pyx_FastGIL_Remember();
      #endif
      /*try:*/ {

        /* "pandas/_libs/hashtable_func_helper.pxi":2742
 * 
 *     with nogil:
 *         for i in range(n):             # <<<<<<<<<<<<<<
 *             kh_put_int32(table, labels[i], &ret)
 *             if ret != 0:
 */
        __pyx_t_1 = __pyx_v_n;
        __pyx_t_9 = __pyx_t_1;
        for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
          __pyx_v_i = __pyx_t_10;

          /* "pandas/_libs/hashtable_func_helper.pxi":2743
 *     with nogil:
 *         for i in range(n):
 *             kh_put_int32(table, labels[i], &ret)             # <<<<<<<<<<<<<<
 *             if ret != 0:
 *                 if needs_resize(ud):
 */
          __pyx_t_11 = __pyx_v_i;
          (void)(kh_put_int32(__pyx_v_table, (*((__pyx_t_5numpy_int32_t const  *) ( /* dim=0 */ (__pyx_v_labels.data + __pyx_t_11 * __pyx_v_labels.strides[0]) ))), (&__pyx_v_ret)));

          /* "pandas/_libs/hashtable_func_helper.pxi":2744
 *         for i in range(n):
 *             kh_put_int32(table, labels[i], &ret)
 *             if ret != 0:             # <<<<<<<<<<<<<<
 *                 if needs_resize(ud):
 *                     with gil:
 */
          __pyx_t_8 = (__pyx_v_ret != 0);
          if (__pyx_t_8) {

            /* "pandas/_libs/hashtable_func_helper.pxi":2745
 *             kh_put_int32(table, labels[i], &ret)
 *             if ret != 0:
 *                 if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                     with gil:
 *                         idx.resize()
 */
            __pyx_t_8 = __pyx_fuse_1__pyx_f_6pandas_5_libs_9hashtable_needs_resize(__pyx_v_ud); if (unlikely(__pyx_t_8 == ((int)-1) && __Pyx_ErrOccurredWithGIL())) __PYX_ERR(5, 2745, __pyx_L4_error)
            if (__pyx_t_8) {

              /* "pandas/_libs/hashtable_func_helper.pxi":2746
 *             if ret != 0:
 *                 if needs_resize(ud):
 *                     with gil:             # <<<<<<<<<<<<<<
 *                         idx.resize()
 *                 append_data_int32(ud, i)
 */
              {
                  #ifdef WITH_THREAD
                  PyGILState_STATE __pyx_gilstate_save = __Pyx_PyGILState_Ensure();
                  #endif
                  /*try:*/ {

                    /* "pandas/_libs/hashtable_func_helper.pxi":2747
 *                 if needs_resize(ud):
 *                     with gil:
 *                         idx.resize()             # <<<<<<<<<<<<<<
 *                 append_data_int32(ud, i)
 * 
 */
                    __pyx_t_5 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_v_idx->__pyx_vtab)->resize(__pyx_v_idx); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2747, __pyx_L13_error)
                    __Pyx_GOTREF(__pyx_t_5);
                    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
                  }

                  /* "pandas/_libs/hashtable_func_helper.pxi":2746
 *             if ret != 0:
 *                 if needs_resize(ud):
 *                     with gil:             # <<<<<<<<<<<<<<
 *                         idx.resize()
 *                 append_data_int32(ud, i)
 */
                  /*finally:*/ {
                    /*normal exit:*/{
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L14;
                    }
                    __pyx_L13_error: {
                      #ifdef WITH_THREAD
                      __Pyx_PyGILState_Release(__pyx_gilstate_save);
                      #endif
                      goto __pyx_L4_error;
                    }
                    __pyx_L14:;
                  }
              }

              /* "pandas/_libs/hashtable_func_helper.pxi":2745
 *             kh_put_int32(table, labels[i], &ret)
 *             if ret != 0:
 *                 if needs_resize(ud):             # <<<<<<<<<<<<<<
 *                     with gil:
 *                         idx.resize()
 */
            }

            /* "pandas/_libs/hashtable_func_helper.pxi":2748
 *                     with gil:
 *                         idx.resize()
 *                 append_data_int32(ud, i)             # <<<<<<<<<<<<<<
 * 
 *     kh_destroy_int32(table)
 */
            __pyx_f_6pandas_5_libs_9hashtable_append_data_int32(__pyx_v_ud, __pyx_v_i); if (unlikely(__Pyx_ErrOccurredWithGIL())) __PYX_ERR(5, 2748, __pyx_L4_error)

            /* "pandas/_libs/hashtable_func_helper.pxi":2744
 *         for i in range(n):
 *             kh_put_int32(table, labels[i], &ret)
 *             if ret != 0:             # <<<<<<<<<<<<<<
 *                 if needs_resize(ud):
 *                     with gil:
 */
          }
        }
      }

      /* "pandas/_libs/hashtable_func_helper.pxi":2741
 *     kh_resize_int32(table, min(kh_needed_n_buckets(n), SIZE_HINT_LIMIT))
 * 
 *     with nogil:             # <<<<<<<<<<<<<<
 *         for i in range(n):
 *             kh_put_int32(table, labels[i], &ret)
 */
      /*finally:*/ {
        /*normal exit:*/{
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L5;
        }
        __pyx_L4_error: {
          #ifdef WITH_THREAD
          __Pyx_FastGIL_Forget();
          Py_BLOCK_THREADS
          #endif
          goto __pyx_L1_error;
        }
        __pyx_L5:;
      }
  }

  /* "pandas/_libs/hashtable_func_helper.pxi":2750
 *                 append_data_int32(ud, i)
 * 
 *     kh_destroy_int32(table)             # <<<<<<<<<<<<<<
 * 
 *     arr = idx.to_array()
 */
  kh_destroy_int32(__pyx_v_table);

  /* "pandas/_libs/hashtable_func_helper.pxi":2752
 *     kh_destroy_int32(table)
 * 
 *     arr = idx.to_array()             # <<<<<<<<<<<<<<
 *     arr = arr[np.asarray(labels)[arr].argsort()]
 * 
 */
  __pyx_t_5 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int32Vector *)__pyx_v_idx->__pyx_vtab)->to_array(__pyx_v_idx, 0)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2752, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __pyx_t_12 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)((PyArrayObject *)__pyx_t_5), &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_12 < 0)) {
      PyErr_Fetch(&__pyx_t_13, &__pyx_t_14, &__pyx_t_15);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_13); Py_XDECREF(__pyx_t_14); Py_XDECREF(__pyx_t_15);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_13, __pyx_t_14, __pyx_t_15);
      }
      __pyx_t_13 = __pyx_t_14 = __pyx_t_15 = 0;
    }
    __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(5, 2752, __pyx_L1_error)
  }
  __pyx_v_arr = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2753
 * 
 *     arr = idx.to_array()
 *     arr = arr[np.asarray(labels)[arr].argsort()]             # <<<<<<<<<<<<<<
 * 
 *     return arr[1:] if arr.size != 0 and labels[arr[0]] == -1 else arr
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_asarray); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __pyx_memoryview_fromslice(__pyx_v_labels, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_int32_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_16 = NULL;
  __pyx_t_12 = 0;
  #if CYTHON_UNPACK_METHODS
  if (unlikely(PyMethod_Check(__pyx_t_6))) {
    __pyx_t_16 = PyMethod_GET_SELF(__pyx_t_6);
    if (likely(__pyx_t_16)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
      __Pyx_INCREF(__pyx_t_16);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_6, function);
      __pyx_t_12 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_16, __pyx_t_7};
    __pyx_t_2 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_12, 1+__pyx_t_12);
    __Pyx_XDECREF(__pyx_t_16); __pyx_t_16 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2753, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __pyx_t_6 = __Pyx_PyObject_GetItem(__pyx_t_2, ((PyObject *)__pyx_v_arr)); if (unlikely(!__pyx_t_6)) __PYX_ERR(5, 2753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_argsort); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = NULL;
  __pyx_t_12 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_6 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_6)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_6);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_12 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_6, NULL};
    __pyx_t_5 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_12, 0+__pyx_t_12);
    __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2753, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_t_2 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_arr), __pyx_t_5); if (unlikely(!__pyx_t_2)) __PYX_ERR(5, 2753, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2753, __pyx_L1_error)
  __pyx_t_17 = ((PyArrayObject *)__pyx_t_2);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __pyx_t_12 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_t_17, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_12 < 0)) {
      PyErr_Fetch(&__pyx_t_15, &__pyx_t_14, &__pyx_t_13);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_15); Py_XDECREF(__pyx_t_14); Py_XDECREF(__pyx_t_13);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_15, __pyx_t_14, __pyx_t_13);
      }
      __pyx_t_15 = __pyx_t_14 = __pyx_t_13 = 0;
    }
    __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_12 < 0))) __PYX_ERR(5, 2753, __pyx_L1_error)
  }
  __pyx_t_17 = 0;
  __Pyx_DECREF_SET(__pyx_v_arr, ((PyArrayObject *)__pyx_t_2));
  __pyx_t_2 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2755
 *     arr = arr[np.asarray(labels)[arr].argsort()]
 * 
 *     return arr[1:] if arr.size != 0 and labels[arr[0]] == -1 else arr             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF((PyObject *)__pyx_r);
  __pyx_t_18 = __pyx_f_5numpy_7ndarray_4size_size(((PyArrayObject *)__pyx_v_arr)); if (unlikely(__pyx_t_18 == ((npy_intp)-1) && PyErr_Occurred())) __PYX_ERR(5, 2755, __pyx_L1_error)
  __pyx_t_19 = (__pyx_t_18 != 0);
  if (__pyx_t_19) {
  } else {
    __pyx_t_8 = __pyx_t_19;
    goto __pyx_L15_bool_binop_done;
  }
  __pyx_t_11 = 0;
  __pyx_t_20 = (*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_int32_t *, __pyx_pybuffernd_arr.rcbuffer->pybuffer.buf, __pyx_t_11, __pyx_pybuffernd_arr.diminfo[0].strides));
  __pyx_t_19 = ((*((__pyx_t_5numpy_int32_t const  *) ( /* dim=0 */ (__pyx_v_labels.data + __pyx_t_20 * __pyx_v_labels.strides[0]) ))) == -1L);
  __pyx_t_8 = __pyx_t_19;
  __pyx_L15_bool_binop_done:;
  if (__pyx_t_8) {
    __pyx_t_5 = __Pyx_PyObject_GetItem(((PyObject *)__pyx_v_arr), __pyx_slice__100); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2755, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(5, 2755, __pyx_L1_error)
    __pyx_t_2 = __pyx_t_5;
    __pyx_t_5 = 0;
  } else {
    __Pyx_INCREF((PyObject *)__pyx_v_arr);
    __pyx_t_2 = ((PyObject *)__pyx_v_arr);
  }
  __pyx_r = ((PyArrayObject *)__pyx_t_2);
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2723
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def _unique_label_indices_int32(const int32_t[:] labels) -> ndarray:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_16);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable._unique_label_indices_int32", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_idx);
  __Pyx_XDECREF((PyObject *)__pyx_v_arr);
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable.pyx":76
 *         Py_ssize_t count
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.count = 0
 * 
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_10Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_10Factorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  CYTHON_UNUSED PyObject *__pyx_v_size_hint = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 76, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(0, 76, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_size_hint = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 76, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Factorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_size_hint), (&PyInt_Type), 0, "size_hint", 1))) __PYX_ERR(0, 76, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_10Factorizer___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer *)__pyx_v_self), __pyx_v_size_hint);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_10Factorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_size_hint) {
  int __pyx_r;

  /* "pandas/_libs/hashtable.pyx":77
 * 
 *     def __cinit__(self, size_hint: int):
 *         self.count = 0             # <<<<<<<<<<<<<<
 * 
 *     def get_count(self) -> int:
 */
  __pyx_v_self->count = 0;

  /* "pandas/_libs/hashtable.pyx":76
 *         Py_ssize_t count
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.count = 0
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  return __pyx_r;
}

/* "pandas/_libs/hashtable.pyx":79
 *         self.count = 0
 * 
 *     def get_count(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.count
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_10Factorizer_3get_count(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_10Factorizer_3get_count = {"get_count", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_10Factorizer_3get_count, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_10Factorizer_3get_count(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_count (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("get_count", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "get_count", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_10Factorizer_2get_count(((struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_10Factorizer_2get_count(struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_count", 1);

  /* "pandas/_libs/hashtable.pyx":80
 * 
 *     def get_count(self) -> int:
 *         return self.count             # <<<<<<<<<<<<<<
 * 
 *     def factorize(self, values, na_sentinel=-1, na_value=None, mask=None) -> np.ndarray:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_self->count); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 80, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(__Pyx_Py3Int_CheckExact(__pyx_t_1)) || __Pyx_RaiseUnexpectedTypeError("int", __pyx_t_1))) __PYX_ERR(0, 80, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pandas/_libs/hashtable.pyx":79
 *         self.count = 0
 * 
 *     def get_count(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.count
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Factorizer.get_count", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable.pyx":82
 *         return self.count
 * 
 *     def factorize(self, values, na_sentinel=-1, na_value=None, mask=None) -> np.ndarray:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_10Factorizer_5factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_10Factorizer_5factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_10Factorizer_5factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_10Factorizer_5factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v_values = 0;
  CYTHON_UNUSED PyObject *__pyx_v_na_sentinel = 0;
  CYTHON_UNUSED PyObject *__pyx_v_na_value = 0;
  CYTHON_UNUSED PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_neg_1));
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 82, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 82, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 82, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 82, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(0, 82, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = values[0];
    __pyx_v_na_sentinel = values[1];
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 4, __pyx_nargs); __PYX_ERR(0, 82, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_10Factorizer_4factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_10Factorizer_4factorize(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v_values, CYTHON_UNUSED PyObject *__pyx_v_na_sentinel, CYTHON_UNUSED PyObject *__pyx_v_na_value, CYTHON_UNUSED PyObject *__pyx_v_mask) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);

  /* "pandas/_libs/hashtable.pyx":83
 * 
 *     def factorize(self, values, na_sentinel=-1, na_value=None, mask=None) -> np.ndarray:
 *         raise NotImplementedError             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_Raise(__pyx_builtin_NotImplementedError, 0, 0, 0);
  __PYX_ERR(0, 83, __pyx_L1_error)

  /* "pandas/_libs/hashtable.pyx":82
 *         return self.count
 * 
 *     def factorize(self, values, na_sentinel=-1, na_value=None, mask=None) -> np.ndarray:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Factorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable.pyx":74
 * cdef class Factorizer:
 *     cdef readonly:
 *         Py_ssize_t count             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, size_hint: int):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_10Factorizer_5count_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_10Factorizer_5count_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_10Factorizer_5count___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_10Factorizer_5count___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyInt_FromSsize_t(__pyx_v_self->count); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 74, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.Factorizer.count.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_10Factorizer_7__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_10Factorizer_7__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_10Factorizer_7__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_10Factorizer_7__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_10Factorizer_6__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_10Factorizer_6__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Factorizer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_10Factorizer_9__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_10Factorizer_9__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_10Factorizer_9__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_10Factorizer_9__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_10Factorizer_8__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_10Factorizer_8__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.Factorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable.pyx":91
 *         ObjectVector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = PyObjectHashTable(size_hint)
 *         self.uniques = ObjectVector()
 */

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_size_hint = 0;
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return -1;
  #endif
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_size_hint,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_VARARGS(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_VARARGS(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_size_hint)) != 0)) {
          (void)__Pyx_Arg_NewRef_VARARGS(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 91, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__cinit__") < 0)) __PYX_ERR(0, 91, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_VARARGS(__pyx_args, 0);
    }
    __pyx_v_size_hint = ((PyObject*)values[0]);
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 1, 1, 1, __pyx_nargs); __PYX_ERR(0, 91, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.ObjectFactorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_size_hint), (&PyInt_Type), 0, "size_hint", 1))) __PYX_ERR(0, 91, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer___cinit__(((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *)__pyx_v_self), __pyx_v_size_hint);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_VARARGS(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer___cinit__(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *__pyx_v_self, PyObject *__pyx_v_size_hint) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 1);

  /* "pandas/_libs/hashtable.pyx":92
 * 
 *     def __cinit__(self, size_hint: int):
 *         self.table = PyObjectHashTable(size_hint)             # <<<<<<<<<<<<<<
 *         self.uniques = ObjectVector()
 * 
 */
  __pyx_t_1 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable), __pyx_v_size_hint); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 92, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable.pyx":93
 *     def __cinit__(self, size_hint: int):
 *         self.table = PyObjectHashTable(size_hint)
 *         self.uniques = ObjectVector()             # <<<<<<<<<<<<<<
 * 
 *     def factorize(
 */
  __pyx_t_1 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 93, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pandas/_libs/hashtable.pyx":91
 *         ObjectVector uniques
 * 
 *     def __cinit__(self, size_hint: int):             # <<<<<<<<<<<<<<
 *         self.table = PyObjectHashTable(size_hint)
 *         self.uniques = ObjectVector()
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.ObjectFactorizer.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable.pyx":95
 *         self.uniques = ObjectVector()
 * 
 *     def factorize(             # <<<<<<<<<<<<<<
 *         self, ndarray[object] values, na_sentinel=-1, na_value=None, mask=None
 *     ) -> np.ndarray:
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
PyDoc_STRVAR(__pyx_doc_6pandas_5_libs_9hashtable_16ObjectFactorizer_2factorize, "\n\n        Returns\n        -------\n        np.ndarray[np.intp]\n\n        Examples\n        --------\n        Factorize values with nans replaced by na_sentinel\n\n        >>> fac = ObjectFactorizer(3)\n        >>> fac.factorize(np.array([1,2,np.nan], dtype='O'), na_sentinel=20)\n        array([ 0,  1, 20])\n        ");
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16ObjectFactorizer_3factorize = {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16ObjectFactorizer_2factorize};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_3factorize(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyArrayObject *__pyx_v_values = 0;
  PyObject *__pyx_v_na_sentinel = 0;
  PyObject *__pyx_v_na_value = 0;
  PyObject *__pyx_v_mask = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[4] = {0,0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("factorize (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_values,&__pyx_n_s_na_sentinel,&__pyx_n_s_na_value,&__pyx_n_s_mask,0};
    values[1] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)__pyx_int_neg_1));

    /* "pandas/_libs/hashtable.pyx":96
 * 
 *     def factorize(
 *         self, ndarray[object] values, na_sentinel=-1, na_value=None, mask=None             # <<<<<<<<<<<<<<
 *     ) -> np.ndarray:
 *         """
 */
    values[2] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    values[3] = __Pyx_Arg_NewRef_FASTCALL(((PyObject *)Py_None));
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_values)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 95, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_sentinel);
          if (value) { values[1] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 95, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_na_value);
          if (value) { values[2] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 95, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  3:
        if (kw_args > 0) {
          PyObject* value = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_mask);
          if (value) { values[3] = __Pyx_Arg_NewRef_FASTCALL(value); kw_args--; }
          else if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 95, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "factorize") < 0)) __PYX_ERR(0, 95, __pyx_L3_error)
      }
    } else {
      switch (__pyx_nargs) {
        case  4: values[3] = __Pyx_Arg_FASTCALL(__pyx_args, 3);
        CYTHON_FALLTHROUGH;
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_values = ((PyArrayObject *)values[0]);
    __pyx_v_na_sentinel = values[1];
    __pyx_v_na_value = values[2];
    __pyx_v_mask = values[3];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("factorize", 0, 1, 4, __pyx_nargs); __PYX_ERR(0, 95, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.ObjectFactorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_values), __pyx_ptype_5numpy_ndarray, 1, "values", 0))) __PYX_ERR(0, 96, __pyx_L1_error)
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_2factorize(((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *)__pyx_v_self), __pyx_v_values, __pyx_v_na_sentinel, __pyx_v_na_value, __pyx_v_mask);

  /* "pandas/_libs/hashtable.pyx":95
 *         self.uniques = ObjectVector()
 * 
 *     def factorize(             # <<<<<<<<<<<<<<
 *         self, ndarray[object] values, na_sentinel=-1, na_value=None, mask=None
 *     ) -> np.ndarray:
 */

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_2factorize(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *__pyx_v_self, PyArrayObject *__pyx_v_values, PyObject *__pyx_v_na_sentinel, PyObject *__pyx_v_na_value, PyObject *__pyx_v_mask) {
  PyArrayObject *__pyx_v_labels = 0;
  struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *__pyx_v_uniques = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_labels;
  __Pyx_Buffer __pyx_pybuffer_labels;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_values;
  __Pyx_Buffer __pyx_pybuffer_values;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyArrayObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("factorize", 1);
  __pyx_pybuffer_labels.pybuffer.buf = NULL;
  __pyx_pybuffer_labels.refcount = 0;
  __pyx_pybuffernd_labels.data = NULL;
  __pyx_pybuffernd_labels.rcbuffer = &__pyx_pybuffer_labels;
  __pyx_pybuffer_values.pybuffer.buf = NULL;
  __pyx_pybuffer_values.refcount = 0;
  __pyx_pybuffernd_values.data = NULL;
  __pyx_pybuffernd_values.rcbuffer = &__pyx_pybuffer_values;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_values.rcbuffer->pybuffer, (PyObject*)__pyx_v_values, &__Pyx_TypeInfo_object, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) __PYX_ERR(0, 95, __pyx_L1_error)
  }
  __pyx_pybuffernd_values.diminfo[0].strides = __pyx_pybuffernd_values.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_values.diminfo[0].shape = __pyx_pybuffernd_values.rcbuffer->pybuffer.shape[0];

  /* "pandas/_libs/hashtable.pyx":115
 *             ndarray[intp_t] labels
 * 
 *         if mask is not None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError("mask not supported for ObjectFactorizer.")
 * 
 */
  __pyx_t_1 = (__pyx_v_mask != Py_None);
  if (unlikely(__pyx_t_1)) {

    /* "pandas/_libs/hashtable.pyx":116
 * 
 *         if mask is not None:
 *             raise NotImplementedError("mask not supported for ObjectFactorizer.")             # <<<<<<<<<<<<<<
 * 
 *         if self.uniques.external_view_exists:
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_NotImplementedError, __pyx_tuple__101, NULL); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 116, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __PYX_ERR(0, 116, __pyx_L1_error)

    /* "pandas/_libs/hashtable.pyx":115
 *             ndarray[intp_t] labels
 * 
 *         if mask is not None:             # <<<<<<<<<<<<<<
 *             raise NotImplementedError("mask not supported for ObjectFactorizer.")
 * 
 */
  }

  /* "pandas/_libs/hashtable.pyx":118
 *             raise NotImplementedError("mask not supported for ObjectFactorizer.")
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = ObjectVector()
 *             uniques.extend(self.uniques.to_array())
 */
  if (__pyx_v_self->uniques->__pyx_base.external_view_exists) {

    /* "pandas/_libs/hashtable.pyx":119
 * 
 *         if self.uniques.external_view_exists:
 *             uniques = ObjectVector()             # <<<<<<<<<<<<<<
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 */
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 119, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_v_uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_t_2);
    __pyx_t_2 = 0;

    /* "pandas/_libs/hashtable.pyx":120
 *         if self.uniques.external_view_exists:
 *             uniques = ObjectVector()
 *             uniques.extend(self.uniques.to_array())             # <<<<<<<<<<<<<<
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 */
    __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_v_self->uniques->__pyx_vtab)->to_array(__pyx_v_self->uniques, 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = ((struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_v_uniques->__pyx_vtab)->extend(__pyx_v_uniques, ((PyArrayObject *)__pyx_t_2)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 120, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "pandas/_libs/hashtable.pyx":121
 *             uniques = ObjectVector()
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques             # <<<<<<<<<<<<<<
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel, na_value)
 */
    __Pyx_INCREF((PyObject *)__pyx_v_uniques);
    __Pyx_GIVEREF((PyObject *)__pyx_v_uniques);
    __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
    __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
    __pyx_v_self->uniques = __pyx_v_uniques;

    /* "pandas/_libs/hashtable.pyx":118
 *             raise NotImplementedError("mask not supported for ObjectFactorizer.")
 * 
 *         if self.uniques.external_view_exists:             # <<<<<<<<<<<<<<
 *             uniques = ObjectVector()
 *             uniques.extend(self.uniques.to_array())
 */
  }

  /* "pandas/_libs/hashtable.pyx":122
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel, na_value)
 *         self.count = len(self.uniques)
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self->table), __pyx_n_s_get_labels); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);

  /* "pandas/_libs/hashtable.pyx":123
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel, na_value)             # <<<<<<<<<<<<<<
 *         self.count = len(self.uniques)
 *         return labels
 */
  __pyx_t_4 = PyInt_FromSsize_t(__pyx_v_self->__pyx_base.count); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 123, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  __pyx_t_6 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
      __pyx_t_6 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[6] = {__pyx_t_5, ((PyObject *)__pyx_v_values), ((PyObject *)__pyx_v_self->uniques), __pyx_t_4, __pyx_v_na_sentinel, __pyx_v_na_value};
    __pyx_t_3 = __Pyx_PyObject_FastCall(__pyx_t_2, __pyx_callargs+1-__pyx_t_6, 5+__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 122, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }

  /* "pandas/_libs/hashtable.pyx":122
 *             uniques.extend(self.uniques.to_array())
 *             self.uniques = uniques
 *         labels = self.table.get_labels(values, self.uniques,             # <<<<<<<<<<<<<<
 *                                        self.count, na_sentinel, na_value)
 *         self.count = len(self.uniques)
 */
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) __PYX_ERR(0, 122, __pyx_L1_error)
  __pyx_t_7 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
    __pyx_t_6 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_t_7, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_6 < 0)) {
      PyErr_Fetch(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_labels.rcbuffer->pybuffer, (PyObject*)__pyx_v_labels, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      }
      __pyx_t_8 = __pyx_t_9 = __pyx_t_10 = 0;
    }
    __pyx_pybuffernd_labels.diminfo[0].strides = __pyx_pybuffernd_labels.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_labels.diminfo[0].shape = __pyx_pybuffernd_labels.rcbuffer->pybuffer.shape[0];
    if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 122, __pyx_L1_error)
  }
  __pyx_t_7 = 0;
  __pyx_v_labels = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pandas/_libs/hashtable.pyx":124
 *         labels = self.table.get_labels(values, self.uniques,
 *                                        self.count, na_sentinel, na_value)
 *         self.count = len(self.uniques)             # <<<<<<<<<<<<<<
 *         return labels
 */
  __pyx_t_3 = ((PyObject *)__pyx_v_self->uniques);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_t_11 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_11 == ((Py_ssize_t)-1))) __PYX_ERR(0, 124, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_self->__pyx_base.count = __pyx_t_11;

  /* "pandas/_libs/hashtable.pyx":125
 *                                        self.count, na_sentinel, na_value)
 *         self.count = len(self.uniques)
 *         return labels             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_labels);
  __pyx_r = ((PyObject *)__pyx_v_labels);
  goto __pyx_L0;

  /* "pandas/_libs/hashtable.pyx":95
 *         self.uniques = ObjectVector()
 * 
 *     def factorize(             # <<<<<<<<<<<<<<
 *         self, ndarray[object] values, na_sentinel=-1, na_value=None, mask=None
 *     ) -> np.ndarray:
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pandas._libs.hashtable.ObjectFactorizer.factorize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_labels.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_values.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_labels);
  __Pyx_XDECREF((PyObject *)__pyx_v_uniques);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable.pyx":88
 * cdef class ObjectFactorizer(Factorizer):
 *     cdef public:
 *         PyObjectHashTable table             # <<<<<<<<<<<<<<
 *         ObjectVector uniques
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_5table_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_5table_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_5table___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_5table___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->table);
  __pyx_r = ((PyObject *)__pyx_v_self->table);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_5table_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_5table_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_5table_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable))))) __PYX_ERR(0, 88, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.ObjectFactorizer.table.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_5table_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_5table_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_5table_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_5table_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->table);
  __Pyx_DECREF((PyObject *)__pyx_v_self->table);
  __pyx_v_self->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pandas/_libs/hashtable.pyx":89
 *     cdef public:
 *         PyObjectHashTable table
 *         ObjectVector uniques             # <<<<<<<<<<<<<<
 * 
 *     def __cinit__(self, size_hint: int):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_7uniques_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_7uniques_1__get__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_7uniques___get__(((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_7uniques___get__(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 1);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF((PyObject *)__pyx_v_self->uniques);
  __pyx_r = ((PyObject *)__pyx_v_self->uniques);
  goto __pyx_L0;

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_7uniques_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_v_value) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_7uniques_2__set__(((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *)__pyx_v_self), ((PyObject *)__pyx_v_value));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_7uniques_2__set__(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *__pyx_v_self, PyObject *__pyx_v_value) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__set__", 1);
  if (!(likely(((__pyx_v_value) == Py_None) || likely(__Pyx_TypeTest(__pyx_v_value, __pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector))))) __PYX_ERR(0, 89, __pyx_L1_error)
  __pyx_t_1 = __pyx_v_value;
  __Pyx_INCREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pandas._libs.hashtable.ObjectFactorizer.uniques.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_7uniques_5__del__(PyObject *__pyx_v_self); /*proto*/
static int __pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_7uniques_5__del__(PyObject *__pyx_v_self) {
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__ (wrapper)", 0);
  __pyx_kwvalues = __Pyx_KwValues_VARARGS(__pyx_args, __pyx_nargs);
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_7uniques_4__del__(((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_7uniques_4__del__(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__del__", 1);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  __Pyx_GOTREF((PyObject *)__pyx_v_self->uniques);
  __Pyx_DECREF((PyObject *)__pyx_v_self->uniques);
  __pyx_v_self->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)Py_None);

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16ObjectFactorizer_5__reduce_cython__ = {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_5__reduce_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  if (unlikely(__pyx_nargs > 0)) {
    __Pyx_RaiseArgtupleInvalid("__reduce_cython__", 1, 0, 0, __pyx_nargs); return NULL;}
  if (unlikely(__pyx_kwds) && __Pyx_NumKwargs_FASTCALL(__pyx_kwds) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__reduce_cython__", 0))) return NULL;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_4__reduce_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_4__reduce_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__reduce_cython__", 1);

  /* "(tree fragment)":2
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 2, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.ObjectFactorizer.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_16ObjectFactorizer_7__setstate_cython__ = {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_7__setstate_cython__(PyObject *__pyx_v_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  CYTHON_UNUSED PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[1] = {0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 3, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__setstate_cython__") < 0)) __PYX_ERR(1, 3, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 1)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
    }
    __pyx_v___pyx_state = values[0];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__setstate_cython__", 1, 1, 1, __pyx_nargs); __PYX_ERR(1, 3, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.ObjectFactorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_6__setstate_cython__(((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *)__pyx_v_self), __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_16ObjectFactorizer_6__setstate_cython__(CYTHON_UNUSED struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *__pyx_v_self, CYTHON_UNUSED PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__setstate_cython__", 1);

  /* "(tree fragment)":4
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"             # <<<<<<<<<<<<<<
 */
  __Pyx_Raise(__pyx_builtin_TypeError, __pyx_kp_s_no_default___reduce___due_to_non, 0, 0);
  __PYX_ERR(1, 4, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_AddTraceback("pandas._libs.hashtable.ObjectFactorizer.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_HashTable(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19__pyx_unpickle_HashTable(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
); /*proto*/
static PyMethodDef __pyx_mdef_6pandas_5_libs_9hashtable_19__pyx_unpickle_HashTable = {"__pyx_unpickle_HashTable", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19__pyx_unpickle_HashTable, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_6pandas_5_libs_9hashtable_19__pyx_unpickle_HashTable(PyObject *__pyx_self, 
#if CYTHON_METH_FASTCALL
PyObject *const *__pyx_args, Py_ssize_t __pyx_nargs, PyObject *__pyx_kwds
#else
PyObject *__pyx_args, PyObject *__pyx_kwds
#endif
) {
  PyObject *__pyx_v___pyx_type = 0;
  long __pyx_v___pyx_checksum;
  PyObject *__pyx_v___pyx_state = 0;
  #if !CYTHON_METH_FASTCALL
  CYTHON_UNUSED Py_ssize_t __pyx_nargs;
  #endif
  CYTHON_UNUSED PyObject *const *__pyx_kwvalues;
  PyObject* values[3] = {0,0,0};
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__pyx_unpickle_HashTable (wrapper)", 0);
  #if !CYTHON_METH_FASTCALL
  #if CYTHON_ASSUME_SAFE_MACROS
  __pyx_nargs = PyTuple_GET_SIZE(__pyx_args);
  #else
  __pyx_nargs = PyTuple_Size(__pyx_args); if (unlikely(__pyx_nargs < 0)) return NULL;
  #endif
  #endif
  __pyx_kwvalues = __Pyx_KwValues_FASTCALL(__pyx_args, __pyx_nargs);
  {
    PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
    if (__pyx_kwds) {
      Py_ssize_t kw_args;
      switch (__pyx_nargs) {
        case  3: values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
        CYTHON_FALLTHROUGH;
        case  2: values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
        CYTHON_FALLTHROUGH;
        case  1: values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = __Pyx_NumKwargs_FASTCALL(__pyx_kwds);
      switch (__pyx_nargs) {
        case  0:
        if (likely((values[0] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_type)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[0]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else goto __pyx_L5_argtuple_error;
        CYTHON_FALLTHROUGH;
        case  1:
        if (likely((values[1] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_checksum)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[1]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_HashTable", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
        }
        CYTHON_FALLTHROUGH;
        case  2:
        if (likely((values[2] = __Pyx_GetKwValue_FASTCALL(__pyx_kwds, __pyx_kwvalues, __pyx_n_s_pyx_state)) != 0)) {
          (void)__Pyx_Arg_NewRef_FASTCALL(values[2]);
          kw_args--;
        }
        else if (unlikely(PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
        else {
          __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_HashTable", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
        }
      }
      if (unlikely(kw_args > 0)) {
        const Py_ssize_t kwd_pos_args = __pyx_nargs;
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_kwvalues, __pyx_pyargnames, 0, values + 0, kwd_pos_args, "__pyx_unpickle_HashTable") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
      }
    } else if (unlikely(__pyx_nargs != 3)) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = __Pyx_Arg_FASTCALL(__pyx_args, 0);
      values[1] = __Pyx_Arg_FASTCALL(__pyx_args, 1);
      values[2] = __Pyx_Arg_FASTCALL(__pyx_args, 2);
    }
    __pyx_v___pyx_type = values[0];
    __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
    __pyx_v___pyx_state = values[2];
  }
  goto __pyx_L6_skip;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_HashTable", 1, 3, 3, __pyx_nargs); __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_L6_skip:;
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_unpickle_HashTable", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_6pandas_5_libs_9hashtable_18__pyx_unpickle_HashTable(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

  /* function exit code */
  {
    Py_ssize_t __pyx_temp;
    for (__pyx_temp=0; __pyx_temp < (Py_ssize_t)(sizeof(values)/sizeof(values[0])); ++__pyx_temp) {
      __Pyx_Arg_XDECREF_FASTCALL(values[__pyx_temp]);
    }
  }
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_6pandas_5_libs_9hashtable_18__pyx_unpickle_HashTable(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_v___pyx_PickleError = 0;
  PyObject *__pyx_v___pyx_result = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_HashTable", 1);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0xe3b0c44, 0xda39a3e, 0xd41d8cd):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 */
  __pyx_t_1 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = (__Pyx_PySequence_ContainsTF(__pyx_t_1, __pyx_tuple__102, Py_NE)); if (unlikely((__pyx_t_2 < 0))) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_2) {

    /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0xe3b0c44, 0xda39a3e, 0xd41d8cd):
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 *     __pyx_result = HashTable.__new__(__pyx_type)
 */
    __pyx_t_1 = PyList_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_n_s_PickleError);
    __Pyx_GIVEREF(__pyx_n_s_PickleError);
    if (__Pyx_PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_PickleError)) __PYX_ERR(1, 5, __pyx_L1_error);
    __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_1, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_1);
    __pyx_v___pyx_PickleError = __pyx_t_1;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "(tree fragment)":6
 *     if __pyx_checksum not in (0xe3b0c44, 0xda39a3e, 0xd41d8cd):
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum             # <<<<<<<<<<<<<<
 *     __pyx_result = HashTable.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
    __pyx_t_3 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_0x_x_vs_0_2, __pyx_t_3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_v___pyx_PickleError, __pyx_t_1, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __PYX_ERR(1, 6, __pyx_L1_error)

    /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0xe3b0c44, 0xda39a3e, 0xd41d8cd):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 */
  }

  /* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 *     __pyx_result = HashTable.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_HashTable__set_state(<HashTable> __pyx_result, __pyx_state)
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_HashTable), __pyx_n_s_new); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  __pyx_t_5 = 0;
  #if CYTHON_UNPACK_METHODS
  if (likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
      __pyx_t_5 = 1;
    }
  }
  #endif
  {
    PyObject *__pyx_callargs[2] = {__pyx_t_4, __pyx_v___pyx_type};
    __pyx_t_1 = __Pyx_PyObject_FastCall(__pyx_t_3, __pyx_callargs+1-__pyx_t_5, 1+__pyx_t_5);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 7, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  }
  __pyx_v___pyx_result = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 *     __pyx_result = HashTable.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_HashTable__set_state(<HashTable> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  __pyx_t_2 = (__pyx_v___pyx_state != Py_None);
  if (__pyx_t_2) {

    /* "(tree fragment)":9
 *     __pyx_result = HashTable.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_HashTable__set_state(<HashTable> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_HashTable__set_state(HashTable __pyx_result, tuple __pyx_state):
 */
    if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None) || __Pyx_RaiseUnexpectedTypeError("tuple", __pyx_v___pyx_state))) __PYX_ERR(1, 9, __pyx_L1_error)
    __pyx_t_1 = __pyx_f_6pandas_5_libs_9hashtable___pyx_unpickle_HashTable__set_state(((struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 9, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "(tree fragment)":8
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 *     __pyx_result = HashTable.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_HashTable__set_state(<HashTable> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
  }

  /* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_HashTable__set_state(<HashTable> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_HashTable__set_state(HashTable __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v___pyx_result);
  __pyx_r = __pyx_v___pyx_result;
  goto __pyx_L0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_HashTable(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_unpickle_HashTable", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v___pyx_PickleError);
  __Pyx_XDECREF(__pyx_v___pyx_result);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_HashTable__set_state(<HashTable> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_HashTable__set_state(HashTable __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */

static PyObject *__pyx_f_6pandas_5_libs_9hashtable___pyx_unpickle_HashTable__set_state(struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__pyx_unpickle_HashTable__set_state", 1);

  /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_HashTable__set_state(HashTable __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(1, 12, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_t_3 = (__pyx_t_2 > 0);
  if (__pyx_t_3) {
  } else {
    __pyx_t_1 = __pyx_t_3;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_3 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_3 == ((int)-1))) __PYX_ERR(1, 12, __pyx_L1_error)
  __pyx_t_1 = __pyx_t_3;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "(tree fragment)":13
 * cdef __pyx_unpickle_HashTable__set_state(HashTable __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])             # <<<<<<<<<<<<<<
 */
    __pyx_t_5 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_update); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(__pyx_v___pyx_state == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(1, 13, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 13, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = NULL;
    __pyx_t_8 = 0;
    #if CYTHON_UNPACK_METHODS
    if (likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
        __pyx_t_8 = 1;
      }
    }
    #endif
    {
      PyObject *__pyx_callargs[2] = {__pyx_t_7, __pyx_t_5};
      __pyx_t_4 = __Pyx_PyObject_FastCall(__pyx_t_6, __pyx_callargs+1-__pyx_t_8, 1+__pyx_t_8);
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_HashTable__set_state(HashTable __pyx_result, tuple __pyx_state):
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */
  }

  /* "(tree fragment)":11
 *         __pyx_unpickle_HashTable__set_state(<HashTable> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_HashTable__set_state(HashTable __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 0 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[0])
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("pandas._libs.hashtable.__pyx_unpickle_HashTable__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_HashTable(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  return o;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_HashTable(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_HashTable) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
  (*Py_TYPE(o)->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_HashTable[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_9HashTable_1__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_9HashTable_3__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_HashTable_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_HashTable},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_HashTable},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_HashTable},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_HashTable_spec = {
  "pandas._libs.hashtable.HashTable",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6pandas_5_libs_9hashtable_HashTable_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_HashTable = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""HashTable", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_HashTable), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_HashTable, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_HashTable, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_HashTable, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt64HashTable __pyx_vtable_6pandas_5_libs_9hashtable_UInt64HashTable;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt64HashTable(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_HashTable(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt64HashTable;
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt64HashTable(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt64HashTable) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_5__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_HashTable(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_UInt64HashTable[] = {
  {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt64HashTable_8sizeof},
  {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt64HashTable_10get_state},
  {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_21map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_23lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_25_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt64HashTable_24_unique},
  {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_27unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt64HashTable_26unique},
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_29factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt64HashTable_28factorize},
  {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_31get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_33__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_35__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_UInt64HashTable_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt64HashTable},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_3__len__},
  {Py_sq_contains, (void *)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_7__contains__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_3__len__},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_UInt64HashTable},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_UInt64HashTable},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_UInt64HashTable_spec = {
  "pandas._libs.hashtable.UInt64HashTable",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6pandas_5_libs_9hashtable_UInt64HashTable_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_UInt64HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_3__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  __pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_7__contains__, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_UInt64HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_15UInt64HashTable_3__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_UInt64HashTable = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""UInt64HashTable", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt64HashTable, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_UInt64HashTable, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_UInt64HashTable, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_UInt64HashTable, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_UInt64HashTable, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int64HashTable __pyx_vtable_6pandas_5_libs_9hashtable_Int64HashTable;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int64HashTable(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_HashTable(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_Int64HashTable;
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int64HashTable(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int64HashTable) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_5__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_HashTable(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Int64HashTable[] = {
  {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int64HashTable_8sizeof},
  {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int64HashTable_10get_state},
  {"map_keys_to_values", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_21map_keys_to_values, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_23map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_25lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_27_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int64HashTable_26_unique},
  {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_29unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int64HashTable_28unique},
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_31factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int64HashTable_30factorize},
  {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_33get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_labels_groupby", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_35get_labels_groupby, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_37__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_39__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Int64HashTable_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int64HashTable},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_3__len__},
  {Py_sq_contains, (void *)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_7__contains__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_3__len__},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Int64HashTable},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Int64HashTable},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Int64HashTable_spec = {
  "pandas._libs.hashtable.Int64HashTable",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6pandas_5_libs_9hashtable_Int64HashTable_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_Int64HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_3__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  __pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_7__contains__, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Int64HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_14Int64HashTable_3__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Int64HashTable = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Int64HashTable", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int64HashTable, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Int64HashTable, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Int64HashTable, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Int64HashTable, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Int64HashTable, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt32HashTable __pyx_vtable_6pandas_5_libs_9hashtable_UInt32HashTable;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt32HashTable(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_HashTable(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt32HashTable;
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt32HashTable(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt32HashTable) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_5__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_HashTable(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_UInt32HashTable[] = {
  {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt32HashTable_8sizeof},
  {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt32HashTable_10get_state},
  {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_21map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_23lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_25_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt32HashTable_24_unique},
  {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_27unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt32HashTable_26unique},
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_29factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt32HashTable_28factorize},
  {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_31get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_33__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_35__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_UInt32HashTable_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt32HashTable},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_3__len__},
  {Py_sq_contains, (void *)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_7__contains__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_3__len__},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_UInt32HashTable},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_UInt32HashTable},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_UInt32HashTable_spec = {
  "pandas._libs.hashtable.UInt32HashTable",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6pandas_5_libs_9hashtable_UInt32HashTable_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_UInt32HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_3__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  __pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_7__contains__, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_UInt32HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_15UInt32HashTable_3__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_UInt32HashTable = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""UInt32HashTable", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt32HashTable, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_UInt32HashTable, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_UInt32HashTable, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_UInt32HashTable, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_UInt32HashTable, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int32HashTable __pyx_vtable_6pandas_5_libs_9hashtable_Int32HashTable;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int32HashTable(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_HashTable(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_Int32HashTable;
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int32HashTable(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int32HashTable) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_5__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_HashTable(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Int32HashTable[] = {
  {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int32HashTable_8sizeof},
  {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int32HashTable_10get_state},
  {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_21map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_23lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_25_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int32HashTable_24_unique},
  {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_27unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int32HashTable_26unique},
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_29factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int32HashTable_28factorize},
  {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_31get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_33__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_35__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Int32HashTable_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int32HashTable},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_3__len__},
  {Py_sq_contains, (void *)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_7__contains__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_3__len__},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Int32HashTable},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Int32HashTable},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Int32HashTable_spec = {
  "pandas._libs.hashtable.Int32HashTable",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6pandas_5_libs_9hashtable_Int32HashTable_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_Int32HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_3__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  __pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_7__contains__, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Int32HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_14Int32HashTable_3__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Int32HashTable = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Int32HashTable", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int32HashTable, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Int32HashTable, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Int32HashTable, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Int32HashTable, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Int32HashTable, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt16HashTable __pyx_vtable_6pandas_5_libs_9hashtable_UInt16HashTable;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt16HashTable(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_HashTable(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt16HashTable;
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt16HashTable(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt16HashTable) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_5__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_HashTable(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_UInt16HashTable[] = {
  {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt16HashTable_8sizeof},
  {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt16HashTable_10get_state},
  {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_21map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_23lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_25_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt16HashTable_24_unique},
  {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_27unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt16HashTable_26unique},
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_29factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt16HashTable_28factorize},
  {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_31get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_33__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_35__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_UInt16HashTable_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt16HashTable},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_3__len__},
  {Py_sq_contains, (void *)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_7__contains__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_3__len__},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_UInt16HashTable},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_UInt16HashTable},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_UInt16HashTable_spec = {
  "pandas._libs.hashtable.UInt16HashTable",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6pandas_5_libs_9hashtable_UInt16HashTable_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_UInt16HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_3__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  __pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_7__contains__, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_UInt16HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_15UInt16HashTable_3__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_UInt16HashTable = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""UInt16HashTable", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt16HashTable, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_UInt16HashTable, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_UInt16HashTable, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_UInt16HashTable, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_UInt16HashTable, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int16HashTable __pyx_vtable_6pandas_5_libs_9hashtable_Int16HashTable;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int16HashTable(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_HashTable(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_Int16HashTable;
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int16HashTable(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int16HashTable) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_5__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_HashTable(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Int16HashTable[] = {
  {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int16HashTable_8sizeof},
  {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int16HashTable_10get_state},
  {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_21map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_23lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_25_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int16HashTable_24_unique},
  {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_27unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int16HashTable_26unique},
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_29factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int16HashTable_28factorize},
  {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_31get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_33__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_35__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Int16HashTable_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int16HashTable},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_3__len__},
  {Py_sq_contains, (void *)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_7__contains__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_3__len__},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Int16HashTable},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Int16HashTable},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Int16HashTable_spec = {
  "pandas._libs.hashtable.Int16HashTable",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6pandas_5_libs_9hashtable_Int16HashTable_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_Int16HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_3__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  __pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_7__contains__, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Int16HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_14Int16HashTable_3__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Int16HashTable = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Int16HashTable", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int16HashTable, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Int16HashTable, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Int16HashTable, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Int16HashTable, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Int16HashTable, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8HashTable __pyx_vtable_6pandas_5_libs_9hashtable_UInt8HashTable;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt8HashTable(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_HashTable(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt8HashTable;
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt8HashTable(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt8HashTable) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_5__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_HashTable(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_UInt8HashTable[] = {
  {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14UInt8HashTable_8sizeof},
  {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14UInt8HashTable_10get_state},
  {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_21map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_23lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_25_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14UInt8HashTable_24_unique},
  {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_27unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14UInt8HashTable_26unique},
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_29factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14UInt8HashTable_28factorize},
  {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_31get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_33__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_35__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_UInt8HashTable_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt8HashTable},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_3__len__},
  {Py_sq_contains, (void *)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_7__contains__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_3__len__},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_UInt8HashTable},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_UInt8HashTable},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_UInt8HashTable_spec = {
  "pandas._libs.hashtable.UInt8HashTable",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6pandas_5_libs_9hashtable_UInt8HashTable_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_UInt8HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_3__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  __pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_7__contains__, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_UInt8HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_14UInt8HashTable_3__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_UInt8HashTable = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""UInt8HashTable", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt8HashTable, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_UInt8HashTable, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_UInt8HashTable, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_UInt8HashTable, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_UInt8HashTable, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int8HashTable __pyx_vtable_6pandas_5_libs_9hashtable_Int8HashTable;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int8HashTable(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_HashTable(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_Int8HashTable;
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int8HashTable(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int8HashTable) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_5__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_HashTable(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Int8HashTable[] = {
  {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_13Int8HashTable_8sizeof},
  {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_13Int8HashTable_10get_state},
  {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_21map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_23lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_25_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_13Int8HashTable_24_unique},
  {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_27unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_13Int8HashTable_26unique},
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_29factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_13Int8HashTable_28factorize},
  {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_31get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_33__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_35__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Int8HashTable_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int8HashTable},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_3__len__},
  {Py_sq_contains, (void *)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_7__contains__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_3__len__},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Int8HashTable},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Int8HashTable},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Int8HashTable_spec = {
  "pandas._libs.hashtable.Int8HashTable",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6pandas_5_libs_9hashtable_Int8HashTable_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_Int8HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_3__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  __pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_7__contains__, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Int8HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_13Int8HashTable_3__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Int8HashTable = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Int8HashTable", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int8HashTable, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Int8HashTable, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Int8HashTable, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Int8HashTable, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Int8HashTable, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float64HashTable __pyx_vtable_6pandas_5_libs_9hashtable_Float64HashTable;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Float64HashTable(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_HashTable(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_Float64HashTable;
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float64HashTable(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float64HashTable) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_5__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_HashTable(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Float64HashTable[] = {
  {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float64HashTable_8sizeof},
  {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float64HashTable_10get_state},
  {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_21map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_23lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_25_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float64HashTable_24_unique},
  {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_27unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float64HashTable_26unique},
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_29factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float64HashTable_28factorize},
  {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_31get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_33__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_35__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Float64HashTable_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float64HashTable},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_3__len__},
  {Py_sq_contains, (void *)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_7__contains__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_3__len__},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Float64HashTable},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Float64HashTable},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Float64HashTable_spec = {
  "pandas._libs.hashtable.Float64HashTable",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6pandas_5_libs_9hashtable_Float64HashTable_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_Float64HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_3__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  __pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_7__contains__, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Float64HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_16Float64HashTable_3__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Float64HashTable = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Float64HashTable", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float64HashTable, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Float64HashTable, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Float64HashTable, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Float64HashTable, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Float64HashTable, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float32HashTable __pyx_vtable_6pandas_5_libs_9hashtable_Float32HashTable;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Float32HashTable(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_HashTable(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_Float32HashTable;
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float32HashTable(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float32HashTable) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_5__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_HashTable(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Float32HashTable[] = {
  {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float32HashTable_8sizeof},
  {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float32HashTable_10get_state},
  {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_21map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_23lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_25_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float32HashTable_24_unique},
  {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_27unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float32HashTable_26unique},
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_29factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16Float32HashTable_28factorize},
  {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_31get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_33__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_35__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Float32HashTable_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float32HashTable},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_3__len__},
  {Py_sq_contains, (void *)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_7__contains__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_3__len__},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Float32HashTable},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Float32HashTable},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Float32HashTable_spec = {
  "pandas._libs.hashtable.Float32HashTable",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6pandas_5_libs_9hashtable_Float32HashTable_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_Float32HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_3__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  __pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_7__contains__, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Float32HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_16Float32HashTable_3__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Float32HashTable = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Float32HashTable", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float32HashTable, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Float32HashTable, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Float32HashTable, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Float32HashTable, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Float32HashTable, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex64HashTable __pyx_vtable_6pandas_5_libs_9hashtable_Complex64HashTable;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Complex64HashTable(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_HashTable(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_Complex64HashTable;
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex64HashTable(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex64HashTable) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_5__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_HashTable(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Complex64HashTable[] = {
  {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_18Complex64HashTable_8sizeof},
  {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_18Complex64HashTable_10get_state},
  {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_21map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_23lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_25_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_18Complex64HashTable_24_unique},
  {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_27unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_18Complex64HashTable_26unique},
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_29factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_18Complex64HashTable_28factorize},
  {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_31get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_33__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_35__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Complex64HashTable_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex64HashTable},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_3__len__},
  {Py_sq_contains, (void *)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_7__contains__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_3__len__},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Complex64HashTable},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Complex64HashTable},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Complex64HashTable_spec = {
  "pandas._libs.hashtable.Complex64HashTable",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6pandas_5_libs_9hashtable_Complex64HashTable_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_Complex64HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_3__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  __pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_7__contains__, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Complex64HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_18Complex64HashTable_3__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Complex64HashTable = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Complex64HashTable", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex64HashTable, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Complex64HashTable, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Complex64HashTable, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Complex64HashTable, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Complex64HashTable, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex128HashTable __pyx_vtable_6pandas_5_libs_9hashtable_Complex128HashTable;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Complex128HashTable(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_HashTable(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_Complex128HashTable;
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex128HashTable(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex128HashTable) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_5__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_HashTable(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Complex128HashTable[] = {
  {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_19Complex128HashTable_8sizeof},
  {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_19Complex128HashTable_10get_state},
  {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_21map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_23lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_25_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_19Complex128HashTable_24_unique},
  {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_27unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_19Complex128HashTable_26unique},
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_29factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_19Complex128HashTable_28factorize},
  {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_31get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_33__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_35__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Complex128HashTable_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex128HashTable},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_3__len__},
  {Py_sq_contains, (void *)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_7__contains__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_3__len__},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Complex128HashTable},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Complex128HashTable},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Complex128HashTable_spec = {
  "pandas._libs.hashtable.Complex128HashTable",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6pandas_5_libs_9hashtable_Complex128HashTable_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_Complex128HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_3__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  __pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_7__contains__, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Complex128HashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_19Complex128HashTable_3__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Complex128HashTable = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Complex128HashTable", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex128HashTable, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Complex128HashTable, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Complex128HashTable, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Complex128HashTable, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Complex128HashTable, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_PyObjectHashTable __pyx_vtable_6pandas_5_libs_9hashtable_PyObjectHashTable;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_PyObjectHashTable(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_HashTable(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_PyObjectHashTable;
  return o;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_PyObjectHashTable(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_PyObjectHashTable) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_HashTable(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_PyObjectHashTable[] = {
  {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_9sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_17PyObjectHashTable_8sizeof},
  {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_11get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_17PyObjectHashTable_10get_state},
  {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_17map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_19lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_21_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_17PyObjectHashTable_20_unique},
  {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_23unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_17PyObjectHashTable_22unique},
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_25factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_17PyObjectHashTable_24factorize},
  {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_27get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_29__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_31__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_PyObjectHashTable_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_PyObjectHashTable},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_5__len__},
  {Py_sq_contains, (void *)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_7__contains__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_5__len__},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_PyObjectHashTable},
  {Py_tp_init, (void *)__pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_PyObjectHashTable},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_PyObjectHashTable_spec = {
  "pandas._libs.hashtable.PyObjectHashTable",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6pandas_5_libs_9hashtable_PyObjectHashTable_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_PyObjectHashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_5__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  __pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_7__contains__, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_PyObjectHashTable = {
  __pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_5__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_PyObjectHashTable = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""PyObjectHashTable", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_PyObjectHashTable, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_PyObjectHashTable, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_PyObjectHashTable, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_PyObjectHashTable, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pandas_5_libs_9hashtable_17PyObjectHashTable_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_PyObjectHashTable, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_StringHashTable __pyx_vtable_6pandas_5_libs_9hashtable_StringHashTable;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_StringHashTable(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_HashTable(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_StringHashTable;
  return o;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_StringHashTable(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_StringHashTable) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_HashTable(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_StringHashTable[] = {
  {"sizeof", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_5sizeof, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"get_state", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_7get_state, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15StringHashTable_6get_state},
  {"get_indexer", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_13get_indexer, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"lookup", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_15lookup, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"map_locations", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_17map_locations, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"_unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_19_unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15StringHashTable_18_unique},
  {"unique", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_21unique, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15StringHashTable_20unique},
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_23factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15StringHashTable_22factorize},
  {"get_labels", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_25get_labels, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_27__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_29__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_StringHashTable_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_StringHashTable},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_StringHashTable},
  {Py_tp_init, (void *)__pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_1__init__},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_StringHashTable},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_StringHashTable_spec = {
  "pandas._libs.hashtable.StringHashTable",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6pandas_5_libs_9hashtable_StringHashTable_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_StringHashTable = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""StringHashTable", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_StringHashTable, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_StringHashTable, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_pw_6pandas_5_libs_9hashtable_15StringHashTable_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_StringHashTable, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Vector(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_6Vector_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Vector(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Vector) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
  (*Py_TYPE(o)->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Vector[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_6Vector_3__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_6Vector_5__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Vector_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Vector},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Vector},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Vector},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Vector_spec = {
  "pandas._libs.hashtable.Vector",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Vector),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6pandas_5_libs_9hashtable_Vector_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Vector = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Vector", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Vector), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Vector, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Vector, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Vector, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int64Vector __pyx_vtable_6pandas_5_libs_9hashtable_Int64Vector;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int64Vector(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Vector(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_Int64Vector;
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int64Vector(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int64Vector) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->ao);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Vector(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int64Vector(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int64Vector)); if (e) return e;
  if (p->ao) {
    e = (*v)(((PyObject *)p->ao), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_Int64Vector(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_Int64Vector);
  tmp = ((PyObject*)p->ao);
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Int64Vector[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Int64Vector_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int64Vector},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_5__len__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_5__len__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_Int64Vector},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_Int64Vector},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Int64Vector},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Int64Vector},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Int64Vector_spec = {
  "pandas._libs.hashtable.Int64Vector",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_Int64Vector_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_Int64Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_5__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Int64Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_11Int64Vector_5__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Int64Vector = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Int64Vector", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int64Vector, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Int64Vector, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Int64Vector, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int64Vector, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_Int64Vector, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Int64Vector, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Int64Vector, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex128Vector __pyx_vtable_6pandas_5_libs_9hashtable_Complex128Vector;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Complex128Vector(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Vector(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_Complex128Vector;
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex128Vector(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex128Vector) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->ao);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Vector(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_Complex128Vector(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_Complex128Vector)); if (e) return e;
  if (p->ao) {
    e = (*v)(((PyObject *)p->ao), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_Complex128Vector(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_Complex128Vector);
  tmp = ((PyObject*)p->ao);
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Complex128Vector[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Complex128Vector_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex128Vector},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_5__len__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_5__len__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_Complex128Vector},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_Complex128Vector},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Complex128Vector},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Complex128Vector},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Complex128Vector_spec = {
  "pandas._libs.hashtable.Complex128Vector",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_Complex128Vector_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_Complex128Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_5__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Complex128Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_16Complex128Vector_5__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Complex128Vector = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Complex128Vector", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex128Vector, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Complex128Vector, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Complex128Vector, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_Complex128Vector, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_Complex128Vector, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Complex128Vector, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Complex128Vector, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Complex64Vector __pyx_vtable_6pandas_5_libs_9hashtable_Complex64Vector;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Complex64Vector(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Vector(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_Complex64Vector;
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex64Vector(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex64Vector) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->ao);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Vector(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_Complex64Vector(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_Complex64Vector)); if (e) return e;
  if (p->ao) {
    e = (*v)(((PyObject *)p->ao), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_Complex64Vector(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_Complex64Vector);
  tmp = ((PyObject*)p->ao);
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Complex64Vector[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Complex64Vector_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex64Vector},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_5__len__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_5__len__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_Complex64Vector},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_Complex64Vector},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Complex64Vector},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Complex64Vector},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Complex64Vector_spec = {
  "pandas._libs.hashtable.Complex64Vector",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_Complex64Vector_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_Complex64Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_5__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Complex64Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_15Complex64Vector_5__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Complex64Vector = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Complex64Vector", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex64Vector, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Complex64Vector, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Complex64Vector, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_Complex64Vector, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_Complex64Vector, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Complex64Vector, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Complex64Vector, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float64Vector __pyx_vtable_6pandas_5_libs_9hashtable_Float64Vector;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Float64Vector(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Vector(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_Float64Vector;
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float64Vector(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float64Vector) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->ao);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Vector(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_Float64Vector(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_Float64Vector)); if (e) return e;
  if (p->ao) {
    e = (*v)(((PyObject *)p->ao), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_Float64Vector(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_Float64Vector);
  tmp = ((PyObject*)p->ao);
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Float64Vector[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Float64Vector_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float64Vector},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_5__len__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_5__len__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_Float64Vector},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_Float64Vector},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Float64Vector},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Float64Vector},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Float64Vector_spec = {
  "pandas._libs.hashtable.Float64Vector",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_Float64Vector_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_Float64Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_5__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Float64Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_13Float64Vector_5__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Float64Vector = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Float64Vector", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float64Vector, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Float64Vector, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Float64Vector, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_Float64Vector, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_Float64Vector, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Float64Vector, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Float64Vector, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt64Vector __pyx_vtable_6pandas_5_libs_9hashtable_UInt64Vector;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt64Vector(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Vector(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt64Vector;
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt64Vector(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt64Vector) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->ao);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Vector(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt64Vector(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt64Vector)); if (e) return e;
  if (p->ao) {
    e = (*v)(((PyObject *)p->ao), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt64Vector(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt64Vector);
  tmp = ((PyObject*)p->ao);
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_UInt64Vector[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_UInt64Vector_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt64Vector},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_5__len__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_5__len__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt64Vector},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_UInt64Vector},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_UInt64Vector},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_UInt64Vector},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_UInt64Vector_spec = {
  "pandas._libs.hashtable.UInt64Vector",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_UInt64Vector_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_UInt64Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_5__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_UInt64Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_12UInt64Vector_5__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_UInt64Vector = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""UInt64Vector", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt64Vector, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_UInt64Vector, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_UInt64Vector, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt64Vector, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt64Vector, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_UInt64Vector, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_UInt64Vector, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Float32Vector __pyx_vtable_6pandas_5_libs_9hashtable_Float32Vector;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Float32Vector(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Vector(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_Float32Vector;
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float32Vector(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float32Vector) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->ao);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Vector(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_Float32Vector(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_Float32Vector)); if (e) return e;
  if (p->ao) {
    e = (*v)(((PyObject *)p->ao), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_Float32Vector(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_Float32Vector);
  tmp = ((PyObject*)p->ao);
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Float32Vector[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Float32Vector_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float32Vector},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_5__len__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_5__len__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_Float32Vector},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_Float32Vector},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Float32Vector},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Float32Vector},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Float32Vector_spec = {
  "pandas._libs.hashtable.Float32Vector",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_Float32Vector_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_Float32Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_5__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Float32Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_13Float32Vector_5__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Float32Vector = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Float32Vector", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float32Vector, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Float32Vector, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Float32Vector, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_Float32Vector, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_Float32Vector, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Float32Vector, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Float32Vector, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt32Vector __pyx_vtable_6pandas_5_libs_9hashtable_UInt32Vector;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt32Vector(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Vector(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt32Vector;
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt32Vector(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt32Vector) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->ao);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Vector(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt32Vector(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt32Vector)); if (e) return e;
  if (p->ao) {
    e = (*v)(((PyObject *)p->ao), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt32Vector(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt32Vector);
  tmp = ((PyObject*)p->ao);
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_UInt32Vector[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_UInt32Vector_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt32Vector},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_5__len__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_5__len__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt32Vector},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_UInt32Vector},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_UInt32Vector},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_UInt32Vector},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_UInt32Vector_spec = {
  "pandas._libs.hashtable.UInt32Vector",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_UInt32Vector_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_UInt32Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_5__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_UInt32Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_12UInt32Vector_5__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_UInt32Vector = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""UInt32Vector", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt32Vector, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_UInt32Vector, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_UInt32Vector, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt32Vector, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt32Vector, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_UInt32Vector, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_UInt32Vector, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int32Vector __pyx_vtable_6pandas_5_libs_9hashtable_Int32Vector;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int32Vector(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Vector(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_Int32Vector;
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int32Vector(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int32Vector) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->ao);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Vector(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int32Vector(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int32Vector)); if (e) return e;
  if (p->ao) {
    e = (*v)(((PyObject *)p->ao), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_Int32Vector(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_Int32Vector);
  tmp = ((PyObject*)p->ao);
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Int32Vector[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Int32Vector_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int32Vector},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_5__len__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_5__len__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_Int32Vector},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_Int32Vector},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Int32Vector},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Int32Vector},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Int32Vector_spec = {
  "pandas._libs.hashtable.Int32Vector",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_Int32Vector_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_Int32Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_5__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Int32Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_11Int32Vector_5__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Int32Vector = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Int32Vector", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int32Vector, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Int32Vector, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Int32Vector, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int32Vector, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_Int32Vector, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Int32Vector, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Int32Vector, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt16Vector __pyx_vtable_6pandas_5_libs_9hashtable_UInt16Vector;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt16Vector(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Vector(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt16Vector;
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt16Vector(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt16Vector) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->ao);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Vector(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt16Vector(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt16Vector)); if (e) return e;
  if (p->ao) {
    e = (*v)(((PyObject *)p->ao), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt16Vector(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt16Vector);
  tmp = ((PyObject*)p->ao);
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_UInt16Vector[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_UInt16Vector_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt16Vector},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_5__len__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_5__len__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt16Vector},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_UInt16Vector},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_UInt16Vector},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_UInt16Vector},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_UInt16Vector_spec = {
  "pandas._libs.hashtable.UInt16Vector",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_UInt16Vector_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_UInt16Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_5__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_UInt16Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_12UInt16Vector_5__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_UInt16Vector = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""UInt16Vector", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt16Vector, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_UInt16Vector, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_UInt16Vector, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt16Vector, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt16Vector, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_UInt16Vector, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_UInt16Vector, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int16Vector __pyx_vtable_6pandas_5_libs_9hashtable_Int16Vector;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int16Vector(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Vector(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_Int16Vector;
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int16Vector(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int16Vector) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->ao);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Vector(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int16Vector(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int16Vector)); if (e) return e;
  if (p->ao) {
    e = (*v)(((PyObject *)p->ao), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_Int16Vector(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_Int16Vector);
  tmp = ((PyObject*)p->ao);
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Int16Vector[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Int16Vector_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int16Vector},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_5__len__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_5__len__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_Int16Vector},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_Int16Vector},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Int16Vector},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Int16Vector},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Int16Vector_spec = {
  "pandas._libs.hashtable.Int16Vector",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_Int16Vector_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_Int16Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_5__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Int16Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_11Int16Vector_5__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Int16Vector = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Int16Vector", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int16Vector, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Int16Vector, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Int16Vector, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int16Vector, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_Int16Vector, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Int16Vector, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Int16Vector, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_UInt8Vector __pyx_vtable_6pandas_5_libs_9hashtable_UInt8Vector;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt8Vector(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Vector(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt8Vector;
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt8Vector(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt8Vector) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->ao);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Vector(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt8Vector(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt8Vector)); if (e) return e;
  if (p->ao) {
    e = (*v)(((PyObject *)p->ao), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt8Vector(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt8Vector);
  tmp = ((PyObject*)p->ao);
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_UInt8Vector[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_UInt8Vector_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt8Vector},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_5__len__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_5__len__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt8Vector},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_UInt8Vector},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_UInt8Vector},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_UInt8Vector},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_UInt8Vector_spec = {
  "pandas._libs.hashtable.UInt8Vector",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_UInt8Vector_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_UInt8Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_5__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_UInt8Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_11UInt8Vector_5__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_UInt8Vector = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""UInt8Vector", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt8Vector, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_UInt8Vector, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_UInt8Vector, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt8Vector, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt8Vector, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_UInt8Vector, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_UInt8Vector, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_Int8Vector __pyx_vtable_6pandas_5_libs_9hashtable_Int8Vector;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int8Vector(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Vector(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_Int8Vector;
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int8Vector(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int8Vector) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->ao);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Vector(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int8Vector(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int8Vector)); if (e) return e;
  if (p->ao) {
    e = (*v)(((PyObject *)p->ao), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_Int8Vector(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_Int8Vector);
  tmp = ((PyObject*)p->ao);
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Int8Vector[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Int8Vector_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int8Vector},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_5__len__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_5__len__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_Int8Vector},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_Int8Vector},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Int8Vector},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Int8Vector},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Int8Vector_spec = {
  "pandas._libs.hashtable.Int8Vector",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_Int8Vector_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_Int8Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_5__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Int8Vector = {
  __pyx_pw_6pandas_5_libs_9hashtable_10Int8Vector_5__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Int8Vector = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Int8Vector", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int8Vector, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_Int8Vector, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Int8Vector, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int8Vector, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_Int8Vector, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Int8Vector, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Int8Vector, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_StringVector __pyx_vtable_6pandas_5_libs_9hashtable_StringVector;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_StringVector(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Vector(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_StringVector;
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_12StringVector_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_StringVector(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_StringVector) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_pw_6pandas_5_libs_9hashtable_12StringVector_3__dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Vector(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_StringVector[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12StringVector_9__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12StringVector_11__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_StringVector_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_StringVector},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_12StringVector_5__len__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_12StringVector_5__len__},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_StringVector},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_StringVector},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_StringVector_spec = {
  "pandas._libs.hashtable.StringVector",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6pandas_5_libs_9hashtable_StringVector_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_StringVector = {
  __pyx_pw_6pandas_5_libs_9hashtable_12StringVector_5__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_StringVector = {
  __pyx_pw_6pandas_5_libs_9hashtable_12StringVector_5__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_StringVector = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""StringVector", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_StringVector, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_StringVector, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_StringVector, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_StringVector, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_StringVector, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_6pandas_5_libs_9hashtable_ObjectVector __pyx_vtable_6pandas_5_libs_9hashtable_ObjectVector;

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_ObjectVector(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Vector(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)o);
  p->__pyx_vtab = __pyx_vtabptr_6pandas_5_libs_9hashtable_ObjectVector;
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_12ObjectVector_1__cinit__(o, __pyx_empty_tuple, NULL) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_ObjectVector(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_ObjectVector) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->ao);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Vector(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_ObjectVector(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_ObjectVector)); if (e) return e;
  if (p->ao) {
    e = (*v)(((PyObject *)p->ao), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_ObjectVector(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_ObjectVector);
  tmp = ((PyObject*)p->ao);
  p->ao = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_ObjectVector[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12ObjectVector_7__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_12ObjectVector_9__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_ObjectVector_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_ObjectVector},
  {Py_sq_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_12ObjectVector_3__len__},
  {Py_mp_length, (void *)__pyx_pw_6pandas_5_libs_9hashtable_12ObjectVector_3__len__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_ObjectVector},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_ObjectVector},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_ObjectVector},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_ObjectVector},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_ObjectVector_spec = {
  "pandas._libs.hashtable.ObjectVector",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_ObjectVector_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_ObjectVector = {
  __pyx_pw_6pandas_5_libs_9hashtable_12ObjectVector_3__len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_ObjectVector = {
  __pyx_pw_6pandas_5_libs_9hashtable_12ObjectVector_3__len__, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_ObjectVector = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""ObjectVector", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_ObjectVector, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_ObjectVector, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_ObjectVector, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_ObjectVector, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_ObjectVector, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_ObjectVector, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_ObjectVector, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Factorizer(PyTypeObject *t, PyObject *a, PyObject *k) {
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_10Factorizer_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Factorizer(PyObject *o) {
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Factorizer) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
  (*Py_TYPE(o)->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_10Factorizer_count(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_10Factorizer_5count_1__get__(o);
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Factorizer[] = {
  {"get_count", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_10Factorizer_3get_count, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_10Factorizer_5factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_10Factorizer_7__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_10Factorizer_9__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_9hashtable_Factorizer[] = {
  {(char *)"count", __pyx_getprop_6pandas_5_libs_9hashtable_10Factorizer_count, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Factorizer_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Factorizer},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Factorizer},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_9hashtable_Factorizer},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Factorizer},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Factorizer_spec = {
  "pandas._libs.hashtable.Factorizer",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE,
  __pyx_type_6pandas_5_libs_9hashtable_Factorizer_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Factorizer = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Factorizer", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Factorizer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Factorizer, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Factorizer, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_9hashtable_Factorizer, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Factorizer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int8Factorizer(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Factorizer(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *)o);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)Py_None); Py_INCREF(Py_None);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int8Factorizer(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int8Factorizer) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->table);
  Py_CLEAR(p->uniques);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Factorizer(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int8Factorizer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int8Factorizer)); if (e) return e;
  if (p->table) {
    e = (*v)(((PyObject *)p->table), a); if (e) return e;
  }
  if (p->uniques) {
    e = (*v)(((PyObject *)p->uniques), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_Int8Factorizer(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_Int8Factorizer);
  tmp = ((PyObject*)p->table);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->uniques);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_14Int8Factorizer_table(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_5table_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_14Int8Factorizer_table(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_5table_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_5table_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_14Int8Factorizer_uniques(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_7uniques_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_14Int8Factorizer_uniques(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_7uniques_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_7uniques_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Int8Factorizer[] = {
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_14Int8Factorizer_2factorize},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_14Int8Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_9hashtable_Int8Factorizer[] = {
  {(char *)"table", __pyx_getprop_6pandas_5_libs_9hashtable_14Int8Factorizer_table, __pyx_setprop_6pandas_5_libs_9hashtable_14Int8Factorizer_table, (char *)0, 0},
  {(char *)"uniques", __pyx_getprop_6pandas_5_libs_9hashtable_14Int8Factorizer_uniques, __pyx_setprop_6pandas_5_libs_9hashtable_14Int8Factorizer_uniques, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Int8Factorizer_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int8Factorizer},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_Int8Factorizer},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_Int8Factorizer},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Int8Factorizer},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_9hashtable_Int8Factorizer},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Int8Factorizer},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Int8Factorizer_spec = {
  "pandas._libs.hashtable.Int8Factorizer",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_Int8Factorizer_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Int8Factorizer = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Int8Factorizer", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Factorizer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int8Factorizer, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int8Factorizer, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_Int8Factorizer, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Int8Factorizer, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_9hashtable_Int8Factorizer, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Int8Factorizer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt8Factorizer(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Factorizer(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *)o);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)Py_None); Py_INCREF(Py_None);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt8Factorizer(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt8Factorizer) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->table);
  Py_CLEAR(p->uniques);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Factorizer(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt8Factorizer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt8Factorizer)); if (e) return e;
  if (p->table) {
    e = (*v)(((PyObject *)p->table), a); if (e) return e;
  }
  if (p->uniques) {
    e = (*v)(((PyObject *)p->uniques), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt8Factorizer(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt8Factorizer);
  tmp = ((PyObject*)p->table);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->uniques);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_15UInt8Factorizer_table(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_5table_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_15UInt8Factorizer_table(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_5table_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_5table_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_15UInt8Factorizer_uniques(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_7uniques_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_15UInt8Factorizer_uniques(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_7uniques_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_7uniques_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_UInt8Factorizer[] = {
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15UInt8Factorizer_2factorize},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15UInt8Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_9hashtable_UInt8Factorizer[] = {
  {(char *)"table", __pyx_getprop_6pandas_5_libs_9hashtable_15UInt8Factorizer_table, __pyx_setprop_6pandas_5_libs_9hashtable_15UInt8Factorizer_table, (char *)0, 0},
  {(char *)"uniques", __pyx_getprop_6pandas_5_libs_9hashtable_15UInt8Factorizer_uniques, __pyx_setprop_6pandas_5_libs_9hashtable_15UInt8Factorizer_uniques, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_UInt8Factorizer_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt8Factorizer},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt8Factorizer},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_UInt8Factorizer},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_UInt8Factorizer},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_9hashtable_UInt8Factorizer},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_UInt8Factorizer},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_UInt8Factorizer_spec = {
  "pandas._libs.hashtable.UInt8Factorizer",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_UInt8Factorizer_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_UInt8Factorizer = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""UInt8Factorizer", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Factorizer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt8Factorizer, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt8Factorizer, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt8Factorizer, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_UInt8Factorizer, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_9hashtable_UInt8Factorizer, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_UInt8Factorizer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int16Factorizer(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Factorizer(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *)o);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)Py_None); Py_INCREF(Py_None);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int16Factorizer(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int16Factorizer) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->table);
  Py_CLEAR(p->uniques);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Factorizer(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int16Factorizer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int16Factorizer)); if (e) return e;
  if (p->table) {
    e = (*v)(((PyObject *)p->table), a); if (e) return e;
  }
  if (p->uniques) {
    e = (*v)(((PyObject *)p->uniques), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_Int16Factorizer(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_Int16Factorizer);
  tmp = ((PyObject*)p->table);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->uniques);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_15Int16Factorizer_table(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_5table_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_15Int16Factorizer_table(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_5table_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_5table_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_15Int16Factorizer_uniques(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_7uniques_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_15Int16Factorizer_uniques(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_7uniques_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_7uniques_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Int16Factorizer[] = {
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15Int16Factorizer_2factorize},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15Int16Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_9hashtable_Int16Factorizer[] = {
  {(char *)"table", __pyx_getprop_6pandas_5_libs_9hashtable_15Int16Factorizer_table, __pyx_setprop_6pandas_5_libs_9hashtable_15Int16Factorizer_table, (char *)0, 0},
  {(char *)"uniques", __pyx_getprop_6pandas_5_libs_9hashtable_15Int16Factorizer_uniques, __pyx_setprop_6pandas_5_libs_9hashtable_15Int16Factorizer_uniques, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Int16Factorizer_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int16Factorizer},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_Int16Factorizer},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_Int16Factorizer},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Int16Factorizer},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_9hashtable_Int16Factorizer},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Int16Factorizer},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Int16Factorizer_spec = {
  "pandas._libs.hashtable.Int16Factorizer",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_Int16Factorizer_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Int16Factorizer = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Int16Factorizer", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Factorizer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int16Factorizer, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int16Factorizer, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_Int16Factorizer, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Int16Factorizer, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_9hashtable_Int16Factorizer, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Int16Factorizer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt16Factorizer(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Factorizer(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *)o);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)Py_None); Py_INCREF(Py_None);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt16Factorizer(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt16Factorizer) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->table);
  Py_CLEAR(p->uniques);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Factorizer(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt16Factorizer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt16Factorizer)); if (e) return e;
  if (p->table) {
    e = (*v)(((PyObject *)p->table), a); if (e) return e;
  }
  if (p->uniques) {
    e = (*v)(((PyObject *)p->uniques), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt16Factorizer(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt16Factorizer);
  tmp = ((PyObject*)p->table);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->uniques);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_16UInt16Factorizer_table(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_5table_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_16UInt16Factorizer_table(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_5table_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_5table_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_16UInt16Factorizer_uniques(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_7uniques_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_16UInt16Factorizer_uniques(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_7uniques_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_7uniques_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_UInt16Factorizer[] = {
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16UInt16Factorizer_2factorize},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16UInt16Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_9hashtable_UInt16Factorizer[] = {
  {(char *)"table", __pyx_getprop_6pandas_5_libs_9hashtable_16UInt16Factorizer_table, __pyx_setprop_6pandas_5_libs_9hashtable_16UInt16Factorizer_table, (char *)0, 0},
  {(char *)"uniques", __pyx_getprop_6pandas_5_libs_9hashtable_16UInt16Factorizer_uniques, __pyx_setprop_6pandas_5_libs_9hashtable_16UInt16Factorizer_uniques, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_UInt16Factorizer_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt16Factorizer},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt16Factorizer},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_UInt16Factorizer},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_UInt16Factorizer},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_9hashtable_UInt16Factorizer},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_UInt16Factorizer},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_UInt16Factorizer_spec = {
  "pandas._libs.hashtable.UInt16Factorizer",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_UInt16Factorizer_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_UInt16Factorizer = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""UInt16Factorizer", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Factorizer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt16Factorizer, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt16Factorizer, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt16Factorizer, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_UInt16Factorizer, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_9hashtable_UInt16Factorizer, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_UInt16Factorizer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int32Factorizer(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Factorizer(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *)o);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)Py_None); Py_INCREF(Py_None);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int32Factorizer(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int32Factorizer) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->table);
  Py_CLEAR(p->uniques);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Factorizer(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int32Factorizer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int32Factorizer)); if (e) return e;
  if (p->table) {
    e = (*v)(((PyObject *)p->table), a); if (e) return e;
  }
  if (p->uniques) {
    e = (*v)(((PyObject *)p->uniques), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_Int32Factorizer(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_Int32Factorizer);
  tmp = ((PyObject*)p->table);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->uniques);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_15Int32Factorizer_table(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_5table_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_15Int32Factorizer_table(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_5table_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_5table_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_15Int32Factorizer_uniques(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_7uniques_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_15Int32Factorizer_uniques(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_7uniques_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_7uniques_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Int32Factorizer[] = {
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15Int32Factorizer_2factorize},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15Int32Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_9hashtable_Int32Factorizer[] = {
  {(char *)"table", __pyx_getprop_6pandas_5_libs_9hashtable_15Int32Factorizer_table, __pyx_setprop_6pandas_5_libs_9hashtable_15Int32Factorizer_table, (char *)0, 0},
  {(char *)"uniques", __pyx_getprop_6pandas_5_libs_9hashtable_15Int32Factorizer_uniques, __pyx_setprop_6pandas_5_libs_9hashtable_15Int32Factorizer_uniques, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Int32Factorizer_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int32Factorizer},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_Int32Factorizer},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_Int32Factorizer},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Int32Factorizer},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_9hashtable_Int32Factorizer},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Int32Factorizer},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Int32Factorizer_spec = {
  "pandas._libs.hashtable.Int32Factorizer",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_Int32Factorizer_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Int32Factorizer = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Int32Factorizer", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Factorizer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int32Factorizer, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int32Factorizer, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_Int32Factorizer, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Int32Factorizer, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_9hashtable_Int32Factorizer, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Int32Factorizer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt32Factorizer(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Factorizer(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *)o);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)Py_None); Py_INCREF(Py_None);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt32Factorizer(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt32Factorizer) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->table);
  Py_CLEAR(p->uniques);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Factorizer(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt32Factorizer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt32Factorizer)); if (e) return e;
  if (p->table) {
    e = (*v)(((PyObject *)p->table), a); if (e) return e;
  }
  if (p->uniques) {
    e = (*v)(((PyObject *)p->uniques), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt32Factorizer(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt32Factorizer);
  tmp = ((PyObject*)p->table);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->uniques);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_16UInt32Factorizer_table(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_5table_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_16UInt32Factorizer_table(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_5table_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_5table_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_16UInt32Factorizer_uniques(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_7uniques_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_16UInt32Factorizer_uniques(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_7uniques_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_7uniques_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_UInt32Factorizer[] = {
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16UInt32Factorizer_2factorize},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16UInt32Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_9hashtable_UInt32Factorizer[] = {
  {(char *)"table", __pyx_getprop_6pandas_5_libs_9hashtable_16UInt32Factorizer_table, __pyx_setprop_6pandas_5_libs_9hashtable_16UInt32Factorizer_table, (char *)0, 0},
  {(char *)"uniques", __pyx_getprop_6pandas_5_libs_9hashtable_16UInt32Factorizer_uniques, __pyx_setprop_6pandas_5_libs_9hashtable_16UInt32Factorizer_uniques, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_UInt32Factorizer_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt32Factorizer},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt32Factorizer},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_UInt32Factorizer},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_UInt32Factorizer},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_9hashtable_UInt32Factorizer},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_UInt32Factorizer},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_UInt32Factorizer_spec = {
  "pandas._libs.hashtable.UInt32Factorizer",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_UInt32Factorizer_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_UInt32Factorizer = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""UInt32Factorizer", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Factorizer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt32Factorizer, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt32Factorizer, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt32Factorizer, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_UInt32Factorizer, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_9hashtable_UInt32Factorizer, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_UInt32Factorizer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Float32Factorizer(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Factorizer(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *)o);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)Py_None); Py_INCREF(Py_None);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float32Factorizer(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float32Factorizer) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->table);
  Py_CLEAR(p->uniques);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Factorizer(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_Float32Factorizer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_Float32Factorizer)); if (e) return e;
  if (p->table) {
    e = (*v)(((PyObject *)p->table), a); if (e) return e;
  }
  if (p->uniques) {
    e = (*v)(((PyObject *)p->uniques), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_Float32Factorizer(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_Float32Factorizer);
  tmp = ((PyObject*)p->table);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->uniques);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_17Float32Factorizer_table(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_5table_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_17Float32Factorizer_table(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_5table_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_5table_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_17Float32Factorizer_uniques(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_7uniques_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_17Float32Factorizer_uniques(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_7uniques_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_7uniques_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Float32Factorizer[] = {
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_17Float32Factorizer_2factorize},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17Float32Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_9hashtable_Float32Factorizer[] = {
  {(char *)"table", __pyx_getprop_6pandas_5_libs_9hashtable_17Float32Factorizer_table, __pyx_setprop_6pandas_5_libs_9hashtable_17Float32Factorizer_table, (char *)0, 0},
  {(char *)"uniques", __pyx_getprop_6pandas_5_libs_9hashtable_17Float32Factorizer_uniques, __pyx_setprop_6pandas_5_libs_9hashtable_17Float32Factorizer_uniques, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Float32Factorizer_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float32Factorizer},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_Float32Factorizer},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_Float32Factorizer},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Float32Factorizer},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_9hashtable_Float32Factorizer},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Float32Factorizer},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Float32Factorizer_spec = {
  "pandas._libs.hashtable.Float32Factorizer",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_Float32Factorizer_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Float32Factorizer = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Float32Factorizer", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Factorizer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float32Factorizer, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_Float32Factorizer, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_Float32Factorizer, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Float32Factorizer, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_9hashtable_Float32Factorizer, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Float32Factorizer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Complex64Factorizer(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Factorizer(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *)o);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)Py_None); Py_INCREF(Py_None);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex64Factorizer(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex64Factorizer) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->table);
  Py_CLEAR(p->uniques);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Factorizer(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_Complex64Factorizer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_Complex64Factorizer)); if (e) return e;
  if (p->table) {
    e = (*v)(((PyObject *)p->table), a); if (e) return e;
  }
  if (p->uniques) {
    e = (*v)(((PyObject *)p->uniques), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_Complex64Factorizer(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_Complex64Factorizer);
  tmp = ((PyObject*)p->table);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->uniques);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_19Complex64Factorizer_table(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_5table_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_19Complex64Factorizer_table(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_5table_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_5table_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_19Complex64Factorizer_uniques(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_7uniques_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_19Complex64Factorizer_uniques(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_7uniques_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_7uniques_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Complex64Factorizer[] = {
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_19Complex64Factorizer_2factorize},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_19Complex64Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_9hashtable_Complex64Factorizer[] = {
  {(char *)"table", __pyx_getprop_6pandas_5_libs_9hashtable_19Complex64Factorizer_table, __pyx_setprop_6pandas_5_libs_9hashtable_19Complex64Factorizer_table, (char *)0, 0},
  {(char *)"uniques", __pyx_getprop_6pandas_5_libs_9hashtable_19Complex64Factorizer_uniques, __pyx_setprop_6pandas_5_libs_9hashtable_19Complex64Factorizer_uniques, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Complex64Factorizer_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex64Factorizer},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_Complex64Factorizer},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_Complex64Factorizer},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Complex64Factorizer},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_9hashtable_Complex64Factorizer},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Complex64Factorizer},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Complex64Factorizer_spec = {
  "pandas._libs.hashtable.Complex64Factorizer",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_Complex64Factorizer_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Complex64Factorizer = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Complex64Factorizer", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Factorizer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex64Factorizer, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_Complex64Factorizer, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_Complex64Factorizer, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Complex64Factorizer, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_9hashtable_Complex64Factorizer, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Complex64Factorizer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Int64Factorizer(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Factorizer(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *)o);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)Py_None); Py_INCREF(Py_None);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int64Factorizer(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int64Factorizer) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->table);
  Py_CLEAR(p->uniques);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Factorizer(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int64Factorizer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int64Factorizer)); if (e) return e;
  if (p->table) {
    e = (*v)(((PyObject *)p->table), a); if (e) return e;
  }
  if (p->uniques) {
    e = (*v)(((PyObject *)p->uniques), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_Int64Factorizer(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_Int64Factorizer);
  tmp = ((PyObject*)p->table);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->uniques);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_15Int64Factorizer_table(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_5table_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_15Int64Factorizer_table(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_5table_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_5table_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_15Int64Factorizer_uniques(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_7uniques_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_15Int64Factorizer_uniques(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_7uniques_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_7uniques_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Int64Factorizer[] = {
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_15Int64Factorizer_2factorize},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_15Int64Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_9hashtable_Int64Factorizer[] = {
  {(char *)"table", __pyx_getprop_6pandas_5_libs_9hashtable_15Int64Factorizer_table, __pyx_setprop_6pandas_5_libs_9hashtable_15Int64Factorizer_table, (char *)0, 0},
  {(char *)"uniques", __pyx_getprop_6pandas_5_libs_9hashtable_15Int64Factorizer_uniques, __pyx_setprop_6pandas_5_libs_9hashtable_15Int64Factorizer_uniques, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Int64Factorizer_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int64Factorizer},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_Int64Factorizer},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_Int64Factorizer},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Int64Factorizer},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_9hashtable_Int64Factorizer},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Int64Factorizer},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Int64Factorizer_spec = {
  "pandas._libs.hashtable.Int64Factorizer",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_Int64Factorizer_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Int64Factorizer = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Int64Factorizer", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Factorizer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Int64Factorizer, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_Int64Factorizer, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_Int64Factorizer, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Int64Factorizer, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_9hashtable_Int64Factorizer, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Int64Factorizer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_UInt64Factorizer(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Factorizer(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *)o);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)Py_None); Py_INCREF(Py_None);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt64Factorizer(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt64Factorizer) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->table);
  Py_CLEAR(p->uniques);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Factorizer(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt64Factorizer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt64Factorizer)); if (e) return e;
  if (p->table) {
    e = (*v)(((PyObject *)p->table), a); if (e) return e;
  }
  if (p->uniques) {
    e = (*v)(((PyObject *)p->uniques), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt64Factorizer(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt64Factorizer);
  tmp = ((PyObject*)p->table);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->uniques);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_16UInt64Factorizer_table(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_5table_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_16UInt64Factorizer_table(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_5table_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_5table_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_16UInt64Factorizer_uniques(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_7uniques_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_16UInt64Factorizer_uniques(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_7uniques_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_7uniques_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_UInt64Factorizer[] = {
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16UInt64Factorizer_2factorize},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16UInt64Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_9hashtable_UInt64Factorizer[] = {
  {(char *)"table", __pyx_getprop_6pandas_5_libs_9hashtable_16UInt64Factorizer_table, __pyx_setprop_6pandas_5_libs_9hashtable_16UInt64Factorizer_table, (char *)0, 0},
  {(char *)"uniques", __pyx_getprop_6pandas_5_libs_9hashtable_16UInt64Factorizer_uniques, __pyx_setprop_6pandas_5_libs_9hashtable_16UInt64Factorizer_uniques, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_UInt64Factorizer_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt64Factorizer},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt64Factorizer},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_UInt64Factorizer},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_UInt64Factorizer},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_9hashtable_UInt64Factorizer},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_UInt64Factorizer},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_UInt64Factorizer_spec = {
  "pandas._libs.hashtable.UInt64Factorizer",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_UInt64Factorizer_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_UInt64Factorizer = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""UInt64Factorizer", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Factorizer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_UInt64Factorizer, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_UInt64Factorizer, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_UInt64Factorizer, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_UInt64Factorizer, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_9hashtable_UInt64Factorizer, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_UInt64Factorizer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Float64Factorizer(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Factorizer(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *)o);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)Py_None); Py_INCREF(Py_None);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float64Factorizer(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float64Factorizer) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->table);
  Py_CLEAR(p->uniques);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Factorizer(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_Float64Factorizer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_Float64Factorizer)); if (e) return e;
  if (p->table) {
    e = (*v)(((PyObject *)p->table), a); if (e) return e;
  }
  if (p->uniques) {
    e = (*v)(((PyObject *)p->uniques), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_Float64Factorizer(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_Float64Factorizer);
  tmp = ((PyObject*)p->table);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->uniques);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_17Float64Factorizer_table(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_5table_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_17Float64Factorizer_table(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_5table_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_5table_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_17Float64Factorizer_uniques(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_7uniques_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_17Float64Factorizer_uniques(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_7uniques_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_7uniques_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Float64Factorizer[] = {
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_17Float64Factorizer_2factorize},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_17Float64Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_9hashtable_Float64Factorizer[] = {
  {(char *)"table", __pyx_getprop_6pandas_5_libs_9hashtable_17Float64Factorizer_table, __pyx_setprop_6pandas_5_libs_9hashtable_17Float64Factorizer_table, (char *)0, 0},
  {(char *)"uniques", __pyx_getprop_6pandas_5_libs_9hashtable_17Float64Factorizer_uniques, __pyx_setprop_6pandas_5_libs_9hashtable_17Float64Factorizer_uniques, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Float64Factorizer_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float64Factorizer},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_Float64Factorizer},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_Float64Factorizer},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Float64Factorizer},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_9hashtable_Float64Factorizer},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Float64Factorizer},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Float64Factorizer_spec = {
  "pandas._libs.hashtable.Float64Factorizer",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_Float64Factorizer_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Float64Factorizer = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Float64Factorizer", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Factorizer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Float64Factorizer, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_Float64Factorizer, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_Float64Factorizer, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Float64Factorizer, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_9hashtable_Float64Factorizer, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Float64Factorizer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_Complex128Factorizer(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Factorizer(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *)o);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)Py_None); Py_INCREF(Py_None);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex128Factorizer(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex128Factorizer) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->table);
  Py_CLEAR(p->uniques);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Factorizer(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_Complex128Factorizer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_Complex128Factorizer)); if (e) return e;
  if (p->table) {
    e = (*v)(((PyObject *)p->table), a); if (e) return e;
  }
  if (p->uniques) {
    e = (*v)(((PyObject *)p->uniques), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_Complex128Factorizer(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_Complex128Factorizer);
  tmp = ((PyObject*)p->table);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->uniques);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_20Complex128Factorizer_table(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_5table_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_20Complex128Factorizer_table(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_5table_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_5table_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_20Complex128Factorizer_uniques(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_7uniques_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_20Complex128Factorizer_uniques(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_7uniques_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_7uniques_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_Complex128Factorizer[] = {
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_20Complex128Factorizer_2factorize},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_20Complex128Factorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_9hashtable_Complex128Factorizer[] = {
  {(char *)"table", __pyx_getprop_6pandas_5_libs_9hashtable_20Complex128Factorizer_table, __pyx_setprop_6pandas_5_libs_9hashtable_20Complex128Factorizer_table, (char *)0, 0},
  {(char *)"uniques", __pyx_getprop_6pandas_5_libs_9hashtable_20Complex128Factorizer_uniques, __pyx_setprop_6pandas_5_libs_9hashtable_20Complex128Factorizer_uniques, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_Complex128Factorizer_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex128Factorizer},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_Complex128Factorizer},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_Complex128Factorizer},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_Complex128Factorizer},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_9hashtable_Complex128Factorizer},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_Complex128Factorizer},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_Complex128Factorizer_spec = {
  "pandas._libs.hashtable.Complex128Factorizer",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_Complex128Factorizer_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_Complex128Factorizer = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Complex128Factorizer", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Factorizer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Complex128Factorizer, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_Complex128Factorizer, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_Complex128Factorizer, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_Complex128Factorizer, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_9hashtable_Complex128Factorizer, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_Complex128Factorizer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_6pandas_5_libs_9hashtable_ObjectFactorizer(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *p;
  PyObject *o = __pyx_tp_new_6pandas_5_libs_9hashtable_Factorizer(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *)o);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *)Py_None); Py_INCREF(Py_None);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_1__cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_6pandas_5_libs_9hashtable_ObjectFactorizer(PyObject *o) {
  struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_6pandas_5_libs_9hashtable_ObjectFactorizer) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->table);
  Py_CLEAR(p->uniques);
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_Factorizer(o);
}

static int __pyx_tp_traverse_6pandas_5_libs_9hashtable_ObjectFactorizer(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *)o;
  e = ((likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) ? ((__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse) ? __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_traverse(o, v, a) : 0) : __Pyx_call_next_tp_traverse(o, v, a, __pyx_tp_traverse_6pandas_5_libs_9hashtable_ObjectFactorizer)); if (e) return e;
  if (p->table) {
    e = (*v)(((PyObject *)p->table), a); if (e) return e;
  }
  if (p->uniques) {
    e = (*v)(((PyObject *)p->uniques), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_6pandas_5_libs_9hashtable_ObjectFactorizer(PyObject *o) {
  PyObject* tmp;
  struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *p = (struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer *)o;
  if (likely(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) { if (__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear) __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_clear(o); } else __Pyx_call_next_tp_clear(o, __pyx_tp_clear_6pandas_5_libs_9hashtable_ObjectFactorizer);
  tmp = ((PyObject*)p->table);
  p->table = ((struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->uniques);
  p->uniques = ((struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_16ObjectFactorizer_table(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_5table_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_16ObjectFactorizer_table(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_5table_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_5table_5__del__(o);
  }
}

static PyObject *__pyx_getprop_6pandas_5_libs_9hashtable_16ObjectFactorizer_uniques(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_7uniques_1__get__(o);
}

static int __pyx_setprop_6pandas_5_libs_9hashtable_16ObjectFactorizer_uniques(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_7uniques_3__set__(o, v);
  }
  else {
    return __pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_7uniques_5__del__(o);
  }
}

static PyMethodDef __pyx_methods_6pandas_5_libs_9hashtable_ObjectFactorizer[] = {
  {"factorize", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_3factorize, __Pyx_METH_FASTCALL|METH_KEYWORDS, __pyx_doc_6pandas_5_libs_9hashtable_16ObjectFactorizer_2factorize},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_5__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw_6pandas_5_libs_9hashtable_16ObjectFactorizer_7__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_6pandas_5_libs_9hashtable_ObjectFactorizer[] = {
  {(char *)"table", __pyx_getprop_6pandas_5_libs_9hashtable_16ObjectFactorizer_table, __pyx_setprop_6pandas_5_libs_9hashtable_16ObjectFactorizer_table, (char *)0, 0},
  {(char *)"uniques", __pyx_getprop_6pandas_5_libs_9hashtable_16ObjectFactorizer_uniques, __pyx_setprop_6pandas_5_libs_9hashtable_16ObjectFactorizer_uniques, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type_6pandas_5_libs_9hashtable_ObjectFactorizer_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_6pandas_5_libs_9hashtable_ObjectFactorizer},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_6pandas_5_libs_9hashtable_ObjectFactorizer},
  {Py_tp_clear, (void *)__pyx_tp_clear_6pandas_5_libs_9hashtable_ObjectFactorizer},
  {Py_tp_methods, (void *)__pyx_methods_6pandas_5_libs_9hashtable_ObjectFactorizer},
  {Py_tp_getset, (void *)__pyx_getsets_6pandas_5_libs_9hashtable_ObjectFactorizer},
  {Py_tp_new, (void *)__pyx_tp_new_6pandas_5_libs_9hashtable_ObjectFactorizer},
  {0, 0},
};
static PyType_Spec __pyx_type_6pandas_5_libs_9hashtable_ObjectFactorizer_spec = {
  "pandas._libs.hashtable.ObjectFactorizer",
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type_6pandas_5_libs_9hashtable_ObjectFactorizer_slots,
};
#else

static PyTypeObject __pyx_type_6pandas_5_libs_9hashtable_ObjectFactorizer = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""ObjectFactorizer", /*tp_name*/
  sizeof(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectFactorizer), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_6pandas_5_libs_9hashtable_ObjectFactorizer, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_6pandas_5_libs_9hashtable_ObjectFactorizer, /*tp_traverse*/
  __pyx_tp_clear_6pandas_5_libs_9hashtable_ObjectFactorizer, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_6pandas_5_libs_9hashtable_ObjectFactorizer, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_6pandas_5_libs_9hashtable_ObjectFactorizer, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_6pandas_5_libs_9hashtable_ObjectFactorizer, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_array __pyx_vtable_array;

static PyObject *__pyx_tp_new_array(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_array_obj *p;
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  p = ((struct __pyx_array_obj *)o);
  p->__pyx_vtab = __pyx_vtabptr_array;
  p->mode = ((PyObject*)Py_None); Py_INCREF(Py_None);
  p->_format = ((PyObject*)Py_None); Py_INCREF(Py_None);
  if (unlikely(__pyx_array___cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_array(PyObject *o) {
  struct __pyx_array_obj *p = (struct __pyx_array_obj *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && (!PyType_IS_GC(Py_TYPE(o)) || !__Pyx_PyObject_GC_IsFinalized(o))) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_array) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_array___dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->mode);
  Py_CLEAR(p->_format);
  #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
  (*Py_TYPE(o)->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
}
static PyObject *__pyx_sq_item_array(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static int __pyx_mp_ass_subscript_array(PyObject *o, PyObject *i, PyObject *v) {
  if (v) {
    return __pyx_array___setitem__(o, i, v);
  }
  else {
    __Pyx_TypeName o_type_name;
    o_type_name = __Pyx_PyType_GetName(Py_TYPE(o));
    PyErr_Format(PyExc_NotImplementedError,
      "Subscript deletion not supported by " __Pyx_FMT_TYPENAME, o_type_name);
    __Pyx_DECREF_TypeName(o_type_name);
    return -1;
  }
}

static PyObject *__pyx_tp_getattro_array(PyObject *o, PyObject *n) {
  PyObject *v = __Pyx_PyObject_GenericGetAttr(o, n);
  if (!v && PyErr_ExceptionMatches(PyExc_AttributeError)) {
    PyErr_Clear();
    v = __pyx_array___getattr__(o, n);
  }
  return v;
}

static PyObject *__pyx_getprop___pyx_array_memview(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_5array_7memview_1__get__(o);
}

static PyMethodDef __pyx_methods_array[] = {
  {"__getattr__", (PyCFunction)__pyx_array___getattr__, METH_O|METH_COEXIST, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_array_1__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_array_3__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_array[] = {
  {(char *)"memview", __pyx_getprop___pyx_array_memview, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
#if !CYTHON_COMPILING_IN_LIMITED_API

static PyBufferProcs __pyx_tp_as_buffer_array = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  __pyx_array_getbuffer, /*bf_getbuffer*/
  0, /*bf_releasebuffer*/
};
#endif
static PyType_Slot __pyx_type___pyx_array_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_array},
  {Py_sq_length, (void *)__pyx_array___len__},
  {Py_sq_item, (void *)__pyx_sq_item_array},
  {Py_mp_length, (void *)__pyx_array___len__},
  {Py_mp_subscript, (void *)__pyx_array___getitem__},
  {Py_mp_ass_subscript, (void *)__pyx_mp_ass_subscript_array},
  {Py_tp_getattro, (void *)__pyx_tp_getattro_array},
  #if defined(Py_bf_getbuffer)
  {Py_bf_getbuffer, (void *)__pyx_array_getbuffer},
  #endif
  {Py_tp_methods, (void *)__pyx_methods_array},
  {Py_tp_getset, (void *)__pyx_getsets_array},
  {Py_tp_new, (void *)__pyx_tp_new_array},
  {0, 0},
};
static PyType_Spec __pyx_type___pyx_array_spec = {
  "pandas._libs.hashtable.array",
  sizeof(struct __pyx_array_obj),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_SEQUENCE,
  __pyx_type___pyx_array_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_array = {
  __pyx_array___len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_array, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_array = {
  __pyx_array___len__, /*mp_length*/
  __pyx_array___getitem__, /*mp_subscript*/
  __pyx_mp_ass_subscript_array, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_array = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  __pyx_array_getbuffer, /*bf_getbuffer*/
  0, /*bf_releasebuffer*/
};

static PyTypeObject __pyx_type___pyx_array = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""array", /*tp_name*/
  sizeof(struct __pyx_array_obj), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_array, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_array, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_array, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  __pyx_tp_getattro_array, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_array, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_SEQUENCE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_array, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_array, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_array, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyObject *__pyx_tp_new_Enum(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_MemviewEnum_obj *p;
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  p = ((struct __pyx_MemviewEnum_obj *)o);
  p->name = Py_None; Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_Enum(PyObject *o) {
  struct __pyx_MemviewEnum_obj *p = (struct __pyx_MemviewEnum_obj *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_Enum) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->name);
  #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
  (*Py_TYPE(o)->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
}

static int __pyx_tp_traverse_Enum(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_MemviewEnum_obj *p = (struct __pyx_MemviewEnum_obj *)o;
  if (p->name) {
    e = (*v)(p->name, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_Enum(PyObject *o) {
  PyObject* tmp;
  struct __pyx_MemviewEnum_obj *p = (struct __pyx_MemviewEnum_obj *)o;
  tmp = ((PyObject*)p->name);
  p->name = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_specialmethod___pyx_MemviewEnum___repr__(PyObject *self, CYTHON_UNUSED PyObject *arg) {
  return __pyx_MemviewEnum___repr__(self);
}

static PyMethodDef __pyx_methods_Enum[] = {
  {"__repr__", (PyCFunction)__pyx_specialmethod___pyx_MemviewEnum___repr__, METH_NOARGS|METH_COEXIST, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_MemviewEnum_1__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_MemviewEnum_3__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type___pyx_MemviewEnum_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_Enum},
  {Py_tp_repr, (void *)__pyx_MemviewEnum___repr__},
  {Py_tp_traverse, (void *)__pyx_tp_traverse_Enum},
  {Py_tp_clear, (void *)__pyx_tp_clear_Enum},
  {Py_tp_methods, (void *)__pyx_methods_Enum},
  {Py_tp_init, (void *)__pyx_MemviewEnum___init__},
  {Py_tp_new, (void *)__pyx_tp_new_Enum},
  {0, 0},
};
static PyType_Spec __pyx_type___pyx_MemviewEnum_spec = {
  "pandas._libs.hashtable.Enum",
  sizeof(struct __pyx_MemviewEnum_obj),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type___pyx_MemviewEnum_slots,
};
#else

static PyTypeObject __pyx_type___pyx_MemviewEnum = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""Enum", /*tp_name*/
  sizeof(struct __pyx_MemviewEnum_obj), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_Enum, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_MemviewEnum___repr__, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_Enum, /*tp_traverse*/
  __pyx_tp_clear_Enum, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_Enum, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  __pyx_MemviewEnum___init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_Enum, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct_memoryview __pyx_vtable_memoryview;

static PyObject *__pyx_tp_new_memoryview(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_memoryview_obj *p;
  PyObject *o;
  #if CYTHON_COMPILING_IN_LIMITED_API
  allocfunc alloc_func = (allocfunc)PyType_GetSlot(t, Py_tp_alloc);
  o = alloc_func(t, 0);
  #else
  if (likely(!__Pyx_PyType_HasFeature(t, Py_TPFLAGS_IS_ABSTRACT))) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  #endif
  p = ((struct __pyx_memoryview_obj *)o);
  p->__pyx_vtab = __pyx_vtabptr_memoryview;
  p->obj = Py_None; Py_INCREF(Py_None);
  p->_size = Py_None; Py_INCREF(Py_None);
  p->_array_interface = Py_None; Py_INCREF(Py_None);
  p->view.obj = NULL;
  if (unlikely(__pyx_memoryview___cinit__(o, a, k) < 0)) goto bad;
  return o;
  bad:
  Py_DECREF(o); o = 0;
  return NULL;
}

static void __pyx_tp_dealloc_memoryview(PyObject *o) {
  struct __pyx_memoryview_obj *p = (struct __pyx_memoryview_obj *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc_memoryview) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_memoryview___dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->obj);
  Py_CLEAR(p->_size);
  Py_CLEAR(p->_array_interface);
  #if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
  (*Py_TYPE(o)->tp_free)(o);
  #else
  {
    freefunc tp_free = (freefunc)PyType_GetSlot(Py_TYPE(o), Py_tp_free);
    if (tp_free) tp_free(o);
  }
  #endif
}

static int __pyx_tp_traverse_memoryview(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_memoryview_obj *p = (struct __pyx_memoryview_obj *)o;
  if (p->obj) {
    e = (*v)(p->obj, a); if (e) return e;
  }
  if (p->_size) {
    e = (*v)(p->_size, a); if (e) return e;
  }
  if (p->_array_interface) {
    e = (*v)(p->_array_interface, a); if (e) return e;
  }
  if (p->view.obj) {
    e = (*v)(p->view.obj, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_memoryview(PyObject *o) {
  PyObject* tmp;
  struct __pyx_memoryview_obj *p = (struct __pyx_memoryview_obj *)o;
  tmp = ((PyObject*)p->obj);
  p->obj = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_size);
  p->_size = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->_array_interface);
  p->_array_interface = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  Py_CLEAR(p->view.obj);
  return 0;
}
static PyObject *__pyx_sq_item_memoryview(PyObject *o, Py_ssize_t i) {
  PyObject *r;
  PyObject *x = PyInt_FromSsize_t(i); if(!x) return 0;
  r = Py_TYPE(o)->tp_as_mapping->mp_subscript(o, x);
  Py_DECREF(x);
  return r;
}

static int __pyx_mp_ass_subscript_memoryview(PyObject *o, PyObject *i, PyObject *v) {
  if (v) {
    return __pyx_memoryview___setitem__(o, i, v);
  }
  else {
    __Pyx_TypeName o_type_name;
    o_type_name = __Pyx_PyType_GetName(Py_TYPE(o));
    PyErr_Format(PyExc_NotImplementedError,
      "Subscript deletion not supported by " __Pyx_FMT_TYPENAME, o_type_name);
    __Pyx_DECREF_TypeName(o_type_name);
    return -1;
  }
}

static PyObject *__pyx_getprop___pyx_memoryview_T(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_1T_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_base(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_4base_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_shape(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_5shape_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_strides(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_7strides_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_suboffsets(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_10suboffsets_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_ndim(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_4ndim_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_itemsize(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_8itemsize_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_nbytes(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_6nbytes_1__get__(o);
}

static PyObject *__pyx_getprop___pyx_memoryview_size(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_15View_dot_MemoryView_10memoryview_4size_1__get__(o);
}

static PyObject *__pyx_specialmethod___pyx_memoryview___repr__(PyObject *self, CYTHON_UNUSED PyObject *arg) {
  return __pyx_memoryview___repr__(self);
}

static PyMethodDef __pyx_methods_memoryview[] = {
  {"__repr__", (PyCFunction)__pyx_specialmethod___pyx_memoryview___repr__, METH_NOARGS|METH_COEXIST, 0},
  {"is_c_contig", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_memoryview_is_c_contig, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"is_f_contig", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_memoryview_is_f_contig, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"copy", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_memoryview_copy, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"copy_fortran", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_memoryview_copy_fortran, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_memoryview_1__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_memoryview_3__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_memoryview[] = {
  {(char *)"T", __pyx_getprop___pyx_memoryview_T, 0, (char *)0, 0},
  {(char *)"base", __pyx_getprop___pyx_memoryview_base, 0, (char *)0, 0},
  {(char *)"shape", __pyx_getprop___pyx_memoryview_shape, 0, (char *)0, 0},
  {(char *)"strides", __pyx_getprop___pyx_memoryview_strides, 0, (char *)0, 0},
  {(char *)"suboffsets", __pyx_getprop___pyx_memoryview_suboffsets, 0, (char *)0, 0},
  {(char *)"ndim", __pyx_getprop___pyx_memoryview_ndim, 0, (char *)0, 0},
  {(char *)"itemsize", __pyx_getprop___pyx_memoryview_itemsize, 0, (char *)0, 0},
  {(char *)"nbytes", __pyx_getprop___pyx_memoryview_nbytes, 0, (char *)0, 0},
  {(char *)"size", __pyx_getprop___pyx_memoryview_size, 0, (char *)0, 0},
  {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
#if !CYTHON_COMPILING_IN_LIMITED_API

static PyBufferProcs __pyx_tp_as_buffer_memoryview = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  __pyx_memoryview_getbuffer, /*bf_getbuffer*/
  0, /*bf_releasebuffer*/
};
#endif
static PyType_Slot __pyx_type___pyx_memoryview_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc_memoryview},
  {Py_tp_repr, (void *)__pyx_memoryview___repr__},
  {Py_sq_length, (void *)__pyx_memoryview___len__},
  {Py_sq_item, (void *)__pyx_sq_item_memoryview},
  {Py_mp_length, (void *)__pyx_memoryview___len__},
  {Py_mp_subscript, (void *)__pyx_memoryview___getitem__},
  {Py_mp_ass_subscript, (void *)__pyx_mp_ass_subscript_memoryview},
  {Py_tp_str, (void *)__pyx_memoryview___str__},
  #if defined(Py_bf_getbuffer)
  {Py_bf_getbuffer, (void *)__pyx_memoryview_getbuffer},
  #endif
  {Py_tp_traverse, (void *)__pyx_tp_traverse_memoryview},
  {Py_tp_clear, (void *)__pyx_tp_clear_memoryview},
  {Py_tp_methods, (void *)__pyx_methods_memoryview},
  {Py_tp_getset, (void *)__pyx_getsets_memoryview},
  {Py_tp_new, (void *)__pyx_tp_new_memoryview},
  {0, 0},
};
static PyType_Spec __pyx_type___pyx_memoryview_spec = {
  "pandas._libs.hashtable.memoryview",
  sizeof(struct __pyx_memoryview_obj),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
  __pyx_type___pyx_memoryview_slots,
};
#else

static PySequenceMethods __pyx_tp_as_sequence_memoryview = {
  __pyx_memoryview___len__, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  __pyx_sq_item_memoryview, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_memoryview = {
  __pyx_memoryview___len__, /*mp_length*/
  __pyx_memoryview___getitem__, /*mp_subscript*/
  __pyx_mp_ass_subscript_memoryview, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_memoryview = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  __pyx_memoryview_getbuffer, /*bf_getbuffer*/
  0, /*bf_releasebuffer*/
};

static PyTypeObject __pyx_type___pyx_memoryview = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""memoryview", /*tp_name*/
  sizeof(struct __pyx_memoryview_obj), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_memoryview, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  __pyx_memoryview___repr__, /*tp_repr*/
  0, /*tp_as_number*/
  &__pyx_tp_as_sequence_memoryview, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_memoryview, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  __pyx_memoryview___str__, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_memoryview, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_memoryview, /*tp_traverse*/
  __pyx_tp_clear_memoryview, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_memoryview, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_memoryview, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_memoryview, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif
static struct __pyx_vtabstruct__memoryviewslice __pyx_vtable__memoryviewslice;

static PyObject *__pyx_tp_new__memoryviewslice(PyTypeObject *t, PyObject *a, PyObject *k) {
  struct __pyx_memoryviewslice_obj *p;
  PyObject *o = __pyx_tp_new_memoryview(t, a, k);
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_memoryviewslice_obj *)o);
  p->__pyx_base.__pyx_vtab = (struct __pyx_vtabstruct_memoryview*)__pyx_vtabptr__memoryviewslice;
  p->from_object = Py_None; Py_INCREF(Py_None);
  p->from_slice.memview = NULL;
  return o;
}

static void __pyx_tp_dealloc__memoryviewslice(PyObject *o) {
  struct __pyx_memoryviewslice_obj *p = (struct __pyx_memoryviewslice_obj *)o;
  #if CYTHON_USE_TP_FINALIZE
  if (unlikely((PY_VERSION_HEX >= 0x03080000 || __Pyx_PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE)) && __Pyx_PyObject_GetSlot(o, tp_finalize, destructor)) && !__Pyx_PyObject_GC_IsFinalized(o)) {
    if (__Pyx_PyObject_GetSlot(o, tp_dealloc, destructor) == __pyx_tp_dealloc__memoryviewslice) {
      if (PyObject_CallFinalizerFromDealloc(o)) return;
    }
  }
  #endif
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) + 1);
    __pyx_memoryviewslice___dealloc__(o);
    __Pyx_SET_REFCNT(o, Py_REFCNT(o) - 1);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->from_object);
  PyObject_GC_Track(o);
  __pyx_tp_dealloc_memoryview(o);
}

static int __pyx_tp_traverse__memoryviewslice(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_memoryviewslice_obj *p = (struct __pyx_memoryviewslice_obj *)o;
  e = __pyx_tp_traverse_memoryview(o, v, a); if (e) return e;
  if (p->from_object) {
    e = (*v)(p->from_object, a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear__memoryviewslice(PyObject *o) {
  PyObject* tmp;
  struct __pyx_memoryviewslice_obj *p = (struct __pyx_memoryviewslice_obj *)o;
  __pyx_tp_clear_memoryview(o);
  tmp = ((PyObject*)p->from_object);
  p->from_object = Py_None; Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  __PYX_XCLEAR_MEMVIEW(&p->from_slice, 1);
  return 0;
}

static PyMethodDef __pyx_methods__memoryviewslice[] = {
  {"__reduce_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_memoryviewslice_1__reduce_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {"__setstate_cython__", (PyCFunction)(void*)(__Pyx_PyCFunction_FastCallWithKeywords)__pyx_pw___pyx_memoryviewslice_3__setstate_cython__, __Pyx_METH_FASTCALL|METH_KEYWORDS, 0},
  {0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_type___pyx_memoryviewslice_slots[] = {
  {Py_tp_dealloc, (void *)__pyx_tp_dealloc__memoryviewslice},
  {Py_tp_doc, (void *)PyDoc_STR("Internal class for passing memoryview slices to Python")},
  {Py_tp_traverse, (void *)__pyx_tp_traverse__memoryviewslice},
  {Py_tp_clear, (void *)__pyx_tp_clear__memoryviewslice},
  {Py_tp_methods, (void *)__pyx_methods__memoryviewslice},
  {Py_tp_new, (void *)__pyx_tp_new__memoryviewslice},
  {0, 0},
};
static PyType_Spec __pyx_type___pyx_memoryviewslice_spec = {
  "pandas._libs.hashtable._memoryviewslice",
  sizeof(struct __pyx_memoryviewslice_obj),
  0,
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_SEQUENCE,
  __pyx_type___pyx_memoryviewslice_slots,
};
#else

static PyTypeObject __pyx_type___pyx_memoryviewslice = {
  PyVarObject_HEAD_INIT(0, 0)
  "pandas._libs.hashtable.""_memoryviewslice", /*tp_name*/
  sizeof(struct __pyx_memoryviewslice_obj), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc__memoryviewslice, /*tp_dealloc*/
  #if PY_VERSION_HEX < 0x030800b4
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030800b4
  0, /*tp_vectorcall_offset*/
  #endif
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_memoryview___repr__, /*tp_repr*/
  #else
  0, /*tp_repr*/
  #endif
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  #if CYTHON_COMPILING_IN_PYPY || 0
  __pyx_memoryview___str__, /*tp_str*/
  #else
  0, /*tp_str*/
  #endif
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC|Py_TPFLAGS_SEQUENCE, /*tp_flags*/
  PyDoc_STR("Internal class for passing memoryview slices to Python"), /*tp_doc*/
  __pyx_tp_traverse__memoryviewslice, /*tp_traverse*/
  __pyx_tp_clear__memoryviewslice, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods__memoryviewslice, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  #if !CYTHON_USE_TYPE_SPECS
  0, /*tp_dictoffset*/
  #endif
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new__memoryviewslice, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  #if CYTHON_USE_TP_FINALIZE
  0, /*tp_finalize*/
  #else
  NULL, /*tp_finalize*/
  #endif
  #endif
  #if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
  0, /*tp_vectorcall*/
  #endif
  #if __PYX_NEED_TP_PRINT_SLOT == 1
  0, /*tp_print*/
  #endif
  #if PY_VERSION_HEX >= 0x030C0000
  0, /*tp_watched*/
  #endif
  #if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
  0, /*tp_pypy_flags*/
  #endif
};
#endif

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif
/* #### Code section: pystring_table ### */

static int __Pyx_CreateStringTabAndInitStrings(void) {
  __Pyx_StringTabEntry __pyx_string_tab[] = {
    {&__pyx_kp_u_, __pyx_k_, sizeof(__pyx_k_), 0, 1, 0, 0},
    {&__pyx_n_s_ASCII, __pyx_k_ASCII, sizeof(__pyx_k_ASCII), 0, 0, 1, 1},
    {&__pyx_kp_s_All_dimensions_preceding_dimensi, __pyx_k_All_dimensions_preceding_dimensi, sizeof(__pyx_k_All_dimensions_preceding_dimensi), 0, 0, 1, 0},
    {&__pyx_n_s_AssertionError, __pyx_k_AssertionError, sizeof(__pyx_k_AssertionError), 0, 0, 1, 1},
    {&__pyx_kp_s_Buffer_view_does_not_expose_stri, __pyx_k_Buffer_view_does_not_expose_stri, sizeof(__pyx_k_Buffer_view_does_not_expose_stri), 0, 0, 1, 0},
    {&__pyx_kp_s_Can_only_create_a_buffer_that_is, __pyx_k_Can_only_create_a_buffer_that_is, sizeof(__pyx_k_Can_only_create_a_buffer_that_is), 0, 0, 1, 0},
    {&__pyx_kp_s_Cannot_assign_to_read_only_memor, __pyx_k_Cannot_assign_to_read_only_memor, sizeof(__pyx_k_Cannot_assign_to_read_only_memor), 0, 0, 1, 0},
    {&__pyx_kp_s_Cannot_create_writable_memory_vi, __pyx_k_Cannot_create_writable_memory_vi, sizeof(__pyx_k_Cannot_create_writable_memory_vi), 0, 0, 1, 0},
    {&__pyx_kp_u_Cannot_index_with_type, __pyx_k_Cannot_index_with_type, sizeof(__pyx_k_Cannot_index_with_type), 0, 1, 0, 0},
    {&__pyx_kp_s_Cannot_transpose_memoryview_with, __pyx_k_Cannot_transpose_memoryview_with, sizeof(__pyx_k_Cannot_transpose_memoryview_with), 0, 0, 1, 0},
    {&__pyx_n_s_Complex128Factorizer, __pyx_k_Complex128Factorizer, sizeof(__pyx_k_Complex128Factorizer), 0, 0, 1, 1},
    {&__pyx_n_s_Complex128Factorizer___reduce_cy, __pyx_k_Complex128Factorizer___reduce_cy, sizeof(__pyx_k_Complex128Factorizer___reduce_cy), 0, 0, 1, 1},
    {&__pyx_n_s_Complex128Factorizer___setstate, __pyx_k_Complex128Factorizer___setstate, sizeof(__pyx_k_Complex128Factorizer___setstate), 0, 0, 1, 1},
    {&__pyx_n_s_Complex128Factorizer_factorize, __pyx_k_Complex128Factorizer_factorize, sizeof(__pyx_k_Complex128Factorizer_factorize), 0, 0, 1, 1},
    {&__pyx_kp_u_Complex128Factorizer_factorize_l, __pyx_k_Complex128Factorizer_factorize_l, sizeof(__pyx_k_Complex128Factorizer_factorize_l), 0, 1, 0, 0},
    {&__pyx_n_s_Complex128HashTable, __pyx_k_Complex128HashTable, sizeof(__pyx_k_Complex128HashTable), 0, 0, 1, 1},
    {&__pyx_n_s_Complex128HashTable___reduce_cyt, __pyx_k_Complex128HashTable___reduce_cyt, sizeof(__pyx_k_Complex128HashTable___reduce_cyt), 0, 0, 1, 1},
    {&__pyx_n_s_Complex128HashTable___setstate_c, __pyx_k_Complex128HashTable___setstate_c, sizeof(__pyx_k_Complex128HashTable___setstate_c), 0, 0, 1, 1},
    {&__pyx_n_s_Complex128HashTable__unique, __pyx_k_Complex128HashTable__unique, sizeof(__pyx_k_Complex128HashTable__unique), 0, 0, 1, 1},
    {&__pyx_n_s_Complex128HashTable_factorize, __pyx_k_Complex128HashTable_factorize, sizeof(__pyx_k_Complex128HashTable_factorize), 0, 0, 1, 1},
    {&__pyx_n_s_Complex128HashTable_get_item, __pyx_k_Complex128HashTable_get_item, sizeof(__pyx_k_Complex128HashTable_get_item), 0, 0, 1, 1},
    {&__pyx_n_s_Complex128HashTable_get_labels, __pyx_k_Complex128HashTable_get_labels, sizeof(__pyx_k_Complex128HashTable_get_labels), 0, 0, 1, 1},
    {&__pyx_n_s_Complex128HashTable_get_na, __pyx_k_Complex128HashTable_get_na, sizeof(__pyx_k_Complex128HashTable_get_na), 0, 0, 1, 1},
    {&__pyx_n_s_Complex128HashTable_get_state, __pyx_k_Complex128HashTable_get_state, sizeof(__pyx_k_Complex128HashTable_get_state), 0, 0, 1, 1},
    {&__pyx_n_s_Complex128HashTable_lookup, __pyx_k_Complex128HashTable_lookup, sizeof(__pyx_k_Complex128HashTable_lookup), 0, 0, 1, 1},
    {&__pyx_n_s_Complex128HashTable_map_location, __pyx_k_Complex128HashTable_map_location, sizeof(__pyx_k_Complex128HashTable_map_location), 0, 0, 1, 1},
    {&__pyx_n_s_Complex128HashTable_set_item, __pyx_k_Complex128HashTable_set_item, sizeof(__pyx_k_Complex128HashTable_set_item), 0, 0, 1, 1},
    {&__pyx_n_s_Complex128HashTable_set_na, __pyx_k_Complex128HashTable_set_na, sizeof(__pyx_k_Complex128HashTable_set_na), 0, 0, 1, 1},
    {&__pyx_n_s_Complex128HashTable_sizeof, __pyx_k_Complex128HashTable_sizeof, sizeof(__pyx_k_Complex128HashTable_sizeof), 0, 0, 1, 1},
    {&__pyx_n_s_Complex128HashTable_unique, __pyx_k_Complex128HashTable_unique, sizeof(__pyx_k_Complex128HashTable_unique), 0, 0, 1, 1},
    {&__pyx_n_s_Complex128Vector, __pyx_k_Complex128Vector, sizeof(__pyx_k_Complex128Vector), 0, 0, 1, 1},
    {&__pyx_n_s_Complex128Vector___reduce_cython, __pyx_k_Complex128Vector___reduce_cython, sizeof(__pyx_k_Complex128Vector___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Complex128Vector___setstate_cyth, __pyx_k_Complex128Vector___setstate_cyth, sizeof(__pyx_k_Complex128Vector___setstate_cyth), 0, 0, 1, 1},
    {&__pyx_n_s_Complex128Vector_to_array, __pyx_k_Complex128Vector_to_array, sizeof(__pyx_k_Complex128Vector_to_array), 0, 0, 1, 1},
    {&__pyx_n_s_Complex64Factorizer, __pyx_k_Complex64Factorizer, sizeof(__pyx_k_Complex64Factorizer), 0, 0, 1, 1},
    {&__pyx_n_s_Complex64Factorizer___reduce_cyt, __pyx_k_Complex64Factorizer___reduce_cyt, sizeof(__pyx_k_Complex64Factorizer___reduce_cyt), 0, 0, 1, 1},
    {&__pyx_n_s_Complex64Factorizer___setstate_c, __pyx_k_Complex64Factorizer___setstate_c, sizeof(__pyx_k_Complex64Factorizer___setstate_c), 0, 0, 1, 1},
    {&__pyx_n_s_Complex64Factorizer_factorize, __pyx_k_Complex64Factorizer_factorize, sizeof(__pyx_k_Complex64Factorizer_factorize), 0, 0, 1, 1},
    {&__pyx_kp_u_Complex64Factorizer_factorize_li, __pyx_k_Complex64Factorizer_factorize_li, sizeof(__pyx_k_Complex64Factorizer_factorize_li), 0, 1, 0, 0},
    {&__pyx_n_s_Complex64HashTable, __pyx_k_Complex64HashTable, sizeof(__pyx_k_Complex64HashTable), 0, 0, 1, 1},
    {&__pyx_n_s_Complex64HashTable___reduce_cyth, __pyx_k_Complex64HashTable___reduce_cyth, sizeof(__pyx_k_Complex64HashTable___reduce_cyth), 0, 0, 1, 1},
    {&__pyx_n_s_Complex64HashTable___setstate_cy, __pyx_k_Complex64HashTable___setstate_cy, sizeof(__pyx_k_Complex64HashTable___setstate_cy), 0, 0, 1, 1},
    {&__pyx_n_s_Complex64HashTable__unique, __pyx_k_Complex64HashTable__unique, sizeof(__pyx_k_Complex64HashTable__unique), 0, 0, 1, 1},
    {&__pyx_n_s_Complex64HashTable_factorize, __pyx_k_Complex64HashTable_factorize, sizeof(__pyx_k_Complex64HashTable_factorize), 0, 0, 1, 1},
    {&__pyx_n_s_Complex64HashTable_get_item, __pyx_k_Complex64HashTable_get_item, sizeof(__pyx_k_Complex64HashTable_get_item), 0, 0, 1, 1},
    {&__pyx_n_s_Complex64HashTable_get_labels, __pyx_k_Complex64HashTable_get_labels, sizeof(__pyx_k_Complex64HashTable_get_labels), 0, 0, 1, 1},
    {&__pyx_n_s_Complex64HashTable_get_na, __pyx_k_Complex64HashTable_get_na, sizeof(__pyx_k_Complex64HashTable_get_na), 0, 0, 1, 1},
    {&__pyx_n_s_Complex64HashTable_get_state, __pyx_k_Complex64HashTable_get_state, sizeof(__pyx_k_Complex64HashTable_get_state), 0, 0, 1, 1},
    {&__pyx_n_s_Complex64HashTable_lookup, __pyx_k_Complex64HashTable_lookup, sizeof(__pyx_k_Complex64HashTable_lookup), 0, 0, 1, 1},
    {&__pyx_n_s_Complex64HashTable_map_locations, __pyx_k_Complex64HashTable_map_locations, sizeof(__pyx_k_Complex64HashTable_map_locations), 0, 0, 1, 1},
    {&__pyx_n_s_Complex64HashTable_set_item, __pyx_k_Complex64HashTable_set_item, sizeof(__pyx_k_Complex64HashTable_set_item), 0, 0, 1, 1},
    {&__pyx_n_s_Complex64HashTable_set_na, __pyx_k_Complex64HashTable_set_na, sizeof(__pyx_k_Complex64HashTable_set_na), 0, 0, 1, 1},
    {&__pyx_n_s_Complex64HashTable_sizeof, __pyx_k_Complex64HashTable_sizeof, sizeof(__pyx_k_Complex64HashTable_sizeof), 0, 0, 1, 1},
    {&__pyx_n_s_Complex64HashTable_unique, __pyx_k_Complex64HashTable_unique, sizeof(__pyx_k_Complex64HashTable_unique), 0, 0, 1, 1},
    {&__pyx_n_s_Complex64Vector, __pyx_k_Complex64Vector, sizeof(__pyx_k_Complex64Vector), 0, 0, 1, 1},
    {&__pyx_n_s_Complex64Vector___reduce_cython, __pyx_k_Complex64Vector___reduce_cython, sizeof(__pyx_k_Complex64Vector___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Complex64Vector___setstate_cytho, __pyx_k_Complex64Vector___setstate_cytho, sizeof(__pyx_k_Complex64Vector___setstate_cytho), 0, 0, 1, 1},
    {&__pyx_n_s_Complex64Vector_to_array, __pyx_k_Complex64Vector_to_array, sizeof(__pyx_k_Complex64Vector_to_array), 0, 0, 1, 1},
    {&__pyx_kp_s_Dimension_d_is_not_direct, __pyx_k_Dimension_d_is_not_direct, sizeof(__pyx_k_Dimension_d_is_not_direct), 0, 0, 1, 0},
    {&__pyx_n_s_Ellipsis, __pyx_k_Ellipsis, sizeof(__pyx_k_Ellipsis), 0, 0, 1, 1},
    {&__pyx_kp_s_Empty_shape_tuple_for_cython_arr, __pyx_k_Empty_shape_tuple_for_cython_arr, sizeof(__pyx_k_Empty_shape_tuple_for_cython_arr), 0, 0, 1, 0},
    {&__pyx_kp_s_Expected_at_least_d_argument_s_g, __pyx_k_Expected_at_least_d_argument_s_g, sizeof(__pyx_k_Expected_at_least_d_argument_s_g), 0, 0, 1, 0},
    {&__pyx_n_s_Factorizer, __pyx_k_Factorizer, sizeof(__pyx_k_Factorizer), 0, 0, 1, 1},
    {&__pyx_n_s_Factorizer___reduce_cython, __pyx_k_Factorizer___reduce_cython, sizeof(__pyx_k_Factorizer___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Factorizer___setstate_cython, __pyx_k_Factorizer___setstate_cython, sizeof(__pyx_k_Factorizer___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Factorizer_factorize, __pyx_k_Factorizer_factorize, sizeof(__pyx_k_Factorizer_factorize), 0, 0, 1, 1},
    {&__pyx_n_s_Factorizer_get_count, __pyx_k_Factorizer_get_count, sizeof(__pyx_k_Factorizer_get_count), 0, 0, 1, 1},
    {&__pyx_n_s_Float32Factorizer, __pyx_k_Float32Factorizer, sizeof(__pyx_k_Float32Factorizer), 0, 0, 1, 1},
    {&__pyx_n_s_Float32Factorizer___reduce_cytho, __pyx_k_Float32Factorizer___reduce_cytho, sizeof(__pyx_k_Float32Factorizer___reduce_cytho), 0, 0, 1, 1},
    {&__pyx_n_s_Float32Factorizer___setstate_cyt, __pyx_k_Float32Factorizer___setstate_cyt, sizeof(__pyx_k_Float32Factorizer___setstate_cyt), 0, 0, 1, 1},
    {&__pyx_n_s_Float32Factorizer_factorize, __pyx_k_Float32Factorizer_factorize, sizeof(__pyx_k_Float32Factorizer_factorize), 0, 0, 1, 1},
    {&__pyx_kp_u_Float32Factorizer_factorize_line, __pyx_k_Float32Factorizer_factorize_line, sizeof(__pyx_k_Float32Factorizer_factorize_line), 0, 1, 0, 0},
    {&__pyx_n_s_Float32HashTable, __pyx_k_Float32HashTable, sizeof(__pyx_k_Float32HashTable), 0, 0, 1, 1},
    {&__pyx_n_s_Float32HashTable___reduce_cython, __pyx_k_Float32HashTable___reduce_cython, sizeof(__pyx_k_Float32HashTable___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Float32HashTable___setstate_cyth, __pyx_k_Float32HashTable___setstate_cyth, sizeof(__pyx_k_Float32HashTable___setstate_cyth), 0, 0, 1, 1},
    {&__pyx_n_s_Float32HashTable__unique, __pyx_k_Float32HashTable__unique, sizeof(__pyx_k_Float32HashTable__unique), 0, 0, 1, 1},
    {&__pyx_n_s_Float32HashTable_factorize, __pyx_k_Float32HashTable_factorize, sizeof(__pyx_k_Float32HashTable_factorize), 0, 0, 1, 1},
    {&__pyx_n_s_Float32HashTable_get_item, __pyx_k_Float32HashTable_get_item, sizeof(__pyx_k_Float32HashTable_get_item), 0, 0, 1, 1},
    {&__pyx_n_s_Float32HashTable_get_labels, __pyx_k_Float32HashTable_get_labels, sizeof(__pyx_k_Float32HashTable_get_labels), 0, 0, 1, 1},
    {&__pyx_n_s_Float32HashTable_get_na, __pyx_k_Float32HashTable_get_na, sizeof(__pyx_k_Float32HashTable_get_na), 0, 0, 1, 1},
    {&__pyx_n_s_Float32HashTable_get_state, __pyx_k_Float32HashTable_get_state, sizeof(__pyx_k_Float32HashTable_get_state), 0, 0, 1, 1},
    {&__pyx_n_s_Float32HashTable_lookup, __pyx_k_Float32HashTable_lookup, sizeof(__pyx_k_Float32HashTable_lookup), 0, 0, 1, 1},
    {&__pyx_n_s_Float32HashTable_map_locations, __pyx_k_Float32HashTable_map_locations, sizeof(__pyx_k_Float32HashTable_map_locations), 0, 0, 1, 1},
    {&__pyx_n_s_Float32HashTable_set_item, __pyx_k_Float32HashTable_set_item, sizeof(__pyx_k_Float32HashTable_set_item), 0, 0, 1, 1},
    {&__pyx_n_s_Float32HashTable_set_na, __pyx_k_Float32HashTable_set_na, sizeof(__pyx_k_Float32HashTable_set_na), 0, 0, 1, 1},
    {&__pyx_n_s_Float32HashTable_sizeof, __pyx_k_Float32HashTable_sizeof, sizeof(__pyx_k_Float32HashTable_sizeof), 0, 0, 1, 1},
    {&__pyx_n_s_Float32HashTable_unique, __pyx_k_Float32HashTable_unique, sizeof(__pyx_k_Float32HashTable_unique), 0, 0, 1, 1},
    {&__pyx_n_s_Float32Vector, __pyx_k_Float32Vector, sizeof(__pyx_k_Float32Vector), 0, 0, 1, 1},
    {&__pyx_n_s_Float32Vector___reduce_cython, __pyx_k_Float32Vector___reduce_cython, sizeof(__pyx_k_Float32Vector___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Float32Vector___setstate_cython, __pyx_k_Float32Vector___setstate_cython, sizeof(__pyx_k_Float32Vector___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Float32Vector_to_array, __pyx_k_Float32Vector_to_array, sizeof(__pyx_k_Float32Vector_to_array), 0, 0, 1, 1},
    {&__pyx_n_s_Float64Factorizer, __pyx_k_Float64Factorizer, sizeof(__pyx_k_Float64Factorizer), 0, 0, 1, 1},
    {&__pyx_n_s_Float64Factorizer___reduce_cytho, __pyx_k_Float64Factorizer___reduce_cytho, sizeof(__pyx_k_Float64Factorizer___reduce_cytho), 0, 0, 1, 1},
    {&__pyx_n_s_Float64Factorizer___setstate_cyt, __pyx_k_Float64Factorizer___setstate_cyt, sizeof(__pyx_k_Float64Factorizer___setstate_cyt), 0, 0, 1, 1},
    {&__pyx_n_s_Float64Factorizer_factorize, __pyx_k_Float64Factorizer_factorize, sizeof(__pyx_k_Float64Factorizer_factorize), 0, 0, 1, 1},
    {&__pyx_kp_u_Float64Factorizer_factorize_line, __pyx_k_Float64Factorizer_factorize_line, sizeof(__pyx_k_Float64Factorizer_factorize_line), 0, 1, 0, 0},
    {&__pyx_n_s_Float64HashTable, __pyx_k_Float64HashTable, sizeof(__pyx_k_Float64HashTable), 0, 0, 1, 1},
    {&__pyx_n_s_Float64HashTable___reduce_cython, __pyx_k_Float64HashTable___reduce_cython, sizeof(__pyx_k_Float64HashTable___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Float64HashTable___setstate_cyth, __pyx_k_Float64HashTable___setstate_cyth, sizeof(__pyx_k_Float64HashTable___setstate_cyth), 0, 0, 1, 1},
    {&__pyx_n_s_Float64HashTable__unique, __pyx_k_Float64HashTable__unique, sizeof(__pyx_k_Float64HashTable__unique), 0, 0, 1, 1},
    {&__pyx_n_s_Float64HashTable_factorize, __pyx_k_Float64HashTable_factorize, sizeof(__pyx_k_Float64HashTable_factorize), 0, 0, 1, 1},
    {&__pyx_n_s_Float64HashTable_get_item, __pyx_k_Float64HashTable_get_item, sizeof(__pyx_k_Float64HashTable_get_item), 0, 0, 1, 1},
    {&__pyx_n_s_Float64HashTable_get_labels, __pyx_k_Float64HashTable_get_labels, sizeof(__pyx_k_Float64HashTable_get_labels), 0, 0, 1, 1},
    {&__pyx_n_s_Float64HashTable_get_na, __pyx_k_Float64HashTable_get_na, sizeof(__pyx_k_Float64HashTable_get_na), 0, 0, 1, 1},
    {&__pyx_n_s_Float64HashTable_get_state, __pyx_k_Float64HashTable_get_state, sizeof(__pyx_k_Float64HashTable_get_state), 0, 0, 1, 1},
    {&__pyx_n_s_Float64HashTable_lookup, __pyx_k_Float64HashTable_lookup, sizeof(__pyx_k_Float64HashTable_lookup), 0, 0, 1, 1},
    {&__pyx_n_s_Float64HashTable_map_locations, __pyx_k_Float64HashTable_map_locations, sizeof(__pyx_k_Float64HashTable_map_locations), 0, 0, 1, 1},
    {&__pyx_n_s_Float64HashTable_set_item, __pyx_k_Float64HashTable_set_item, sizeof(__pyx_k_Float64HashTable_set_item), 0, 0, 1, 1},
    {&__pyx_n_s_Float64HashTable_set_na, __pyx_k_Float64HashTable_set_na, sizeof(__pyx_k_Float64HashTable_set_na), 0, 0, 1, 1},
    {&__pyx_n_s_Float64HashTable_sizeof, __pyx_k_Float64HashTable_sizeof, sizeof(__pyx_k_Float64HashTable_sizeof), 0, 0, 1, 1},
    {&__pyx_n_s_Float64HashTable_unique, __pyx_k_Float64HashTable_unique, sizeof(__pyx_k_Float64HashTable_unique), 0, 0, 1, 1},
    {&__pyx_n_s_Float64Vector, __pyx_k_Float64Vector, sizeof(__pyx_k_Float64Vector), 0, 0, 1, 1},
    {&__pyx_n_s_Float64Vector___reduce_cython, __pyx_k_Float64Vector___reduce_cython, sizeof(__pyx_k_Float64Vector___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Float64Vector___setstate_cython, __pyx_k_Float64Vector___setstate_cython, sizeof(__pyx_k_Float64Vector___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Float64Vector_to_array, __pyx_k_Float64Vector_to_array, sizeof(__pyx_k_Float64Vector_to_array), 0, 0, 1, 1},
    {&__pyx_kp_s_Function_call_with_ambiguous_arg, __pyx_k_Function_call_with_ambiguous_arg, sizeof(__pyx_k_Function_call_with_ambiguous_arg), 0, 0, 1, 0},
    {&__pyx_n_s_HashTable, __pyx_k_HashTable, sizeof(__pyx_k_HashTable), 0, 0, 1, 1},
    {&__pyx_n_s_HashTable___reduce_cython, __pyx_k_HashTable___reduce_cython, sizeof(__pyx_k_HashTable___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_HashTable___setstate_cython, __pyx_k_HashTable___setstate_cython, sizeof(__pyx_k_HashTable___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_ImportError, __pyx_k_ImportError, sizeof(__pyx_k_ImportError), 0, 0, 1, 1},
    {&__pyx_kp_s_Incompatible_checksums_0x_x_vs_0, __pyx_k_Incompatible_checksums_0x_x_vs_0, sizeof(__pyx_k_Incompatible_checksums_0x_x_vs_0), 0, 0, 1, 0},
    {&__pyx_kp_s_Incompatible_checksums_0x_x_vs_0_2, __pyx_k_Incompatible_checksums_0x_x_vs_0_2, sizeof(__pyx_k_Incompatible_checksums_0x_x_vs_0_2), 0, 0, 1, 0},
    {&__pyx_n_s_IndexError, __pyx_k_IndexError, sizeof(__pyx_k_IndexError), 0, 0, 1, 1},
    {&__pyx_kp_s_Index_out_of_bounds_axis_d, __pyx_k_Index_out_of_bounds_axis_d, sizeof(__pyx_k_Index_out_of_bounds_axis_d), 0, 0, 1, 0},
    {&__pyx_kp_s_Indirect_dimensions_not_supporte, __pyx_k_Indirect_dimensions_not_supporte, sizeof(__pyx_k_Indirect_dimensions_not_supporte), 0, 0, 1, 0},
    {&__pyx_n_s_Int16Factorizer, __pyx_k_Int16Factorizer, sizeof(__pyx_k_Int16Factorizer), 0, 0, 1, 1},
    {&__pyx_n_s_Int16Factorizer___reduce_cython, __pyx_k_Int16Factorizer___reduce_cython, sizeof(__pyx_k_Int16Factorizer___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Int16Factorizer___setstate_cytho, __pyx_k_Int16Factorizer___setstate_cytho, sizeof(__pyx_k_Int16Factorizer___setstate_cytho), 0, 0, 1, 1},
    {&__pyx_n_s_Int16Factorizer_factorize, __pyx_k_Int16Factorizer_factorize, sizeof(__pyx_k_Int16Factorizer_factorize), 0, 0, 1, 1},
    {&__pyx_kp_u_Int16Factorizer_factorize_line_5, __pyx_k_Int16Factorizer_factorize_line_5, sizeof(__pyx_k_Int16Factorizer_factorize_line_5), 0, 1, 0, 0},
    {&__pyx_n_s_Int16HashTable, __pyx_k_Int16HashTable, sizeof(__pyx_k_Int16HashTable), 0, 0, 1, 1},
    {&__pyx_n_s_Int16HashTable___reduce_cython, __pyx_k_Int16HashTable___reduce_cython, sizeof(__pyx_k_Int16HashTable___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Int16HashTable___setstate_cython, __pyx_k_Int16HashTable___setstate_cython, sizeof(__pyx_k_Int16HashTable___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Int16HashTable__unique, __pyx_k_Int16HashTable__unique, sizeof(__pyx_k_Int16HashTable__unique), 0, 0, 1, 1},
    {&__pyx_n_s_Int16HashTable_factorize, __pyx_k_Int16HashTable_factorize, sizeof(__pyx_k_Int16HashTable_factorize), 0, 0, 1, 1},
    {&__pyx_n_s_Int16HashTable_get_item, __pyx_k_Int16HashTable_get_item, sizeof(__pyx_k_Int16HashTable_get_item), 0, 0, 1, 1},
    {&__pyx_n_s_Int16HashTable_get_labels, __pyx_k_Int16HashTable_get_labels, sizeof(__pyx_k_Int16HashTable_get_labels), 0, 0, 1, 1},
    {&__pyx_n_s_Int16HashTable_get_na, __pyx_k_Int16HashTable_get_na, sizeof(__pyx_k_Int16HashTable_get_na), 0, 0, 1, 1},
    {&__pyx_n_s_Int16HashTable_get_state, __pyx_k_Int16HashTable_get_state, sizeof(__pyx_k_Int16HashTable_get_state), 0, 0, 1, 1},
    {&__pyx_n_s_Int16HashTable_lookup, __pyx_k_Int16HashTable_lookup, sizeof(__pyx_k_Int16HashTable_lookup), 0, 0, 1, 1},
    {&__pyx_n_s_Int16HashTable_map_locations, __pyx_k_Int16HashTable_map_locations, sizeof(__pyx_k_Int16HashTable_map_locations), 0, 0, 1, 1},
    {&__pyx_n_s_Int16HashTable_set_item, __pyx_k_Int16HashTable_set_item, sizeof(__pyx_k_Int16HashTable_set_item), 0, 0, 1, 1},
    {&__pyx_n_s_Int16HashTable_set_na, __pyx_k_Int16HashTable_set_na, sizeof(__pyx_k_Int16HashTable_set_na), 0, 0, 1, 1},
    {&__pyx_n_s_Int16HashTable_sizeof, __pyx_k_Int16HashTable_sizeof, sizeof(__pyx_k_Int16HashTable_sizeof), 0, 0, 1, 1},
    {&__pyx_n_s_Int16HashTable_unique, __pyx_k_Int16HashTable_unique, sizeof(__pyx_k_Int16HashTable_unique), 0, 0, 1, 1},
    {&__pyx_n_s_Int16Vector, __pyx_k_Int16Vector, sizeof(__pyx_k_Int16Vector), 0, 0, 1, 1},
    {&__pyx_n_s_Int16Vector___reduce_cython, __pyx_k_Int16Vector___reduce_cython, sizeof(__pyx_k_Int16Vector___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Int16Vector___setstate_cython, __pyx_k_Int16Vector___setstate_cython, sizeof(__pyx_k_Int16Vector___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Int16Vector_to_array, __pyx_k_Int16Vector_to_array, sizeof(__pyx_k_Int16Vector_to_array), 0, 0, 1, 1},
    {&__pyx_n_s_Int32Factorizer, __pyx_k_Int32Factorizer, sizeof(__pyx_k_Int32Factorizer), 0, 0, 1, 1},
    {&__pyx_n_s_Int32Factorizer___reduce_cython, __pyx_k_Int32Factorizer___reduce_cython, sizeof(__pyx_k_Int32Factorizer___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Int32Factorizer___setstate_cytho, __pyx_k_Int32Factorizer___setstate_cytho, sizeof(__pyx_k_Int32Factorizer___setstate_cytho), 0, 0, 1, 1},
    {&__pyx_n_s_Int32Factorizer_factorize, __pyx_k_Int32Factorizer_factorize, sizeof(__pyx_k_Int32Factorizer_factorize), 0, 0, 1, 1},
    {&__pyx_kp_u_Int32Factorizer_factorize_line_4, __pyx_k_Int32Factorizer_factorize_line_4, sizeof(__pyx_k_Int32Factorizer_factorize_line_4), 0, 1, 0, 0},
    {&__pyx_n_s_Int32HashTable, __pyx_k_Int32HashTable, sizeof(__pyx_k_Int32HashTable), 0, 0, 1, 1},
    {&__pyx_n_s_Int32HashTable___reduce_cython, __pyx_k_Int32HashTable___reduce_cython, sizeof(__pyx_k_Int32HashTable___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Int32HashTable___setstate_cython, __pyx_k_Int32HashTable___setstate_cython, sizeof(__pyx_k_Int32HashTable___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Int32HashTable__unique, __pyx_k_Int32HashTable__unique, sizeof(__pyx_k_Int32HashTable__unique), 0, 0, 1, 1},
    {&__pyx_n_s_Int32HashTable_factorize, __pyx_k_Int32HashTable_factorize, sizeof(__pyx_k_Int32HashTable_factorize), 0, 0, 1, 1},
    {&__pyx_n_s_Int32HashTable_get_item, __pyx_k_Int32HashTable_get_item, sizeof(__pyx_k_Int32HashTable_get_item), 0, 0, 1, 1},
    {&__pyx_n_s_Int32HashTable_get_labels, __pyx_k_Int32HashTable_get_labels, sizeof(__pyx_k_Int32HashTable_get_labels), 0, 0, 1, 1},
    {&__pyx_n_s_Int32HashTable_get_na, __pyx_k_Int32HashTable_get_na, sizeof(__pyx_k_Int32HashTable_get_na), 0, 0, 1, 1},
    {&__pyx_n_s_Int32HashTable_get_state, __pyx_k_Int32HashTable_get_state, sizeof(__pyx_k_Int32HashTable_get_state), 0, 0, 1, 1},
    {&__pyx_n_s_Int32HashTable_lookup, __pyx_k_Int32HashTable_lookup, sizeof(__pyx_k_Int32HashTable_lookup), 0, 0, 1, 1},
    {&__pyx_n_s_Int32HashTable_map_locations, __pyx_k_Int32HashTable_map_locations, sizeof(__pyx_k_Int32HashTable_map_locations), 0, 0, 1, 1},
    {&__pyx_n_s_Int32HashTable_set_item, __pyx_k_Int32HashTable_set_item, sizeof(__pyx_k_Int32HashTable_set_item), 0, 0, 1, 1},
    {&__pyx_n_s_Int32HashTable_set_na, __pyx_k_Int32HashTable_set_na, sizeof(__pyx_k_Int32HashTable_set_na), 0, 0, 1, 1},
    {&__pyx_n_s_Int32HashTable_sizeof, __pyx_k_Int32HashTable_sizeof, sizeof(__pyx_k_Int32HashTable_sizeof), 0, 0, 1, 1},
    {&__pyx_n_s_Int32HashTable_unique, __pyx_k_Int32HashTable_unique, sizeof(__pyx_k_Int32HashTable_unique), 0, 0, 1, 1},
    {&__pyx_n_s_Int32Vector, __pyx_k_Int32Vector, sizeof(__pyx_k_Int32Vector), 0, 0, 1, 1},
    {&__pyx_n_s_Int32Vector___reduce_cython, __pyx_k_Int32Vector___reduce_cython, sizeof(__pyx_k_Int32Vector___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Int32Vector___setstate_cython, __pyx_k_Int32Vector___setstate_cython, sizeof(__pyx_k_Int32Vector___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Int32Vector_to_array, __pyx_k_Int32Vector_to_array, sizeof(__pyx_k_Int32Vector_to_array), 0, 0, 1, 1},
    {&__pyx_n_s_Int64Factorizer, __pyx_k_Int64Factorizer, sizeof(__pyx_k_Int64Factorizer), 0, 0, 1, 1},
    {&__pyx_n_s_Int64Factorizer___reduce_cython, __pyx_k_Int64Factorizer___reduce_cython, sizeof(__pyx_k_Int64Factorizer___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Int64Factorizer___setstate_cytho, __pyx_k_Int64Factorizer___setstate_cytho, sizeof(__pyx_k_Int64Factorizer___setstate_cytho), 0, 0, 1, 1},
    {&__pyx_n_s_Int64Factorizer_factorize, __pyx_k_Int64Factorizer_factorize, sizeof(__pyx_k_Int64Factorizer_factorize), 0, 0, 1, 1},
    {&__pyx_kp_u_Int64Factorizer_factorize_line_3, __pyx_k_Int64Factorizer_factorize_line_3, sizeof(__pyx_k_Int64Factorizer_factorize_line_3), 0, 1, 0, 0},
    {&__pyx_n_s_Int64HashTable, __pyx_k_Int64HashTable, sizeof(__pyx_k_Int64HashTable), 0, 0, 1, 1},
    {&__pyx_n_s_Int64HashTable___reduce_cython, __pyx_k_Int64HashTable___reduce_cython, sizeof(__pyx_k_Int64HashTable___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Int64HashTable___setstate_cython, __pyx_k_Int64HashTable___setstate_cython, sizeof(__pyx_k_Int64HashTable___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Int64HashTable__unique, __pyx_k_Int64HashTable__unique, sizeof(__pyx_k_Int64HashTable__unique), 0, 0, 1, 1},
    {&__pyx_n_s_Int64HashTable_factorize, __pyx_k_Int64HashTable_factorize, sizeof(__pyx_k_Int64HashTable_factorize), 0, 0, 1, 1},
    {&__pyx_n_s_Int64HashTable_get_item, __pyx_k_Int64HashTable_get_item, sizeof(__pyx_k_Int64HashTable_get_item), 0, 0, 1, 1},
    {&__pyx_n_s_Int64HashTable_get_labels, __pyx_k_Int64HashTable_get_labels, sizeof(__pyx_k_Int64HashTable_get_labels), 0, 0, 1, 1},
    {&__pyx_n_s_Int64HashTable_get_labels_groupb, __pyx_k_Int64HashTable_get_labels_groupb, sizeof(__pyx_k_Int64HashTable_get_labels_groupb), 0, 0, 1, 1},
    {&__pyx_n_s_Int64HashTable_get_na, __pyx_k_Int64HashTable_get_na, sizeof(__pyx_k_Int64HashTable_get_na), 0, 0, 1, 1},
    {&__pyx_n_s_Int64HashTable_get_state, __pyx_k_Int64HashTable_get_state, sizeof(__pyx_k_Int64HashTable_get_state), 0, 0, 1, 1},
    {&__pyx_n_s_Int64HashTable_lookup, __pyx_k_Int64HashTable_lookup, sizeof(__pyx_k_Int64HashTable_lookup), 0, 0, 1, 1},
    {&__pyx_n_s_Int64HashTable_map_keys_to_value, __pyx_k_Int64HashTable_map_keys_to_value, sizeof(__pyx_k_Int64HashTable_map_keys_to_value), 0, 0, 1, 1},
    {&__pyx_n_s_Int64HashTable_map_locations, __pyx_k_Int64HashTable_map_locations, sizeof(__pyx_k_Int64HashTable_map_locations), 0, 0, 1, 1},
    {&__pyx_n_s_Int64HashTable_set_item, __pyx_k_Int64HashTable_set_item, sizeof(__pyx_k_Int64HashTable_set_item), 0, 0, 1, 1},
    {&__pyx_n_s_Int64HashTable_set_na, __pyx_k_Int64HashTable_set_na, sizeof(__pyx_k_Int64HashTable_set_na), 0, 0, 1, 1},
    {&__pyx_n_s_Int64HashTable_sizeof, __pyx_k_Int64HashTable_sizeof, sizeof(__pyx_k_Int64HashTable_sizeof), 0, 0, 1, 1},
    {&__pyx_n_s_Int64HashTable_unique, __pyx_k_Int64HashTable_unique, sizeof(__pyx_k_Int64HashTable_unique), 0, 0, 1, 1},
    {&__pyx_n_s_Int64Vector, __pyx_k_Int64Vector, sizeof(__pyx_k_Int64Vector), 0, 0, 1, 1},
    {&__pyx_n_s_Int64Vector___reduce_cython, __pyx_k_Int64Vector___reduce_cython, sizeof(__pyx_k_Int64Vector___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Int64Vector___setstate_cython, __pyx_k_Int64Vector___setstate_cython, sizeof(__pyx_k_Int64Vector___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Int64Vector_to_array, __pyx_k_Int64Vector_to_array, sizeof(__pyx_k_Int64Vector_to_array), 0, 0, 1, 1},
    {&__pyx_n_s_Int8Factorizer, __pyx_k_Int8Factorizer, sizeof(__pyx_k_Int8Factorizer), 0, 0, 1, 1},
    {&__pyx_n_s_Int8Factorizer___reduce_cython, __pyx_k_Int8Factorizer___reduce_cython, sizeof(__pyx_k_Int8Factorizer___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Int8Factorizer___setstate_cython, __pyx_k_Int8Factorizer___setstate_cython, sizeof(__pyx_k_Int8Factorizer___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Int8Factorizer_factorize, __pyx_k_Int8Factorizer_factorize, sizeof(__pyx_k_Int8Factorizer_factorize), 0, 0, 1, 1},
    {&__pyx_kp_u_Int8Factorizer_factorize_line_66, __pyx_k_Int8Factorizer_factorize_line_66, sizeof(__pyx_k_Int8Factorizer_factorize_line_66), 0, 1, 0, 0},
    {&__pyx_n_s_Int8HashTable, __pyx_k_Int8HashTable, sizeof(__pyx_k_Int8HashTable), 0, 0, 1, 1},
    {&__pyx_n_s_Int8HashTable___reduce_cython, __pyx_k_Int8HashTable___reduce_cython, sizeof(__pyx_k_Int8HashTable___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Int8HashTable___setstate_cython, __pyx_k_Int8HashTable___setstate_cython, sizeof(__pyx_k_Int8HashTable___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Int8HashTable__unique, __pyx_k_Int8HashTable__unique, sizeof(__pyx_k_Int8HashTable__unique), 0, 0, 1, 1},
    {&__pyx_n_s_Int8HashTable_factorize, __pyx_k_Int8HashTable_factorize, sizeof(__pyx_k_Int8HashTable_factorize), 0, 0, 1, 1},
    {&__pyx_n_s_Int8HashTable_get_item, __pyx_k_Int8HashTable_get_item, sizeof(__pyx_k_Int8HashTable_get_item), 0, 0, 1, 1},
    {&__pyx_n_s_Int8HashTable_get_labels, __pyx_k_Int8HashTable_get_labels, sizeof(__pyx_k_Int8HashTable_get_labels), 0, 0, 1, 1},
    {&__pyx_n_s_Int8HashTable_get_na, __pyx_k_Int8HashTable_get_na, sizeof(__pyx_k_Int8HashTable_get_na), 0, 0, 1, 1},
    {&__pyx_n_s_Int8HashTable_get_state, __pyx_k_Int8HashTable_get_state, sizeof(__pyx_k_Int8HashTable_get_state), 0, 0, 1, 1},
    {&__pyx_n_s_Int8HashTable_lookup, __pyx_k_Int8HashTable_lookup, sizeof(__pyx_k_Int8HashTable_lookup), 0, 0, 1, 1},
    {&__pyx_n_s_Int8HashTable_map_locations, __pyx_k_Int8HashTable_map_locations, sizeof(__pyx_k_Int8HashTable_map_locations), 0, 0, 1, 1},
    {&__pyx_n_s_Int8HashTable_set_item, __pyx_k_Int8HashTable_set_item, sizeof(__pyx_k_Int8HashTable_set_item), 0, 0, 1, 1},
    {&__pyx_n_s_Int8HashTable_set_na, __pyx_k_Int8HashTable_set_na, sizeof(__pyx_k_Int8HashTable_set_na), 0, 0, 1, 1},
    {&__pyx_n_s_Int8HashTable_sizeof, __pyx_k_Int8HashTable_sizeof, sizeof(__pyx_k_Int8HashTable_sizeof), 0, 0, 1, 1},
    {&__pyx_n_s_Int8HashTable_unique, __pyx_k_Int8HashTable_unique, sizeof(__pyx_k_Int8HashTable_unique), 0, 0, 1, 1},
    {&__pyx_n_s_Int8Vector, __pyx_k_Int8Vector, sizeof(__pyx_k_Int8Vector), 0, 0, 1, 1},
    {&__pyx_n_s_Int8Vector___reduce_cython, __pyx_k_Int8Vector___reduce_cython, sizeof(__pyx_k_Int8Vector___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Int8Vector___setstate_cython, __pyx_k_Int8Vector___setstate_cython, sizeof(__pyx_k_Int8Vector___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Int8Vector_to_array, __pyx_k_Int8Vector_to_array, sizeof(__pyx_k_Int8Vector_to_array), 0, 0, 1, 1},
    {&__pyx_n_s_IntpHashTable, __pyx_k_IntpHashTable, sizeof(__pyx_k_IntpHashTable), 0, 0, 1, 1},
    {&__pyx_kp_u_Invalid_mode_expected_c_or_fortr, __pyx_k_Invalid_mode_expected_c_or_fortr, sizeof(__pyx_k_Invalid_mode_expected_c_or_fortr), 0, 1, 0, 0},
    {&__pyx_kp_u_Invalid_shape_in_axis, __pyx_k_Invalid_shape_in_axis, sizeof(__pyx_k_Invalid_shape_in_axis), 0, 1, 0, 0},
    {&__pyx_n_s_KeyError, __pyx_k_KeyError, sizeof(__pyx_k_KeyError), 0, 0, 1, 1},
    {&__pyx_n_s_MemoryError, __pyx_k_MemoryError, sizeof(__pyx_k_MemoryError), 0, 0, 1, 1},
    {&__pyx_kp_s_MemoryView_of_r_at_0x_x, __pyx_k_MemoryView_of_r_at_0x_x, sizeof(__pyx_k_MemoryView_of_r_at_0x_x), 0, 0, 1, 0},
    {&__pyx_kp_s_MemoryView_of_r_object, __pyx_k_MemoryView_of_r_object, sizeof(__pyx_k_MemoryView_of_r_object), 0, 0, 1, 0},
    {&__pyx_n_u_NA, __pyx_k_NA, sizeof(__pyx_k_NA), 0, 1, 0, 1},
    {&__pyx_kp_s_No_matching_signature_found, __pyx_k_No_matching_signature_found, sizeof(__pyx_k_No_matching_signature_found), 0, 0, 1, 0},
    {&__pyx_n_s_None, __pyx_k_None, sizeof(__pyx_k_None), 0, 0, 1, 1},
    {&__pyx_n_s_NotImplementedError, __pyx_k_NotImplementedError, sizeof(__pyx_k_NotImplementedError), 0, 0, 1, 1},
    {&__pyx_n_b_O, __pyx_k_O, sizeof(__pyx_k_O), 0, 0, 0, 1},
    {&__pyx_n_s_ObjectFactorizer, __pyx_k_ObjectFactorizer, sizeof(__pyx_k_ObjectFactorizer), 0, 0, 1, 1},
    {&__pyx_n_s_ObjectFactorizer___reduce_cython, __pyx_k_ObjectFactorizer___reduce_cython, sizeof(__pyx_k_ObjectFactorizer___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_ObjectFactorizer___setstate_cyth, __pyx_k_ObjectFactorizer___setstate_cyth, sizeof(__pyx_k_ObjectFactorizer___setstate_cyth), 0, 0, 1, 1},
    {&__pyx_n_s_ObjectFactorizer_factorize, __pyx_k_ObjectFactorizer_factorize, sizeof(__pyx_k_ObjectFactorizer_factorize), 0, 0, 1, 1},
    {&__pyx_kp_u_ObjectFactorizer_factorize_line, __pyx_k_ObjectFactorizer_factorize_line, sizeof(__pyx_k_ObjectFactorizer_factorize_line), 0, 1, 0, 0},
    {&__pyx_n_s_ObjectVector, __pyx_k_ObjectVector, sizeof(__pyx_k_ObjectVector), 0, 0, 1, 1},
    {&__pyx_n_s_ObjectVector___reduce_cython, __pyx_k_ObjectVector___reduce_cython, sizeof(__pyx_k_ObjectVector___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_ObjectVector___setstate_cython, __pyx_k_ObjectVector___setstate_cython, sizeof(__pyx_k_ObjectVector___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_ObjectVector_to_array, __pyx_k_ObjectVector_to_array, sizeof(__pyx_k_ObjectVector_to_array), 0, 0, 1, 1},
    {&__pyx_kp_u_Out_of_bounds_on_buffer_access_a, __pyx_k_Out_of_bounds_on_buffer_access_a, sizeof(__pyx_k_Out_of_bounds_on_buffer_access_a), 0, 1, 0, 0},
    {&__pyx_n_s_PickleError, __pyx_k_PickleError, sizeof(__pyx_k_PickleError), 0, 0, 1, 1},
    {&__pyx_n_s_PyObjectHashTable, __pyx_k_PyObjectHashTable, sizeof(__pyx_k_PyObjectHashTable), 0, 0, 1, 1},
    {&__pyx_n_s_PyObjectHashTable___reduce_cytho, __pyx_k_PyObjectHashTable___reduce_cytho, sizeof(__pyx_k_PyObjectHashTable___reduce_cytho), 0, 0, 1, 1},
    {&__pyx_n_s_PyObjectHashTable___setstate_cyt, __pyx_k_PyObjectHashTable___setstate_cyt, sizeof(__pyx_k_PyObjectHashTable___setstate_cyt), 0, 0, 1, 1},
    {&__pyx_n_s_PyObjectHashTable__unique, __pyx_k_PyObjectHashTable__unique, sizeof(__pyx_k_PyObjectHashTable__unique), 0, 0, 1, 1},
    {&__pyx_n_s_PyObjectHashTable_factorize, __pyx_k_PyObjectHashTable_factorize, sizeof(__pyx_k_PyObjectHashTable_factorize), 0, 0, 1, 1},
    {&__pyx_n_s_PyObjectHashTable_get_item, __pyx_k_PyObjectHashTable_get_item, sizeof(__pyx_k_PyObjectHashTable_get_item), 0, 0, 1, 1},
    {&__pyx_n_s_PyObjectHashTable_get_labels, __pyx_k_PyObjectHashTable_get_labels, sizeof(__pyx_k_PyObjectHashTable_get_labels), 0, 0, 1, 1},
    {&__pyx_n_s_PyObjectHashTable_get_state, __pyx_k_PyObjectHashTable_get_state, sizeof(__pyx_k_PyObjectHashTable_get_state), 0, 0, 1, 1},
    {&__pyx_n_s_PyObjectHashTable_lookup, __pyx_k_PyObjectHashTable_lookup, sizeof(__pyx_k_PyObjectHashTable_lookup), 0, 0, 1, 1},
    {&__pyx_n_s_PyObjectHashTable_map_locations, __pyx_k_PyObjectHashTable_map_locations, sizeof(__pyx_k_PyObjectHashTable_map_locations), 0, 0, 1, 1},
    {&__pyx_n_s_PyObjectHashTable_set_item, __pyx_k_PyObjectHashTable_set_item, sizeof(__pyx_k_PyObjectHashTable_set_item), 0, 0, 1, 1},
    {&__pyx_n_s_PyObjectHashTable_sizeof, __pyx_k_PyObjectHashTable_sizeof, sizeof(__pyx_k_PyObjectHashTable_sizeof), 0, 0, 1, 1},
    {&__pyx_n_s_PyObjectHashTable_unique, __pyx_k_PyObjectHashTable_unique, sizeof(__pyx_k_PyObjectHashTable_unique), 0, 0, 1, 1},
    {&__pyx_kp_u_Returns_ndarray_intp_t_Examples, __pyx_k_Returns_ndarray_intp_t_Examples, sizeof(__pyx_k_Returns_ndarray_intp_t_Examples), 0, 1, 0, 0},
    {&__pyx_kp_u_Returns_ndarray_intp_t_Examples_10, __pyx_k_Returns_ndarray_intp_t_Examples_10, sizeof(__pyx_k_Returns_ndarray_intp_t_Examples_10), 0, 1, 0, 0},
    {&__pyx_kp_u_Returns_ndarray_intp_t_Examples_11, __pyx_k_Returns_ndarray_intp_t_Examples_11, sizeof(__pyx_k_Returns_ndarray_intp_t_Examples_11), 0, 1, 0, 0},
    {&__pyx_kp_u_Returns_ndarray_intp_t_Examples_12, __pyx_k_Returns_ndarray_intp_t_Examples_12, sizeof(__pyx_k_Returns_ndarray_intp_t_Examples_12), 0, 1, 0, 0},
    {&__pyx_kp_u_Returns_ndarray_intp_t_Examples_2, __pyx_k_Returns_ndarray_intp_t_Examples_2, sizeof(__pyx_k_Returns_ndarray_intp_t_Examples_2), 0, 1, 0, 0},
    {&__pyx_kp_u_Returns_ndarray_intp_t_Examples_3, __pyx_k_Returns_ndarray_intp_t_Examples_3, sizeof(__pyx_k_Returns_ndarray_intp_t_Examples_3), 0, 1, 0, 0},
    {&__pyx_kp_u_Returns_ndarray_intp_t_Examples_4, __pyx_k_Returns_ndarray_intp_t_Examples_4, sizeof(__pyx_k_Returns_ndarray_intp_t_Examples_4), 0, 1, 0, 0},
    {&__pyx_kp_u_Returns_ndarray_intp_t_Examples_5, __pyx_k_Returns_ndarray_intp_t_Examples_5, sizeof(__pyx_k_Returns_ndarray_intp_t_Examples_5), 0, 1, 0, 0},
    {&__pyx_kp_u_Returns_ndarray_intp_t_Examples_6, __pyx_k_Returns_ndarray_intp_t_Examples_6, sizeof(__pyx_k_Returns_ndarray_intp_t_Examples_6), 0, 1, 0, 0},
    {&__pyx_kp_u_Returns_ndarray_intp_t_Examples_7, __pyx_k_Returns_ndarray_intp_t_Examples_7, sizeof(__pyx_k_Returns_ndarray_intp_t_Examples_7), 0, 1, 0, 0},
    {&__pyx_kp_u_Returns_ndarray_intp_t_Examples_8, __pyx_k_Returns_ndarray_intp_t_Examples_8, sizeof(__pyx_k_Returns_ndarray_intp_t_Examples_8), 0, 1, 0, 0},
    {&__pyx_kp_u_Returns_ndarray_intp_t_Examples_9, __pyx_k_Returns_ndarray_intp_t_Examples_9, sizeof(__pyx_k_Returns_ndarray_intp_t_Examples_9), 0, 1, 0, 0},
    {&__pyx_kp_u_Returns_np_ndarray_np_intp_Exam, __pyx_k_Returns_np_ndarray_np_intp_Exam, sizeof(__pyx_k_Returns_np_ndarray_np_intp_Exam), 0, 1, 0, 0},
    {&__pyx_n_s_SIZE_HINT_LIMIT, __pyx_k_SIZE_HINT_LIMIT, sizeof(__pyx_k_SIZE_HINT_LIMIT), 0, 0, 1, 1},
    {&__pyx_n_s_Sequence, __pyx_k_Sequence, sizeof(__pyx_k_Sequence), 0, 0, 1, 1},
    {&__pyx_kp_s_Step_may_not_be_zero_axis_d, __pyx_k_Step_may_not_be_zero_axis_d, sizeof(__pyx_k_Step_may_not_be_zero_axis_d), 0, 0, 1, 0},
    {&__pyx_n_s_StringHashTable, __pyx_k_StringHashTable, sizeof(__pyx_k_StringHashTable), 0, 0, 1, 1},
    {&__pyx_n_s_StringHashTable___reduce_cython, __pyx_k_StringHashTable___reduce_cython, sizeof(__pyx_k_StringHashTable___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_StringHashTable___setstate_cytho, __pyx_k_StringHashTable___setstate_cytho, sizeof(__pyx_k_StringHashTable___setstate_cytho), 0, 0, 1, 1},
    {&__pyx_n_s_StringHashTable__unique, __pyx_k_StringHashTable__unique, sizeof(__pyx_k_StringHashTable__unique), 0, 0, 1, 1},
    {&__pyx_n_s_StringHashTable_factorize, __pyx_k_StringHashTable_factorize, sizeof(__pyx_k_StringHashTable_factorize), 0, 0, 1, 1},
    {&__pyx_n_s_StringHashTable_get_indexer, __pyx_k_StringHashTable_get_indexer, sizeof(__pyx_k_StringHashTable_get_indexer), 0, 0, 1, 1},
    {&__pyx_n_s_StringHashTable_get_item, __pyx_k_StringHashTable_get_item, sizeof(__pyx_k_StringHashTable_get_item), 0, 0, 1, 1},
    {&__pyx_n_s_StringHashTable_get_labels, __pyx_k_StringHashTable_get_labels, sizeof(__pyx_k_StringHashTable_get_labels), 0, 0, 1, 1},
    {&__pyx_n_s_StringHashTable_get_state, __pyx_k_StringHashTable_get_state, sizeof(__pyx_k_StringHashTable_get_state), 0, 0, 1, 1},
    {&__pyx_n_s_StringHashTable_lookup, __pyx_k_StringHashTable_lookup, sizeof(__pyx_k_StringHashTable_lookup), 0, 0, 1, 1},
    {&__pyx_n_s_StringHashTable_map_locations, __pyx_k_StringHashTable_map_locations, sizeof(__pyx_k_StringHashTable_map_locations), 0, 0, 1, 1},
    {&__pyx_n_s_StringHashTable_set_item, __pyx_k_StringHashTable_set_item, sizeof(__pyx_k_StringHashTable_set_item), 0, 0, 1, 1},
    {&__pyx_n_s_StringHashTable_sizeof, __pyx_k_StringHashTable_sizeof, sizeof(__pyx_k_StringHashTable_sizeof), 0, 0, 1, 1},
    {&__pyx_n_s_StringHashTable_unique, __pyx_k_StringHashTable_unique, sizeof(__pyx_k_StringHashTable_unique), 0, 0, 1, 1},
    {&__pyx_n_s_StringVector, __pyx_k_StringVector, sizeof(__pyx_k_StringVector), 0, 0, 1, 1},
    {&__pyx_n_s_StringVector___reduce_cython, __pyx_k_StringVector___reduce_cython, sizeof(__pyx_k_StringVector___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_StringVector___setstate_cython, __pyx_k_StringVector___setstate_cython, sizeof(__pyx_k_StringVector___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_StringVector_to_array, __pyx_k_StringVector_to_array, sizeof(__pyx_k_StringVector_to_array), 0, 0, 1, 1},
    {&__pyx_n_s_TypeError, __pyx_k_TypeError, sizeof(__pyx_k_TypeError), 0, 0, 1, 1},
    {&__pyx_n_s_UInt16Factorizer, __pyx_k_UInt16Factorizer, sizeof(__pyx_k_UInt16Factorizer), 0, 0, 1, 1},
    {&__pyx_n_s_UInt16Factorizer___reduce_cython, __pyx_k_UInt16Factorizer___reduce_cython, sizeof(__pyx_k_UInt16Factorizer___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_UInt16Factorizer___setstate_cyth, __pyx_k_UInt16Factorizer___setstate_cyth, sizeof(__pyx_k_UInt16Factorizer___setstate_cyth), 0, 0, 1, 1},
    {&__pyx_n_s_UInt16Factorizer_factorize, __pyx_k_UInt16Factorizer_factorize, sizeof(__pyx_k_UInt16Factorizer_factorize), 0, 0, 1, 1},
    {&__pyx_kp_u_UInt16Factorizer_factorize_line, __pyx_k_UInt16Factorizer_factorize_line, sizeof(__pyx_k_UInt16Factorizer_factorize_line), 0, 1, 0, 0},
    {&__pyx_n_s_UInt16HashTable, __pyx_k_UInt16HashTable, sizeof(__pyx_k_UInt16HashTable), 0, 0, 1, 1},
    {&__pyx_n_s_UInt16HashTable___reduce_cython, __pyx_k_UInt16HashTable___reduce_cython, sizeof(__pyx_k_UInt16HashTable___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_UInt16HashTable___setstate_cytho, __pyx_k_UInt16HashTable___setstate_cytho, sizeof(__pyx_k_UInt16HashTable___setstate_cytho), 0, 0, 1, 1},
    {&__pyx_n_s_UInt16HashTable__unique, __pyx_k_UInt16HashTable__unique, sizeof(__pyx_k_UInt16HashTable__unique), 0, 0, 1, 1},
    {&__pyx_n_s_UInt16HashTable_factorize, __pyx_k_UInt16HashTable_factorize, sizeof(__pyx_k_UInt16HashTable_factorize), 0, 0, 1, 1},
    {&__pyx_n_s_UInt16HashTable_get_item, __pyx_k_UInt16HashTable_get_item, sizeof(__pyx_k_UInt16HashTable_get_item), 0, 0, 1, 1},
    {&__pyx_n_s_UInt16HashTable_get_labels, __pyx_k_UInt16HashTable_get_labels, sizeof(__pyx_k_UInt16HashTable_get_labels), 0, 0, 1, 1},
    {&__pyx_n_s_UInt16HashTable_get_na, __pyx_k_UInt16HashTable_get_na, sizeof(__pyx_k_UInt16HashTable_get_na), 0, 0, 1, 1},
    {&__pyx_n_s_UInt16HashTable_get_state, __pyx_k_UInt16HashTable_get_state, sizeof(__pyx_k_UInt16HashTable_get_state), 0, 0, 1, 1},
    {&__pyx_n_s_UInt16HashTable_lookup, __pyx_k_UInt16HashTable_lookup, sizeof(__pyx_k_UInt16HashTable_lookup), 0, 0, 1, 1},
    {&__pyx_n_s_UInt16HashTable_map_locations, __pyx_k_UInt16HashTable_map_locations, sizeof(__pyx_k_UInt16HashTable_map_locations), 0, 0, 1, 1},
    {&__pyx_n_s_UInt16HashTable_set_item, __pyx_k_UInt16HashTable_set_item, sizeof(__pyx_k_UInt16HashTable_set_item), 0, 0, 1, 1},
    {&__pyx_n_s_UInt16HashTable_set_na, __pyx_k_UInt16HashTable_set_na, sizeof(__pyx_k_UInt16HashTable_set_na), 0, 0, 1, 1},
    {&__pyx_n_s_UInt16HashTable_sizeof, __pyx_k_UInt16HashTable_sizeof, sizeof(__pyx_k_UInt16HashTable_sizeof), 0, 0, 1, 1},
    {&__pyx_n_s_UInt16HashTable_unique, __pyx_k_UInt16HashTable_unique, sizeof(__pyx_k_UInt16HashTable_unique), 0, 0, 1, 1},
    {&__pyx_n_s_UInt16Vector, __pyx_k_UInt16Vector, sizeof(__pyx_k_UInt16Vector), 0, 0, 1, 1},
    {&__pyx_n_s_UInt16Vector___reduce_cython, __pyx_k_UInt16Vector___reduce_cython, sizeof(__pyx_k_UInt16Vector___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_UInt16Vector___setstate_cython, __pyx_k_UInt16Vector___setstate_cython, sizeof(__pyx_k_UInt16Vector___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_UInt16Vector_to_array, __pyx_k_UInt16Vector_to_array, sizeof(__pyx_k_UInt16Vector_to_array), 0, 0, 1, 1},
    {&__pyx_n_s_UInt32Factorizer, __pyx_k_UInt32Factorizer, sizeof(__pyx_k_UInt32Factorizer), 0, 0, 1, 1},
    {&__pyx_n_s_UInt32Factorizer___reduce_cython, __pyx_k_UInt32Factorizer___reduce_cython, sizeof(__pyx_k_UInt32Factorizer___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_UInt32Factorizer___setstate_cyth, __pyx_k_UInt32Factorizer___setstate_cyth, sizeof(__pyx_k_UInt32Factorizer___setstate_cyth), 0, 0, 1, 1},
    {&__pyx_n_s_UInt32Factorizer_factorize, __pyx_k_UInt32Factorizer_factorize, sizeof(__pyx_k_UInt32Factorizer_factorize), 0, 0, 1, 1},
    {&__pyx_kp_u_UInt32Factorizer_factorize_line, __pyx_k_UInt32Factorizer_factorize_line, sizeof(__pyx_k_UInt32Factorizer_factorize_line), 0, 1, 0, 0},
    {&__pyx_n_s_UInt32HashTable, __pyx_k_UInt32HashTable, sizeof(__pyx_k_UInt32HashTable), 0, 0, 1, 1},
    {&__pyx_n_s_UInt32HashTable___reduce_cython, __pyx_k_UInt32HashTable___reduce_cython, sizeof(__pyx_k_UInt32HashTable___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_UInt32HashTable___setstate_cytho, __pyx_k_UInt32HashTable___setstate_cytho, sizeof(__pyx_k_UInt32HashTable___setstate_cytho), 0, 0, 1, 1},
    {&__pyx_n_s_UInt32HashTable__unique, __pyx_k_UInt32HashTable__unique, sizeof(__pyx_k_UInt32HashTable__unique), 0, 0, 1, 1},
    {&__pyx_n_s_UInt32HashTable_factorize, __pyx_k_UInt32HashTable_factorize, sizeof(__pyx_k_UInt32HashTable_factorize), 0, 0, 1, 1},
    {&__pyx_n_s_UInt32HashTable_get_item, __pyx_k_UInt32HashTable_get_item, sizeof(__pyx_k_UInt32HashTable_get_item), 0, 0, 1, 1},
    {&__pyx_n_s_UInt32HashTable_get_labels, __pyx_k_UInt32HashTable_get_labels, sizeof(__pyx_k_UInt32HashTable_get_labels), 0, 0, 1, 1},
    {&__pyx_n_s_UInt32HashTable_get_na, __pyx_k_UInt32HashTable_get_na, sizeof(__pyx_k_UInt32HashTable_get_na), 0, 0, 1, 1},
    {&__pyx_n_s_UInt32HashTable_get_state, __pyx_k_UInt32HashTable_get_state, sizeof(__pyx_k_UInt32HashTable_get_state), 0, 0, 1, 1},
    {&__pyx_n_s_UInt32HashTable_lookup, __pyx_k_UInt32HashTable_lookup, sizeof(__pyx_k_UInt32HashTable_lookup), 0, 0, 1, 1},
    {&__pyx_n_s_UInt32HashTable_map_locations, __pyx_k_UInt32HashTable_map_locations, sizeof(__pyx_k_UInt32HashTable_map_locations), 0, 0, 1, 1},
    {&__pyx_n_s_UInt32HashTable_set_item, __pyx_k_UInt32HashTable_set_item, sizeof(__pyx_k_UInt32HashTable_set_item), 0, 0, 1, 1},
    {&__pyx_n_s_UInt32HashTable_set_na, __pyx_k_UInt32HashTable_set_na, sizeof(__pyx_k_UInt32HashTable_set_na), 0, 0, 1, 1},
    {&__pyx_n_s_UInt32HashTable_sizeof, __pyx_k_UInt32HashTable_sizeof, sizeof(__pyx_k_UInt32HashTable_sizeof), 0, 0, 1, 1},
    {&__pyx_n_s_UInt32HashTable_unique, __pyx_k_UInt32HashTable_unique, sizeof(__pyx_k_UInt32HashTable_unique), 0, 0, 1, 1},
    {&__pyx_n_s_UInt32Vector, __pyx_k_UInt32Vector, sizeof(__pyx_k_UInt32Vector), 0, 0, 1, 1},
    {&__pyx_n_s_UInt32Vector___reduce_cython, __pyx_k_UInt32Vector___reduce_cython, sizeof(__pyx_k_UInt32Vector___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_UInt32Vector___setstate_cython, __pyx_k_UInt32Vector___setstate_cython, sizeof(__pyx_k_UInt32Vector___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_UInt32Vector_to_array, __pyx_k_UInt32Vector_to_array, sizeof(__pyx_k_UInt32Vector_to_array), 0, 0, 1, 1},
    {&__pyx_n_s_UInt64Factorizer, __pyx_k_UInt64Factorizer, sizeof(__pyx_k_UInt64Factorizer), 0, 0, 1, 1},
    {&__pyx_n_s_UInt64Factorizer___reduce_cython, __pyx_k_UInt64Factorizer___reduce_cython, sizeof(__pyx_k_UInt64Factorizer___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_UInt64Factorizer___setstate_cyth, __pyx_k_UInt64Factorizer___setstate_cyth, sizeof(__pyx_k_UInt64Factorizer___setstate_cyth), 0, 0, 1, 1},
    {&__pyx_n_s_UInt64Factorizer_factorize, __pyx_k_UInt64Factorizer_factorize, sizeof(__pyx_k_UInt64Factorizer_factorize), 0, 0, 1, 1},
    {&__pyx_kp_u_UInt64Factorizer_factorize_line, __pyx_k_UInt64Factorizer_factorize_line, sizeof(__pyx_k_UInt64Factorizer_factorize_line), 0, 1, 0, 0},
    {&__pyx_n_s_UInt64HashTable, __pyx_k_UInt64HashTable, sizeof(__pyx_k_UInt64HashTable), 0, 0, 1, 1},
    {&__pyx_n_s_UInt64HashTable___reduce_cython, __pyx_k_UInt64HashTable___reduce_cython, sizeof(__pyx_k_UInt64HashTable___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_UInt64HashTable___setstate_cytho, __pyx_k_UInt64HashTable___setstate_cytho, sizeof(__pyx_k_UInt64HashTable___setstate_cytho), 0, 0, 1, 1},
    {&__pyx_n_s_UInt64HashTable__unique, __pyx_k_UInt64HashTable__unique, sizeof(__pyx_k_UInt64HashTable__unique), 0, 0, 1, 1},
    {&__pyx_n_s_UInt64HashTable_factorize, __pyx_k_UInt64HashTable_factorize, sizeof(__pyx_k_UInt64HashTable_factorize), 0, 0, 1, 1},
    {&__pyx_n_s_UInt64HashTable_get_item, __pyx_k_UInt64HashTable_get_item, sizeof(__pyx_k_UInt64HashTable_get_item), 0, 0, 1, 1},
    {&__pyx_n_s_UInt64HashTable_get_labels, __pyx_k_UInt64HashTable_get_labels, sizeof(__pyx_k_UInt64HashTable_get_labels), 0, 0, 1, 1},
    {&__pyx_n_s_UInt64HashTable_get_na, __pyx_k_UInt64HashTable_get_na, sizeof(__pyx_k_UInt64HashTable_get_na), 0, 0, 1, 1},
    {&__pyx_n_s_UInt64HashTable_get_state, __pyx_k_UInt64HashTable_get_state, sizeof(__pyx_k_UInt64HashTable_get_state), 0, 0, 1, 1},
    {&__pyx_n_s_UInt64HashTable_lookup, __pyx_k_UInt64HashTable_lookup, sizeof(__pyx_k_UInt64HashTable_lookup), 0, 0, 1, 1},
    {&__pyx_n_s_UInt64HashTable_map_locations, __pyx_k_UInt64HashTable_map_locations, sizeof(__pyx_k_UInt64HashTable_map_locations), 0, 0, 1, 1},
    {&__pyx_n_s_UInt64HashTable_set_item, __pyx_k_UInt64HashTable_set_item, sizeof(__pyx_k_UInt64HashTable_set_item), 0, 0, 1, 1},
    {&__pyx_n_s_UInt64HashTable_set_na, __pyx_k_UInt64HashTable_set_na, sizeof(__pyx_k_UInt64HashTable_set_na), 0, 0, 1, 1},
    {&__pyx_n_s_UInt64HashTable_sizeof, __pyx_k_UInt64HashTable_sizeof, sizeof(__pyx_k_UInt64HashTable_sizeof), 0, 0, 1, 1},
    {&__pyx_n_s_UInt64HashTable_unique, __pyx_k_UInt64HashTable_unique, sizeof(__pyx_k_UInt64HashTable_unique), 0, 0, 1, 1},
    {&__pyx_n_s_UInt64Vector, __pyx_k_UInt64Vector, sizeof(__pyx_k_UInt64Vector), 0, 0, 1, 1},
    {&__pyx_n_s_UInt64Vector___reduce_cython, __pyx_k_UInt64Vector___reduce_cython, sizeof(__pyx_k_UInt64Vector___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_UInt64Vector___setstate_cython, __pyx_k_UInt64Vector___setstate_cython, sizeof(__pyx_k_UInt64Vector___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_UInt64Vector_to_array, __pyx_k_UInt64Vector_to_array, sizeof(__pyx_k_UInt64Vector_to_array), 0, 0, 1, 1},
    {&__pyx_n_s_UInt8Factorizer, __pyx_k_UInt8Factorizer, sizeof(__pyx_k_UInt8Factorizer), 0, 0, 1, 1},
    {&__pyx_n_s_UInt8Factorizer___reduce_cython, __pyx_k_UInt8Factorizer___reduce_cython, sizeof(__pyx_k_UInt8Factorizer___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_UInt8Factorizer___setstate_cytho, __pyx_k_UInt8Factorizer___setstate_cytho, sizeof(__pyx_k_UInt8Factorizer___setstate_cytho), 0, 0, 1, 1},
    {&__pyx_n_s_UInt8Factorizer_factorize, __pyx_k_UInt8Factorizer_factorize, sizeof(__pyx_k_UInt8Factorizer_factorize), 0, 0, 1, 1},
    {&__pyx_kp_u_UInt8Factorizer_factorize_line_6, __pyx_k_UInt8Factorizer_factorize_line_6, sizeof(__pyx_k_UInt8Factorizer_factorize_line_6), 0, 1, 0, 0},
    {&__pyx_n_s_UInt8HashTable, __pyx_k_UInt8HashTable, sizeof(__pyx_k_UInt8HashTable), 0, 0, 1, 1},
    {&__pyx_n_s_UInt8HashTable___reduce_cython, __pyx_k_UInt8HashTable___reduce_cython, sizeof(__pyx_k_UInt8HashTable___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_UInt8HashTable___setstate_cython, __pyx_k_UInt8HashTable___setstate_cython, sizeof(__pyx_k_UInt8HashTable___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_UInt8HashTable__unique, __pyx_k_UInt8HashTable__unique, sizeof(__pyx_k_UInt8HashTable__unique), 0, 0, 1, 1},
    {&__pyx_n_s_UInt8HashTable_factorize, __pyx_k_UInt8HashTable_factorize, sizeof(__pyx_k_UInt8HashTable_factorize), 0, 0, 1, 1},
    {&__pyx_n_s_UInt8HashTable_get_item, __pyx_k_UInt8HashTable_get_item, sizeof(__pyx_k_UInt8HashTable_get_item), 0, 0, 1, 1},
    {&__pyx_n_s_UInt8HashTable_get_labels, __pyx_k_UInt8HashTable_get_labels, sizeof(__pyx_k_UInt8HashTable_get_labels), 0, 0, 1, 1},
    {&__pyx_n_s_UInt8HashTable_get_na, __pyx_k_UInt8HashTable_get_na, sizeof(__pyx_k_UInt8HashTable_get_na), 0, 0, 1, 1},
    {&__pyx_n_s_UInt8HashTable_get_state, __pyx_k_UInt8HashTable_get_state, sizeof(__pyx_k_UInt8HashTable_get_state), 0, 0, 1, 1},
    {&__pyx_n_s_UInt8HashTable_lookup, __pyx_k_UInt8HashTable_lookup, sizeof(__pyx_k_UInt8HashTable_lookup), 0, 0, 1, 1},
    {&__pyx_n_s_UInt8HashTable_map_locations, __pyx_k_UInt8HashTable_map_locations, sizeof(__pyx_k_UInt8HashTable_map_locations), 0, 0, 1, 1},
    {&__pyx_n_s_UInt8HashTable_set_item, __pyx_k_UInt8HashTable_set_item, sizeof(__pyx_k_UInt8HashTable_set_item), 0, 0, 1, 1},
    {&__pyx_n_s_UInt8HashTable_set_na, __pyx_k_UInt8HashTable_set_na, sizeof(__pyx_k_UInt8HashTable_set_na), 0, 0, 1, 1},
    {&__pyx_n_s_UInt8HashTable_sizeof, __pyx_k_UInt8HashTable_sizeof, sizeof(__pyx_k_UInt8HashTable_sizeof), 0, 0, 1, 1},
    {&__pyx_n_s_UInt8HashTable_unique, __pyx_k_UInt8HashTable_unique, sizeof(__pyx_k_UInt8HashTable_unique), 0, 0, 1, 1},
    {&__pyx_n_s_UInt8Vector, __pyx_k_UInt8Vector, sizeof(__pyx_k_UInt8Vector), 0, 0, 1, 1},
    {&__pyx_n_s_UInt8Vector___reduce_cython, __pyx_k_UInt8Vector___reduce_cython, sizeof(__pyx_k_UInt8Vector___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_UInt8Vector___setstate_cython, __pyx_k_UInt8Vector___setstate_cython, sizeof(__pyx_k_UInt8Vector___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_UInt8Vector_to_array, __pyx_k_UInt8Vector_to_array, sizeof(__pyx_k_UInt8Vector_to_array), 0, 0, 1, 1},
    {&__pyx_kp_s_Unable_to_convert_item_to_object, __pyx_k_Unable_to_convert_item_to_object, sizeof(__pyx_k_Unable_to_convert_item_to_object), 0, 0, 1, 0},
    {&__pyx_n_s_UnicodeEncodeError, __pyx_k_UnicodeEncodeError, sizeof(__pyx_k_UnicodeEncodeError), 0, 0, 1, 1},
    {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
    {&__pyx_n_s_Vector, __pyx_k_Vector, sizeof(__pyx_k_Vector), 0, 0, 1, 1},
    {&__pyx_n_s_Vector___reduce_cython, __pyx_k_Vector___reduce_cython, sizeof(__pyx_k_Vector___reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_Vector___setstate_cython, __pyx_k_Vector___setstate_cython, sizeof(__pyx_k_Vector___setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_View_MemoryView, __pyx_k_View_MemoryView, sizeof(__pyx_k_View_MemoryView), 0, 0, 1, 1},
    {&__pyx_n_s__191, __pyx_k__191, sizeof(__pyx_k__191), 0, 0, 1, 1},
    {&__pyx_kp_u__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 1, 0, 0},
    {&__pyx_n_s__3, __pyx_k__3, sizeof(__pyx_k__3), 0, 0, 1, 1},
    {&__pyx_n_s__490, __pyx_k__490, sizeof(__pyx_k__490), 0, 0, 1, 1},
    {&__pyx_kp_u__6, __pyx_k__6, sizeof(__pyx_k__6), 0, 1, 0, 0},
    {&__pyx_kp_s__69, __pyx_k__69, sizeof(__pyx_k__69), 0, 0, 1, 0},
    {&__pyx_kp_u__7, __pyx_k__7, sizeof(__pyx_k__7), 0, 1, 0, 0},
    {&__pyx_kp_s__70, __pyx_k__70, sizeof(__pyx_k__70), 0, 0, 1, 0},
    {&__pyx_kp_u__70, __pyx_k__70, sizeof(__pyx_k__70), 0, 1, 0, 0},
    {&__pyx_kp_s__86, __pyx_k__86, sizeof(__pyx_k__86), 0, 0, 1, 0},
    {&__pyx_n_s_a, __pyx_k_a, sizeof(__pyx_k_a), 0, 0, 1, 1},
    {&__pyx_n_s_abc, __pyx_k_abc, sizeof(__pyx_k_abc), 0, 0, 1, 1},
    {&__pyx_n_s_allocate_buffer, __pyx_k_allocate_buffer, sizeof(__pyx_k_allocate_buffer), 0, 0, 1, 1},
    {&__pyx_kp_u_and, __pyx_k_and, sizeof(__pyx_k_and), 0, 1, 0, 0},
    {&__pyx_n_s_args, __pyx_k_args, sizeof(__pyx_k_args), 0, 0, 1, 1},
    {&__pyx_n_s_argsort, __pyx_k_argsort, sizeof(__pyx_k_argsort), 0, 0, 1, 1},
    {&__pyx_n_s_arr, __pyx_k_arr, sizeof(__pyx_k_arr), 0, 0, 1, 1},
    {&__pyx_n_s_arr_uniques, __pyx_k_arr_uniques, sizeof(__pyx_k_arr_uniques), 0, 0, 1, 1},
    {&__pyx_n_s_asarray, __pyx_k_asarray, sizeof(__pyx_k_asarray), 0, 0, 1, 1},
    {&__pyx_n_s_asyncio_coroutines, __pyx_k_asyncio_coroutines, sizeof(__pyx_k_asyncio_coroutines), 0, 0, 1, 1},
    {&__pyx_n_s_b, __pyx_k_b, sizeof(__pyx_k_b), 0, 0, 1, 1},
    {&__pyx_n_s_base, __pyx_k_base, sizeof(__pyx_k_base), 0, 0, 1, 1},
    {&__pyx_n_s_bool, __pyx_k_bool, sizeof(__pyx_k_bool), 0, 0, 1, 1},
    {&__pyx_n_u_bool, __pyx_k_bool, sizeof(__pyx_k_bool), 0, 1, 0, 1},
    {&__pyx_n_s_bool_2, __pyx_k_bool_2, sizeof(__pyx_k_bool_2), 0, 0, 1, 1},
    {&__pyx_n_s_c, __pyx_k_c, sizeof(__pyx_k_c), 0, 0, 1, 1},
    {&__pyx_n_u_c, __pyx_k_c, sizeof(__pyx_k_c), 0, 1, 0, 1},
    {&__pyx_n_s_class, __pyx_k_class, sizeof(__pyx_k_class), 0, 0, 1, 1},
    {&__pyx_n_s_class_getitem, __pyx_k_class_getitem, sizeof(__pyx_k_class_getitem), 0, 0, 1, 1},
    {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
    {&__pyx_n_s_collections, __pyx_k_collections, sizeof(__pyx_k_collections), 0, 0, 1, 1},
    {&__pyx_kp_s_collections_abc, __pyx_k_collections_abc, sizeof(__pyx_k_collections_abc), 0, 0, 1, 0},
    {&__pyx_n_s_complex128, __pyx_k_complex128, sizeof(__pyx_k_complex128), 0, 0, 1, 1},
    {&__pyx_n_s_complex64, __pyx_k_complex64, sizeof(__pyx_k_complex64), 0, 0, 1, 1},
    {&__pyx_kp_s_contiguous_and_direct, __pyx_k_contiguous_and_direct, sizeof(__pyx_k_contiguous_and_direct), 0, 0, 1, 0},
    {&__pyx_kp_s_contiguous_and_indirect, __pyx_k_contiguous_and_indirect, sizeof(__pyx_k_contiguous_and_indirect), 0, 0, 1, 0},
    {&__pyx_n_s_count, __pyx_k_count, sizeof(__pyx_k_count), 0, 0, 1, 1},
    {&__pyx_n_s_count_prior, __pyx_k_count_prior, sizeof(__pyx_k_count_prior), 0, 0, 1, 1},
    {&__pyx_n_s_counts, __pyx_k_counts, sizeof(__pyx_k_counts), 0, 0, 1, 1},
    {&__pyx_n_s_deep, __pyx_k_deep, sizeof(__pyx_k_deep), 0, 0, 1, 1},
    {&__pyx_n_s_defaults, __pyx_k_defaults, sizeof(__pyx_k_defaults), 0, 0, 1, 1},
    {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
    {&__pyx_n_s_dict_2, __pyx_k_dict_2, sizeof(__pyx_k_dict_2), 0, 0, 1, 1},
    {&__pyx_kp_s_dict_str_int, __pyx_k_dict_str_int, sizeof(__pyx_k_dict_str_int), 0, 0, 1, 0},
    {&__pyx_kp_u_disable, __pyx_k_disable, sizeof(__pyx_k_disable), 0, 1, 0, 0},
    {&__pyx_kp_s_double_complex, __pyx_k_double_complex, sizeof(__pyx_k_double_complex), 0, 0, 1, 0},
    {&__pyx_n_s_dropna, __pyx_k_dropna, sizeof(__pyx_k_dropna), 0, 0, 1, 1},
    {&__pyx_n_s_dtype, __pyx_k_dtype, sizeof(__pyx_k_dtype), 0, 0, 1, 1},
    {&__pyx_n_s_dtype_is_object, __pyx_k_dtype_is_object, sizeof(__pyx_k_dtype_is_object), 0, 0, 1, 1},
    {&__pyx_n_s_duplicated, __pyx_k_duplicated, sizeof(__pyx_k_duplicated), 0, 0, 1, 1},
    {&__pyx_n_s_empty, __pyx_k_empty, sizeof(__pyx_k_empty), 0, 0, 1, 1},
    {&__pyx_kp_u_enable, __pyx_k_enable, sizeof(__pyx_k_enable), 0, 1, 0, 0},
    {&__pyx_n_s_encode, __pyx_k_encode, sizeof(__pyx_k_encode), 0, 0, 1, 1},
    {&__pyx_n_s_enumerate, __pyx_k_enumerate, sizeof(__pyx_k_enumerate), 0, 0, 1, 1},
    {&__pyx_n_s_error, __pyx_k_error, sizeof(__pyx_k_error), 0, 0, 1, 1},
    {&__pyx_kp_u_external_reference_but_Vector_re, __pyx_k_external_reference_but_Vector_re, sizeof(__pyx_k_external_reference_but_Vector_re), 0, 1, 0, 0},
    {&__pyx_kp_u_external_reference_to_result_mas, __pyx_k_external_reference_to_result_mas, sizeof(__pyx_k_external_reference_to_result_mas), 0, 1, 0, 0},
    {&__pyx_kp_u_external_reference_to_uniques_he, __pyx_k_external_reference_to_uniques_he, sizeof(__pyx_k_external_reference_to_uniques_he), 0, 1, 0, 0},
    {&__pyx_n_s_factorize, __pyx_k_factorize, sizeof(__pyx_k_factorize), 0, 0, 1, 1},
    {&__pyx_n_u_first, __pyx_k_first, sizeof(__pyx_k_first), 0, 1, 0, 1},
    {&__pyx_n_s_flags, __pyx_k_flags, sizeof(__pyx_k_flags), 0, 0, 1, 1},
    {&__pyx_n_s_float32, __pyx_k_float32, sizeof(__pyx_k_float32), 0, 0, 1, 1},
    {&__pyx_n_s_float32_t, __pyx_k_float32_t, sizeof(__pyx_k_float32_t), 0, 0, 1, 1},
    {&__pyx_n_s_float64, __pyx_k_float64, sizeof(__pyx_k_float64), 0, 0, 1, 1},
    {&__pyx_n_s_float64_t, __pyx_k_float64_t, sizeof(__pyx_k_float64_t), 0, 0, 1, 1},
    {&__pyx_kp_s_float_complex, __pyx_k_float_complex, sizeof(__pyx_k_float_complex), 0, 0, 1, 0},
    {&__pyx_n_s_for_flags, __pyx_k_for_flags, sizeof(__pyx_k_for_flags), 0, 0, 1, 1},
    {&__pyx_n_s_for_pairs, __pyx_k_for_pairs, sizeof(__pyx_k_for_pairs), 0, 0, 1, 1},
    {&__pyx_n_s_format, __pyx_k_format, sizeof(__pyx_k_format), 0, 0, 1, 1},
    {&__pyx_n_s_fortran, __pyx_k_fortran, sizeof(__pyx_k_fortran), 0, 0, 1, 1},
    {&__pyx_n_u_fortran, __pyx_k_fortran, sizeof(__pyx_k_fortran), 0, 1, 0, 1},
    {&__pyx_n_s_fused_sigindex, __pyx_k_fused_sigindex, sizeof(__pyx_k_fused_sigindex), 0, 0, 1, 1},
    {&__pyx_kp_u_gc, __pyx_k_gc, sizeof(__pyx_k_gc), 0, 1, 0, 0},
    {&__pyx_n_s_get, __pyx_k_get, sizeof(__pyx_k_get), 0, 0, 1, 1},
    {&__pyx_n_s_get_count, __pyx_k_get_count, sizeof(__pyx_k_get_count), 0, 0, 1, 1},
    {&__pyx_n_s_get_hashtable_trace_domain, __pyx_k_get_hashtable_trace_domain, sizeof(__pyx_k_get_hashtable_trace_domain), 0, 0, 1, 1},
    {&__pyx_n_s_get_indexer, __pyx_k_get_indexer, sizeof(__pyx_k_get_indexer), 0, 0, 1, 1},
    {&__pyx_n_s_get_item, __pyx_k_get_item, sizeof(__pyx_k_get_item), 0, 0, 1, 1},
    {&__pyx_n_s_get_labels, __pyx_k_get_labels, sizeof(__pyx_k_get_labels), 0, 0, 1, 1},
    {&__pyx_n_s_get_labels_groupby, __pyx_k_get_labels_groupby, sizeof(__pyx_k_get_labels_groupby), 0, 0, 1, 1},
    {&__pyx_n_s_get_na, __pyx_k_get_na, sizeof(__pyx_k_get_na), 0, 0, 1, 1},
    {&__pyx_n_s_get_state, __pyx_k_get_state, sizeof(__pyx_k_get_state), 0, 0, 1, 1},
    {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
    {&__pyx_kp_u_got, __pyx_k_got, sizeof(__pyx_k_got), 0, 1, 0, 0},
    {&__pyx_kp_u_got_differing_extents_in_dimensi, __pyx_k_got_differing_extents_in_dimensi, sizeof(__pyx_k_got_differing_extents_in_dimensi), 0, 1, 0, 0},
    {&__pyx_n_s_i, __pyx_k_i, sizeof(__pyx_k_i), 0, 0, 1, 1},
    {&__pyx_n_s_id, __pyx_k_id, sizeof(__pyx_k_id), 0, 0, 1, 1},
    {&__pyx_n_s_idx, __pyx_k_idx, sizeof(__pyx_k_idx), 0, 0, 1, 1},
    {&__pyx_n_s_ignore_na, __pyx_k_ignore_na, sizeof(__pyx_k_ignore_na), 0, 0, 1, 1},
    {&__pyx_n_s_imag, __pyx_k_imag, sizeof(__pyx_k_imag), 0, 0, 1, 1},
    {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
    {&__pyx_n_s_index, __pyx_k_index, sizeof(__pyx_k_index), 0, 0, 1, 1},
    {&__pyx_n_s_initializing, __pyx_k_initializing, sizeof(__pyx_k_initializing), 0, 0, 1, 1},
    {&__pyx_n_s_int, __pyx_k_int, sizeof(__pyx_k_int), 0, 0, 1, 1},
    {&__pyx_n_s_int16, __pyx_k_int16, sizeof(__pyx_k_int16), 0, 0, 1, 1},
    {&__pyx_n_s_int16_t, __pyx_k_int16_t, sizeof(__pyx_k_int16_t), 0, 0, 1, 1},
    {&__pyx_n_s_int32, __pyx_k_int32, sizeof(__pyx_k_int32), 0, 0, 1, 1},
    {&__pyx_n_s_int32_t, __pyx_k_int32_t, sizeof(__pyx_k_int32_t), 0, 0, 1, 1},
    {&__pyx_n_s_int64, __pyx_k_int64, sizeof(__pyx_k_int64), 0, 0, 1, 1},
    {&__pyx_n_s_int64_t, __pyx_k_int64_t, sizeof(__pyx_k_int64_t), 0, 0, 1, 1},
    {&__pyx_n_s_int8, __pyx_k_int8, sizeof(__pyx_k_int8), 0, 0, 1, 1},
    {&__pyx_n_s_int8_t, __pyx_k_int8_t, sizeof(__pyx_k_int8_t), 0, 0, 1, 1},
    {&__pyx_n_s_intp, __pyx_k_intp, sizeof(__pyx_k_intp), 0, 0, 1, 1},
    {&__pyx_n_s_is_coroutine, __pyx_k_is_coroutine, sizeof(__pyx_k_is_coroutine), 0, 0, 1, 1},
    {&__pyx_kp_u_isenabled, __pyx_k_isenabled, sizeof(__pyx_k_isenabled), 0, 1, 0, 0},
    {&__pyx_n_s_ismember, __pyx_k_ismember, sizeof(__pyx_k_ismember), 0, 0, 1, 1},
    {&__pyx_n_s_itemsize, __pyx_k_itemsize, sizeof(__pyx_k_itemsize), 0, 0, 1, 1},
    {&__pyx_kp_s_itemsize_0_for_cython_array, __pyx_k_itemsize_0_for_cython_array, sizeof(__pyx_k_itemsize_0_for_cython_array), 0, 0, 1, 0},
    {&__pyx_n_s_j, __pyx_k_j, sizeof(__pyx_k_j), 0, 0, 1, 1},
    {&__pyx_n_s_k, __pyx_k_k, sizeof(__pyx_k_k), 0, 0, 1, 1},
    {&__pyx_n_s_keep, __pyx_k_keep, sizeof(__pyx_k_keep), 0, 0, 1, 1},
    {&__pyx_kp_u_keep_must_be_either_first_last_o, __pyx_k_keep_must_be_either_first_last_o, sizeof(__pyx_k_keep_must_be_either_first_last_o), 0, 1, 0, 0},
    {&__pyx_n_s_key, __pyx_k_key, sizeof(__pyx_k_key), 0, 0, 1, 1},
    {&__pyx_n_s_keys, __pyx_k_keys, sizeof(__pyx_k_keys), 0, 0, 1, 1},
    {&__pyx_n_s_kind, __pyx_k_kind, sizeof(__pyx_k_kind), 0, 0, 1, 1},
    {&__pyx_n_s_kwargs, __pyx_k_kwargs, sizeof(__pyx_k_kwargs), 0, 0, 1, 1},
    {&__pyx_n_s_labels, __pyx_k_labels, sizeof(__pyx_k_labels), 0, 0, 1, 1},
    {&__pyx_n_u_last, __pyx_k_last, sizeof(__pyx_k_last), 0, 1, 0, 1},
    {&__pyx_n_s_locs, __pyx_k_locs, sizeof(__pyx_k_locs), 0, 0, 1, 1},
    {&__pyx_n_s_lookup, __pyx_k_lookup, sizeof(__pyx_k_lookup), 0, 0, 1, 1},
    {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
    {&__pyx_n_s_map_keys_to_values, __pyx_k_map_keys_to_values, sizeof(__pyx_k_map_keys_to_values), 0, 0, 1, 1},
    {&__pyx_n_s_map_locations, __pyx_k_map_locations, sizeof(__pyx_k_map_locations), 0, 0, 1, 1},
    {&__pyx_n_s_mask, __pyx_k_mask, sizeof(__pyx_k_mask), 0, 0, 1, 1},
    {&__pyx_kp_u_mask_not_supported_for_ObjectFac, __pyx_k_mask_not_supported_for_ObjectFac, sizeof(__pyx_k_mask_not_supported_for_ObjectFac), 0, 1, 0, 0},
    {&__pyx_n_s_mask_values, __pyx_k_mask_values, sizeof(__pyx_k_mask_values), 0, 0, 1, 1},
    {&__pyx_n_s_max_count, __pyx_k_max_count, sizeof(__pyx_k_max_count), 0, 0, 1, 1},
    {&__pyx_n_s_memview, __pyx_k_memview, sizeof(__pyx_k_memview), 0, 0, 1, 1},
    {&__pyx_n_s_mode, __pyx_k_mode, sizeof(__pyx_k_mode), 0, 0, 1, 1},
    {&__pyx_n_s_modes, __pyx_k_modes, sizeof(__pyx_k_modes), 0, 0, 1, 1},
    {&__pyx_n_s_n, __pyx_k_n, sizeof(__pyx_k_n), 0, 0, 1, 1},
    {&__pyx_n_u_n_buckets, __pyx_k_n_buckets, sizeof(__pyx_k_n_buckets), 0, 1, 0, 1},
    {&__pyx_n_u_n_occupied, __pyx_k_n_occupied, sizeof(__pyx_k_n_occupied), 0, 1, 0, 1},
    {&__pyx_n_s_na_position, __pyx_k_na_position, sizeof(__pyx_k_na_position), 0, 0, 1, 1},
    {&__pyx_n_s_na_sentinel, __pyx_k_na_sentinel, sizeof(__pyx_k_na_sentinel), 0, 0, 1, 1},
    {&__pyx_n_s_na_string_sentinel, __pyx_k_na_string_sentinel, sizeof(__pyx_k_na_string_sentinel), 0, 0, 1, 1},
    {&__pyx_n_s_na_value, __pyx_k_na_value, sizeof(__pyx_k_na_value), 0, 0, 1, 1},
    {&__pyx_n_s_na_value2, __pyx_k_na_value2, sizeof(__pyx_k_na_value2), 0, 0, 1, 1},
    {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
    {&__pyx_n_s_name_2, __pyx_k_name_2, sizeof(__pyx_k_name_2), 0, 0, 1, 1},
    {&__pyx_n_u_nan, __pyx_k_nan, sizeof(__pyx_k_nan), 0, 1, 0, 1},
    {&__pyx_n_s_ndarray, __pyx_k_ndarray, sizeof(__pyx_k_ndarray), 0, 0, 1, 1},
    {&__pyx_n_s_ndim, __pyx_k_ndim, sizeof(__pyx_k_ndim), 0, 0, 1, 1},
    {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
    {&__pyx_n_s_nkeys, __pyx_k_nkeys, sizeof(__pyx_k_nkeys), 0, 0, 1, 1},
    {&__pyx_kp_s_no_default___reduce___due_to_non, __pyx_k_no_default___reduce___due_to_non, sizeof(__pyx_k_no_default___reduce___due_to_non), 0, 0, 1, 0},
    {&__pyx_n_s_np, __pyx_k_np, sizeof(__pyx_k_np), 0, 0, 1, 1},
    {&__pyx_kp_s_np_ndarray, __pyx_k_np_ndarray, sizeof(__pyx_k_np_ndarray), 0, 0, 1, 0},
    {&__pyx_n_s_numpy, __pyx_k_numpy, sizeof(__pyx_k_numpy), 0, 0, 1, 1},
    {&__pyx_kp_u_numpy_core_multiarray_failed_to, __pyx_k_numpy_core_multiarray_failed_to, sizeof(__pyx_k_numpy_core_multiarray_failed_to), 0, 1, 0, 0},
    {&__pyx_kp_u_numpy_core_umath_failed_to_impor, __pyx_k_numpy_core_umath_failed_to_impor, sizeof(__pyx_k_numpy_core_umath_failed_to_impor), 0, 1, 0, 0},
    {&__pyx_n_s_obj, __pyx_k_obj, sizeof(__pyx_k_obj), 0, 0, 1, 1},
    {&__pyx_n_s_object, __pyx_k_object, sizeof(__pyx_k_object), 0, 0, 1, 1},
    {&__pyx_n_s_object_hash, __pyx_k_object_hash, sizeof(__pyx_k_object_hash), 0, 0, 1, 1},
    {&__pyx_n_s_objects_are_equal, __pyx_k_objects_are_equal, sizeof(__pyx_k_objects_are_equal), 0, 0, 1, 1},
    {&__pyx_n_s_overhead, __pyx_k_overhead, sizeof(__pyx_k_overhead), 0, 0, 1, 1},
    {&__pyx_n_s_pack, __pyx_k_pack, sizeof(__pyx_k_pack), 0, 0, 1, 1},
    {&__pyx_n_s_pandas__libs_hashtable, __pyx_k_pandas__libs_hashtable, sizeof(__pyx_k_pandas__libs_hashtable), 0, 0, 1, 1},
    {&__pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_k_pandas__libs_hashtable_class_hel, sizeof(__pyx_k_pandas__libs_hashtable_class_hel), 0, 0, 1, 0},
    {&__pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_k_pandas__libs_hashtable_func_help, sizeof(__pyx_k_pandas__libs_hashtable_func_help), 0, 0, 1, 0},
    {&__pyx_kp_s_pandas__libs_hashtable_pyx, __pyx_k_pandas__libs_hashtable_pyx, sizeof(__pyx_k_pandas__libs_hashtable_pyx), 0, 0, 1, 0},
    {&__pyx_n_s_pickle, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_PickleError, __pyx_k_pyx_PickleError, sizeof(__pyx_k_pyx_PickleError), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_checksum, __pyx_k_pyx_checksum, sizeof(__pyx_k_pyx_checksum), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_0duplicated, __pyx_k_pyx_fuse_0duplicated, sizeof(__pyx_k_pyx_fuse_0duplicated), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_0ismember, __pyx_k_pyx_fuse_0ismember, sizeof(__pyx_k_pyx_fuse_0ismember), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_0value_count, __pyx_k_pyx_fuse_0value_count, sizeof(__pyx_k_pyx_fuse_0value_count), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_10duplicated, __pyx_k_pyx_fuse_10duplicated, sizeof(__pyx_k_pyx_fuse_10duplicated), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_10ismember, __pyx_k_pyx_fuse_10ismember, sizeof(__pyx_k_pyx_fuse_10ismember), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_10value_count, __pyx_k_pyx_fuse_10value_count, sizeof(__pyx_k_pyx_fuse_10value_count), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_11duplicated, __pyx_k_pyx_fuse_11duplicated, sizeof(__pyx_k_pyx_fuse_11duplicated), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_11ismember, __pyx_k_pyx_fuse_11ismember, sizeof(__pyx_k_pyx_fuse_11ismember), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_11value_count, __pyx_k_pyx_fuse_11value_count, sizeof(__pyx_k_pyx_fuse_11value_count), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_12duplicated, __pyx_k_pyx_fuse_12duplicated, sizeof(__pyx_k_pyx_fuse_12duplicated), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_12ismember, __pyx_k_pyx_fuse_12ismember, sizeof(__pyx_k_pyx_fuse_12ismember), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_12value_count, __pyx_k_pyx_fuse_12value_count, sizeof(__pyx_k_pyx_fuse_12value_count), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_1duplicated, __pyx_k_pyx_fuse_1duplicated, sizeof(__pyx_k_pyx_fuse_1duplicated), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_1ismember, __pyx_k_pyx_fuse_1ismember, sizeof(__pyx_k_pyx_fuse_1ismember), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_1value_count, __pyx_k_pyx_fuse_1value_count, sizeof(__pyx_k_pyx_fuse_1value_count), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_2duplicated, __pyx_k_pyx_fuse_2duplicated, sizeof(__pyx_k_pyx_fuse_2duplicated), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_2ismember, __pyx_k_pyx_fuse_2ismember, sizeof(__pyx_k_pyx_fuse_2ismember), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_2value_count, __pyx_k_pyx_fuse_2value_count, sizeof(__pyx_k_pyx_fuse_2value_count), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_3duplicated, __pyx_k_pyx_fuse_3duplicated, sizeof(__pyx_k_pyx_fuse_3duplicated), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_3ismember, __pyx_k_pyx_fuse_3ismember, sizeof(__pyx_k_pyx_fuse_3ismember), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_3value_count, __pyx_k_pyx_fuse_3value_count, sizeof(__pyx_k_pyx_fuse_3value_count), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_4duplicated, __pyx_k_pyx_fuse_4duplicated, sizeof(__pyx_k_pyx_fuse_4duplicated), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_4ismember, __pyx_k_pyx_fuse_4ismember, sizeof(__pyx_k_pyx_fuse_4ismember), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_4value_count, __pyx_k_pyx_fuse_4value_count, sizeof(__pyx_k_pyx_fuse_4value_count), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_5duplicated, __pyx_k_pyx_fuse_5duplicated, sizeof(__pyx_k_pyx_fuse_5duplicated), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_5ismember, __pyx_k_pyx_fuse_5ismember, sizeof(__pyx_k_pyx_fuse_5ismember), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_5value_count, __pyx_k_pyx_fuse_5value_count, sizeof(__pyx_k_pyx_fuse_5value_count), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_6duplicated, __pyx_k_pyx_fuse_6duplicated, sizeof(__pyx_k_pyx_fuse_6duplicated), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_6ismember, __pyx_k_pyx_fuse_6ismember, sizeof(__pyx_k_pyx_fuse_6ismember), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_6value_count, __pyx_k_pyx_fuse_6value_count, sizeof(__pyx_k_pyx_fuse_6value_count), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_7duplicated, __pyx_k_pyx_fuse_7duplicated, sizeof(__pyx_k_pyx_fuse_7duplicated), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_7ismember, __pyx_k_pyx_fuse_7ismember, sizeof(__pyx_k_pyx_fuse_7ismember), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_7value_count, __pyx_k_pyx_fuse_7value_count, sizeof(__pyx_k_pyx_fuse_7value_count), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_8duplicated, __pyx_k_pyx_fuse_8duplicated, sizeof(__pyx_k_pyx_fuse_8duplicated), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_8ismember, __pyx_k_pyx_fuse_8ismember, sizeof(__pyx_k_pyx_fuse_8ismember), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_8value_count, __pyx_k_pyx_fuse_8value_count, sizeof(__pyx_k_pyx_fuse_8value_count), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_9duplicated, __pyx_k_pyx_fuse_9duplicated, sizeof(__pyx_k_pyx_fuse_9duplicated), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_9ismember, __pyx_k_pyx_fuse_9ismember, sizeof(__pyx_k_pyx_fuse_9ismember), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_fuse_9value_count, __pyx_k_pyx_fuse_9value_count, sizeof(__pyx_k_pyx_fuse_9value_count), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_result, __pyx_k_pyx_result, sizeof(__pyx_k_pyx_result), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_state, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_type, __pyx_k_pyx_type, sizeof(__pyx_k_pyx_type), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_unpickle_Enum, __pyx_k_pyx_unpickle_Enum, sizeof(__pyx_k_pyx_unpickle_Enum), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_unpickle_HashTable, __pyx_k_pyx_unpickle_HashTable, sizeof(__pyx_k_pyx_unpickle_HashTable), 0, 0, 1, 1},
    {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
    {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
    {&__pyx_n_s_real, __pyx_k_real, sizeof(__pyx_k_real), 0, 0, 1, 1},
    {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
    {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
    {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
    {&__pyx_n_s_refcheck, __pyx_k_refcheck, sizeof(__pyx_k_refcheck), 0, 0, 1, 1},
    {&__pyx_n_s_register, __pyx_k_register, sizeof(__pyx_k_register), 0, 0, 1, 1},
    {&__pyx_n_s_resbuf, __pyx_k_resbuf, sizeof(__pyx_k_resbuf), 0, 0, 1, 1},
    {&__pyx_n_s_resize, __pyx_k_resize, sizeof(__pyx_k_resize), 0, 0, 1, 1},
    {&__pyx_n_s_result_mask, __pyx_k_result_mask, sizeof(__pyx_k_result_mask), 0, 0, 1, 1},
    {&__pyx_n_s_ret, __pyx_k_ret, sizeof(__pyx_k_ret), 0, 0, 1, 1},
    {&__pyx_n_s_return, __pyx_k_return, sizeof(__pyx_k_return), 0, 0, 1, 1},
    {&__pyx_n_s_return_inverse, __pyx_k_return_inverse, sizeof(__pyx_k_return_inverse), 0, 0, 1, 1},
    {&__pyx_n_s_rmd, __pyx_k_rmd, sizeof(__pyx_k_rmd), 0, 0, 1, 1},
    {&__pyx_n_s_s, __pyx_k_s, sizeof(__pyx_k_s), 0, 0, 1, 1},
    {&__pyx_n_s_seen_na, __pyx_k_seen_na, sizeof(__pyx_k_seen_na), 0, 0, 1, 1},
    {&__pyx_n_s_self, __pyx_k_self, sizeof(__pyx_k_self), 0, 0, 1, 1},
    {&__pyx_kp_s_self_table_cannot_be_converted_t, __pyx_k_self_table_cannot_be_converted_t, sizeof(__pyx_k_self_table_cannot_be_converted_t), 0, 0, 1, 0},
    {&__pyx_n_s_set_item, __pyx_k_set_item, sizeof(__pyx_k_set_item), 0, 0, 1, 1},
    {&__pyx_n_s_set_na, __pyx_k_set_na, sizeof(__pyx_k_set_na), 0, 0, 1, 1},
    {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
    {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
    {&__pyx_n_s_shape, __pyx_k_shape, sizeof(__pyx_k_shape), 0, 0, 1, 1},
    {&__pyx_kp_u_should_have_raised_on_append, __pyx_k_should_have_raised_on_append, sizeof(__pyx_k_should_have_raised_on_append), 0, 1, 0, 0},
    {&__pyx_n_s_signatures, __pyx_k_signatures, sizeof(__pyx_k_signatures), 0, 0, 1, 1},
    {&__pyx_n_s_size, __pyx_k_size, sizeof(__pyx_k_size), 0, 0, 1, 1},
    {&__pyx_n_u_size, __pyx_k_size, sizeof(__pyx_k_size), 0, 1, 0, 1},
    {&__pyx_n_s_size_hint, __pyx_k_size_hint, sizeof(__pyx_k_size_hint), 0, 0, 1, 1},
    {&__pyx_n_s_sizeof, __pyx_k_sizeof, sizeof(__pyx_k_sizeof), 0, 0, 1, 1},
    {&__pyx_n_s_spec, __pyx_k_spec, sizeof(__pyx_k_spec), 0, 0, 1, 1},
    {&__pyx_n_s_split, __pyx_k_split, sizeof(__pyx_k_split), 0, 0, 1, 1},
    {&__pyx_n_s_start, __pyx_k_start, sizeof(__pyx_k_start), 0, 0, 1, 1},
    {&__pyx_n_s_state, __pyx_k_state, sizeof(__pyx_k_state), 0, 0, 1, 1},
    {&__pyx_n_s_step, __pyx_k_step, sizeof(__pyx_k_step), 0, 0, 1, 1},
    {&__pyx_n_s_stop, __pyx_k_stop, sizeof(__pyx_k_stop), 0, 0, 1, 1},
    {&__pyx_kp_s_strided_and_direct, __pyx_k_strided_and_direct, sizeof(__pyx_k_strided_and_direct), 0, 0, 1, 0},
    {&__pyx_kp_s_strided_and_direct_or_indirect, __pyx_k_strided_and_direct_or_indirect, sizeof(__pyx_k_strided_and_direct_or_indirect), 0, 0, 1, 0},
    {&__pyx_kp_s_strided_and_indirect, __pyx_k_strided_and_indirect, sizeof(__pyx_k_strided_and_indirect), 0, 0, 1, 0},
    {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
    {&__pyx_n_s_strip, __pyx_k_strip, sizeof(__pyx_k_strip), 0, 0, 1, 1},
    {&__pyx_n_s_struct, __pyx_k_struct, sizeof(__pyx_k_struct), 0, 0, 1, 1},
    {&__pyx_n_s_sys, __pyx_k_sys, sizeof(__pyx_k_sys), 0, 0, 1, 1},
    {&__pyx_n_s_table, __pyx_k_table, sizeof(__pyx_k_table), 0, 0, 1, 1},
    {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
    {&__pyx_n_s_to_array, __pyx_k_to_array, sizeof(__pyx_k_to_array), 0, 0, 1, 1},
    {&__pyx_kp_s_tuple_ndarray_ndarray, __pyx_k_tuple_ndarray_ndarray, sizeof(__pyx_k_tuple_ndarray_ndarray), 0, 0, 1, 0},
    {&__pyx_n_s_ud, __pyx_k_ud, sizeof(__pyx_k_ud), 0, 0, 1, 1},
    {&__pyx_n_s_uindexer, __pyx_k_uindexer, sizeof(__pyx_k_uindexer), 0, 0, 1, 1},
    {&__pyx_n_s_uint16, __pyx_k_uint16, sizeof(__pyx_k_uint16), 0, 0, 1, 1},
    {&__pyx_n_s_uint16_t, __pyx_k_uint16_t, sizeof(__pyx_k_uint16_t), 0, 0, 1, 1},
    {&__pyx_n_s_uint32, __pyx_k_uint32, sizeof(__pyx_k_uint32), 0, 0, 1, 1},
    {&__pyx_n_s_uint32_t, __pyx_k_uint32_t, sizeof(__pyx_k_uint32_t), 0, 0, 1, 1},
    {&__pyx_n_s_uint64, __pyx_k_uint64, sizeof(__pyx_k_uint64), 0, 0, 1, 1},
    {&__pyx_n_s_uint64_t, __pyx_k_uint64_t, sizeof(__pyx_k_uint64_t), 0, 0, 1, 1},
    {&__pyx_n_s_uint8, __pyx_k_uint8, sizeof(__pyx_k_uint8), 0, 0, 1, 1},
    {&__pyx_n_u_uint8, __pyx_k_uint8, sizeof(__pyx_k_uint8), 0, 1, 0, 1},
    {&__pyx_n_s_uint8_t, __pyx_k_uint8_t, sizeof(__pyx_k_uint8_t), 0, 0, 1, 1},
    {&__pyx_kp_s_unable_to_allocate_array_data, __pyx_k_unable_to_allocate_array_data, sizeof(__pyx_k_unable_to_allocate_array_data), 0, 0, 1, 0},
    {&__pyx_kp_s_unable_to_allocate_shape_and_str, __pyx_k_unable_to_allocate_shape_and_str, sizeof(__pyx_k_unable_to_allocate_shape_and_str), 0, 0, 1, 0},
    {&__pyx_n_s_unique, __pyx_k_unique, sizeof(__pyx_k_unique), 0, 0, 1, 1},
    {&__pyx_n_s_unique_2, __pyx_k_unique_2, sizeof(__pyx_k_unique_2), 0, 0, 1, 1},
    {&__pyx_n_s_unique_label_indices, __pyx_k_unique_label_indices, sizeof(__pyx_k_unique_label_indices), 0, 0, 1, 1},
    {&__pyx_n_s_unique_label_indices_int32, __pyx_k_unique_label_indices_int32, sizeof(__pyx_k_unique_label_indices_int32), 0, 0, 1, 1},
    {&__pyx_n_s_unique_label_indices_int64, __pyx_k_unique_label_indices_int64, sizeof(__pyx_k_unique_label_indices_int64), 0, 0, 1, 1},
    {&__pyx_n_s_uniques, __pyx_k_uniques, sizeof(__pyx_k_uniques), 0, 0, 1, 1},
    {&__pyx_n_s_uniques_vector, __pyx_k_uniques_vector, sizeof(__pyx_k_uniques_vector), 0, 0, 1, 1},
    {&__pyx_n_s_unpack, __pyx_k_unpack, sizeof(__pyx_k_unpack), 0, 0, 1, 1},
    {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
    {&__pyx_n_u_upper_bound, __pyx_k_upper_bound, sizeof(__pyx_k_upper_bound), 0, 1, 0, 1},
    {&__pyx_n_s_use_mask, __pyx_k_use_mask, sizeof(__pyx_k_use_mask), 0, 0, 1, 1},
    {&__pyx_n_s_use_na_value, __pyx_k_use_na_value, sizeof(__pyx_k_use_na_value), 0, 0, 1, 1},
    {&__pyx_n_s_use_result_mask, __pyx_k_use_result_mask, sizeof(__pyx_k_use_result_mask), 0, 0, 1, 1},
    {&__pyx_n_s_use_setstate, __pyx_k_use_setstate, sizeof(__pyx_k_use_setstate), 0, 0, 1, 1},
    {&__pyx_n_s_uses_mask, __pyx_k_uses_mask, sizeof(__pyx_k_uses_mask), 0, 0, 1, 1},
    {&__pyx_kp_u_uses_mask_not_implemented_with_d, __pyx_k_uses_mask_not_implemented_with_d, sizeof(__pyx_k_uses_mask_not_implemented_with_d), 0, 1, 0, 0},
    {&__pyx_kp_u_uses_mask_not_implemented_with_o, __pyx_k_uses_mask_not_implemented_with_o, sizeof(__pyx_k_uses_mask_not_implemented_with_o), 0, 1, 0, 0},
    {&__pyx_n_s_v, __pyx_k_v, sizeof(__pyx_k_v), 0, 0, 1, 1},
    {&__pyx_n_s_val, __pyx_k_val, sizeof(__pyx_k_val), 0, 0, 1, 1},
    {&__pyx_n_s_value_count, __pyx_k_value_count, sizeof(__pyx_k_value_count), 0, 0, 1, 1},
    {&__pyx_n_s_values, __pyx_k_values, sizeof(__pyx_k_values), 0, 0, 1, 1},
    {&__pyx_n_s_vecs, __pyx_k_vecs, sizeof(__pyx_k_vecs), 0, 0, 1, 1},
    {&__pyx_n_s_version_info, __pyx_k_version_info, sizeof(__pyx_k_version_info), 0, 0, 1, 1},
    {&__pyx_n_s_view, __pyx_k_view, sizeof(__pyx_k_view), 0, 0, 1, 1},
    {&__pyx_n_s_zeros, __pyx_k_zeros, sizeof(__pyx_k_zeros), 0, 0, 1, 1},
    {0, 0, 0, 0, 0, 0, 0}
  };
  return __Pyx_InitStrings(__pyx_string_tab);
}
/* #### Code section: cached_builtins ### */
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) __PYX_ERR(0, 69, __pyx_L1_error)
  __pyx_builtin_TypeError = __Pyx_GetBuiltinName(__pyx_n_s_TypeError); if (!__pyx_builtin_TypeError) __PYX_ERR(1, 2, __pyx_L1_error)
  __pyx_builtin_MemoryError = __Pyx_GetBuiltinName(__pyx_n_s_MemoryError); if (!__pyx_builtin_MemoryError) __PYX_ERR(2, 433, __pyx_L1_error)
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(2, 473, __pyx_L1_error)
  __pyx_builtin_object = __Pyx_GetBuiltinName(__pyx_n_s_object); if (!__pyx_builtin_object) __PYX_ERR(2, 1124, __pyx_L1_error)
  __pyx_builtin_KeyError = __Pyx_GetBuiltinName(__pyx_n_s_KeyError); if (!__pyx_builtin_KeyError) __PYX_ERR(2, 1268, __pyx_L1_error)
  __pyx_builtin_NotImplementedError = __Pyx_GetBuiltinName(__pyx_n_s_NotImplementedError); if (!__pyx_builtin_NotImplementedError) __PYX_ERR(2, 1279, __pyx_L1_error)
  __pyx_builtin_UnicodeEncodeError = __Pyx_GetBuiltinName(__pyx_n_s_UnicodeEncodeError); if (!__pyx_builtin_UnicodeEncodeError) __PYX_ERR(2, 6931, __pyx_L1_error)
  __pyx_builtin___import__ = __Pyx_GetBuiltinName(__pyx_n_s_import); if (!__pyx_builtin___import__) __PYX_ERR(1, 100, __pyx_L1_error)
  __pyx_builtin_enumerate = __Pyx_GetBuiltinName(__pyx_n_s_enumerate); if (!__pyx_builtin_enumerate) __PYX_ERR(1, 159, __pyx_L1_error)
  __pyx_builtin_AssertionError = __Pyx_GetBuiltinName(__pyx_n_s_AssertionError); if (!__pyx_builtin_AssertionError) __PYX_ERR(1, 373, __pyx_L1_error)
  __pyx_builtin_Ellipsis = __Pyx_GetBuiltinName(__pyx_n_s_Ellipsis); if (!__pyx_builtin_Ellipsis) __PYX_ERR(1, 408, __pyx_L1_error)
  __pyx_builtin_id = __Pyx_GetBuiltinName(__pyx_n_s_id); if (!__pyx_builtin_id) __PYX_ERR(1, 618, __pyx_L1_error)
  __pyx_builtin_IndexError = __Pyx_GetBuiltinName(__pyx_n_s_IndexError); if (!__pyx_builtin_IndexError) __PYX_ERR(1, 914, __pyx_L1_error)
  __pyx_builtin_ImportError = __Pyx_GetBuiltinName(__pyx_n_s_ImportError); if (!__pyx_builtin_ImportError) __PYX_ERR(3, 984, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: cached_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "View.MemoryView":582
 *     def suboffsets(self):
 *         if self.view.suboffsets == NULL:
 *             return (-1,) * self.view.ndim             # <<<<<<<<<<<<<<
 * 
 *         return tuple([suboffset for suboffset in self.view.suboffsets[:self.view.ndim]])
 */
  __pyx_tuple__4 = PyTuple_New(1); if (unlikely(!__pyx_tuple__4)) __PYX_ERR(1, 582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__4);
  __Pyx_INCREF(__pyx_int_neg_1);
  __Pyx_GIVEREF(__pyx_int_neg_1);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_tuple__4, 0, __pyx_int_neg_1)) __PYX_ERR(1, 582, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_tuple__4);

  /* "View.MemoryView":679
 *     tup = <tuple>index if isinstance(index, tuple) else (index,)
 * 
 *     result = [slice(None)] * ndim             # <<<<<<<<<<<<<<
 *     have_slices = False
 *     seen_ellipsis = False
 */
  __pyx_slice__5 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_slice__5)) __PYX_ERR(1, 679, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__5);
  __Pyx_GIVEREF(__pyx_slice__5);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0x82a3537, 0x6ae9995, 0xb068931):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0x82a3537, 0x6ae9995, 0xb068931) = (name))" % __pyx_checksum
 */
  __pyx_tuple__8 = PyTuple_Pack(3, __pyx_int_136983863, __pyx_int_112105877, __pyx_int_184977713); if (unlikely(!__pyx_tuple__8)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__8);
  __Pyx_GIVEREF(__pyx_tuple__8);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":984
 *         __pyx_import_array()
 *     except Exception:
 *         raise ImportError("numpy.core.multiarray failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_umath() except -1:
 */
  __pyx_tuple__9 = PyTuple_Pack(1, __pyx_kp_u_numpy_core_multiarray_failed_to); if (unlikely(!__pyx_tuple__9)) __PYX_ERR(3, 984, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);

  /* "../recipe-sysroot-native/usr/lib/python3.12/site-packages/numpy/__init__.cython-30.pxd":990
 *         _import_umath()
 *     except Exception:
 *         raise ImportError("numpy.core.umath failed to import")             # <<<<<<<<<<<<<<
 * 
 * cdef inline int import_ufunc() except -1:
 */
  __pyx_tuple__10 = PyTuple_Pack(1, __pyx_kp_u_numpy_core_umath_failed_to_impor); if (unlikely(!__pyx_tuple__10)) __PYX_ERR(3, 990, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__10);
  __Pyx_GIVEREF(__pyx_tuple__10);

  /* "pandas/_libs/hashtable_class_helper.pxi":456
 *             if self.external_view_exists:
 *                 # should never happen
 *                 raise ValueError("should have raised on append()")             # <<<<<<<<<<<<<<
 *             self.ao.resize(self.data.n, refcheck=False)
 *             self.data.m = self.data.n
 */
  __pyx_tuple__11 = PyTuple_Pack(1, __pyx_kp_u_should_have_raised_on_append); if (unlikely(!__pyx_tuple__11)) __PYX_ERR(2, 456, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);

  /* "pandas/_libs/hashtable_class_helper.pxi":466
 *         if needs_resize(self.data):
 *             if self.external_view_exists:
 *                 raise ValueError("external reference but "             # <<<<<<<<<<<<<<
 *                                  "Vector.resize() needed")
 *             self.resize()
 */
  __pyx_tuple__12 = PyTuple_Pack(1, __pyx_kp_u_external_reference_but_Vector_re); if (unlikely(!__pyx_tuple__12)) __PYX_ERR(2, 466, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__12);
  __Pyx_GIVEREF(__pyx_tuple__12);

  /* "pandas/_libs/hashtable_class_helper.pxi":1282
 * 
 *         if self.na_position == -1:
 *             raise KeyError("NA")             # <<<<<<<<<<<<<<
 *         return self.na_position
 * 
 */
  __pyx_tuple__13 = PyTuple_Pack(1, __pyx_n_u_NA); if (unlikely(!__pyx_tuple__13)) __PYX_ERR(2, 1282, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__13);
  __Pyx_GIVEREF(__pyx_tuple__13);

  /* "pandas/_libs/hashtable_class_helper.pxi":1484
 *                             with gil:
 *                                 if uniques.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "uniques held, but "
 *                                                      "Vector.resize() needed")
 */
  __pyx_tuple__16 = PyTuple_Pack(1, __pyx_kp_u_external_reference_to_uniques_he); if (unlikely(!__pyx_tuple__16)) __PYX_ERR(2, 1484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__16);
  __Pyx_GIVEREF(__pyx_tuple__16);

  /* "pandas/_libs/hashtable_class_helper.pxi":1489
 *                                 uniques.resize()
 *                                 if result_mask.external_view_exists:
 *                                     raise ValueError("external reference to "             # <<<<<<<<<<<<<<
 *                                                      "result_mask held, but "
 *                                                      "Vector.resize() needed")
 */
  __pyx_tuple__17 = PyTuple_Pack(1, __pyx_kp_u_external_reference_to_result_mas); if (unlikely(!__pyx_tuple__17)) __PYX_ERR(2, 1489, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__17);
  __Pyx_GIVEREF(__pyx_tuple__17);

  /* "pandas/_libs/hashtable_func_helper.pxi":26
 * 
 *     if uses_mask and not dropna:
 *         raise NotImplementedError("uses_mask not implemented with dropna=False")             # <<<<<<<<<<<<<<
 * 
 *     # we track the order in which keys are first seen (GH39009),
 */
  __pyx_tuple__41 = PyTuple_Pack(1, __pyx_kp_u_uses_mask_not_implemented_with_d); if (unlikely(!__pyx_tuple__41)) __PYX_ERR(5, 26, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__41);
  __Pyx_GIVEREF(__pyx_tuple__41);

  /* "pandas/_libs/hashtable_func_helper.pxi":85
 * 
 *     if keep not in ('last', 'first', False):
 *         raise ValueError('keep must be either "first", "last" or False')             # <<<<<<<<<<<<<<
 * 
 *     if keep == "last":
 */
  __pyx_tuple__43 = PyTuple_Pack(1, __pyx_kp_u_keep_must_be_either_first_last_o); if (unlikely(!__pyx_tuple__43)) __PYX_ERR(5, 85, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__43);
  __Pyx_GIVEREF(__pyx_tuple__43);

  /* "pandas/_libs/hashtable_func_helper.pxi":1589
 * 
 *     if uses_mask:
 *         raise NotImplementedError("uses_mask not implemented with object dtype")             # <<<<<<<<<<<<<<
 * 
 *     kh_resize_pymap(table, n // 10)
 */
  __pyx_tuple__59 = PyTuple_Pack(1, __pyx_kp_u_uses_mask_not_implemented_with_o); if (unlikely(!__pyx_tuple__59)) __PYX_ERR(5, 1589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__59);
  __Pyx_GIVEREF(__pyx_tuple__59);

  /* "pandas/_libs/hashtable_func_helper.pxi":2532
 * 
 * 
 * cpdef value_count(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return value_count_object(values, dropna, mask=mask)
 */
  __pyx_tuple__71 = PyTuple_Pack(1, __pyx_kp_s_No_matching_signature_found); if (unlikely(!__pyx_tuple__71)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__71);
  __Pyx_GIVEREF(__pyx_tuple__71);
  __pyx_tuple__72 = PyTuple_Pack(1, __pyx_kp_s_Function_call_with_ambiguous_arg); if (unlikely(!__pyx_tuple__72)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__72);
  __Pyx_GIVEREF(__pyx_tuple__72);

  /* "pandas/_libs/hashtable_func_helper.pxi":2720
 *     arr = arr[np.asarray(labels)[arr].argsort()]
 * 
 *     return arr[1:] if arr.size != 0 and labels[arr[0]] == -1 else arr             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_slice__100 = PySlice_New(__pyx_int_1, Py_None, Py_None); if (unlikely(!__pyx_slice__100)) __PYX_ERR(5, 2720, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_slice__100);
  __Pyx_GIVEREF(__pyx_slice__100);

  /* "pandas/_libs/hashtable.pyx":116
 * 
 *         if mask is not None:
 *             raise NotImplementedError("mask not supported for ObjectFactorizer.")             # <<<<<<<<<<<<<<
 * 
 *         if self.uniques.external_view_exists:
 */
  __pyx_tuple__101 = PyTuple_Pack(1, __pyx_kp_u_mask_not_supported_for_ObjectFac); if (unlikely(!__pyx_tuple__101)) __PYX_ERR(0, 116, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__101);
  __Pyx_GIVEREF(__pyx_tuple__101);

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum not in (0xe3b0c44, 0xda39a3e, 0xd41d8cd):             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError, "Incompatible checksums (0x%x vs (0xe3b0c44, 0xda39a3e, 0xd41d8cd) = ())" % __pyx_checksum
 */
  __pyx_tuple__102 = PyTuple_Pack(3, __pyx_int_238750788, __pyx_int_228825662, __pyx_int_222419149); if (unlikely(!__pyx_tuple__102)) __PYX_ERR(1, 4, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__102);
  __Pyx_GIVEREF(__pyx_tuple__102);

  /* "View.MemoryView":100
 * cdef object __pyx_collections_abc_Sequence "__pyx_collections_abc_Sequence"
 * try:
 *     if __import__("sys").version_info >= (3, 3):             # <<<<<<<<<<<<<<
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 *     else:
 */
  __pyx_tuple__103 = PyTuple_Pack(1, __pyx_n_s_sys); if (unlikely(!__pyx_tuple__103)) __PYX_ERR(1, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__103);
  __Pyx_GIVEREF(__pyx_tuple__103);
  __pyx_tuple__104 = PyTuple_Pack(2, __pyx_int_3, __pyx_int_3); if (unlikely(!__pyx_tuple__104)) __PYX_ERR(1, 100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__104);
  __Pyx_GIVEREF(__pyx_tuple__104);

  /* "View.MemoryView":101
 * try:
 *     if __import__("sys").version_info >= (3, 3):
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence             # <<<<<<<<<<<<<<
 *     else:
 *         __pyx_collections_abc_Sequence = __import__("collections").Sequence
 */
  __pyx_tuple__105 = PyTuple_Pack(1, __pyx_kp_s_collections_abc); if (unlikely(!__pyx_tuple__105)) __PYX_ERR(1, 101, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__105);
  __Pyx_GIVEREF(__pyx_tuple__105);

  /* "View.MemoryView":103
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 *     else:
 *         __pyx_collections_abc_Sequence = __import__("collections").Sequence             # <<<<<<<<<<<<<<
 * except:
 * 
 */
  __pyx_tuple__106 = PyTuple_Pack(1, __pyx_n_s_collections); if (unlikely(!__pyx_tuple__106)) __PYX_ERR(1, 103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__106);
  __Pyx_GIVEREF(__pyx_tuple__106);

  /* "View.MemoryView":309
 *         return self.name
 * 
 * cdef generic = Enum("<strided and direct or indirect>")             # <<<<<<<<<<<<<<
 * cdef strided = Enum("<strided and direct>") # default
 * cdef indirect = Enum("<strided and indirect>")
 */
  __pyx_tuple__107 = PyTuple_Pack(1, __pyx_kp_s_strided_and_direct_or_indirect); if (unlikely(!__pyx_tuple__107)) __PYX_ERR(1, 309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__107);
  __Pyx_GIVEREF(__pyx_tuple__107);

  /* "View.MemoryView":310
 * 
 * cdef generic = Enum("<strided and direct or indirect>")
 * cdef strided = Enum("<strided and direct>") # default             # <<<<<<<<<<<<<<
 * cdef indirect = Enum("<strided and indirect>")
 * 
 */
  __pyx_tuple__108 = PyTuple_Pack(1, __pyx_kp_s_strided_and_direct); if (unlikely(!__pyx_tuple__108)) __PYX_ERR(1, 310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__108);
  __Pyx_GIVEREF(__pyx_tuple__108);

  /* "View.MemoryView":311
 * cdef generic = Enum("<strided and direct or indirect>")
 * cdef strided = Enum("<strided and direct>") # default
 * cdef indirect = Enum("<strided and indirect>")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__109 = PyTuple_Pack(1, __pyx_kp_s_strided_and_indirect); if (unlikely(!__pyx_tuple__109)) __PYX_ERR(1, 311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__109);
  __Pyx_GIVEREF(__pyx_tuple__109);

  /* "View.MemoryView":314
 * 
 * 
 * cdef contiguous = Enum("<contiguous and direct>")             # <<<<<<<<<<<<<<
 * cdef indirect_contiguous = Enum("<contiguous and indirect>")
 * 
 */
  __pyx_tuple__110 = PyTuple_Pack(1, __pyx_kp_s_contiguous_and_direct); if (unlikely(!__pyx_tuple__110)) __PYX_ERR(1, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__110);
  __Pyx_GIVEREF(__pyx_tuple__110);

  /* "View.MemoryView":315
 * 
 * cdef contiguous = Enum("<contiguous and direct>")
 * cdef indirect_contiguous = Enum("<contiguous and indirect>")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_tuple__111 = PyTuple_Pack(1, __pyx_kp_s_contiguous_and_indirect); if (unlikely(!__pyx_tuple__111)) __PYX_ERR(1, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__111);
  __Pyx_GIVEREF(__pyx_tuple__111);

  /* "(tree fragment)":1
 * def __pyx_unpickle_Enum(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_tuple__112 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__112)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__112);
  __Pyx_GIVEREF(__pyx_tuple__112);
  __pyx_codeobj__113 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__112, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_Enum, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__113)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "pandas/_libs/hashtable.pyx":39
 * 
 * 
 * def get_hashtable_trace_domain():             # <<<<<<<<<<<<<<
 *     return KHASH_TRACE_DOMAIN
 * 
 */
  __pyx_codeobj__114 = (PyObject*)__Pyx_PyCode_New(0, 0, 0, 0, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_pyx, __pyx_n_s_get_hashtable_trace_domain, 39, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__114)) __PYX_ERR(0, 39, __pyx_L1_error)

  /* "pandas/_libs/hashtable.pyx":43
 * 
 * 
 * def object_hash(obj):             # <<<<<<<<<<<<<<
 *     return kh_python_hash_func(obj)
 * 
 */
  __pyx_tuple__115 = PyTuple_Pack(1, __pyx_n_s_obj); if (unlikely(!__pyx_tuple__115)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__115);
  __Pyx_GIVEREF(__pyx_tuple__115);
  __pyx_codeobj__116 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__115, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_pyx, __pyx_n_s_object_hash, 43, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__116)) __PYX_ERR(0, 43, __pyx_L1_error)

  /* "pandas/_libs/hashtable.pyx":47
 * 
 * 
 * def objects_are_equal(a, b):             # <<<<<<<<<<<<<<
 *     return kh_python_hash_equal(a, b)
 * 
 */
  __pyx_tuple__117 = PyTuple_Pack(2, __pyx_n_s_a, __pyx_n_s_b); if (unlikely(!__pyx_tuple__117)) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__117);
  __Pyx_GIVEREF(__pyx_tuple__117);
  __pyx_codeobj__118 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__117, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_pyx, __pyx_n_s_objects_are_equal, 47, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__118)) __PYX_ERR(0, 47, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_tuple__119 = PyTuple_Pack(1, __pyx_n_s_self); if (unlikely(!__pyx_tuple__119)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__119);
  __Pyx_GIVEREF(__pyx_tuple__119);
  __pyx_codeobj__120 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__120)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_tuple__121 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_pyx_state); if (unlikely(!__pyx_tuple__121)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__121);
  __Pyx_GIVEREF(__pyx_tuple__121);
  __pyx_codeobj__122 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__122)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":452
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_codeobj__123 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_to_array, 452, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__123)) __PYX_ERR(2, 452, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__124 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__124)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__125 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__125)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":507
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_codeobj__126 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_to_array, 507, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__126)) __PYX_ERR(2, 507, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__127 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__127)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__128 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__128)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":562
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_codeobj__129 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_to_array, 562, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__129)) __PYX_ERR(2, 562, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__130 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__130)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__131 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__131)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":617
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_codeobj__132 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_to_array, 617, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__132)) __PYX_ERR(2, 617, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__133 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__133)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__134 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__134)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":669
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_codeobj__135 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_to_array, 669, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__135)) __PYX_ERR(2, 669, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__136 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__136)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__137 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__137)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":724
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_codeobj__138 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_to_array, 724, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__138)) __PYX_ERR(2, 724, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__139 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__139)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__140 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__140)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":779
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_codeobj__141 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_to_array, 779, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__141)) __PYX_ERR(2, 779, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__142 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__142)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__143 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__143)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":834
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_codeobj__144 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_to_array, 834, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__144)) __PYX_ERR(2, 834, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__145 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__145)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__146 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__146)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":889
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_codeobj__147 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_to_array, 889, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__147)) __PYX_ERR(2, 889, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__148 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__148)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__149 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__149)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":944
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_codeobj__150 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_to_array, 944, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__150)) __PYX_ERR(2, 944, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__151 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__151)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__152 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__152)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":999
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_codeobj__153 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_to_array, 999, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__153)) __PYX_ERR(2, 999, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__154 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__154)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__155 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__155)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1054
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_codeobj__156 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_to_array, 1054, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__156)) __PYX_ERR(2, 1054, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__157 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__157)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__158 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__158)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1118
 *         return self.data.n
 * 
 *     cpdef ndarray[object, ndim=1] to_array(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             ndarray ao
 */
  __pyx_codeobj__159 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_to_array, 1118, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__159)) __PYX_ERR(2, 1118, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__160 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__160)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__161 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__161)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1173
 *         self.n += 1
 * 
 *     cpdef ndarray[object, ndim=1] to_array(self):             # <<<<<<<<<<<<<<
 *         if self.m != self.n:
 *             if self.external_view_exists:
 */
  __pyx_codeobj__162 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_to_array, 1173, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__162)) __PYX_ERR(2, 1173, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__163 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__163)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__164 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__164)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */
  __pyx_tuple__165 = PyTuple_Pack(4, __pyx_n_s_self, __pyx_n_s_state, __pyx_n_s_dict_2, __pyx_n_s_use_setstate); if (unlikely(!__pyx_tuple__165)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__165);
  __Pyx_GIVEREF(__pyx_tuple__165);
  __pyx_codeobj__166 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 4, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__165, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__166)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_HashTable, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_HashTable__set_state(self, __pyx_state)
 */
  __pyx_codeobj__167 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 16, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__167)) __PYX_ERR(1, 16, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1227
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_tuple__168 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_deep, __pyx_n_s_overhead, __pyx_n_s_for_flags, __pyx_n_s_for_pairs); if (unlikely(!__pyx_tuple__168)) __PYX_ERR(2, 1227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__168);
  __Pyx_GIVEREF(__pyx_tuple__168);
  __pyx_codeobj__169 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__168, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_sizeof, 1227, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__169)) __PYX_ERR(2, 1227, __pyx_L1_error)
  __pyx_tuple__170 = PyTuple_Pack(1, Py_False); if (unlikely(!__pyx_tuple__170)) __PYX_ERR(2, 1227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__170);
  __Pyx_GIVEREF(__pyx_tuple__170);

  /* "pandas/_libs/hashtable_class_helper.pxi":1235
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_codeobj__171 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_state, 1235, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__171)) __PYX_ERR(2, 1235, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1244
 *         }
 * 
 *     cpdef get_item(self, complex128_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_tuple__172 = PyTuple_Pack(2, __pyx_n_s_self, __pyx_n_s_val); if (unlikely(!__pyx_tuple__172)) __PYX_ERR(2, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__172);
  __Pyx_GIVEREF(__pyx_tuple__172);
  __pyx_codeobj__173 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_item, 1244, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__173)) __PYX_ERR(2, 1244, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1270
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_codeobj__174 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_na, 1270, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__174)) __PYX_ERR(2, 1270, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1285
 *         return self.na_position
 * 
 *     cpdef set_item(self, complex128_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_tuple__175 = PyTuple_Pack(3, __pyx_n_s_self, __pyx_n_s_key, __pyx_n_s_val); if (unlikely(!__pyx_tuple__175)) __PYX_ERR(2, 1285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__175);
  __Pyx_GIVEREF(__pyx_tuple__175);
  __pyx_codeobj__176 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__175, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_item, 1285, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__176)) __PYX_ERR(2, 1285, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1300
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_codeobj__177 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_na, 1300, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__177)) __PYX_ERR(2, 1300, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1313
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const complex128_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_tuple__178 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_values, __pyx_n_s_mask, __pyx_n_s_i, __pyx_n_s_n, __pyx_n_s_ret, __pyx_n_s_val, __pyx_n_s_k, __pyx_n_s_na_position); if (unlikely(!__pyx_tuple__178)) __PYX_ERR(2, 1313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__178);
  __Pyx_GIVEREF(__pyx_tuple__178);
  __pyx_codeobj__179 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__178, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_map_locations, 1313, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__179)) __PYX_ERR(2, 1313, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1342
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const complex128_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_tuple__180 = PyTuple_Pack(10, __pyx_n_s_self, __pyx_n_s_values, __pyx_n_s_mask, __pyx_n_s_i, __pyx_n_s_n, __pyx_n_s_ret, __pyx_n_s_val, __pyx_n_s_k, __pyx_n_s_locs, __pyx_n_s_na_position); if (unlikely(!__pyx_tuple__180)) __PYX_ERR(2, 1342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__180);
  __Pyx_GIVEREF(__pyx_tuple__180);
  __pyx_codeobj__181 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__180, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_lookup, 1342, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__181)) __PYX_ERR(2, 1342, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1371
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const complex128_t[:] values, Complex128Vector uniques,
 */
  __pyx_tuple__182 = PyTuple_Pack(26, __pyx_n_s_self, __pyx_n_s_values, __pyx_n_s_uniques, __pyx_n_s_count_prior, __pyx_n_s_na_sentinel, __pyx_n_s_na_value, __pyx_n_s_ignore_na, __pyx_n_s_mask, __pyx_n_s_return_inverse, __pyx_n_s_use_result_mask, __pyx_n_s_i, __pyx_n_s_idx, __pyx_n_s_count, __pyx_n_s_n, __pyx_n_s_labels, __pyx_n_s_ret, __pyx_n_s_val, __pyx_n_s_na_value2, __pyx_n_s_k, __pyx_n_s_ud, __pyx_n_s_result_mask, __pyx_n_s_rmd, __pyx_n_s_use_na_value, __pyx_n_s_use_mask, __pyx_n_s_seen_na, __pyx_n_s_mask_values); if (unlikely(!__pyx_tuple__182)) __PYX_ERR(2, 1371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__182);
  __Pyx_GIVEREF(__pyx_tuple__182);
  __pyx_codeobj__183 = (PyObject*)__Pyx_PyCode_New(10, 0, 0, 26, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__182, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique, 1371, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__183)) __PYX_ERR(2, 1371, __pyx_L1_error)
  __pyx_tuple__184 = PyTuple_Pack(7, __pyx_int_0, __pyx_int_neg_1, Py_None, Py_False, Py_None, Py_False, Py_False); if (unlikely(!__pyx_tuple__184)) __PYX_ERR(2, 1371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__184);
  __Pyx_GIVEREF(__pyx_tuple__184);

  /* "pandas/_libs/hashtable_class_helper.pxi":1536
 *         return uniques.to_array()
 * 
 *     def unique(self, const complex128_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_tuple__185 = PyTuple_Pack(6, __pyx_n_s_self, __pyx_n_s_values, __pyx_n_s_return_inverse, __pyx_n_s_mask, __pyx_n_s_uniques, __pyx_n_s_use_result_mask); if (unlikely(!__pyx_tuple__185)) __PYX_ERR(2, 1536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__185);
  __Pyx_GIVEREF(__pyx_tuple__185);
  __pyx_codeobj__186 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__185, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique_2, 1536, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__186)) __PYX_ERR(2, 1536, __pyx_L1_error)
  __pyx_tuple__187 = PyTuple_Pack(2, Py_False, Py_None); if (unlikely(!__pyx_tuple__187)) __PYX_ERR(2, 1536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__187);
  __Pyx_GIVEREF(__pyx_tuple__187);

  /* "pandas/_libs/hashtable_class_helper.pxi":1565
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const complex128_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_tuple__188 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_values, __pyx_n_s_na_sentinel, __pyx_n_s_na_value, __pyx_n_s_mask, __pyx_n_s_ignore_na, __pyx_n_s_uniques_vector); if (unlikely(!__pyx_tuple__188)) __PYX_ERR(2, 1565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__188);
  __Pyx_GIVEREF(__pyx_tuple__188);
  __pyx_codeobj__189 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__188, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 1565, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__189)) __PYX_ERR(2, 1565, __pyx_L1_error)
  __pyx_tuple__190 = PyTuple_Pack(4, __pyx_int_neg_1, Py_None, Py_None, Py_True); if (unlikely(!__pyx_tuple__190)) __PYX_ERR(2, 1565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__190);
  __Pyx_GIVEREF(__pyx_tuple__190);

  /* "pandas/_libs/hashtable_class_helper.pxi":1601
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const complex128_t[:] values, Complex128Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_tuple__192 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_values, __pyx_n_s_uniques, __pyx_n_s_count_prior, __pyx_n_s_na_sentinel, __pyx_n_s_na_value, __pyx_n_s_mask, __pyx_n_s__191, __pyx_n_s_labels); if (unlikely(!__pyx_tuple__192)) __PYX_ERR(2, 1601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__192);
  __Pyx_GIVEREF(__pyx_tuple__192);
  __pyx_codeobj__193 = (PyObject*)__Pyx_PyCode_New(7, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__192, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_labels, 1601, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__193)) __PYX_ERR(2, 1601, __pyx_L1_error)
  __pyx_tuple__194 = PyTuple_Pack(4, __pyx_int_0, __pyx_int_neg_1, Py_None, Py_None); if (unlikely(!__pyx_tuple__194)) __PYX_ERR(2, 1601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__194);
  __Pyx_GIVEREF(__pyx_tuple__194);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__195 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__195)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__196 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__196)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1621
 *         self.uniques = Complex128Vector()
 * 
 *     def factorize(self, const khcomplex128_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_tuple__197 = PyTuple_Pack(7, __pyx_n_s_self, __pyx_n_s_values, __pyx_n_s_na_sentinel, __pyx_n_s_na_value, __pyx_n_s_mask, __pyx_n_s_labels, __pyx_n_s_uniques); if (unlikely(!__pyx_tuple__197)) __PYX_ERR(2, 1621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__197);
  __Pyx_GIVEREF(__pyx_tuple__197);
  __pyx_codeobj__198 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__197, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 1621, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__198)) __PYX_ERR(2, 1621, __pyx_L1_error)
  __pyx_tuple__199 = PyTuple_Pack(3, __pyx_int_neg_1, Py_None, Py_None); if (unlikely(!__pyx_tuple__199)) __PYX_ERR(2, 1621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__199);
  __Pyx_GIVEREF(__pyx_tuple__199);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__200 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__200)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__201 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__201)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1681
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_codeobj__202 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__168, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_sizeof, 1681, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__202)) __PYX_ERR(2, 1681, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1689
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_codeobj__203 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_state, 1689, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__203)) __PYX_ERR(2, 1689, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1698
 *         }
 * 
 *     cpdef get_item(self, float64_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_codeobj__204 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_item, 1698, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__204)) __PYX_ERR(2, 1698, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1724
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_codeobj__205 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_na, 1724, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__205)) __PYX_ERR(2, 1724, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1739
 *         return self.na_position
 * 
 *     cpdef set_item(self, float64_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_codeobj__206 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__175, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_item, 1739, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__206)) __PYX_ERR(2, 1739, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1754
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_codeobj__207 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_na, 1754, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__207)) __PYX_ERR(2, 1754, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1767
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const float64_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_codeobj__208 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__178, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_map_locations, 1767, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__208)) __PYX_ERR(2, 1767, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1796
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const float64_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_codeobj__209 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__180, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_lookup, 1796, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__209)) __PYX_ERR(2, 1796, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1825
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const float64_t[:] values, Float64Vector uniques,
 */
  __pyx_codeobj__210 = (PyObject*)__Pyx_PyCode_New(10, 0, 0, 26, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__182, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique, 1825, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__210)) __PYX_ERR(2, 1825, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1990
 *         return uniques.to_array()
 * 
 *     def unique(self, const float64_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_codeobj__211 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__185, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique_2, 1990, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__211)) __PYX_ERR(2, 1990, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2019
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const float64_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_codeobj__212 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__188, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 2019, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__212)) __PYX_ERR(2, 2019, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2055
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const float64_t[:] values, Float64Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_codeobj__213 = (PyObject*)__Pyx_PyCode_New(7, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__192, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_labels, 2055, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__213)) __PYX_ERR(2, 2055, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__214 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__214)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__215 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__215)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2075
 *         self.uniques = Float64Vector()
 * 
 *     def factorize(self, const float64_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_codeobj__216 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__197, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 2075, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__216)) __PYX_ERR(2, 2075, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__217 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__217)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__218 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__218)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2135
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_codeobj__219 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__168, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_sizeof, 2135, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__219)) __PYX_ERR(2, 2135, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2143
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_codeobj__220 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_state, 2143, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__220)) __PYX_ERR(2, 2143, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2152
 *         }
 * 
 *     cpdef get_item(self, uint64_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_codeobj__221 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_item, 2152, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__221)) __PYX_ERR(2, 2152, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2178
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_codeobj__222 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_na, 2178, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__222)) __PYX_ERR(2, 2178, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2193
 *         return self.na_position
 * 
 *     cpdef set_item(self, uint64_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_codeobj__223 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__175, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_item, 2193, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__223)) __PYX_ERR(2, 2193, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2208
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_codeobj__224 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_na, 2208, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__224)) __PYX_ERR(2, 2208, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2221
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const uint64_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_codeobj__225 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__178, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_map_locations, 2221, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__225)) __PYX_ERR(2, 2221, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2250
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const uint64_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_codeobj__226 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__180, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_lookup, 2250, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__226)) __PYX_ERR(2, 2250, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2279
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const uint64_t[:] values, UInt64Vector uniques,
 */
  __pyx_codeobj__227 = (PyObject*)__Pyx_PyCode_New(10, 0, 0, 26, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__182, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique, 2279, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__227)) __PYX_ERR(2, 2279, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2444
 *         return uniques.to_array()
 * 
 *     def unique(self, const uint64_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_codeobj__228 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__185, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique_2, 2444, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__228)) __PYX_ERR(2, 2444, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2473
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const uint64_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_codeobj__229 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__188, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 2473, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__229)) __PYX_ERR(2, 2473, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2509
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const uint64_t[:] values, UInt64Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_codeobj__230 = (PyObject*)__Pyx_PyCode_New(7, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__192, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_labels, 2509, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__230)) __PYX_ERR(2, 2509, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__231 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__231)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__232 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__232)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2529
 *         self.uniques = UInt64Vector()
 * 
 *     def factorize(self, const uint64_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_codeobj__233 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__197, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 2529, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__233)) __PYX_ERR(2, 2529, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__234 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__234)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__235 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__235)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2589
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_codeobj__236 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__168, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_sizeof, 2589, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__236)) __PYX_ERR(2, 2589, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2597
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_codeobj__237 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_state, 2597, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__237)) __PYX_ERR(2, 2597, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2606
 *         }
 * 
 *     cpdef get_item(self, int64_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_codeobj__238 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_item, 2606, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__238)) __PYX_ERR(2, 2606, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2632
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_codeobj__239 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_na, 2632, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__239)) __PYX_ERR(2, 2632, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2647
 *         return self.na_position
 * 
 *     cpdef set_item(self, int64_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_codeobj__240 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__175, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_item, 2647, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__240)) __PYX_ERR(2, 2647, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2662
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_codeobj__241 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_na, 2662, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__241)) __PYX_ERR(2, 2662, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2676
 *     # We only use this for int64, can reduce build size and make .pyi
 *     #  more accurate by only implementing it for int64
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_keys_to_values(
 *         self, const int64_t[:] keys, const int64_t[:] values
 */
  __pyx_tuple__242 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_keys, __pyx_n_s_values, __pyx_n_s_i, __pyx_n_s_n, __pyx_n_s_ret, __pyx_n_s_key, __pyx_n_s_k); if (unlikely(!__pyx_tuple__242)) __PYX_ERR(2, 2676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__242);
  __Pyx_GIVEREF(__pyx_tuple__242);
  __pyx_codeobj__243 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__242, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_map_keys_to_values, 2676, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__243)) __PYX_ERR(2, 2676, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2692
 *                 self.table.vals[k] = <Py_ssize_t>values[i]
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const int64_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_codeobj__244 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__178, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_map_locations, 2692, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__244)) __PYX_ERR(2, 2692, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2721
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const int64_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_codeobj__245 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__180, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_lookup, 2721, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__245)) __PYX_ERR(2, 2721, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2750
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const int64_t[:] values, Int64Vector uniques,
 */
  __pyx_codeobj__246 = (PyObject*)__Pyx_PyCode_New(10, 0, 0, 26, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__182, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique, 2750, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__246)) __PYX_ERR(2, 2750, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2915
 *         return uniques.to_array()
 * 
 *     def unique(self, const int64_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_codeobj__247 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__185, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique_2, 2915, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__247)) __PYX_ERR(2, 2915, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2944
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const int64_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_codeobj__248 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__188, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 2944, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__248)) __PYX_ERR(2, 2944, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2980
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const int64_t[:] values, Int64Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_codeobj__249 = (PyObject*)__Pyx_PyCode_New(7, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__192, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_labels, 2980, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__249)) __PYX_ERR(2, 2980, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2989
 *         return labels
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def get_labels_groupby(
 *         self, const int64_t[:] values
 */
  __pyx_tuple__250 = PyTuple_Pack(13, __pyx_n_s_self, __pyx_n_s_values, __pyx_n_s_i, __pyx_n_s_n, __pyx_n_s_labels, __pyx_n_s_idx, __pyx_n_s_count, __pyx_n_s_ret, __pyx_n_s_val, __pyx_n_s_k, __pyx_n_s_uniques, __pyx_n_s_ud, __pyx_n_s_arr_uniques); if (unlikely(!__pyx_tuple__250)) __PYX_ERR(2, 2989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__250);
  __Pyx_GIVEREF(__pyx_tuple__250);
  __pyx_codeobj__251 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 13, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__250, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_labels_groupby, 2989, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__251)) __PYX_ERR(2, 2989, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__252 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__252)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__253 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__253)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3045
 *         self.uniques = Int64Vector()
 * 
 *     def factorize(self, const int64_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_codeobj__254 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__197, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 3045, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__254)) __PYX_ERR(2, 3045, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__255 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__255)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__256 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__256)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3105
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_codeobj__257 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__168, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_sizeof, 3105, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__257)) __PYX_ERR(2, 3105, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3113
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_codeobj__258 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_state, 3113, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__258)) __PYX_ERR(2, 3113, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3122
 *         }
 * 
 *     cpdef get_item(self, complex64_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_codeobj__259 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_item, 3122, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__259)) __PYX_ERR(2, 3122, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3148
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_codeobj__260 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_na, 3148, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__260)) __PYX_ERR(2, 3148, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3163
 *         return self.na_position
 * 
 *     cpdef set_item(self, complex64_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_codeobj__261 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__175, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_item, 3163, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__261)) __PYX_ERR(2, 3163, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3178
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_codeobj__262 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_na, 3178, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__262)) __PYX_ERR(2, 3178, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3191
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const complex64_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_codeobj__263 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__178, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_map_locations, 3191, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__263)) __PYX_ERR(2, 3191, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3220
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const complex64_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_codeobj__264 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__180, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_lookup, 3220, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__264)) __PYX_ERR(2, 3220, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3249
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const complex64_t[:] values, Complex64Vector uniques,
 */
  __pyx_codeobj__265 = (PyObject*)__Pyx_PyCode_New(10, 0, 0, 26, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__182, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique, 3249, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__265)) __PYX_ERR(2, 3249, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3414
 *         return uniques.to_array()
 * 
 *     def unique(self, const complex64_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_codeobj__266 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__185, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique_2, 3414, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__266)) __PYX_ERR(2, 3414, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3443
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const complex64_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_codeobj__267 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__188, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 3443, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__267)) __PYX_ERR(2, 3443, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3479
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const complex64_t[:] values, Complex64Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_codeobj__268 = (PyObject*)__Pyx_PyCode_New(7, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__192, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_labels, 3479, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__268)) __PYX_ERR(2, 3479, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__269 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__269)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__270 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__270)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3499
 *         self.uniques = Complex64Vector()
 * 
 *     def factorize(self, const khcomplex64_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_codeobj__271 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__197, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 3499, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__271)) __PYX_ERR(2, 3499, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__272 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__272)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__273 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__273)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3559
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_codeobj__274 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__168, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_sizeof, 3559, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__274)) __PYX_ERR(2, 3559, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3567
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_codeobj__275 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_state, 3567, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__275)) __PYX_ERR(2, 3567, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3576
 *         }
 * 
 *     cpdef get_item(self, float32_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_codeobj__276 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_item, 3576, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__276)) __PYX_ERR(2, 3576, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3602
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_codeobj__277 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_na, 3602, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__277)) __PYX_ERR(2, 3602, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3617
 *         return self.na_position
 * 
 *     cpdef set_item(self, float32_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_codeobj__278 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__175, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_item, 3617, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__278)) __PYX_ERR(2, 3617, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3632
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_codeobj__279 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_na, 3632, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__279)) __PYX_ERR(2, 3632, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3645
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const float32_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_codeobj__280 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__178, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_map_locations, 3645, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__280)) __PYX_ERR(2, 3645, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3674
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const float32_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_codeobj__281 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__180, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_lookup, 3674, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__281)) __PYX_ERR(2, 3674, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3703
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const float32_t[:] values, Float32Vector uniques,
 */
  __pyx_codeobj__282 = (PyObject*)__Pyx_PyCode_New(10, 0, 0, 26, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__182, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique, 3703, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__282)) __PYX_ERR(2, 3703, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3868
 *         return uniques.to_array()
 * 
 *     def unique(self, const float32_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_codeobj__283 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__185, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique_2, 3868, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__283)) __PYX_ERR(2, 3868, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3897
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const float32_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_codeobj__284 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__188, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 3897, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__284)) __PYX_ERR(2, 3897, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3933
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const float32_t[:] values, Float32Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_codeobj__285 = (PyObject*)__Pyx_PyCode_New(7, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__192, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_labels, 3933, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__285)) __PYX_ERR(2, 3933, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__286 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__286)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__287 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__287)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3953
 *         self.uniques = Float32Vector()
 * 
 *     def factorize(self, const float32_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_codeobj__288 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__197, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 3953, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__288)) __PYX_ERR(2, 3953, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__289 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__289)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__290 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__290)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4013
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_codeobj__291 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__168, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_sizeof, 4013, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__291)) __PYX_ERR(2, 4013, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4021
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_codeobj__292 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_state, 4021, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__292)) __PYX_ERR(2, 4021, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4030
 *         }
 * 
 *     cpdef get_item(self, uint32_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_codeobj__293 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_item, 4030, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__293)) __PYX_ERR(2, 4030, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4056
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_codeobj__294 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_na, 4056, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__294)) __PYX_ERR(2, 4056, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4071
 *         return self.na_position
 * 
 *     cpdef set_item(self, uint32_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_codeobj__295 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__175, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_item, 4071, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__295)) __PYX_ERR(2, 4071, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4086
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_codeobj__296 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_na, 4086, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__296)) __PYX_ERR(2, 4086, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4099
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const uint32_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_codeobj__297 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__178, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_map_locations, 4099, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__297)) __PYX_ERR(2, 4099, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4128
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const uint32_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_codeobj__298 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__180, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_lookup, 4128, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__298)) __PYX_ERR(2, 4128, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4157
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const uint32_t[:] values, UInt32Vector uniques,
 */
  __pyx_codeobj__299 = (PyObject*)__Pyx_PyCode_New(10, 0, 0, 26, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__182, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique, 4157, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__299)) __PYX_ERR(2, 4157, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4322
 *         return uniques.to_array()
 * 
 *     def unique(self, const uint32_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_codeobj__300 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__185, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique_2, 4322, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__300)) __PYX_ERR(2, 4322, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4351
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const uint32_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_codeobj__301 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__188, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 4351, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__301)) __PYX_ERR(2, 4351, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4387
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const uint32_t[:] values, UInt32Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_codeobj__302 = (PyObject*)__Pyx_PyCode_New(7, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__192, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_labels, 4387, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__302)) __PYX_ERR(2, 4387, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__303 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__303)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__304 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__304)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4407
 *         self.uniques = UInt32Vector()
 * 
 *     def factorize(self, const uint32_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_codeobj__305 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__197, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 4407, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__305)) __PYX_ERR(2, 4407, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__306 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__306)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__307 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__307)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4467
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_codeobj__308 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__168, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_sizeof, 4467, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__308)) __PYX_ERR(2, 4467, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4475
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_codeobj__309 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_state, 4475, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__309)) __PYX_ERR(2, 4475, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4484
 *         }
 * 
 *     cpdef get_item(self, int32_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_codeobj__310 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_item, 4484, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__310)) __PYX_ERR(2, 4484, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4510
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_codeobj__311 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_na, 4510, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__311)) __PYX_ERR(2, 4510, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4525
 *         return self.na_position
 * 
 *     cpdef set_item(self, int32_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_codeobj__312 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__175, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_item, 4525, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__312)) __PYX_ERR(2, 4525, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4540
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_codeobj__313 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_na, 4540, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__313)) __PYX_ERR(2, 4540, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4553
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const int32_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_codeobj__314 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__178, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_map_locations, 4553, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__314)) __PYX_ERR(2, 4553, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4582
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const int32_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_codeobj__315 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__180, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_lookup, 4582, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__315)) __PYX_ERR(2, 4582, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4611
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const int32_t[:] values, Int32Vector uniques,
 */
  __pyx_codeobj__316 = (PyObject*)__Pyx_PyCode_New(10, 0, 0, 26, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__182, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique, 4611, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__316)) __PYX_ERR(2, 4611, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4776
 *         return uniques.to_array()
 * 
 *     def unique(self, const int32_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_codeobj__317 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__185, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique_2, 4776, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__317)) __PYX_ERR(2, 4776, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4805
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const int32_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_codeobj__318 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__188, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 4805, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__318)) __PYX_ERR(2, 4805, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4841
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const int32_t[:] values, Int32Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_codeobj__319 = (PyObject*)__Pyx_PyCode_New(7, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__192, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_labels, 4841, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__319)) __PYX_ERR(2, 4841, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__320 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__320)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__321 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__321)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4861
 *         self.uniques = Int32Vector()
 * 
 *     def factorize(self, const int32_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_codeobj__322 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__197, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 4861, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__322)) __PYX_ERR(2, 4861, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__323 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__323)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__324 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__324)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4921
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_codeobj__325 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__168, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_sizeof, 4921, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__325)) __PYX_ERR(2, 4921, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4929
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_codeobj__326 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_state, 4929, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__326)) __PYX_ERR(2, 4929, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4938
 *         }
 * 
 *     cpdef get_item(self, uint16_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_codeobj__327 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_item, 4938, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__327)) __PYX_ERR(2, 4938, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4964
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_codeobj__328 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_na, 4964, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__328)) __PYX_ERR(2, 4964, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4979
 *         return self.na_position
 * 
 *     cpdef set_item(self, uint16_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_codeobj__329 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__175, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_item, 4979, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__329)) __PYX_ERR(2, 4979, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4994
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_codeobj__330 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_na, 4994, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__330)) __PYX_ERR(2, 4994, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5007
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const uint16_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_codeobj__331 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__178, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_map_locations, 5007, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__331)) __PYX_ERR(2, 5007, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5036
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const uint16_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_codeobj__332 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__180, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_lookup, 5036, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__332)) __PYX_ERR(2, 5036, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5065
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const uint16_t[:] values, UInt16Vector uniques,
 */
  __pyx_codeobj__333 = (PyObject*)__Pyx_PyCode_New(10, 0, 0, 26, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__182, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique, 5065, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__333)) __PYX_ERR(2, 5065, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5230
 *         return uniques.to_array()
 * 
 *     def unique(self, const uint16_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_codeobj__334 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__185, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique_2, 5230, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__334)) __PYX_ERR(2, 5230, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5259
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const uint16_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_codeobj__335 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__188, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 5259, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__335)) __PYX_ERR(2, 5259, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5295
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const uint16_t[:] values, UInt16Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_codeobj__336 = (PyObject*)__Pyx_PyCode_New(7, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__192, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_labels, 5295, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__336)) __PYX_ERR(2, 5295, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__337 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__337)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__338 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__338)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5315
 *         self.uniques = UInt16Vector()
 * 
 *     def factorize(self, const uint16_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_codeobj__339 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__197, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 5315, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__339)) __PYX_ERR(2, 5315, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__340 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__340)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__341 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__341)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5375
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_codeobj__342 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__168, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_sizeof, 5375, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__342)) __PYX_ERR(2, 5375, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5383
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_codeobj__343 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_state, 5383, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__343)) __PYX_ERR(2, 5383, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5392
 *         }
 * 
 *     cpdef get_item(self, int16_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_codeobj__344 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_item, 5392, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__344)) __PYX_ERR(2, 5392, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5418
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_codeobj__345 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_na, 5418, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__345)) __PYX_ERR(2, 5418, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5433
 *         return self.na_position
 * 
 *     cpdef set_item(self, int16_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_codeobj__346 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__175, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_item, 5433, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__346)) __PYX_ERR(2, 5433, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5448
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_codeobj__347 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_na, 5448, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__347)) __PYX_ERR(2, 5448, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5461
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const int16_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_codeobj__348 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__178, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_map_locations, 5461, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__348)) __PYX_ERR(2, 5461, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5490
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const int16_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_codeobj__349 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__180, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_lookup, 5490, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__349)) __PYX_ERR(2, 5490, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5519
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const int16_t[:] values, Int16Vector uniques,
 */
  __pyx_codeobj__350 = (PyObject*)__Pyx_PyCode_New(10, 0, 0, 26, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__182, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique, 5519, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__350)) __PYX_ERR(2, 5519, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5684
 *         return uniques.to_array()
 * 
 *     def unique(self, const int16_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_codeobj__351 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__185, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique_2, 5684, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__351)) __PYX_ERR(2, 5684, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5713
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const int16_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_codeobj__352 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__188, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 5713, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__352)) __PYX_ERR(2, 5713, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5749
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const int16_t[:] values, Int16Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_codeobj__353 = (PyObject*)__Pyx_PyCode_New(7, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__192, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_labels, 5749, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__353)) __PYX_ERR(2, 5749, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__354 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__354)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__355 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__355)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5769
 *         self.uniques = Int16Vector()
 * 
 *     def factorize(self, const int16_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_codeobj__356 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__197, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 5769, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__356)) __PYX_ERR(2, 5769, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__357 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__357)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__358 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__358)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5829
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_codeobj__359 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__168, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_sizeof, 5829, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__359)) __PYX_ERR(2, 5829, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5837
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_codeobj__360 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_state, 5837, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__360)) __PYX_ERR(2, 5837, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5846
 *         }
 * 
 *     cpdef get_item(self, uint8_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_codeobj__361 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_item, 5846, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__361)) __PYX_ERR(2, 5846, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5872
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_codeobj__362 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_na, 5872, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__362)) __PYX_ERR(2, 5872, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5887
 *         return self.na_position
 * 
 *     cpdef set_item(self, uint8_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_codeobj__363 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__175, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_item, 5887, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__363)) __PYX_ERR(2, 5887, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5902
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_codeobj__364 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_na, 5902, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__364)) __PYX_ERR(2, 5902, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5915
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const uint8_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_codeobj__365 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__178, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_map_locations, 5915, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__365)) __PYX_ERR(2, 5915, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5944
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const uint8_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_codeobj__366 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__180, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_lookup, 5944, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__366)) __PYX_ERR(2, 5944, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5973
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const uint8_t[:] values, UInt8Vector uniques,
 */
  __pyx_codeobj__367 = (PyObject*)__Pyx_PyCode_New(10, 0, 0, 26, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__182, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique, 5973, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__367)) __PYX_ERR(2, 5973, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6138
 *         return uniques.to_array()
 * 
 *     def unique(self, const uint8_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_codeobj__368 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__185, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique_2, 6138, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__368)) __PYX_ERR(2, 6138, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6167
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const uint8_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_codeobj__369 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__188, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 6167, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__369)) __PYX_ERR(2, 6167, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6203
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const uint8_t[:] values, UInt8Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_codeobj__370 = (PyObject*)__Pyx_PyCode_New(7, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__192, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_labels, 6203, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__370)) __PYX_ERR(2, 6203, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__371 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__371)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__372 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__372)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6223
 *         self.uniques = UInt8Vector()
 * 
 *     def factorize(self, const uint8_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_codeobj__373 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__197, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 6223, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__373)) __PYX_ERR(2, 6223, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__374 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__374)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__375 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__375)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6283
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_codeobj__376 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__168, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_sizeof, 6283, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__376)) __PYX_ERR(2, 6283, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6291
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_codeobj__377 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_state, 6291, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__377)) __PYX_ERR(2, 6291, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6300
 *         }
 * 
 *     cpdef get_item(self, int8_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_codeobj__378 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_item, 6300, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__378)) __PYX_ERR(2, 6300, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6326
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_codeobj__379 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_na, 6326, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__379)) __PYX_ERR(2, 6326, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6341
 *         return self.na_position
 * 
 *     cpdef set_item(self, int8_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_codeobj__380 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__175, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_item, 6341, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__380)) __PYX_ERR(2, 6341, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6356
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_codeobj__381 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_na, 6356, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__381)) __PYX_ERR(2, 6356, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6369
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const int8_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_codeobj__382 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__178, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_map_locations, 6369, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__382)) __PYX_ERR(2, 6369, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6398
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const int8_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_codeobj__383 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__180, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_lookup, 6398, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__383)) __PYX_ERR(2, 6398, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6427
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const int8_t[:] values, Int8Vector uniques,
 */
  __pyx_codeobj__384 = (PyObject*)__Pyx_PyCode_New(10, 0, 0, 26, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__182, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique, 6427, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__384)) __PYX_ERR(2, 6427, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6592
 *         return uniques.to_array()
 * 
 *     def unique(self, const int8_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_codeobj__385 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 6, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__185, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique_2, 6592, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__385)) __PYX_ERR(2, 6592, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6621
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const int8_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_codeobj__386 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__188, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 6621, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__386)) __PYX_ERR(2, 6621, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6657
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const int8_t[:] values, Int8Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_codeobj__387 = (PyObject*)__Pyx_PyCode_New(7, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__192, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_labels, 6657, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__387)) __PYX_ERR(2, 6657, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__388 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__388)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__389 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__389)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6677
 *         self.uniques = Int8Vector()
 * 
 *     def factorize(self, const int8_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_codeobj__390 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__197, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 6677, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__390)) __PYX_ERR(2, 6677, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__391 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__391)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__392 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__392)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6721
 *             self.table = NULL
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 */
  __pyx_codeobj__393 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__168, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_sizeof, 6721, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__393)) __PYX_ERR(2, 6721, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6728
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_codeobj__394 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_state, 6728, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__394)) __PYX_ERR(2, 6728, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6737
 *         }
 * 
 *     cpdef get_item(self, str val):             # <<<<<<<<<<<<<<
 *         cdef:
 *             khiter_t k
 */
  __pyx_codeobj__395 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_item, 6737, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__395)) __PYX_ERR(2, 6737, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6749
 *             raise KeyError(val)
 * 
 *     cpdef set_item(self, str key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         cdef:
 *             khiter_t k
 */
  __pyx_codeobj__396 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__175, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_item, 6749, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__396)) __PYX_ERR(2, 6749, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6763
 *             raise KeyError(key)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def get_indexer(self, ndarray[object] values) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_tuple__397 = PyTuple_Pack(11, __pyx_n_s_self, __pyx_n_s_values, __pyx_n_s_i, __pyx_n_s_n, __pyx_n_s_labels, __pyx_n_s_resbuf, __pyx_n_s_k, __pyx_n_s_table, __pyx_n_s_v, __pyx_n_s_vecs, __pyx_n_s_val); if (unlikely(!__pyx_tuple__397)) __PYX_ERR(2, 6763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__397);
  __Pyx_GIVEREF(__pyx_tuple__397);
  __pyx_codeobj__398 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 11, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__397, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_indexer, 6763, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__398)) __PYX_ERR(2, 6763, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6792
 *         return labels
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, ndarray[object] values, object mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_tuple__399 = PyTuple_Pack(11, __pyx_n_s_self, __pyx_n_s_values, __pyx_n_s_mask, __pyx_n_s_i, __pyx_n_s_n, __pyx_n_s_ret, __pyx_n_s_val, __pyx_n_s_v, __pyx_n_s_k, __pyx_n_s_locs, __pyx_n_s_vecs); if (unlikely(!__pyx_tuple__399)) __PYX_ERR(2, 6792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__399);
  __Pyx_GIVEREF(__pyx_tuple__399);
  __pyx_codeobj__400 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 11, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__399, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_lookup, 6792, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__400)) __PYX_ERR(2, 6792, __pyx_L1_error)
  __pyx_tuple__401 = PyTuple_Pack(1, Py_None); if (unlikely(!__pyx_tuple__401)) __PYX_ERR(2, 6792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__401);
  __Pyx_GIVEREF(__pyx_tuple__401);

  /* "pandas/_libs/hashtable_class_helper.pxi":6829
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, ndarray[object] values, object mask = None) -> None:
 *         # mask not yet implemented
 */
  __pyx_tuple__402 = PyTuple_Pack(10, __pyx_n_s_self, __pyx_n_s_values, __pyx_n_s_mask, __pyx_n_s_i, __pyx_n_s_n, __pyx_n_s_ret, __pyx_n_s_val, __pyx_n_s_v, __pyx_n_s_vecs, __pyx_n_s_k); if (unlikely(!__pyx_tuple__402)) __PYX_ERR(2, 6829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__402);
  __Pyx_GIVEREF(__pyx_tuple__402);
  __pyx_codeobj__403 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 10, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__402, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_map_locations, 6829, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__403)) __PYX_ERR(2, 6829, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6860
 *         free(vecs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, ndarray[object] values, ObjectVector uniques,
 */
  __pyx_tuple__404 = PyTuple_Pack(20, __pyx_n_s_self, __pyx_n_s_values, __pyx_n_s_uniques, __pyx_n_s_count_prior, __pyx_n_s_na_sentinel, __pyx_n_s_na_value, __pyx_n_s_ignore_na, __pyx_n_s_return_inverse, __pyx_n_s_i, __pyx_n_s_idx, __pyx_n_s_count, __pyx_n_s_n, __pyx_n_s_labels, __pyx_n_s_uindexer, __pyx_n_s_ret, __pyx_n_s_val, __pyx_n_s_v, __pyx_n_s_vecs, __pyx_n_s_k, __pyx_n_s_use_na_value); if (unlikely(!__pyx_tuple__404)) __PYX_ERR(2, 6860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__404);
  __Pyx_GIVEREF(__pyx_tuple__404);
  __pyx_codeobj__405 = (PyObject*)__Pyx_PyCode_New(8, 0, 0, 20, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__404, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique, 6860, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__405)) __PYX_ERR(2, 6860, __pyx_L1_error)
  __pyx_tuple__406 = PyTuple_Pack(5, __pyx_int_0, __pyx_int_neg_1, Py_None, Py_False, Py_False); if (unlikely(!__pyx_tuple__406)) __PYX_ERR(2, 6860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__406);
  __Pyx_GIVEREF(__pyx_tuple__406);

  /* "pandas/_libs/hashtable_class_helper.pxi":6968
 *         return uniques.to_array()
 * 
 *     def unique(self, ndarray[object] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_tuple__407 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_values, __pyx_n_s_return_inverse, __pyx_n_s_mask, __pyx_n_s_uniques); if (unlikely(!__pyx_tuple__407)) __PYX_ERR(2, 6968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__407);
  __Pyx_GIVEREF(__pyx_tuple__407);
  __pyx_codeobj__408 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__407, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique_2, 6968, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__408)) __PYX_ERR(2, 6968, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6993
 *                             return_inverse=return_inverse)
 * 
 *     def factorize(self, ndarray[object] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_codeobj__409 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__188, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 6993, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__409)) __PYX_ERR(2, 6993, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":7027
 *                             return_inverse=True)
 * 
 *     def get_labels(self, ndarray[object] values, ObjectVector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None):
 */
  __pyx_tuple__410 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_values, __pyx_n_s_uniques, __pyx_n_s_count_prior, __pyx_n_s_na_sentinel, __pyx_n_s_na_value, __pyx_n_s__191, __pyx_n_s_labels); if (unlikely(!__pyx_tuple__410)) __PYX_ERR(2, 7027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__410);
  __Pyx_GIVEREF(__pyx_tuple__410);
  __pyx_codeobj__411 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__410, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_labels, 7027, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__411)) __PYX_ERR(2, 7027, __pyx_L1_error)
  __pyx_tuple__412 = PyTuple_Pack(3, __pyx_int_0, __pyx_int_neg_1, Py_None); if (unlikely(!__pyx_tuple__412)) __PYX_ERR(2, 7027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__412);
  __Pyx_GIVEREF(__pyx_tuple__412);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__413 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__413)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 */
  __pyx_codeobj__414 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__414)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":7060
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_codeobj__415 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__168, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_sizeof, 7060, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__415)) __PYX_ERR(2, 7060, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":7068
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """
 *         returns infos about the current state of the hashtable like size,
 */
  __pyx_codeobj__416 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_state, 7068, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__416)) __PYX_ERR(2, 7068, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":7080
 *         }
 * 
 *     cpdef get_item(self, object val):             # <<<<<<<<<<<<<<
 *         cdef:
 *             khiter_t k
 */
  __pyx_codeobj__417 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__172, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_item, 7080, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__417)) __PYX_ERR(2, 7080, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":7090
 *             raise KeyError(val)
 * 
 *     cpdef set_item(self, object key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         cdef:
 *             khiter_t k
 */
  __pyx_codeobj__418 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__175, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_set_item, 7090, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__418)) __PYX_ERR(2, 7090, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":7104
 *             raise KeyError(key)
 * 
 *     def map_locations(self, ndarray[object] values, object mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # mask not yet implemented
 *         cdef:
 */
  __pyx_tuple__419 = PyTuple_Pack(8, __pyx_n_s_self, __pyx_n_s_values, __pyx_n_s_mask, __pyx_n_s_i, __pyx_n_s_n, __pyx_n_s_ret, __pyx_n_s_val, __pyx_n_s_k); if (unlikely(!__pyx_tuple__419)) __PYX_ERR(2, 7104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__419);
  __Pyx_GIVEREF(__pyx_tuple__419);
  __pyx_codeobj__420 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__419, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_map_locations, 7104, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__420)) __PYX_ERR(2, 7104, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":7119
 *             self.table.vals[k] = i
 * 
 *     def lookup(self, ndarray[object] values, object mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # mask not yet implemented
 */
  __pyx_tuple__421 = PyTuple_Pack(9, __pyx_n_s_self, __pyx_n_s_values, __pyx_n_s_mask, __pyx_n_s_i, __pyx_n_s_n, __pyx_n_s_ret, __pyx_n_s_val, __pyx_n_s_k, __pyx_n_s_locs); if (unlikely(!__pyx_tuple__421)) __PYX_ERR(2, 7119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__421);
  __Pyx_GIVEREF(__pyx_tuple__421);
  __pyx_codeobj__422 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 9, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__421, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_lookup, 7119, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__422)) __PYX_ERR(2, 7119, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":7141
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, ndarray[object] values, ObjectVector uniques,
 */
  __pyx_tuple__423 = PyTuple_Pack(17, __pyx_n_s_self, __pyx_n_s_values, __pyx_n_s_uniques, __pyx_n_s_count_prior, __pyx_n_s_na_sentinel, __pyx_n_s_na_value, __pyx_n_s_ignore_na, __pyx_n_s_return_inverse, __pyx_n_s_i, __pyx_n_s_idx, __pyx_n_s_count, __pyx_n_s_n, __pyx_n_s_labels, __pyx_n_s_ret, __pyx_n_s_val, __pyx_n_s_k, __pyx_n_s_use_na_value); if (unlikely(!__pyx_tuple__423)) __PYX_ERR(2, 7141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__423);
  __Pyx_GIVEREF(__pyx_tuple__423);
  __pyx_codeobj__424 = (PyObject*)__Pyx_PyCode_New(8, 0, 0, 17, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__423, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique, 7141, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__424)) __PYX_ERR(2, 7141, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":7225
 *         return uniques.to_array()
 * 
 *     def unique(self, ndarray[object] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_codeobj__425 = (PyObject*)__Pyx_PyCode_New(4, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__407, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_unique_2, 7225, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__425)) __PYX_ERR(2, 7225, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":7250
 *                             return_inverse=return_inverse)
 * 
 *     def factorize(self, ndarray[object] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_codeobj__426 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__188, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_factorize, 7250, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__426)) __PYX_ERR(2, 7250, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":7284
 *                             return_inverse=True)
 * 
 *     def get_labels(self, ndarray[object] values, ObjectVector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None):
 */
  __pyx_codeobj__427 = (PyObject*)__Pyx_PyCode_New(6, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__410, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_class_hel, __pyx_n_s_get_labels, 7284, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__427)) __PYX_ERR(2, 7284, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__428 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__428)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 */
  __pyx_codeobj__429 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__429)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable_func_helper.pxi":2532
 * 
 * 
 * cpdef value_count(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return value_count_object(values, dropna, mask=mask)
 */
  __pyx_tuple__430 = PyTuple_Pack(3, __pyx_n_s_values, __pyx_n_s_dropna, __pyx_n_s_mask); if (unlikely(!__pyx_tuple__430)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__430);
  __Pyx_GIVEREF(__pyx_tuple__430);
  __pyx_codeobj__431 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__430, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_0value_count, 2532, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__431)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_codeobj__432 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__430, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_0value_count, 2532, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__432)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_codeobj__433 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__430, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_1value_count, 2532, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__433)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_codeobj__434 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__430, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_2value_count, 2532, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__434)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_codeobj__435 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__430, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_3value_count, 2532, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__435)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_codeobj__436 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__430, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_4value_count, 2532, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__436)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_codeobj__437 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__430, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_5value_count, 2532, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__437)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_codeobj__438 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__430, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_6value_count, 2532, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__438)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_codeobj__439 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__430, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_7value_count, 2532, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__439)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_codeobj__440 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__430, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_8value_count, 2532, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__440)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_codeobj__441 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__430, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_9value_count, 2532, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__441)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_codeobj__442 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__430, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_10value_count, 2532, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__442)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_codeobj__443 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__430, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_11value_count, 2532, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__443)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_codeobj__444 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__430, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_12value_count, 2532, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__444)) __PYX_ERR(5, 2532, __pyx_L1_error)

  /* "pandas/_libs/hashtable_func_helper.pxi":2568
 * 
 * 
 * cpdef duplicated(ndarray[htfunc_t] values, object keep="first", const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return duplicated_object(values, keep, mask=mask)
 */
  __pyx_tuple__445 = PyTuple_Pack(2, __pyx_n_u_first, Py_None); if (unlikely(!__pyx_tuple__445)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__445);
  __Pyx_GIVEREF(__pyx_tuple__445);
  __pyx_tuple__446 = PyTuple_Pack(3, __pyx_n_s_values, __pyx_n_s_keep, __pyx_n_s_mask); if (unlikely(!__pyx_tuple__446)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__446);
  __Pyx_GIVEREF(__pyx_tuple__446);
  __pyx_codeobj__447 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__446, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_0duplicated, 2568, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__447)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_codeobj__448 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__446, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_0duplicated, 2568, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__448)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_codeobj__449 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__446, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_1duplicated, 2568, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__449)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_codeobj__450 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__446, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_2duplicated, 2568, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__450)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_codeobj__451 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__446, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_3duplicated, 2568, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__451)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_codeobj__452 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__446, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_4duplicated, 2568, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__452)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_codeobj__453 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__446, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_5duplicated, 2568, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__453)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_codeobj__454 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__446, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_6duplicated, 2568, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__454)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_codeobj__455 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__446, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_7duplicated, 2568, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__455)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_codeobj__456 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__446, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_8duplicated, 2568, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__456)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_codeobj__457 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__446, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_9duplicated, 2568, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__457)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_codeobj__458 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__446, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_10duplicated, 2568, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__458)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_codeobj__459 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__446, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_11duplicated, 2568, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__459)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_codeobj__460 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 3, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__446, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_12duplicated, 2568, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__460)) __PYX_ERR(5, 2568, __pyx_L1_error)

  /* "pandas/_libs/hashtable_func_helper.pxi":2604
 * 
 * 
 * cpdef ismember(ndarray[htfunc_t] arr, ndarray[htfunc_t] values):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return ismember_object(arr, values)
 */
  __pyx_tuple__461 = PyTuple_Pack(2, __pyx_n_s_arr, __pyx_n_s_values); if (unlikely(!__pyx_tuple__461)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__461);
  __Pyx_GIVEREF(__pyx_tuple__461);
  __pyx_codeobj__462 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__461, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_0ismember, 2604, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__462)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_codeobj__463 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__461, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_0ismember, 2604, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__463)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_codeobj__464 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__461, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_1ismember, 2604, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__464)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_codeobj__465 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__461, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_2ismember, 2604, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__465)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_codeobj__466 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__461, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_3ismember, 2604, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__466)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_codeobj__467 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__461, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_4ismember, 2604, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__467)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_codeobj__468 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__461, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_5ismember, 2604, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__468)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_codeobj__469 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__461, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_6ismember, 2604, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__469)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_codeobj__470 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__461, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_7ismember, 2604, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__470)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_codeobj__471 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__461, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_8ismember, 2604, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__471)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_codeobj__472 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__461, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_9ismember, 2604, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__472)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_codeobj__473 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__461, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_10ismember, 2604, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__473)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_codeobj__474 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__461, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_11ismember, 2604, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__474)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_codeobj__475 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__461, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_pyx_fuse_12ismember, 2604, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__475)) __PYX_ERR(5, 2604, __pyx_L1_error)

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */
  __pyx_tuple__476 = PyTuple_Pack(11, __pyx_n_s_values, __pyx_n_s_dropna, __pyx_n_s_mask, __pyx_n_s_keys, __pyx_n_s_modes, __pyx_n_s_counts, __pyx_n_s_count, __pyx_n_s_max_count, __pyx_n_s_nkeys, __pyx_n_s_k, __pyx_n_s_j); if (unlikely(!__pyx_tuple__476)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__476);
  __Pyx_GIVEREF(__pyx_tuple__476);
  __pyx_codeobj__477 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 11, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__476, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_mode, 2640, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__477)) __PYX_ERR(5, 2640, __pyx_L1_error)

  /* "pandas/_libs/hashtable_func_helper.pxi":2688
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def _unique_label_indices_int64(const int64_t[:] labels) -> ndarray:
 */
  __pyx_tuple__478 = PyTuple_Pack(8, __pyx_n_s_labels, __pyx_n_s_ret, __pyx_n_s_i, __pyx_n_s_n, __pyx_n_s_table, __pyx_n_s_idx, __pyx_n_s_arr, __pyx_n_s_ud); if (unlikely(!__pyx_tuple__478)) __PYX_ERR(5, 2688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__478);
  __Pyx_GIVEREF(__pyx_tuple__478);
  __pyx_codeobj__479 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__478, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_unique_label_indices_int64, 2688, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__479)) __PYX_ERR(5, 2688, __pyx_L1_error)

  /* "pandas/_libs/hashtable_func_helper.pxi":2723
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def _unique_label_indices_int32(const int32_t[:] labels) -> ndarray:
 */
  __pyx_codeobj__480 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 8, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__478, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_func_help, __pyx_n_s_unique_label_indices_int32, 2723, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__480)) __PYX_ERR(5, 2723, __pyx_L1_error)

  /* "pandas/_libs/hashtable.pyx":79
 *         self.count = 0
 * 
 *     def get_count(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.count
 * 
 */
  __pyx_codeobj__481 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_pyx, __pyx_n_s_get_count, 79, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__481)) __PYX_ERR(0, 79, __pyx_L1_error)

  /* "pandas/_libs/hashtable.pyx":82
 *         return self.count
 * 
 *     def factorize(self, values, na_sentinel=-1, na_value=None, mask=None) -> np.ndarray:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */
  __pyx_tuple__482 = PyTuple_Pack(5, __pyx_n_s_self, __pyx_n_s_values, __pyx_n_s_na_sentinel, __pyx_n_s_na_value, __pyx_n_s_mask); if (unlikely(!__pyx_tuple__482)) __PYX_ERR(0, 82, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__482);
  __Pyx_GIVEREF(__pyx_tuple__482);
  __pyx_codeobj__483 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__482, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_pyx, __pyx_n_s_factorize, 82, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__483)) __PYX_ERR(0, 82, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__484 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__484)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__485 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__485)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "pandas/_libs/hashtable.pyx":95
 *         self.uniques = ObjectVector()
 * 
 *     def factorize(             # <<<<<<<<<<<<<<
 *         self, ndarray[object] values, na_sentinel=-1, na_value=None, mask=None
 *     ) -> np.ndarray:
 */
  __pyx_codeobj__486 = (PyObject*)__Pyx_PyCode_New(5, 0, 0, 7, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__197, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_pandas__libs_hashtable_pyx, __pyx_n_s_factorize, 95, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__486)) __PYX_ERR(0, 95, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_codeobj__487 = (PyObject*)__Pyx_PyCode_New(1, 0, 0, 1, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__119, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_reduce_cython, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__487)) __PYX_ERR(1, 1, __pyx_L1_error)

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_codeobj__488 = (PyObject*)__Pyx_PyCode_New(2, 0, 0, 2, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__121, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_setstate_cython, 3, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__488)) __PYX_ERR(1, 3, __pyx_L1_error)

  /* "(tree fragment)":1
 * def __pyx_unpickle_HashTable(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_codeobj__489 = (PyObject*)__Pyx_PyCode_New(3, 0, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__112, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_HashTable, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__489)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}
/* #### Code section: init_constants ### */

static CYTHON_SMALL_CODE int __Pyx_InitConstants(void) {
  __pyx_umethod_PyDict_Type_get.type = (PyObject*)&PyDict_Type;
  __pyx_umethod_PyDict_Type_get.method_name = &__pyx_n_s_get;
  __pyx_umethod_PyDict_Type_values.type = (PyObject*)&PyDict_Type;
  __pyx_umethod_PyDict_Type_values.method_name = &__pyx_n_s_values;
  if (__Pyx_CreateStringTabAndInitStrings() < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_2 = PyInt_FromLong(2); if (unlikely(!__pyx_int_2)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_3 = PyInt_FromLong(3); if (unlikely(!__pyx_int_3)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_1048583 = PyInt_FromLong(1048583L); if (unlikely(!__pyx_int_1048583)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_112105877 = PyInt_FromLong(112105877L); if (unlikely(!__pyx_int_112105877)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_136983863 = PyInt_FromLong(136983863L); if (unlikely(!__pyx_int_136983863)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_184977713 = PyInt_FromLong(184977713L); if (unlikely(!__pyx_int_184977713)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_222419149 = PyInt_FromLong(222419149L); if (unlikely(!__pyx_int_222419149)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_228825662 = PyInt_FromLong(228825662L); if (unlikely(!__pyx_int_228825662)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_238750788 = PyInt_FromLong(238750788L); if (unlikely(!__pyx_int_238750788)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_neg_1 = PyInt_FromLong(-1); if (unlikely(!__pyx_int_neg_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_globals ### */

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  /* AssertionsEnabled.init */
  if (likely(__Pyx_init_assertions_enabled() == 0)); else

if (unlikely(PyErr_Occurred())) __PYX_ERR(0, 1, __pyx_L1_error)

  return 0;
  __pyx_L1_error:;
  return -1;
}
/* #### Code section: init_module ### */

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __pyx_collections_abc_Sequence = Py_None; Py_INCREF(Py_None);
  generic = Py_None; Py_INCREF(Py_None);
  strided = Py_None; Py_INCREF(Py_None);
  indirect = Py_None; Py_INCREF(Py_None);
  contiguous = Py_None; Py_INCREF(Py_None);
  indirect_contiguous = Py_None; Py_INCREF(Py_None);
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_6pandas_5_libs_9hashtable_HashTable = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_HashTable_spec, NULL); if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_HashTable)) __PYX_ERR(2, 1191, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_HashTable_spec, __pyx_ptype_6pandas_5_libs_9hashtable_HashTable) < 0) __PYX_ERR(2, 1191, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_HashTable = &__pyx_type_6pandas_5_libs_9hashtable_HashTable;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_HashTable) < 0) __PYX_ERR(2, 1191, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_HashTable->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_HashTable->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_HashTable->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_HashTable->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_HashTable, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_HashTable) < 0) __PYX_ERR(2, 1191, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_HashTable) < 0) __PYX_ERR(2, 1191, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt64HashTable = &__pyx_vtable_6pandas_5_libs_9hashtable_UInt64HashTable;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt64HashTable.get_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *, __pyx_t_5numpy_uint64_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_15UInt64HashTable_get_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt64HashTable.set_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *, __pyx_t_5numpy_uint64_t, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_15UInt64HashTable_set_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt64HashTable.get_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_15UInt64HashTable_get_na;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt64HashTable.set_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64HashTable *, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_15UInt64HashTable_set_na;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_HashTable); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2103, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_UInt64HashTable_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable)) __PYX_ERR(2, 2103, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_UInt64HashTable_spec, __pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable) < 0) __PYX_ERR(2, 2103, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable = &__pyx_type_6pandas_5_libs_9hashtable_UInt64HashTable;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_HashTable;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable) < 0) __PYX_ERR(2, 2103, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable, __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt64HashTable) < 0) __PYX_ERR(2, 2103, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable) < 0) __PYX_ERR(2, 2103, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_UInt64HashTable, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable) < 0) __PYX_ERR(2, 2103, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable) < 0) __PYX_ERR(2, 2103, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_Int64HashTable = &__pyx_vtable_6pandas_5_libs_9hashtable_Int64HashTable;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int64HashTable.get_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *, __pyx_t_5numpy_int64_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_14Int64HashTable_get_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int64HashTable.set_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *, __pyx_t_5numpy_int64_t, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_14Int64HashTable_set_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int64HashTable.get_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_14Int64HashTable_get_na;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int64HashTable.set_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64HashTable *, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_14Int64HashTable_set_na;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_HashTable); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2557, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Int64HashTable_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable)) __PYX_ERR(2, 2557, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Int64HashTable_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable) < 0) __PYX_ERR(2, 2557, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable = &__pyx_type_6pandas_5_libs_9hashtable_Int64HashTable;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_HashTable;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable) < 0) __PYX_ERR(2, 2557, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable, __pyx_vtabptr_6pandas_5_libs_9hashtable_Int64HashTable) < 0) __PYX_ERR(2, 2557, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable) < 0) __PYX_ERR(2, 2557, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Int64HashTable, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable) < 0) __PYX_ERR(2, 2557, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable) < 0) __PYX_ERR(2, 2557, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt32HashTable = &__pyx_vtable_6pandas_5_libs_9hashtable_UInt32HashTable;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt32HashTable.get_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *, __pyx_t_5numpy_uint32_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_15UInt32HashTable_get_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt32HashTable.set_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *, __pyx_t_5numpy_uint32_t, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_15UInt32HashTable_set_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt32HashTable.get_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_15UInt32HashTable_get_na;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt32HashTable.set_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32HashTable *, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_15UInt32HashTable_set_na;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_HashTable); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3981, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_UInt32HashTable_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable)) __PYX_ERR(2, 3981, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_UInt32HashTable_spec, __pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable) < 0) __PYX_ERR(2, 3981, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable = &__pyx_type_6pandas_5_libs_9hashtable_UInt32HashTable;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_HashTable;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable) < 0) __PYX_ERR(2, 3981, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable, __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt32HashTable) < 0) __PYX_ERR(2, 3981, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable) < 0) __PYX_ERR(2, 3981, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_UInt32HashTable, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable) < 0) __PYX_ERR(2, 3981, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable) < 0) __PYX_ERR(2, 3981, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_Int32HashTable = &__pyx_vtable_6pandas_5_libs_9hashtable_Int32HashTable;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int32HashTable.get_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *, __pyx_t_5numpy_int32_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_14Int32HashTable_get_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int32HashTable.set_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *, __pyx_t_5numpy_int32_t, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_14Int32HashTable_set_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int32HashTable.get_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_14Int32HashTable_get_na;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int32HashTable.set_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32HashTable *, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_14Int32HashTable_set_na;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_HashTable); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4435, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Int32HashTable_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable)) __PYX_ERR(2, 4435, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Int32HashTable_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable) < 0) __PYX_ERR(2, 4435, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable = &__pyx_type_6pandas_5_libs_9hashtable_Int32HashTable;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_HashTable;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable) < 0) __PYX_ERR(2, 4435, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable, __pyx_vtabptr_6pandas_5_libs_9hashtable_Int32HashTable) < 0) __PYX_ERR(2, 4435, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable) < 0) __PYX_ERR(2, 4435, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Int32HashTable, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable) < 0) __PYX_ERR(2, 4435, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable) < 0) __PYX_ERR(2, 4435, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt16HashTable = &__pyx_vtable_6pandas_5_libs_9hashtable_UInt16HashTable;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt16HashTable.get_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *, __pyx_t_5numpy_uint16_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_15UInt16HashTable_get_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt16HashTable.set_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *, __pyx_t_5numpy_uint16_t, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_15UInt16HashTable_set_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt16HashTable.get_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_15UInt16HashTable_get_na;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt16HashTable.set_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16HashTable *, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_15UInt16HashTable_set_na;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_HashTable); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_UInt16HashTable_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable)) __PYX_ERR(2, 4889, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_UInt16HashTable_spec, __pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable) < 0) __PYX_ERR(2, 4889, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable = &__pyx_type_6pandas_5_libs_9hashtable_UInt16HashTable;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_HashTable;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable) < 0) __PYX_ERR(2, 4889, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable, __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt16HashTable) < 0) __PYX_ERR(2, 4889, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable) < 0) __PYX_ERR(2, 4889, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_UInt16HashTable, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable) < 0) __PYX_ERR(2, 4889, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable) < 0) __PYX_ERR(2, 4889, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_Int16HashTable = &__pyx_vtable_6pandas_5_libs_9hashtable_Int16HashTable;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int16HashTable.get_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *, __pyx_t_5numpy_int16_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_14Int16HashTable_get_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int16HashTable.set_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *, __pyx_t_5numpy_int16_t, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_14Int16HashTable_set_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int16HashTable.get_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_14Int16HashTable_get_na;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int16HashTable.set_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16HashTable *, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_14Int16HashTable_set_na;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_HashTable); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Int16HashTable_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable)) __PYX_ERR(2, 5343, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Int16HashTable_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable) < 0) __PYX_ERR(2, 5343, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable = &__pyx_type_6pandas_5_libs_9hashtable_Int16HashTable;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_HashTable;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable) < 0) __PYX_ERR(2, 5343, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable, __pyx_vtabptr_6pandas_5_libs_9hashtable_Int16HashTable) < 0) __PYX_ERR(2, 5343, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable) < 0) __PYX_ERR(2, 5343, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Int16HashTable, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable) < 0) __PYX_ERR(2, 5343, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable) < 0) __PYX_ERR(2, 5343, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt8HashTable = &__pyx_vtable_6pandas_5_libs_9hashtable_UInt8HashTable;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt8HashTable.get_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *, __pyx_t_5numpy_uint8_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_14UInt8HashTable_get_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt8HashTable.set_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *, __pyx_t_5numpy_uint8_t, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_14UInt8HashTable_set_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt8HashTable.get_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_14UInt8HashTable_get_na;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt8HashTable.set_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8HashTable *, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_14UInt8HashTable_set_na;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_HashTable); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_UInt8HashTable_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable)) __PYX_ERR(2, 5797, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_UInt8HashTable_spec, __pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable) < 0) __PYX_ERR(2, 5797, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable = &__pyx_type_6pandas_5_libs_9hashtable_UInt8HashTable;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_HashTable;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable) < 0) __PYX_ERR(2, 5797, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable, __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt8HashTable) < 0) __PYX_ERR(2, 5797, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable) < 0) __PYX_ERR(2, 5797, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_UInt8HashTable, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable) < 0) __PYX_ERR(2, 5797, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable) < 0) __PYX_ERR(2, 5797, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_Int8HashTable = &__pyx_vtable_6pandas_5_libs_9hashtable_Int8HashTable;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int8HashTable.get_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *, __pyx_t_5numpy_int8_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_13Int8HashTable_get_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int8HashTable.set_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *, __pyx_t_5numpy_int8_t, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_13Int8HashTable_set_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int8HashTable.get_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_13Int8HashTable_get_na;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int8HashTable.set_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8HashTable *, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_13Int8HashTable_set_na;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_HashTable); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Int8HashTable_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable)) __PYX_ERR(2, 6251, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Int8HashTable_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable) < 0) __PYX_ERR(2, 6251, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable = &__pyx_type_6pandas_5_libs_9hashtable_Int8HashTable;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_HashTable;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable) < 0) __PYX_ERR(2, 6251, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable, __pyx_vtabptr_6pandas_5_libs_9hashtable_Int8HashTable) < 0) __PYX_ERR(2, 6251, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable) < 0) __PYX_ERR(2, 6251, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Int8HashTable, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable) < 0) __PYX_ERR(2, 6251, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable) < 0) __PYX_ERR(2, 6251, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_Float64HashTable = &__pyx_vtable_6pandas_5_libs_9hashtable_Float64HashTable;
  __pyx_vtable_6pandas_5_libs_9hashtable_Float64HashTable.get_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *, __pyx_t_5numpy_float64_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_16Float64HashTable_get_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_Float64HashTable.set_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *, __pyx_t_5numpy_float64_t, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_16Float64HashTable_set_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_Float64HashTable.get_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_16Float64HashTable_get_na;
  __pyx_vtable_6pandas_5_libs_9hashtable_Float64HashTable.set_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64HashTable *, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_16Float64HashTable_set_na;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_HashTable); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1649, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Float64HashTable_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable)) __PYX_ERR(2, 1649, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Float64HashTable_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable) < 0) __PYX_ERR(2, 1649, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable = &__pyx_type_6pandas_5_libs_9hashtable_Float64HashTable;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_HashTable;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable) < 0) __PYX_ERR(2, 1649, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable, __pyx_vtabptr_6pandas_5_libs_9hashtable_Float64HashTable) < 0) __PYX_ERR(2, 1649, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable) < 0) __PYX_ERR(2, 1649, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Float64HashTable, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable) < 0) __PYX_ERR(2, 1649, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable) < 0) __PYX_ERR(2, 1649, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_Float32HashTable = &__pyx_vtable_6pandas_5_libs_9hashtable_Float32HashTable;
  __pyx_vtable_6pandas_5_libs_9hashtable_Float32HashTable.get_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *, __pyx_t_5numpy_float32_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_16Float32HashTable_get_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_Float32HashTable.set_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *, __pyx_t_5numpy_float32_t, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_16Float32HashTable_set_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_Float32HashTable.get_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_16Float32HashTable_get_na;
  __pyx_vtable_6pandas_5_libs_9hashtable_Float32HashTable.set_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32HashTable *, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_16Float32HashTable_set_na;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_HashTable); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3527, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Float32HashTable_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable)) __PYX_ERR(2, 3527, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Float32HashTable_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable) < 0) __PYX_ERR(2, 3527, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable = &__pyx_type_6pandas_5_libs_9hashtable_Float32HashTable;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_HashTable;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable) < 0) __PYX_ERR(2, 3527, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable, __pyx_vtabptr_6pandas_5_libs_9hashtable_Float32HashTable) < 0) __PYX_ERR(2, 3527, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable) < 0) __PYX_ERR(2, 3527, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Float32HashTable, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable) < 0) __PYX_ERR(2, 3527, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable) < 0) __PYX_ERR(2, 3527, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_Complex64HashTable = &__pyx_vtable_6pandas_5_libs_9hashtable_Complex64HashTable;
  __pyx_vtable_6pandas_5_libs_9hashtable_Complex64HashTable.get_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *, __pyx_t_float_complex, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_18Complex64HashTable_get_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_Complex64HashTable.set_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *, __pyx_t_float_complex, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_18Complex64HashTable_set_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_Complex64HashTable.get_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_18Complex64HashTable_get_na;
  __pyx_vtable_6pandas_5_libs_9hashtable_Complex64HashTable.set_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64HashTable *, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_18Complex64HashTable_set_na;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_HashTable); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3073, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Complex64HashTable_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable)) __PYX_ERR(2, 3073, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Complex64HashTable_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable) < 0) __PYX_ERR(2, 3073, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable = &__pyx_type_6pandas_5_libs_9hashtable_Complex64HashTable;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_HashTable;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable) < 0) __PYX_ERR(2, 3073, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable, __pyx_vtabptr_6pandas_5_libs_9hashtable_Complex64HashTable) < 0) __PYX_ERR(2, 3073, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable) < 0) __PYX_ERR(2, 3073, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Complex64HashTable, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable) < 0) __PYX_ERR(2, 3073, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable) < 0) __PYX_ERR(2, 3073, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_Complex128HashTable = &__pyx_vtable_6pandas_5_libs_9hashtable_Complex128HashTable;
  __pyx_vtable_6pandas_5_libs_9hashtable_Complex128HashTable.get_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *, __pyx_t_double_complex, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_19Complex128HashTable_get_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_Complex128HashTable.set_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *, __pyx_t_double_complex, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_19Complex128HashTable_set_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_Complex128HashTable.get_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_19Complex128HashTable_get_na;
  __pyx_vtable_6pandas_5_libs_9hashtable_Complex128HashTable.set_na = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128HashTable *, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_19Complex128HashTable_set_na;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_HashTable); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1195, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Complex128HashTable_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable)) __PYX_ERR(2, 1195, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Complex128HashTable_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable) < 0) __PYX_ERR(2, 1195, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable = &__pyx_type_6pandas_5_libs_9hashtable_Complex128HashTable;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_HashTable;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable) < 0) __PYX_ERR(2, 1195, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable, __pyx_vtabptr_6pandas_5_libs_9hashtable_Complex128HashTable) < 0) __PYX_ERR(2, 1195, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable) < 0) __PYX_ERR(2, 1195, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Complex128HashTable, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable) < 0) __PYX_ERR(2, 1195, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable) < 0) __PYX_ERR(2, 1195, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_PyObjectHashTable = &__pyx_vtable_6pandas_5_libs_9hashtable_PyObjectHashTable;
  __pyx_vtable_6pandas_5_libs_9hashtable_PyObjectHashTable.get_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_17PyObjectHashTable_get_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_PyObjectHashTable.set_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_PyObjectHashTable *, PyObject *, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_17PyObjectHashTable_set_item;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_HashTable); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 7037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_PyObjectHashTable_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable)) __PYX_ERR(2, 7037, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_PyObjectHashTable_spec, __pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable) < 0) __PYX_ERR(2, 7037, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable = &__pyx_type_6pandas_5_libs_9hashtable_PyObjectHashTable;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_HashTable;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable) < 0) __PYX_ERR(2, 7037, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable, __pyx_vtabptr_6pandas_5_libs_9hashtable_PyObjectHashTable) < 0) __PYX_ERR(2, 7037, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable) < 0) __PYX_ERR(2, 7037, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_PyObjectHashTable, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable) < 0) __PYX_ERR(2, 7037, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable) < 0) __PYX_ERR(2, 7037, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_StringHashTable = &__pyx_vtable_6pandas_5_libs_9hashtable_StringHashTable;
  __pyx_vtable_6pandas_5_libs_9hashtable_StringHashTable.get_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *, PyObject *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_15StringHashTable_get_item;
  __pyx_vtable_6pandas_5_libs_9hashtable_StringHashTable.set_item = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_StringHashTable *, PyObject *, Py_ssize_t, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_15StringHashTable_set_item;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_HashTable); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6706, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_StringHashTable_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable)) __PYX_ERR(2, 6706, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_StringHashTable_spec, __pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable) < 0) __PYX_ERR(2, 6706, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable = &__pyx_type_6pandas_5_libs_9hashtable_StringHashTable;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_HashTable;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable) < 0) __PYX_ERR(2, 6706, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable, __pyx_vtabptr_6pandas_5_libs_9hashtable_StringHashTable) < 0) __PYX_ERR(2, 6706, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable) < 0) __PYX_ERR(2, 6706, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_StringHashTable, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable) < 0) __PYX_ERR(2, 6706, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable) < 0) __PYX_ERR(2, 6706, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_6pandas_5_libs_9hashtable_Vector = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Vector_spec, NULL); if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Vector)) __PYX_ERR(2, 413, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Vector_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Vector) < 0) __PYX_ERR(2, 413, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Vector = &__pyx_type_6pandas_5_libs_9hashtable_Vector;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Vector) < 0) __PYX_ERR(2, 413, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Vector->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Vector, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Vector) < 0) __PYX_ERR(2, 413, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Vector) < 0) __PYX_ERR(2, 413, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_Int64Vector = &__pyx_vtable_6pandas_5_libs_9hashtable_Int64Vector;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int64Vector.resize = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *))__pyx_f_6pandas_5_libs_9hashtable_11Int64Vector_resize;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int64Vector.to_array = (PyArrayObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_11Int64Vector_to_array;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int64Vector.append = (void (*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *, __pyx_t_5numpy_int64_t))__pyx_f_6pandas_5_libs_9hashtable_11Int64Vector_append;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int64Vector.extend = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int64Vector *, __Pyx_memviewslice))__pyx_f_6pandas_5_libs_9hashtable_11Int64Vector_extend;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Vector); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 641, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Int64Vector_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector)) __PYX_ERR(2, 641, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Int64Vector_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector) < 0) __PYX_ERR(2, 641, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector = &__pyx_type_6pandas_5_libs_9hashtable_Int64Vector;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Vector;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector) < 0) __PYX_ERR(2, 641, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector, __pyx_vtabptr_6pandas_5_libs_9hashtable_Int64Vector) < 0) __PYX_ERR(2, 641, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector) < 0) __PYX_ERR(2, 641, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Int64Vector, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector) < 0) __PYX_ERR(2, 641, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector) < 0) __PYX_ERR(2, 641, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_Complex128Vector = &__pyx_vtable_6pandas_5_libs_9hashtable_Complex128Vector;
  __pyx_vtable_6pandas_5_libs_9hashtable_Complex128Vector.resize = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *))__pyx_f_6pandas_5_libs_9hashtable_16Complex128Vector_resize;
  __pyx_vtable_6pandas_5_libs_9hashtable_Complex128Vector.to_array = (PyArrayObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_16Complex128Vector_to_array;
  __pyx_vtable_6pandas_5_libs_9hashtable_Complex128Vector.append = (void (*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *, khcomplex128_t))__pyx_f_6pandas_5_libs_9hashtable_16Complex128Vector_append;
  __pyx_vtable_6pandas_5_libs_9hashtable_Complex128Vector.extend = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex128Vector *, __Pyx_memviewslice))__pyx_f_6pandas_5_libs_9hashtable_16Complex128Vector_extend;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Vector); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 421, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Complex128Vector_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector)) __PYX_ERR(2, 421, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Complex128Vector_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector) < 0) __PYX_ERR(2, 421, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector = &__pyx_type_6pandas_5_libs_9hashtable_Complex128Vector;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Vector;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector) < 0) __PYX_ERR(2, 421, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector, __pyx_vtabptr_6pandas_5_libs_9hashtable_Complex128Vector) < 0) __PYX_ERR(2, 421, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector) < 0) __PYX_ERR(2, 421, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Complex128Vector, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector) < 0) __PYX_ERR(2, 421, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector) < 0) __PYX_ERR(2, 421, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_Complex64Vector = &__pyx_vtable_6pandas_5_libs_9hashtable_Complex64Vector;
  __pyx_vtable_6pandas_5_libs_9hashtable_Complex64Vector.resize = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *))__pyx_f_6pandas_5_libs_9hashtable_15Complex64Vector_resize;
  __pyx_vtable_6pandas_5_libs_9hashtable_Complex64Vector.to_array = (PyArrayObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_15Complex64Vector_to_array;
  __pyx_vtable_6pandas_5_libs_9hashtable_Complex64Vector.append = (void (*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *, khcomplex64_t))__pyx_f_6pandas_5_libs_9hashtable_15Complex64Vector_append;
  __pyx_vtable_6pandas_5_libs_9hashtable_Complex64Vector.extend = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Complex64Vector *, __Pyx_memviewslice))__pyx_f_6pandas_5_libs_9hashtable_15Complex64Vector_extend;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Vector); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 476, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Complex64Vector_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector)) __PYX_ERR(2, 476, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Complex64Vector_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector) < 0) __PYX_ERR(2, 476, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector = &__pyx_type_6pandas_5_libs_9hashtable_Complex64Vector;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Vector;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector) < 0) __PYX_ERR(2, 476, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector, __pyx_vtabptr_6pandas_5_libs_9hashtable_Complex64Vector) < 0) __PYX_ERR(2, 476, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector) < 0) __PYX_ERR(2, 476, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Complex64Vector, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector) < 0) __PYX_ERR(2, 476, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector) < 0) __PYX_ERR(2, 476, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_Float64Vector = &__pyx_vtable_6pandas_5_libs_9hashtable_Float64Vector;
  __pyx_vtable_6pandas_5_libs_9hashtable_Float64Vector.resize = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *))__pyx_f_6pandas_5_libs_9hashtable_13Float64Vector_resize;
  __pyx_vtable_6pandas_5_libs_9hashtable_Float64Vector.to_array = (PyArrayObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_13Float64Vector_to_array;
  __pyx_vtable_6pandas_5_libs_9hashtable_Float64Vector.append = (void (*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *, __pyx_t_5numpy_float64_t))__pyx_f_6pandas_5_libs_9hashtable_13Float64Vector_append;
  __pyx_vtable_6pandas_5_libs_9hashtable_Float64Vector.extend = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float64Vector *, __Pyx_memviewslice))__pyx_f_6pandas_5_libs_9hashtable_13Float64Vector_extend;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Vector); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 531, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Float64Vector_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector)) __PYX_ERR(2, 531, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Float64Vector_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector) < 0) __PYX_ERR(2, 531, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector = &__pyx_type_6pandas_5_libs_9hashtable_Float64Vector;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Vector;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector) < 0) __PYX_ERR(2, 531, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector, __pyx_vtabptr_6pandas_5_libs_9hashtable_Float64Vector) < 0) __PYX_ERR(2, 531, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector) < 0) __PYX_ERR(2, 531, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Float64Vector, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector) < 0) __PYX_ERR(2, 531, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector) < 0) __PYX_ERR(2, 531, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt64Vector = &__pyx_vtable_6pandas_5_libs_9hashtable_UInt64Vector;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt64Vector.resize = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *))__pyx_f_6pandas_5_libs_9hashtable_12UInt64Vector_resize;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt64Vector.to_array = (PyArrayObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_12UInt64Vector_to_array;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt64Vector.append = (void (*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *, __pyx_t_5numpy_uint64_t))__pyx_f_6pandas_5_libs_9hashtable_12UInt64Vector_append;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt64Vector.extend = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt64Vector *, __Pyx_memviewslice))__pyx_f_6pandas_5_libs_9hashtable_12UInt64Vector_extend;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Vector); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 586, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_UInt64Vector_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector)) __PYX_ERR(2, 586, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_UInt64Vector_spec, __pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector) < 0) __PYX_ERR(2, 586, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector = &__pyx_type_6pandas_5_libs_9hashtable_UInt64Vector;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Vector;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector) < 0) __PYX_ERR(2, 586, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector, __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt64Vector) < 0) __PYX_ERR(2, 586, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector) < 0) __PYX_ERR(2, 586, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_UInt64Vector, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector) < 0) __PYX_ERR(2, 586, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector) < 0) __PYX_ERR(2, 586, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_Float32Vector = &__pyx_vtable_6pandas_5_libs_9hashtable_Float32Vector;
  __pyx_vtable_6pandas_5_libs_9hashtable_Float32Vector.resize = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *))__pyx_f_6pandas_5_libs_9hashtable_13Float32Vector_resize;
  __pyx_vtable_6pandas_5_libs_9hashtable_Float32Vector.to_array = (PyArrayObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_13Float32Vector_to_array;
  __pyx_vtable_6pandas_5_libs_9hashtable_Float32Vector.append = (void (*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *, __pyx_t_5numpy_float32_t))__pyx_f_6pandas_5_libs_9hashtable_13Float32Vector_append;
  __pyx_vtable_6pandas_5_libs_9hashtable_Float32Vector.extend = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Float32Vector *, __Pyx_memviewslice))__pyx_f_6pandas_5_libs_9hashtable_13Float32Vector_extend;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Vector); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Float32Vector_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector)) __PYX_ERR(2, 693, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Float32Vector_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector) < 0) __PYX_ERR(2, 693, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector = &__pyx_type_6pandas_5_libs_9hashtable_Float32Vector;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Vector;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector) < 0) __PYX_ERR(2, 693, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector, __pyx_vtabptr_6pandas_5_libs_9hashtable_Float32Vector) < 0) __PYX_ERR(2, 693, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector) < 0) __PYX_ERR(2, 693, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Float32Vector, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector) < 0) __PYX_ERR(2, 693, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector) < 0) __PYX_ERR(2, 693, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt32Vector = &__pyx_vtable_6pandas_5_libs_9hashtable_UInt32Vector;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt32Vector.resize = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *))__pyx_f_6pandas_5_libs_9hashtable_12UInt32Vector_resize;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt32Vector.to_array = (PyArrayObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_12UInt32Vector_to_array;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt32Vector.append = (void (*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *, __pyx_t_5numpy_uint32_t))__pyx_f_6pandas_5_libs_9hashtable_12UInt32Vector_append;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt32Vector.extend = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt32Vector *, __Pyx_memviewslice))__pyx_f_6pandas_5_libs_9hashtable_12UInt32Vector_extend;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Vector); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 748, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_UInt32Vector_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector)) __PYX_ERR(2, 748, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_UInt32Vector_spec, __pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector) < 0) __PYX_ERR(2, 748, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector = &__pyx_type_6pandas_5_libs_9hashtable_UInt32Vector;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Vector;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector) < 0) __PYX_ERR(2, 748, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector, __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt32Vector) < 0) __PYX_ERR(2, 748, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector) < 0) __PYX_ERR(2, 748, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_UInt32Vector, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector) < 0) __PYX_ERR(2, 748, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector) < 0) __PYX_ERR(2, 748, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_Int32Vector = &__pyx_vtable_6pandas_5_libs_9hashtable_Int32Vector;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int32Vector.resize = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *))__pyx_f_6pandas_5_libs_9hashtable_11Int32Vector_resize;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int32Vector.to_array = (PyArrayObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_11Int32Vector_to_array;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int32Vector.append = (void (*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *, __pyx_t_5numpy_int32_t))__pyx_f_6pandas_5_libs_9hashtable_11Int32Vector_append;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int32Vector.extend = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int32Vector *, __Pyx_memviewslice))__pyx_f_6pandas_5_libs_9hashtable_11Int32Vector_extend;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Vector); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 803, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Int32Vector_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector)) __PYX_ERR(2, 803, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Int32Vector_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector) < 0) __PYX_ERR(2, 803, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector = &__pyx_type_6pandas_5_libs_9hashtable_Int32Vector;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Vector;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector) < 0) __PYX_ERR(2, 803, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector, __pyx_vtabptr_6pandas_5_libs_9hashtable_Int32Vector) < 0) __PYX_ERR(2, 803, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector) < 0) __PYX_ERR(2, 803, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Int32Vector, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector) < 0) __PYX_ERR(2, 803, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector) < 0) __PYX_ERR(2, 803, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt16Vector = &__pyx_vtable_6pandas_5_libs_9hashtable_UInt16Vector;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt16Vector.resize = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *))__pyx_f_6pandas_5_libs_9hashtable_12UInt16Vector_resize;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt16Vector.to_array = (PyArrayObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_12UInt16Vector_to_array;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt16Vector.append = (void (*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *, __pyx_t_5numpy_uint16_t))__pyx_f_6pandas_5_libs_9hashtable_12UInt16Vector_append;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt16Vector.extend = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt16Vector *, __Pyx_memviewslice))__pyx_f_6pandas_5_libs_9hashtable_12UInt16Vector_extend;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Vector); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 858, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_UInt16Vector_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector)) __PYX_ERR(2, 858, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_UInt16Vector_spec, __pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector) < 0) __PYX_ERR(2, 858, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector = &__pyx_type_6pandas_5_libs_9hashtable_UInt16Vector;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Vector;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector) < 0) __PYX_ERR(2, 858, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector, __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt16Vector) < 0) __PYX_ERR(2, 858, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector) < 0) __PYX_ERR(2, 858, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_UInt16Vector, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector) < 0) __PYX_ERR(2, 858, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector) < 0) __PYX_ERR(2, 858, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_Int16Vector = &__pyx_vtable_6pandas_5_libs_9hashtable_Int16Vector;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int16Vector.resize = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *))__pyx_f_6pandas_5_libs_9hashtable_11Int16Vector_resize;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int16Vector.to_array = (PyArrayObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_11Int16Vector_to_array;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int16Vector.append = (void (*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *, __pyx_t_5numpy_int16_t))__pyx_f_6pandas_5_libs_9hashtable_11Int16Vector_append;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int16Vector.extend = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int16Vector *, __Pyx_memviewslice))__pyx_f_6pandas_5_libs_9hashtable_11Int16Vector_extend;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Vector); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 913, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Int16Vector_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector)) __PYX_ERR(2, 913, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Int16Vector_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector) < 0) __PYX_ERR(2, 913, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector = &__pyx_type_6pandas_5_libs_9hashtable_Int16Vector;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Vector;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector) < 0) __PYX_ERR(2, 913, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector, __pyx_vtabptr_6pandas_5_libs_9hashtable_Int16Vector) < 0) __PYX_ERR(2, 913, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector) < 0) __PYX_ERR(2, 913, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Int16Vector, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector) < 0) __PYX_ERR(2, 913, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector) < 0) __PYX_ERR(2, 913, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt8Vector = &__pyx_vtable_6pandas_5_libs_9hashtable_UInt8Vector;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt8Vector.resize = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *))__pyx_f_6pandas_5_libs_9hashtable_11UInt8Vector_resize;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt8Vector.to_array = (PyArrayObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_11UInt8Vector_to_array;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt8Vector.append = (void (*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *, __pyx_t_5numpy_uint8_t))__pyx_f_6pandas_5_libs_9hashtable_11UInt8Vector_append;
  __pyx_vtable_6pandas_5_libs_9hashtable_UInt8Vector.extend = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_UInt8Vector *, __Pyx_memviewslice))__pyx_f_6pandas_5_libs_9hashtable_11UInt8Vector_extend;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Vector); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_UInt8Vector_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector)) __PYX_ERR(2, 968, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_UInt8Vector_spec, __pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector) < 0) __PYX_ERR(2, 968, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector = &__pyx_type_6pandas_5_libs_9hashtable_UInt8Vector;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Vector;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector) < 0) __PYX_ERR(2, 968, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector, __pyx_vtabptr_6pandas_5_libs_9hashtable_UInt8Vector) < 0) __PYX_ERR(2, 968, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector) < 0) __PYX_ERR(2, 968, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_UInt8Vector, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector) < 0) __PYX_ERR(2, 968, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector) < 0) __PYX_ERR(2, 968, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_Int8Vector = &__pyx_vtable_6pandas_5_libs_9hashtable_Int8Vector;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int8Vector.resize = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *))__pyx_f_6pandas_5_libs_9hashtable_10Int8Vector_resize;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int8Vector.to_array = (PyArrayObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_10Int8Vector_to_array;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int8Vector.append = (void (*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *, __pyx_t_5numpy_int8_t))__pyx_f_6pandas_5_libs_9hashtable_10Int8Vector_append;
  __pyx_vtable_6pandas_5_libs_9hashtable_Int8Vector.extend = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_Int8Vector *, __Pyx_memviewslice))__pyx_f_6pandas_5_libs_9hashtable_10Int8Vector_extend;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Vector); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1023, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Int8Vector_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector)) __PYX_ERR(2, 1023, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Int8Vector_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector) < 0) __PYX_ERR(2, 1023, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector = &__pyx_type_6pandas_5_libs_9hashtable_Int8Vector;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Vector;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector) < 0) __PYX_ERR(2, 1023, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector, __pyx_vtabptr_6pandas_5_libs_9hashtable_Int8Vector) < 0) __PYX_ERR(2, 1023, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector) < 0) __PYX_ERR(2, 1023, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Int8Vector, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector) < 0) __PYX_ERR(2, 1023, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector) < 0) __PYX_ERR(2, 1023, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_StringVector = &__pyx_vtable_6pandas_5_libs_9hashtable_StringVector;
  __pyx_vtable_6pandas_5_libs_9hashtable_StringVector.resize = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *))__pyx_f_6pandas_5_libs_9hashtable_12StringVector_resize;
  __pyx_vtable_6pandas_5_libs_9hashtable_StringVector.to_array = (PyArrayObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_12StringVector_to_array;
  __pyx_vtable_6pandas_5_libs_9hashtable_StringVector.append = (void (*)(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *, char *))__pyx_f_6pandas_5_libs_9hashtable_12StringVector_append;
  __pyx_vtable_6pandas_5_libs_9hashtable_StringVector.extend = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_StringVector *, PyArrayObject *))__pyx_f_6pandas_5_libs_9hashtable_12StringVector_extend;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Vector); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1078, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_StringVector = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_StringVector_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_StringVector)) __PYX_ERR(2, 1078, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_StringVector_spec, __pyx_ptype_6pandas_5_libs_9hashtable_StringVector) < 0) __PYX_ERR(2, 1078, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_StringVector = &__pyx_type_6pandas_5_libs_9hashtable_StringVector;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_StringVector->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Vector;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_StringVector) < 0) __PYX_ERR(2, 1078, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_StringVector->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_StringVector->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_StringVector->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_StringVector->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_StringVector, __pyx_vtabptr_6pandas_5_libs_9hashtable_StringVector) < 0) __PYX_ERR(2, 1078, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_StringVector) < 0) __PYX_ERR(2, 1078, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_StringVector, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_StringVector) < 0) __PYX_ERR(2, 1078, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_StringVector) < 0) __PYX_ERR(2, 1078, __pyx_L1_error)
  #endif
  __pyx_vtabptr_6pandas_5_libs_9hashtable_ObjectVector = &__pyx_vtable_6pandas_5_libs_9hashtable_ObjectVector;
  __pyx_vtable_6pandas_5_libs_9hashtable_ObjectVector.append = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *, PyObject *))__pyx_f_6pandas_5_libs_9hashtable_12ObjectVector_append;
  __pyx_vtable_6pandas_5_libs_9hashtable_ObjectVector.to_array = (PyArrayObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *, int __pyx_skip_dispatch))__pyx_f_6pandas_5_libs_9hashtable_12ObjectVector_to_array;
  __pyx_vtable_6pandas_5_libs_9hashtable_ObjectVector.extend = (PyObject *(*)(struct __pyx_obj_6pandas_5_libs_9hashtable_ObjectVector *, PyArrayObject *))__pyx_f_6pandas_5_libs_9hashtable_12ObjectVector_extend;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Vector); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1144, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_ObjectVector_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector)) __PYX_ERR(2, 1144, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_ObjectVector_spec, __pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector) < 0) __PYX_ERR(2, 1144, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector = &__pyx_type_6pandas_5_libs_9hashtable_ObjectVector;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Vector;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector) < 0) __PYX_ERR(2, 1144, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector, __pyx_vtabptr_6pandas_5_libs_9hashtable_ObjectVector) < 0) __PYX_ERR(2, 1144, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector) < 0) __PYX_ERR(2, 1144, __pyx_L1_error)
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_ObjectVector, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector) < 0) __PYX_ERR(2, 1144, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector) < 0) __PYX_ERR(2, 1144, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Factorizer_spec, NULL); if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer)) __PYX_ERR(0, 72, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Factorizer_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer) < 0) __PYX_ERR(0, 72, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer = &__pyx_type_6pandas_5_libs_9hashtable_Factorizer;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer) < 0) __PYX_ERR(0, 72, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Factorizer, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer) < 0) __PYX_ERR(0, 72, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer) < 0) __PYX_ERR(0, 72, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6668, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Int8Factorizer = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Int8Factorizer_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int8Factorizer)) __PYX_ERR(2, 6668, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Int8Factorizer_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Int8Factorizer) < 0) __PYX_ERR(2, 6668, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Int8Factorizer = &__pyx_type_6pandas_5_libs_9hashtable_Int8Factorizer;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Int8Factorizer->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Int8Factorizer) < 0) __PYX_ERR(2, 6668, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Int8Factorizer->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int8Factorizer->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Int8Factorizer->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Int8Factorizer->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Int8Factorizer, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int8Factorizer) < 0) __PYX_ERR(2, 6668, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int8Factorizer) < 0) __PYX_ERR(2, 6668, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 6214, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt8Factorizer = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_UInt8Factorizer_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Factorizer)) __PYX_ERR(2, 6214, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_UInt8Factorizer_spec, __pyx_ptype_6pandas_5_libs_9hashtable_UInt8Factorizer) < 0) __PYX_ERR(2, 6214, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt8Factorizer = &__pyx_type_6pandas_5_libs_9hashtable_UInt8Factorizer;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt8Factorizer->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Factorizer) < 0) __PYX_ERR(2, 6214, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt8Factorizer->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Factorizer->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_UInt8Factorizer->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_UInt8Factorizer->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_UInt8Factorizer, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt8Factorizer) < 0) __PYX_ERR(2, 6214, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt8Factorizer) < 0) __PYX_ERR(2, 6214, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5760, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Int16Factorizer = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Int16Factorizer_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int16Factorizer)) __PYX_ERR(2, 5760, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Int16Factorizer_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Int16Factorizer) < 0) __PYX_ERR(2, 5760, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Int16Factorizer = &__pyx_type_6pandas_5_libs_9hashtable_Int16Factorizer;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Int16Factorizer->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Int16Factorizer) < 0) __PYX_ERR(2, 5760, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Int16Factorizer->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int16Factorizer->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Int16Factorizer->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Int16Factorizer->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Int16Factorizer, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int16Factorizer) < 0) __PYX_ERR(2, 5760, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int16Factorizer) < 0) __PYX_ERR(2, 5760, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 5306, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt16Factorizer = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_UInt16Factorizer_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Factorizer)) __PYX_ERR(2, 5306, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_UInt16Factorizer_spec, __pyx_ptype_6pandas_5_libs_9hashtable_UInt16Factorizer) < 0) __PYX_ERR(2, 5306, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt16Factorizer = &__pyx_type_6pandas_5_libs_9hashtable_UInt16Factorizer;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt16Factorizer->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Factorizer) < 0) __PYX_ERR(2, 5306, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt16Factorizer->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Factorizer->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_UInt16Factorizer->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_UInt16Factorizer->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_UInt16Factorizer, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt16Factorizer) < 0) __PYX_ERR(2, 5306, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt16Factorizer) < 0) __PYX_ERR(2, 5306, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4852, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Int32Factorizer = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Int32Factorizer_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int32Factorizer)) __PYX_ERR(2, 4852, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Int32Factorizer_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Int32Factorizer) < 0) __PYX_ERR(2, 4852, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Int32Factorizer = &__pyx_type_6pandas_5_libs_9hashtable_Int32Factorizer;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Int32Factorizer->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Int32Factorizer) < 0) __PYX_ERR(2, 4852, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Int32Factorizer->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int32Factorizer->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Int32Factorizer->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Int32Factorizer->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Int32Factorizer, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int32Factorizer) < 0) __PYX_ERR(2, 4852, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int32Factorizer) < 0) __PYX_ERR(2, 4852, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 4398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt32Factorizer = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_UInt32Factorizer_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Factorizer)) __PYX_ERR(2, 4398, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_UInt32Factorizer_spec, __pyx_ptype_6pandas_5_libs_9hashtable_UInt32Factorizer) < 0) __PYX_ERR(2, 4398, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt32Factorizer = &__pyx_type_6pandas_5_libs_9hashtable_UInt32Factorizer;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt32Factorizer->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Factorizer) < 0) __PYX_ERR(2, 4398, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt32Factorizer->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Factorizer->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_UInt32Factorizer->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_UInt32Factorizer->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_UInt32Factorizer, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt32Factorizer) < 0) __PYX_ERR(2, 4398, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt32Factorizer) < 0) __PYX_ERR(2, 4398, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Float32Factorizer = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Float32Factorizer_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Float32Factorizer)) __PYX_ERR(2, 3944, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Float32Factorizer_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Float32Factorizer) < 0) __PYX_ERR(2, 3944, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Float32Factorizer = &__pyx_type_6pandas_5_libs_9hashtable_Float32Factorizer;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Float32Factorizer->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Float32Factorizer) < 0) __PYX_ERR(2, 3944, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Float32Factorizer->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Float32Factorizer->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Float32Factorizer->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Float32Factorizer->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Float32Factorizer, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Float32Factorizer) < 0) __PYX_ERR(2, 3944, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Float32Factorizer) < 0) __PYX_ERR(2, 3944, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex64Factorizer = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Complex64Factorizer_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Factorizer)) __PYX_ERR(2, 3490, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Complex64Factorizer_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Complex64Factorizer) < 0) __PYX_ERR(2, 3490, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex64Factorizer = &__pyx_type_6pandas_5_libs_9hashtable_Complex64Factorizer;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex64Factorizer->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Factorizer) < 0) __PYX_ERR(2, 3490, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex64Factorizer->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Factorizer->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Complex64Factorizer->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Complex64Factorizer->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Complex64Factorizer, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Complex64Factorizer) < 0) __PYX_ERR(2, 3490, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Complex64Factorizer) < 0) __PYX_ERR(2, 3490, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 3036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Int64Factorizer = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Int64Factorizer_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int64Factorizer)) __PYX_ERR(2, 3036, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Int64Factorizer_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Int64Factorizer) < 0) __PYX_ERR(2, 3036, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Int64Factorizer = &__pyx_type_6pandas_5_libs_9hashtable_Int64Factorizer;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Int64Factorizer->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Int64Factorizer) < 0) __PYX_ERR(2, 3036, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Int64Factorizer->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Int64Factorizer->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Int64Factorizer->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Int64Factorizer->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Int64Factorizer, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int64Factorizer) < 0) __PYX_ERR(2, 3036, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Int64Factorizer) < 0) __PYX_ERR(2, 3036, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2520, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt64Factorizer = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_UInt64Factorizer_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Factorizer)) __PYX_ERR(2, 2520, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_UInt64Factorizer_spec, __pyx_ptype_6pandas_5_libs_9hashtable_UInt64Factorizer) < 0) __PYX_ERR(2, 2520, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt64Factorizer = &__pyx_type_6pandas_5_libs_9hashtable_UInt64Factorizer;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt64Factorizer->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Factorizer) < 0) __PYX_ERR(2, 2520, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_UInt64Factorizer->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Factorizer->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_UInt64Factorizer->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_UInt64Factorizer->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_UInt64Factorizer, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt64Factorizer) < 0) __PYX_ERR(2, 2520, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_UInt64Factorizer) < 0) __PYX_ERR(2, 2520, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 2066, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Float64Factorizer = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Float64Factorizer_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Float64Factorizer)) __PYX_ERR(2, 2066, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Float64Factorizer_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Float64Factorizer) < 0) __PYX_ERR(2, 2066, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Float64Factorizer = &__pyx_type_6pandas_5_libs_9hashtable_Float64Factorizer;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Float64Factorizer->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Float64Factorizer) < 0) __PYX_ERR(2, 2066, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Float64Factorizer->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Float64Factorizer->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Float64Factorizer->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Float64Factorizer->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Float64Factorizer, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Float64Factorizer) < 0) __PYX_ERR(2, 2066, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Float64Factorizer) < 0) __PYX_ERR(2, 2066, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1612, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex128Factorizer = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_Complex128Factorizer_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Factorizer)) __PYX_ERR(2, 1612, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_Complex128Factorizer_spec, __pyx_ptype_6pandas_5_libs_9hashtable_Complex128Factorizer) < 0) __PYX_ERR(2, 1612, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex128Factorizer = &__pyx_type_6pandas_5_libs_9hashtable_Complex128Factorizer;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex128Factorizer->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Factorizer) < 0) __PYX_ERR(2, 1612, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_Complex128Factorizer->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Factorizer->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_Complex128Factorizer->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_Complex128Factorizer->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_Complex128Factorizer, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Complex128Factorizer) < 0) __PYX_ERR(2, 1612, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_Complex128Factorizer) < 0) __PYX_ERR(2, 1612, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 86, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_9hashtable_ObjectFactorizer = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type_6pandas_5_libs_9hashtable_ObjectFactorizer_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_ptype_6pandas_5_libs_9hashtable_ObjectFactorizer)) __PYX_ERR(0, 86, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type_6pandas_5_libs_9hashtable_ObjectFactorizer_spec, __pyx_ptype_6pandas_5_libs_9hashtable_ObjectFactorizer) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  #else
  __pyx_ptype_6pandas_5_libs_9hashtable_ObjectFactorizer = &__pyx_type_6pandas_5_libs_9hashtable_ObjectFactorizer;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_ptype_6pandas_5_libs_9hashtable_ObjectFactorizer->tp_base = __pyx_ptype_6pandas_5_libs_9hashtable_Factorizer;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_ptype_6pandas_5_libs_9hashtable_ObjectFactorizer) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_ptype_6pandas_5_libs_9hashtable_ObjectFactorizer->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_ptype_6pandas_5_libs_9hashtable_ObjectFactorizer->tp_dictoffset && __pyx_ptype_6pandas_5_libs_9hashtable_ObjectFactorizer->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_ptype_6pandas_5_libs_9hashtable_ObjectFactorizer->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_ObjectFactorizer, (PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_ObjectFactorizer) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_ptype_6pandas_5_libs_9hashtable_ObjectFactorizer) < 0) __PYX_ERR(0, 86, __pyx_L1_error)
  #endif
  __pyx_vtabptr_array = &__pyx_vtable_array;
  __pyx_vtable_array.get_memview = (PyObject *(*)(struct __pyx_array_obj *))__pyx_array_get_memview;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_array_type = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type___pyx_array_spec, NULL); if (unlikely(!__pyx_array_type)) __PYX_ERR(1, 114, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_array_type->tp_as_buffer = &__pyx_tp_as_buffer_array;
  if (!__pyx_array_type->tp_as_buffer->bf_releasebuffer && __pyx_array_type->tp_base->tp_as_buffer && __pyx_array_type->tp_base->tp_as_buffer->bf_releasebuffer) {
    __pyx_array_type->tp_as_buffer->bf_releasebuffer = __pyx_array_type->tp_base->tp_as_buffer->bf_releasebuffer;
  }
  #elif defined(Py_bf_getbuffer) && defined(Py_bf_releasebuffer)
  /* PY_VERSION_HEX >= 0x03090000 || Py_LIMITED_API >= 0x030B0000 */
  #elif defined(_MSC_VER)
  #pragma message ("The buffer protocol is not supported in the Limited C-API < 3.11.")
  #else
  #warning "The buffer protocol is not supported in the Limited C-API < 3.11."
  #endif
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type___pyx_array_spec, __pyx_array_type) < 0) __PYX_ERR(1, 114, __pyx_L1_error)
  #else
  __pyx_array_type = &__pyx_type___pyx_array;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_array_type) < 0) __PYX_ERR(1, 114, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_array_type->tp_print = 0;
  #endif
  if (__Pyx_SetVtable(__pyx_array_type, __pyx_vtabptr_array) < 0) __PYX_ERR(1, 114, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_array_type) < 0) __PYX_ERR(1, 114, __pyx_L1_error)
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_array_type) < 0) __PYX_ERR(1, 114, __pyx_L1_error)
  #endif
  #if CYTHON_USE_TYPE_SPECS
  __pyx_MemviewEnum_type = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type___pyx_MemviewEnum_spec, NULL); if (unlikely(!__pyx_MemviewEnum_type)) __PYX_ERR(1, 302, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type___pyx_MemviewEnum_spec, __pyx_MemviewEnum_type) < 0) __PYX_ERR(1, 302, __pyx_L1_error)
  #else
  __pyx_MemviewEnum_type = &__pyx_type___pyx_MemviewEnum;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_MemviewEnum_type) < 0) __PYX_ERR(1, 302, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_MemviewEnum_type->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_MemviewEnum_type->tp_dictoffset && __pyx_MemviewEnum_type->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_MemviewEnum_type->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_MemviewEnum_type) < 0) __PYX_ERR(1, 302, __pyx_L1_error)
  #endif
  __pyx_vtabptr_memoryview = &__pyx_vtable_memoryview;
  __pyx_vtable_memoryview.get_item_pointer = (char *(*)(struct __pyx_memoryview_obj *, PyObject *))__pyx_memoryview_get_item_pointer;
  __pyx_vtable_memoryview.is_slice = (PyObject *(*)(struct __pyx_memoryview_obj *, PyObject *))__pyx_memoryview_is_slice;
  __pyx_vtable_memoryview.setitem_slice_assignment = (PyObject *(*)(struct __pyx_memoryview_obj *, PyObject *, PyObject *))__pyx_memoryview_setitem_slice_assignment;
  __pyx_vtable_memoryview.setitem_slice_assign_scalar = (PyObject *(*)(struct __pyx_memoryview_obj *, struct __pyx_memoryview_obj *, PyObject *))__pyx_memoryview_setitem_slice_assign_scalar;
  __pyx_vtable_memoryview.setitem_indexed = (PyObject *(*)(struct __pyx_memoryview_obj *, PyObject *, PyObject *))__pyx_memoryview_setitem_indexed;
  __pyx_vtable_memoryview.convert_item_to_object = (PyObject *(*)(struct __pyx_memoryview_obj *, char *))__pyx_memoryview_convert_item_to_object;
  __pyx_vtable_memoryview.assign_item_from_object = (PyObject *(*)(struct __pyx_memoryview_obj *, char *, PyObject *))__pyx_memoryview_assign_item_from_object;
  __pyx_vtable_memoryview._get_base = (PyObject *(*)(struct __pyx_memoryview_obj *))__pyx_memoryview__get_base;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_memoryview_type = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type___pyx_memoryview_spec, NULL); if (unlikely(!__pyx_memoryview_type)) __PYX_ERR(1, 337, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_memoryview_type->tp_as_buffer = &__pyx_tp_as_buffer_memoryview;
  if (!__pyx_memoryview_type->tp_as_buffer->bf_releasebuffer && __pyx_memoryview_type->tp_base->tp_as_buffer && __pyx_memoryview_type->tp_base->tp_as_buffer->bf_releasebuffer) {
    __pyx_memoryview_type->tp_as_buffer->bf_releasebuffer = __pyx_memoryview_type->tp_base->tp_as_buffer->bf_releasebuffer;
  }
  #elif defined(Py_bf_getbuffer) && defined(Py_bf_releasebuffer)
  /* PY_VERSION_HEX >= 0x03090000 || Py_LIMITED_API >= 0x030B0000 */
  #elif defined(_MSC_VER)
  #pragma message ("The buffer protocol is not supported in the Limited C-API < 3.11.")
  #else
  #warning "The buffer protocol is not supported in the Limited C-API < 3.11."
  #endif
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type___pyx_memoryview_spec, __pyx_memoryview_type) < 0) __PYX_ERR(1, 337, __pyx_L1_error)
  #else
  __pyx_memoryview_type = &__pyx_type___pyx_memoryview;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_memoryview_type) < 0) __PYX_ERR(1, 337, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_memoryview_type->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_memoryview_type->tp_dictoffset && __pyx_memoryview_type->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_memoryview_type->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_memoryview_type, __pyx_vtabptr_memoryview) < 0) __PYX_ERR(1, 337, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_memoryview_type) < 0) __PYX_ERR(1, 337, __pyx_L1_error)
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_memoryview_type) < 0) __PYX_ERR(1, 337, __pyx_L1_error)
  #endif
  __pyx_vtabptr__memoryviewslice = &__pyx_vtable__memoryviewslice;
  __pyx_vtable__memoryviewslice.__pyx_base = *__pyx_vtabptr_memoryview;
  __pyx_vtable__memoryviewslice.__pyx_base.convert_item_to_object = (PyObject *(*)(struct __pyx_memoryview_obj *, char *))__pyx_memoryviewslice_convert_item_to_object;
  __pyx_vtable__memoryviewslice.__pyx_base.assign_item_from_object = (PyObject *(*)(struct __pyx_memoryview_obj *, char *, PyObject *))__pyx_memoryviewslice_assign_item_from_object;
  __pyx_vtable__memoryviewslice.__pyx_base._get_base = (PyObject *(*)(struct __pyx_memoryview_obj *))__pyx_memoryviewslice__get_base;
  #if CYTHON_USE_TYPE_SPECS
  __pyx_t_1 = PyTuple_Pack(1, (PyObject *)__pyx_memoryview_type); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 952, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_memoryviewslice_type = (PyTypeObject *) __Pyx_PyType_FromModuleAndSpec(__pyx_m, &__pyx_type___pyx_memoryviewslice_spec, __pyx_t_1);
  __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(!__pyx_memoryviewslice_type)) __PYX_ERR(1, 952, __pyx_L1_error)
  if (__Pyx_fix_up_extension_type_from_spec(&__pyx_type___pyx_memoryviewslice_spec, __pyx_memoryviewslice_type) < 0) __PYX_ERR(1, 952, __pyx_L1_error)
  #else
  __pyx_memoryviewslice_type = &__pyx_type___pyx_memoryviewslice;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  __pyx_memoryviewslice_type->tp_base = __pyx_memoryview_type;
  #endif
  #if !CYTHON_USE_TYPE_SPECS
  if (__Pyx_PyType_Ready(__pyx_memoryviewslice_type) < 0) __PYX_ERR(1, 952, __pyx_L1_error)
  #endif
  #if PY_MAJOR_VERSION < 3
  __pyx_memoryviewslice_type->tp_print = 0;
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_memoryviewslice_type->tp_dictoffset && __pyx_memoryviewslice_type->tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_memoryviewslice_type->tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #endif
  if (__Pyx_SetVtable(__pyx_memoryviewslice_type, __pyx_vtabptr__memoryviewslice) < 0) __PYX_ERR(1, 952, __pyx_L1_error)
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_MergeVtables(__pyx_memoryviewslice_type) < 0) __PYX_ERR(1, 952, __pyx_L1_error)
  #endif
  #if !CYTHON_COMPILING_IN_LIMITED_API
  if (__Pyx_setup_reduce((PyObject *) __pyx_memoryviewslice_type) < 0) __PYX_ERR(1, 952, __pyx_L1_error)
  #endif
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_7cpython_4type_type = __Pyx_ImportType_3_0_8(__pyx_t_1, __Pyx_BUILTIN_MODULE_NAME, "type", 
  #if defined(PYPY_VERSION_NUM) && PYPY_VERSION_NUM < 0x050B0000
  sizeof(PyTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyTypeObject),
  #elif CYTHON_COMPILING_IN_LIMITED_API
  sizeof(PyTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyTypeObject),
  #else
  sizeof(PyHeapTypeObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyHeapTypeObject),
  #endif
  __Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_7cpython_4type_type) __PYX_ERR(6, 9, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("numpy"); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 202, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_5numpy_dtype = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "dtype", sizeof(PyArray_Descr), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyArray_Descr),__Pyx_ImportType_CheckSize_Ignore_3_0_8); if (!__pyx_ptype_5numpy_dtype) __PYX_ERR(3, 202, __pyx_L1_error)
  __pyx_ptype_5numpy_flatiter = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "flatiter", sizeof(PyArrayIterObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyArrayIterObject),__Pyx_ImportType_CheckSize_Ignore_3_0_8); if (!__pyx_ptype_5numpy_flatiter) __PYX_ERR(3, 225, __pyx_L1_error)
  __pyx_ptype_5numpy_broadcast = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "broadcast", sizeof(PyArrayMultiIterObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyArrayMultiIterObject),__Pyx_ImportType_CheckSize_Ignore_3_0_8); if (!__pyx_ptype_5numpy_broadcast) __PYX_ERR(3, 229, __pyx_L1_error)
  __pyx_ptype_5numpy_ndarray = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "ndarray", sizeof(PyArrayObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyArrayObject),__Pyx_ImportType_CheckSize_Ignore_3_0_8); if (!__pyx_ptype_5numpy_ndarray) __PYX_ERR(3, 238, __pyx_L1_error)
  __pyx_ptype_5numpy_generic = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "generic", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_5numpy_generic) __PYX_ERR(3, 809, __pyx_L1_error)
  __pyx_ptype_5numpy_number = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "number", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_5numpy_number) __PYX_ERR(3, 811, __pyx_L1_error)
  __pyx_ptype_5numpy_integer = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "integer", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_5numpy_integer) __PYX_ERR(3, 813, __pyx_L1_error)
  __pyx_ptype_5numpy_signedinteger = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "signedinteger", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_5numpy_signedinteger) __PYX_ERR(3, 815, __pyx_L1_error)
  __pyx_ptype_5numpy_unsignedinteger = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "unsignedinteger", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_5numpy_unsignedinteger) __PYX_ERR(3, 817, __pyx_L1_error)
  __pyx_ptype_5numpy_inexact = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "inexact", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_5numpy_inexact) __PYX_ERR(3, 819, __pyx_L1_error)
  __pyx_ptype_5numpy_floating = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "floating", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_5numpy_floating) __PYX_ERR(3, 821, __pyx_L1_error)
  __pyx_ptype_5numpy_complexfloating = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "complexfloating", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_5numpy_complexfloating) __PYX_ERR(3, 823, __pyx_L1_error)
  __pyx_ptype_5numpy_flexible = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "flexible", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_5numpy_flexible) __PYX_ERR(3, 825, __pyx_L1_error)
  __pyx_ptype_5numpy_character = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "character", sizeof(PyObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyObject),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_5numpy_character) __PYX_ERR(3, 827, __pyx_L1_error)
  __pyx_ptype_5numpy_ufunc = __Pyx_ImportType_3_0_8(__pyx_t_1, "numpy", "ufunc", sizeof(PyUFuncObject), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(PyUFuncObject),__Pyx_ImportType_CheckSize_Ignore_3_0_8); if (!__pyx_ptype_5numpy_ufunc) __PYX_ERR(3, 866, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("pandas._libs.missing"); if (unlikely(!__pyx_t_1)) __PYX_ERR(7, 17, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_6pandas_5_libs_7missing_C_NAType = __Pyx_ImportType_3_0_8(__pyx_t_1, "pandas._libs.missing", "C_NAType", sizeof(struct __pyx_obj_6pandas_5_libs_7missing_C_NAType), __PYX_GET_STRUCT_ALIGNMENT_3_0_8(struct __pyx_obj_6pandas_5_libs_7missing_C_NAType),__Pyx_ImportType_CheckSize_Warn_3_0_8); if (!__pyx_ptype_6pandas_5_libs_7missing_C_NAType) __PYX_ERR(7, 17, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __pyx_t_1 = PyImport_ImportModule("pandas._libs.missing"); if (!__pyx_t_1) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_ImportVoidPtr_3_0_8(__pyx_t_1, "C_NA", (void **)&__pyx_vp_6pandas_5_libs_7missing_C_NA, "struct __pyx_obj_6pandas_5_libs_7missing_C_NAType *") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __pyx_t_1 = PyImport_ImportModule("pandas._libs.missing"); if (!__pyx_t_1) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (__Pyx_ImportFunction_3_0_8(__pyx_t_1, "checknull", (void (**)(void))&__pyx_f_6pandas_5_libs_7missing_checknull, "int (PyObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_6pandas_5_libs_7missing_checknull *__pyx_optional_args)") < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}


#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_hashtable(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
  {Py_mod_create, (void*)__pyx_pymod_create},
  {Py_mod_exec, (void*)__pyx_pymod_exec_hashtable},
  {0, NULL}
};
#endif

#ifdef __cplusplus
namespace {
  struct PyModuleDef __pyx_moduledef =
  #else
  static struct PyModuleDef __pyx_moduledef =
  #endif
  {
      PyModuleDef_HEAD_INIT,
      "hashtable",
      0, /* m_doc */
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      0, /* m_size */
    #elif CYTHON_USE_MODULE_STATE
      sizeof(__pyx_mstate), /* m_size */
    #else
      -1, /* m_size */
    #endif
      __pyx_methods /* m_methods */,
    #if CYTHON_PEP489_MULTI_PHASE_INIT
      __pyx_moduledef_slots, /* m_slots */
    #else
      NULL, /* m_reload */
    #endif
    #if CYTHON_USE_MODULE_STATE
      __pyx_m_traverse, /* m_traverse */
      __pyx_m_clear, /* m_clear */
      NULL /* m_free */
    #else
      NULL, /* m_traverse */
      NULL, /* m_clear */
      NULL /* m_free */
    #endif
  };
  #ifdef __cplusplus
} /* anonymous namespace */
#endif
#endif

#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC inithashtable(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC inithashtable(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_hashtable(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_hashtable(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
#if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *module, const char* from_name, const char* to_name, int allow_none)
#else
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none)
#endif
{
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
#if CYTHON_COMPILING_IN_LIMITED_API
            result = PyModule_AddObject(module, to_name, value);
#else
            result = PyDict_SetItemString(moddict, to_name, value);
#endif
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    CYTHON_UNUSED_VAR(def);
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    moddict = module;
#else
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
#endif
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_hashtable(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  int stringtab_initialized = 0;
  #if CYTHON_USE_MODULE_STATE
  int pystate_addmodule_run = 0;
  #endif
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  static PyThread_type_lock __pyx_t_8[8];
  int __pyx_t_9;
  __pyx_t_5numpy_int64_t __pyx_t_10;
  __Pyx_memviewslice __pyx_t_11 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_12 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_13 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_14 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_15 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_16 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_17 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_18 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_19 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_20 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_21 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_22 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_23 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_24 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_25 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_26 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_27 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_28 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_29 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_30 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_31 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_32 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_33 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_34 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_35 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_36 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_37 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_38 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_39 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_40 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_41 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_42 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_43 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_44 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_45 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_46 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_47 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_48 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_49 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_50 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_51 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_52 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_53 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_54 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_55 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_56 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_57 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_58 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_59 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_60 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_61 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_62 = { 0, 0, { 0 }, { 0 }, { 0 } };
  __Pyx_memviewslice __pyx_t_63 = { 0, 0, { 0 }, { 0 }, { 0 } };
  PyObject *__pyx_t_64 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'hashtable' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("hashtable", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #elif CYTHON_USE_MODULE_STATE
  __pyx_t_1 = PyModule_Create(&__pyx_moduledef); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  {
    int add_module_result = PyState_AddModule(__pyx_t_1, &__pyx_moduledef);
    __pyx_t_1 = 0; /* transfer ownership from __pyx_t_1 to "hashtable" pseudovariable */
    if (unlikely((add_module_result < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    pystate_addmodule_run = 1;
  }
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #endif
  CYTHON_UNUSED_VAR(__pyx_t_1);
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = __Pyx_PyImport_AddModuleRef(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_cython_runtime = __Pyx_PyImport_AddModuleRef((const char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_hashtable(void)", 0);
  if (__Pyx_check_binary_version(__PYX_LIMITED_VERSION_HEX, __Pyx_get_runtime_version(), CYTHON_COMPILING_IN_LIMITED_API) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init(__pyx_m) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(WITH_THREAD) && PY_VERSION_HEX < 0x030700F0 && defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  PyEval_InitThreads();
  #endif
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  stringtab_initialized = 1;
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_pandas___libs__hashtable) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name_2, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "pandas._libs.hashtable")) {
      if (unlikely((PyDict_SetItemString(modules, "pandas._libs.hashtable", __pyx_m) < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  if (unlikely((__Pyx_modinit_type_init_code() < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_type_import_code() < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_variable_import_code() < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely((__Pyx_modinit_function_import_code() < 0))) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "View.MemoryView":99
 * 
 * cdef object __pyx_collections_abc_Sequence "__pyx_collections_abc_Sequence"
 * try:             # <<<<<<<<<<<<<<
 *     if __import__("sys").version_info >= (3, 3):
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "View.MemoryView":100
 * cdef object __pyx_collections_abc_Sequence "__pyx_collections_abc_Sequence"
 * try:
 *     if __import__("sys").version_info >= (3, 3):             # <<<<<<<<<<<<<<
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 *     else:
 */
      __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin___import__, __pyx_tuple__103, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 100, __pyx_L2_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_version_info); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 100, __pyx_L2_error)
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyObject_RichCompare(__pyx_t_5, __pyx_tuple__104, Py_GE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 100, __pyx_L2_error)
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(1, 100, __pyx_L2_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {

        /* "View.MemoryView":101
 * try:
 *     if __import__("sys").version_info >= (3, 3):
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence             # <<<<<<<<<<<<<<
 *     else:
 *         __pyx_collections_abc_Sequence = __import__("collections").Sequence
 */
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin___import__, __pyx_tuple__105, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 101, __pyx_L2_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_abc); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 101, __pyx_L2_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_Sequence); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 101, __pyx_L2_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_XGOTREF(__pyx_collections_abc_Sequence);
        __Pyx_DECREF_SET(__pyx_collections_abc_Sequence, __pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_4);
        __pyx_t_4 = 0;

        /* "View.MemoryView":100
 * cdef object __pyx_collections_abc_Sequence "__pyx_collections_abc_Sequence"
 * try:
 *     if __import__("sys").version_info >= (3, 3):             # <<<<<<<<<<<<<<
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 *     else:
 */
        goto __pyx_L8;
      }

      /* "View.MemoryView":103
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 *     else:
 *         __pyx_collections_abc_Sequence = __import__("collections").Sequence             # <<<<<<<<<<<<<<
 * except:
 * 
 */
      /*else*/ {
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin___import__, __pyx_tuple__106, NULL); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 103, __pyx_L2_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_Sequence); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 103, __pyx_L2_error)
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_XGOTREF(__pyx_collections_abc_Sequence);
        __Pyx_DECREF_SET(__pyx_collections_abc_Sequence, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        __pyx_t_5 = 0;
      }
      __pyx_L8:;

      /* "View.MemoryView":99
 * 
 * cdef object __pyx_collections_abc_Sequence "__pyx_collections_abc_Sequence"
 * try:             # <<<<<<<<<<<<<<
 *     if __import__("sys").version_info >= (3, 3):
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L7_try_end;
    __pyx_L2_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "View.MemoryView":104
 *     else:
 *         __pyx_collections_abc_Sequence = __import__("collections").Sequence
 * except:             # <<<<<<<<<<<<<<
 * 
 *     __pyx_collections_abc_Sequence = None
 */
    /*except:*/ {
      __Pyx_AddTraceback("View.MemoryView", __pyx_clineno, __pyx_lineno, __pyx_filename);
      if (__Pyx_GetException(&__pyx_t_5, &__pyx_t_4, &__pyx_t_7) < 0) __PYX_ERR(1, 104, __pyx_L4_except_error)
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_4);
      __Pyx_XGOTREF(__pyx_t_7);

      /* "View.MemoryView":106
 * except:
 * 
 *     __pyx_collections_abc_Sequence = None             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __Pyx_INCREF(Py_None);
      __Pyx_XGOTREF(__pyx_collections_abc_Sequence);
      __Pyx_DECREF_SET(__pyx_collections_abc_Sequence, Py_None);
      __Pyx_GIVEREF(Py_None);
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L3_exception_handled;
    }

    /* "View.MemoryView":99
 * 
 * cdef object __pyx_collections_abc_Sequence "__pyx_collections_abc_Sequence"
 * try:             # <<<<<<<<<<<<<<
 *     if __import__("sys").version_info >= (3, 3):
 *         __pyx_collections_abc_Sequence = __import__("collections.abc").abc.Sequence
 */
    __pyx_L4_except_error:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    goto __pyx_L1_error;
    __pyx_L3_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L7_try_end:;
  }

  /* "View.MemoryView":241
 * 
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_2, &__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_1);
    /*try:*/ {

      /* "View.MemoryView":242
 * 
 *     try:
 *         count = __pyx_collections_abc_Sequence.count             # <<<<<<<<<<<<<<
 *         index = __pyx_collections_abc_Sequence.index
 *     except:
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_collections_abc_Sequence, __pyx_n_s_count); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 242, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_SetItemOnTypeDict(__pyx_array_type, __pyx_n_s_count, __pyx_t_7) < 0) __PYX_ERR(1, 242, __pyx_L11_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      PyType_Modified(__pyx_array_type);

      /* "View.MemoryView":243
 *     try:
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index             # <<<<<<<<<<<<<<
 *     except:
 *         pass
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_collections_abc_Sequence, __pyx_n_s_index); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 243, __pyx_L11_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_SetItemOnTypeDict(__pyx_array_type, __pyx_n_s_index, __pyx_t_7) < 0) __PYX_ERR(1, 243, __pyx_L11_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      PyType_Modified(__pyx_array_type);

      /* "View.MemoryView":241
 * 
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index
 */
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L16_try_end;
    __pyx_L11_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "View.MemoryView":244
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index
 *     except:             # <<<<<<<<<<<<<<
 *         pass
 * 
 */
    /*except:*/ {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L12_exception_handled;
    }
    __pyx_L12_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    __pyx_L16_try_end:;
  }

  /* "View.MemoryView":309
 *         return self.name
 * 
 * cdef generic = Enum("<strided and direct or indirect>")             # <<<<<<<<<<<<<<
 * cdef strided = Enum("<strided and direct>") # default
 * cdef indirect = Enum("<strided and indirect>")
 */
  __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_MemviewEnum_type), __pyx_tuple__107, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 309, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_XGOTREF(generic);
  __Pyx_DECREF_SET(generic, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;

  /* "View.MemoryView":310
 * 
 * cdef generic = Enum("<strided and direct or indirect>")
 * cdef strided = Enum("<strided and direct>") # default             # <<<<<<<<<<<<<<
 * cdef indirect = Enum("<strided and indirect>")
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_MemviewEnum_type), __pyx_tuple__108, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 310, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_XGOTREF(strided);
  __Pyx_DECREF_SET(strided, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;

  /* "View.MemoryView":311
 * cdef generic = Enum("<strided and direct or indirect>")
 * cdef strided = Enum("<strided and direct>") # default
 * cdef indirect = Enum("<strided and indirect>")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_MemviewEnum_type), __pyx_tuple__109, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 311, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_XGOTREF(indirect);
  __Pyx_DECREF_SET(indirect, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;

  /* "View.MemoryView":314
 * 
 * 
 * cdef contiguous = Enum("<contiguous and direct>")             # <<<<<<<<<<<<<<
 * cdef indirect_contiguous = Enum("<contiguous and indirect>")
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_MemviewEnum_type), __pyx_tuple__110, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_XGOTREF(contiguous);
  __Pyx_DECREF_SET(contiguous, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;

  /* "View.MemoryView":315
 * 
 * cdef contiguous = Enum("<contiguous and direct>")
 * cdef indirect_contiguous = Enum("<contiguous and indirect>")             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_MemviewEnum_type), __pyx_tuple__111, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_XGOTREF(indirect_contiguous);
  __Pyx_DECREF_SET(indirect_contiguous, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;

  /* "View.MemoryView":323
 * 
 * 
 * cdef int __pyx_memoryview_thread_locks_used = 0             # <<<<<<<<<<<<<<
 * cdef PyThread_type_lock[8] __pyx_memoryview_thread_locks = [
 *     PyThread_allocate_lock(),
 */
  __pyx_memoryview_thread_locks_used = 0;

  /* "View.MemoryView":324
 * 
 * cdef int __pyx_memoryview_thread_locks_used = 0
 * cdef PyThread_type_lock[8] __pyx_memoryview_thread_locks = [             # <<<<<<<<<<<<<<
 *     PyThread_allocate_lock(),
 *     PyThread_allocate_lock(),
 */
  __pyx_t_8[0] = PyThread_allocate_lock();
  __pyx_t_8[1] = PyThread_allocate_lock();
  __pyx_t_8[2] = PyThread_allocate_lock();
  __pyx_t_8[3] = PyThread_allocate_lock();
  __pyx_t_8[4] = PyThread_allocate_lock();
  __pyx_t_8[5] = PyThread_allocate_lock();
  __pyx_t_8[6] = PyThread_allocate_lock();
  __pyx_t_8[7] = PyThread_allocate_lock();
  memcpy(&(__pyx_memoryview_thread_locks[0]), __pyx_t_8, sizeof(__pyx_memoryview_thread_locks[0]) * (8));

  /* "View.MemoryView":982
 * 
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_1, &__pyx_t_2, &__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_3);
    /*try:*/ {

      /* "View.MemoryView":983
 * 
 *     try:
 *         count = __pyx_collections_abc_Sequence.count             # <<<<<<<<<<<<<<
 *         index = __pyx_collections_abc_Sequence.index
 *     except:
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_collections_abc_Sequence, __pyx_n_s_count); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 983, __pyx_L17_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_SetItemOnTypeDict(__pyx_memoryviewslice_type, __pyx_n_s_count, __pyx_t_7) < 0) __PYX_ERR(1, 983, __pyx_L17_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      PyType_Modified(__pyx_memoryviewslice_type);

      /* "View.MemoryView":984
 *     try:
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index             # <<<<<<<<<<<<<<
 *     except:
 *         pass
 */
      __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_collections_abc_Sequence, __pyx_n_s_index); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 984, __pyx_L17_error)
      __Pyx_GOTREF(__pyx_t_7);
      if (__Pyx_SetItemOnTypeDict(__pyx_memoryviewslice_type, __pyx_n_s_index, __pyx_t_7) < 0) __PYX_ERR(1, 984, __pyx_L17_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      PyType_Modified(__pyx_memoryviewslice_type);

      /* "View.MemoryView":982
 * 
 * 
 *     try:             # <<<<<<<<<<<<<<
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index
 */
    }
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    goto __pyx_L22_try_end;
    __pyx_L17_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "View.MemoryView":985
 *         count = __pyx_collections_abc_Sequence.count
 *         index = __pyx_collections_abc_Sequence.index
 *     except:             # <<<<<<<<<<<<<<
 *         pass
 * 
 */
    /*except:*/ {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L18_exception_handled;
    }
    __pyx_L18_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_ExceptionReset(__pyx_t_1, __pyx_t_2, __pyx_t_3);
    __pyx_L22_try_end:;
  }

  /* "View.MemoryView":988
 *         pass
 * 
 * try:             # <<<<<<<<<<<<<<
 *     if __pyx_collections_abc_Sequence:
 * 
 */
  {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ExceptionSave(&__pyx_t_3, &__pyx_t_2, &__pyx_t_1);
    __Pyx_XGOTREF(__pyx_t_3);
    __Pyx_XGOTREF(__pyx_t_2);
    __Pyx_XGOTREF(__pyx_t_1);
    /*try:*/ {

      /* "View.MemoryView":989
 * 
 * try:
 *     if __pyx_collections_abc_Sequence:             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_collections_abc_Sequence); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(1, 989, __pyx_L23_error)
      if (__pyx_t_6) {

        /* "View.MemoryView":993
 * 
 * 
 *         __pyx_collections_abc_Sequence.register(_memoryviewslice)             # <<<<<<<<<<<<<<
 *         __pyx_collections_abc_Sequence.register(array)
 * except:
 */
        __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_collections_abc_Sequence, __pyx_n_s_register); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 993, __pyx_L23_error)
        __Pyx_GOTREF(__pyx_t_7);
        __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_7, ((PyObject *)__pyx_memoryviewslice_type)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 993, __pyx_L23_error)
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "View.MemoryView":994
 * 
 *         __pyx_collections_abc_Sequence.register(_memoryviewslice)
 *         __pyx_collections_abc_Sequence.register(array)             # <<<<<<<<<<<<<<
 * except:
 *     pass  # ignore failure, it's a minor issue
 */
        __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_collections_abc_Sequence, __pyx_n_s_register); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 994, __pyx_L23_error)
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_4, ((PyObject *)__pyx_array_type)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 994, __pyx_L23_error)
        __Pyx_GOTREF(__pyx_t_7);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

        /* "View.MemoryView":989
 * 
 * try:
 *     if __pyx_collections_abc_Sequence:             # <<<<<<<<<<<<<<
 * 
 * 
 */
      }

      /* "View.MemoryView":988
 *         pass
 * 
 * try:             # <<<<<<<<<<<<<<
 *     if __pyx_collections_abc_Sequence:
 * 
 */
    }
    __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    goto __pyx_L28_try_end;
    __pyx_L23_error:;
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;

    /* "View.MemoryView":995
 *         __pyx_collections_abc_Sequence.register(_memoryviewslice)
 *         __pyx_collections_abc_Sequence.register(array)
 * except:             # <<<<<<<<<<<<<<
 *     pass  # ignore failure, it's a minor issue
 * 
 */
    /*except:*/ {
      __Pyx_ErrRestore(0,0,0);
      goto __pyx_L24_exception_handled;
    }
    __pyx_L24_exception_handled:;
    __Pyx_XGIVEREF(__pyx_t_3);
    __Pyx_XGIVEREF(__pyx_t_2);
    __Pyx_XGIVEREF(__pyx_t_1);
    __Pyx_ExceptionReset(__pyx_t_3, __pyx_t_2, __pyx_t_1);
    __pyx_L28_try_end:;
  }

  /* "(tree fragment)":1
 * def __pyx_unpickle_Enum(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_7 = PyCFunction_NewEx(&__pyx_mdef_15View_dot_MemoryView_1__pyx_unpickle_Enum, NULL, __pyx_n_s_View_MemoryView); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_Enum, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable.pyx":15
 * )
 * 
 * import numpy as np             # <<<<<<<<<<<<<<
 * 
 * cimport numpy as cnp
 */
  __pyx_t_7 = __Pyx_ImportDottedModule(__pyx_n_s_numpy, NULL); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_np, __pyx_t_7) < 0) __PYX_ERR(0, 15, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable.pyx":20
 * from numpy cimport ndarray
 * 
 * cnp.import_array()             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_9 = __pyx_f_5numpy_import_array(); if (unlikely(__pyx_t_9 == ((int)-1))) __PYX_ERR(0, 20, __pyx_L1_error)

  /* "pandas/_libs/hashtable.pyx":39
 * 
 * 
 * def get_hashtable_trace_domain():             # <<<<<<<<<<<<<<
 *     return KHASH_TRACE_DOMAIN
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_1get_hashtable_trace_domain, 0, __pyx_n_s_get_hashtable_trace_domain, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__114)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_get_hashtable_trace_domain, __pyx_t_7) < 0) __PYX_ERR(0, 39, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable.pyx":43
 * 
 * 
 * def object_hash(obj):             # <<<<<<<<<<<<<<
 *     return kh_python_hash_func(obj)
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_3object_hash, 0, __pyx_n_s_object_hash, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__116)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_object_hash, __pyx_t_7) < 0) __PYX_ERR(0, 43, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable.pyx":47
 * 
 * 
 * def objects_are_equal(a, b):             # <<<<<<<<<<<<<<
 *     return kh_python_hash_equal(a, b)
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_5objects_are_equal, 0, __pyx_n_s_objects_are_equal, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__118)); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_objects_are_equal, __pyx_t_7) < 0) __PYX_ERR(0, 47, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable.pyx":51
 * 
 * 
 * cdef int64_t NPY_NAT = util.get_nat()             # <<<<<<<<<<<<<<
 * SIZE_HINT_LIMIT = (1 << 20) + 7
 * 
 */
  __pyx_t_10 = __pyx_f_6pandas_5_libs_6tslibs_4util_get_nat(); if (unlikely(__pyx_t_10 == ((__pyx_t_5numpy_int64_t)-1) && PyErr_Occurred())) __PYX_ERR(0, 51, __pyx_L1_error)
  __pyx_v_6pandas_5_libs_9hashtable_NPY_NAT = __pyx_t_10;

  /* "pandas/_libs/hashtable.pyx":52
 * 
 * cdef int64_t NPY_NAT = util.get_nat()
 * SIZE_HINT_LIMIT = (1 << 20) + 7             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_SIZE_HINT_LIMIT, __pyx_int_1048583) < 0) __PYX_ERR(0, 52, __pyx_L1_error)

  /* "pandas/_libs/hashtable.pyx":55
 * 
 * 
 * cdef Py_ssize_t _INIT_VEC_CAP = 128             # <<<<<<<<<<<<<<
 * 
 * include "hashtable_class_helper.pxi"
 */
  __pyx_v_6pandas_5_libs_9hashtable__INIT_VEC_CAP = 0x80;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_6Vector_3__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Vector___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__120)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_6Vector_5__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Vector___setstate_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__122)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":452
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Complex128Vector_7to_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex128Vector_to_array, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__123)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 452, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector, __pyx_n_s_to_array, __pyx_t_7) < 0) __PYX_ERR(2, 452, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Vector);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Complex128Vector_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex128Vector___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__124)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Complex128Vector_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex128Vector___setstate_cyth, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__125)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":507
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15Complex64Vector_7to_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex64Vector_to_array, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__126)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 507, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector, __pyx_n_s_to_array, __pyx_t_7) < 0) __PYX_ERR(2, 507, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Vector);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15Complex64Vector_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex64Vector___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__127)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15Complex64Vector_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex64Vector___setstate_cytho, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__128)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":562
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_13Float64Vector_7to_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float64Vector_to_array, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__129)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 562, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector, __pyx_n_s_to_array, __pyx_t_7) < 0) __PYX_ERR(2, 562, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float64Vector);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_13Float64Vector_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float64Vector___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__130)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_13Float64Vector_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float64Vector___setstate_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__131)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":617
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_12UInt64Vector_7to_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt64Vector_to_array, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__132)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector, __pyx_n_s_to_array, __pyx_t_7) < 0) __PYX_ERR(2, 617, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Vector);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_12UInt64Vector_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt64Vector___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__133)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_12UInt64Vector_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt64Vector___setstate_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__134)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":669
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_11Int64Vector_7to_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int64Vector_to_array, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__135)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 669, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector, __pyx_n_s_to_array, __pyx_t_7) < 0) __PYX_ERR(2, 669, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int64Vector);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_11Int64Vector_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int64Vector___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__136)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_11Int64Vector_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int64Vector___setstate_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__137)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":724
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_13Float32Vector_7to_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float32Vector_to_array, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__138)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector, __pyx_n_s_to_array, __pyx_t_7) < 0) __PYX_ERR(2, 724, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float32Vector);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_13Float32Vector_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float32Vector___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__139)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_13Float32Vector_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float32Vector___setstate_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__140)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":779
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_12UInt32Vector_7to_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt32Vector_to_array, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__141)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 779, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector, __pyx_n_s_to_array, __pyx_t_7) < 0) __PYX_ERR(2, 779, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Vector);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_12UInt32Vector_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt32Vector___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__142)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_12UInt32Vector_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt32Vector___setstate_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__143)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":834
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_11Int32Vector_7to_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int32Vector_to_array, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__144)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 834, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector, __pyx_n_s_to_array, __pyx_t_7) < 0) __PYX_ERR(2, 834, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int32Vector);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_11Int32Vector_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int32Vector___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__145)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_11Int32Vector_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int32Vector___setstate_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__146)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":889
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_12UInt16Vector_7to_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt16Vector_to_array, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__147)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 889, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector, __pyx_n_s_to_array, __pyx_t_7) < 0) __PYX_ERR(2, 889, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Vector);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_12UInt16Vector_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt16Vector___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__148)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_12UInt16Vector_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt16Vector___setstate_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__149)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":944
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_11Int16Vector_7to_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int16Vector_to_array, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__150)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector, __pyx_n_s_to_array, __pyx_t_7) < 0) __PYX_ERR(2, 944, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int16Vector);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_11Int16Vector_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int16Vector___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__151)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_11Int16Vector_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int16Vector___setstate_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__152)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":999
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_11UInt8Vector_7to_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt8Vector_to_array, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__153)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 999, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector, __pyx_n_s_to_array, __pyx_t_7) < 0) __PYX_ERR(2, 999, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Vector);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_11UInt8Vector_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt8Vector___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__154)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_11UInt8Vector_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt8Vector___setstate_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__155)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1054
 *         return self.data.n
 * 
 *     cpdef ndarray to_array(self):             # <<<<<<<<<<<<<<
 *         if self.data.m != self.data.n:
 *             if self.external_view_exists:
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_10Int8Vector_7to_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int8Vector_to_array, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__156)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1054, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector, __pyx_n_s_to_array, __pyx_t_7) < 0) __PYX_ERR(2, 1054, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int8Vector);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_10Int8Vector_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int8Vector___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__157)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_10Int8Vector_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int8Vector___setstate_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__158)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1118
 *         return self.data.n
 * 
 *     cpdef ndarray[object, ndim=1] to_array(self):             # <<<<<<<<<<<<<<
 *         cdef:
 *             ndarray ao
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_12StringVector_7to_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_StringVector_to_array, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__159)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_StringVector, __pyx_n_s_to_array, __pyx_t_7) < 0) __PYX_ERR(2, 1118, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_StringVector);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_12StringVector_9__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_StringVector___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__160)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_12StringVector_11__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_StringVector___setstate_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__161)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1173
 *         self.n += 1
 * 
 *     cpdef ndarray[object, ndim=1] to_array(self):             # <<<<<<<<<<<<<<
 *         if self.m != self.n:
 *             if self.external_view_exists:
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_12ObjectVector_5to_array, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_ObjectVector_to_array, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__162)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1173, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector, __pyx_n_s_to_array, __pyx_t_7) < 0) __PYX_ERR(2, 1173, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_ObjectVector);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_12ObjectVector_7__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_ObjectVector___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__163)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_12ObjectVector_9__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_ObjectVector___setstate_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__164)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_9HashTable_1__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_HashTable___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__166)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_HashTable, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_HashTable);

  /* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_HashTable, (type(self), 0xe3b0c44, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_HashTable__set_state(self, __pyx_state)
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_9HashTable_3__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_HashTable___setstate_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__167)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 16, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_HashTable, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 16, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":1227
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_deep, __pyx_n_s_bool) < 0) __PYX_ERR(2, 1227, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_n_s_int) < 0) __PYX_ERR(2, 1227, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_9sizeof, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex128HashTable_sizeof, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__169)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1227, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__170);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable, __pyx_n_s_sizeof, __pyx_t_4) < 0) __PYX_ERR(2, 1227, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":1235
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_kp_s_dict_str_int) < 0) __PYX_ERR(2, 1235, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_11get_state, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex128HashTable_get_state, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__171)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1235, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable, __pyx_n_s_get_state, __pyx_t_7) < 0) __PYX_ERR(2, 1235, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":1244
 *         }
 * 
 *     cpdef get_item(self, complex128_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_13get_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex128HashTable_get_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__173)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1244, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable, __pyx_n_s_get_item, __pyx_t_7) < 0) __PYX_ERR(2, 1244, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":1270
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_15get_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex128HashTable_get_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__174)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1270, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable, __pyx_n_s_get_na, __pyx_t_7) < 0) __PYX_ERR(2, 1270, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":1285
 *         return self.na_position
 * 
 *     cpdef set_item(self, complex128_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_17set_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex128HashTable_set_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__176)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1285, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable, __pyx_n_s_set_item, __pyx_t_7) < 0) __PYX_ERR(2, 1285, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":1300
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_19set_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex128HashTable_set_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__177)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable, __pyx_n_s_set_na, __pyx_t_7) < 0) __PYX_ERR(2, 1300, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":1314
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const complex128_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_11 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_11.memview)) __PYX_ERR(2, 1314, __pyx_L1_error)
  __pyx_k__14 = __pyx_t_11;
  __pyx_t_11.memview = NULL;
  __pyx_t_11.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":1313
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const complex128_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_11 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_11.memview)) __PYX_ERR(2, 1314, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1314
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const complex128_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_7 = __pyx_memoryview_fromslice(__pyx_t_11, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_11, 1);
  __pyx_t_11.memview = NULL; __pyx_t_11.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":1313
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const complex128_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_7)) __PYX_ERR(2, 1313, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_n_s_None) < 0) __PYX_ERR(2, 1313, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_21map_locations, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex128HashTable_map_location, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__179)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1313, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable, __pyx_n_s_map_locations, __pyx_t_5) < 0) __PYX_ERR(2, 1313, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":1343
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const complex128_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_12.memview)) __PYX_ERR(2, 1343, __pyx_L1_error)
  __pyx_k__15 = __pyx_t_12;
  __pyx_t_12.memview = NULL;
  __pyx_t_12.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":1342
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const complex128_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_12 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_12.memview)) __PYX_ERR(2, 1343, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1343
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const complex128_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_12, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1343, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_12, 1);
  __pyx_t_12.memview = NULL; __pyx_t_12.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":1342
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const complex128_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5)) __PYX_ERR(2, 1342, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_ndarray) < 0) __PYX_ERR(2, 1342, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_23lookup, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex128HashTable_lookup, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__181)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1342, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_t_7);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable, __pyx_n_s_lookup, __pyx_t_4) < 0) __PYX_ERR(2, 1342, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":1371
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const complex128_t[:] values, Complex128Vector uniques,
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_25_unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex128HashTable__unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__183)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1371, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__184);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable, __pyx_n_s_unique, __pyx_t_4) < 0) __PYX_ERR(2, 1371, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":1536
 *         return uniques.to_array()
 * 
 *     def unique(self, const complex128_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_27unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex128HashTable_unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__186)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1536, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__187);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable, __pyx_n_s_unique_2, __pyx_t_4) < 0) __PYX_ERR(2, 1536, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":1565
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const complex128_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_29factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex128HashTable_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__189)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1565, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__190);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable, __pyx_n_s_factorize, __pyx_t_4) < 0) __PYX_ERR(2, 1565, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":1601
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const complex128_t[:] values, Complex128Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_31get_labels, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex128HashTable_get_labels, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__193)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1601, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__194);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable, __pyx_n_s_get_labels, __pyx_t_4) < 0) __PYX_ERR(2, 1601, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex128HashTable);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_33__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex128HashTable___reduce_cyt, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__195)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_4) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_19Complex128HashTable_35__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex128HashTable___setstate_c, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__196)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_4) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1621
 *         self.uniques = Complex128Vector()
 * 
 *     def factorize(self, const khcomplex128_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_kp_s_np_ndarray) < 0) __PYX_ERR(2, 1621, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_20Complex128Factorizer_3factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex128Factorizer_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__198)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__199);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Factorizer, __pyx_n_s_factorize, __pyx_t_5) < 0) __PYX_ERR(2, 1621, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex128Factorizer);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_20Complex128Factorizer_5__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex128Factorizer___reduce_cy, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__200)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_5) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_20Complex128Factorizer_7__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex128Factorizer___setstate, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__201)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_5) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":1681
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_deep, __pyx_n_s_bool) < 0) __PYX_ERR(2, 1681, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_int) < 0) __PYX_ERR(2, 1681, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_9sizeof, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float64HashTable_sizeof, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__202)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1681, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__170);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable, __pyx_n_s_sizeof, __pyx_t_4) < 0) __PYX_ERR(2, 1681, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":1689
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_kp_s_dict_str_int) < 0) __PYX_ERR(2, 1689, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_11get_state, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float64HashTable_get_state, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__203)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1689, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable, __pyx_n_s_get_state, __pyx_t_5) < 0) __PYX_ERR(2, 1689, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":1698
 *         }
 * 
 *     cpdef get_item(self, float64_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_13get_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float64HashTable_get_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__204)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1698, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable, __pyx_n_s_get_item, __pyx_t_5) < 0) __PYX_ERR(2, 1698, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":1724
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_15get_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float64HashTable_get_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__205)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1724, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable, __pyx_n_s_get_na, __pyx_t_5) < 0) __PYX_ERR(2, 1724, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":1739
 *         return self.na_position
 * 
 *     cpdef set_item(self, float64_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_17set_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float64HashTable_set_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__206)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1739, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable, __pyx_n_s_set_item, __pyx_t_5) < 0) __PYX_ERR(2, 1739, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":1754
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_19set_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float64HashTable_set_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__207)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1754, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable, __pyx_n_s_set_na, __pyx_t_5) < 0) __PYX_ERR(2, 1754, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":1768
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const float64_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(2, 1768, __pyx_L1_error)
  __pyx_k__18 = __pyx_t_13;
  __pyx_t_13.memview = NULL;
  __pyx_t_13.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":1767
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const float64_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_13 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_13.memview)) __PYX_ERR(2, 1768, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1768
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const float64_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_13, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1768, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_13, 1);
  __pyx_t_13.memview = NULL; __pyx_t_13.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":1767
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const float64_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5)) __PYX_ERR(2, 1767, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_None) < 0) __PYX_ERR(2, 1767, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_21map_locations, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float64HashTable_map_locations, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__208)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1767, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable, __pyx_n_s_map_locations, __pyx_t_7) < 0) __PYX_ERR(2, 1767, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":1797
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const float64_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_14 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_14.memview)) __PYX_ERR(2, 1797, __pyx_L1_error)
  __pyx_k__19 = __pyx_t_14;
  __pyx_t_14.memview = NULL;
  __pyx_t_14.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":1796
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const float64_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_14 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_14.memview)) __PYX_ERR(2, 1797, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":1797
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const float64_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_7 = __pyx_memoryview_fromslice(__pyx_t_14, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1797, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_14, 1);
  __pyx_t_14.memview = NULL; __pyx_t_14.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":1796
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const float64_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 1796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7)) __PYX_ERR(2, 1796, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 1796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_n_s_ndarray) < 0) __PYX_ERR(2, 1796, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_23lookup, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float64HashTable_lookup, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__209)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1796, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable, __pyx_n_s_lookup, __pyx_t_4) < 0) __PYX_ERR(2, 1796, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":1825
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const float64_t[:] values, Float64Vector uniques,
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_25_unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float64HashTable__unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__210)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1825, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__184);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable, __pyx_n_s_unique, __pyx_t_4) < 0) __PYX_ERR(2, 1825, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":1990
 *         return uniques.to_array()
 * 
 *     def unique(self, const float64_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_27unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float64HashTable_unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__211)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 1990, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__187);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable, __pyx_n_s_unique_2, __pyx_t_4) < 0) __PYX_ERR(2, 1990, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2019
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const float64_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_29factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float64HashTable_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__212)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2019, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__190);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable, __pyx_n_s_factorize, __pyx_t_4) < 0) __PYX_ERR(2, 2019, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2055
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const float64_t[:] values, Float64Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_31get_labels, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float64HashTable_get_labels, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__213)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2055, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__194);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable, __pyx_n_s_get_labels, __pyx_t_4) < 0) __PYX_ERR(2, 2055, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float64HashTable);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_33__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float64HashTable___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__214)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_4) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float64HashTable_35__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float64HashTable___setstate_cyth, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__215)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_4) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2075
 *         self.uniques = Float64Vector()
 * 
 *     def factorize(self, const float64_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2075, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_kp_s_np_ndarray) < 0) __PYX_ERR(2, 2075, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_17Float64Factorizer_3factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float64Factorizer_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__216)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2075, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__199);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float64Factorizer, __pyx_n_s_factorize, __pyx_t_7) < 0) __PYX_ERR(2, 2075, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float64Factorizer);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_17Float64Factorizer_5__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float64Factorizer___reduce_cytho, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__217)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_17Float64Factorizer_7__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float64Factorizer___setstate_cyt, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__218)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2135
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_deep, __pyx_n_s_bool) < 0) __PYX_ERR(2, 2135, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_n_s_int) < 0) __PYX_ERR(2, 2135, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_9sizeof, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt64HashTable_sizeof, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__219)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2135, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__170);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable, __pyx_n_s_sizeof, __pyx_t_4) < 0) __PYX_ERR(2, 2135, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2143
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_kp_s_dict_str_int) < 0) __PYX_ERR(2, 2143, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_11get_state, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt64HashTable_get_state, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__220)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2143, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable, __pyx_n_s_get_state, __pyx_t_7) < 0) __PYX_ERR(2, 2143, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2152
 *         }
 * 
 *     cpdef get_item(self, uint64_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_13get_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt64HashTable_get_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__221)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2152, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable, __pyx_n_s_get_item, __pyx_t_7) < 0) __PYX_ERR(2, 2152, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2178
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_15get_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt64HashTable_get_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__222)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable, __pyx_n_s_get_na, __pyx_t_7) < 0) __PYX_ERR(2, 2178, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2193
 *         return self.na_position
 * 
 *     cpdef set_item(self, uint64_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_17set_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt64HashTable_set_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__223)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2193, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable, __pyx_n_s_set_item, __pyx_t_7) < 0) __PYX_ERR(2, 2193, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2208
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_19set_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt64HashTable_set_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__224)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2208, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable, __pyx_n_s_set_na, __pyx_t_7) < 0) __PYX_ERR(2, 2208, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2222
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const uint64_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_15 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_15.memview)) __PYX_ERR(2, 2222, __pyx_L1_error)
  __pyx_k__20 = __pyx_t_15;
  __pyx_t_15.memview = NULL;
  __pyx_t_15.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":2221
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const uint64_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_15 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_15.memview)) __PYX_ERR(2, 2222, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2222
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const uint64_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_7 = __pyx_memoryview_fromslice(__pyx_t_15, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_15, 1);
  __pyx_t_15.memview = NULL; __pyx_t_15.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":2221
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const uint64_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_7)) __PYX_ERR(2, 2221, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_n_s_None) < 0) __PYX_ERR(2, 2221, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_21map_locations, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt64HashTable_map_locations, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__225)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable, __pyx_n_s_map_locations, __pyx_t_5) < 0) __PYX_ERR(2, 2221, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2251
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const uint64_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_16 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_16.memview)) __PYX_ERR(2, 2251, __pyx_L1_error)
  __pyx_k__21 = __pyx_t_16;
  __pyx_t_16.memview = NULL;
  __pyx_t_16.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":2250
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const uint64_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_16 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_16.memview)) __PYX_ERR(2, 2251, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2251
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const uint64_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_16, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2251, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_16, 1);
  __pyx_t_16.memview = NULL; __pyx_t_16.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":2250
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const uint64_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5)) __PYX_ERR(2, 2250, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_ndarray) < 0) __PYX_ERR(2, 2250, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_23lookup, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt64HashTable_lookup, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__226)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_t_7);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable, __pyx_n_s_lookup, __pyx_t_4) < 0) __PYX_ERR(2, 2250, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2279
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const uint64_t[:] values, UInt64Vector uniques,
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_25_unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt64HashTable__unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__227)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2279, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__184);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable, __pyx_n_s_unique, __pyx_t_4) < 0) __PYX_ERR(2, 2279, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2444
 *         return uniques.to_array()
 * 
 *     def unique(self, const uint64_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_27unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt64HashTable_unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__228)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2444, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__187);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable, __pyx_n_s_unique_2, __pyx_t_4) < 0) __PYX_ERR(2, 2444, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2473
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const uint64_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_29factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt64HashTable_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__229)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2473, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__190);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable, __pyx_n_s_factorize, __pyx_t_4) < 0) __PYX_ERR(2, 2473, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2509
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const uint64_t[:] values, UInt64Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_31get_labels, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt64HashTable_get_labels, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__230)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2509, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__194);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable, __pyx_n_s_get_labels, __pyx_t_4) < 0) __PYX_ERR(2, 2509, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt64HashTable);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_33__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt64HashTable___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__231)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_4) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt64HashTable_35__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt64HashTable___setstate_cytho, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__232)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_4) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2529
 *         self.uniques = UInt64Vector()
 * 
 *     def factorize(self, const uint64_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_kp_s_np_ndarray) < 0) __PYX_ERR(2, 2529, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16UInt64Factorizer_3factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt64Factorizer_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__233)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2529, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__199);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Factorizer, __pyx_n_s_factorize, __pyx_t_5) < 0) __PYX_ERR(2, 2529, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt64Factorizer);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16UInt64Factorizer_5__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt64Factorizer___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__234)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_5) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16UInt64Factorizer_7__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt64Factorizer___setstate_cyth, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__235)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_5) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":2589
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_deep, __pyx_n_s_bool) < 0) __PYX_ERR(2, 2589, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_int) < 0) __PYX_ERR(2, 2589, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_9sizeof, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int64HashTable_sizeof, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__236)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2589, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__170);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable, __pyx_n_s_sizeof, __pyx_t_4) < 0) __PYX_ERR(2, 2589, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2597
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_kp_s_dict_str_int) < 0) __PYX_ERR(2, 2597, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_11get_state, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int64HashTable_get_state, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__237)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2597, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable, __pyx_n_s_get_state, __pyx_t_5) < 0) __PYX_ERR(2, 2597, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2606
 *         }
 * 
 *     cpdef get_item(self, int64_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_13get_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int64HashTable_get_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__238)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2606, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable, __pyx_n_s_get_item, __pyx_t_5) < 0) __PYX_ERR(2, 2606, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2632
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_15get_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int64HashTable_get_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__239)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable, __pyx_n_s_get_na, __pyx_t_5) < 0) __PYX_ERR(2, 2632, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2647
 *         return self.na_position
 * 
 *     cpdef set_item(self, int64_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_17set_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int64HashTable_set_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__240)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2647, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable, __pyx_n_s_set_item, __pyx_t_5) < 0) __PYX_ERR(2, 2647, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2662
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_19set_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int64HashTable_set_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__241)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2662, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable, __pyx_n_s_set_na, __pyx_t_5) < 0) __PYX_ERR(2, 2662, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2676
 *     # We only use this for int64, can reduce build size and make .pyi
 *     #  more accurate by only implementing it for int64
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_keys_to_values(
 *         self, const int64_t[:] keys, const int64_t[:] values
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_None) < 0) __PYX_ERR(2, 2676, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_21map_keys_to_values, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int64HashTable_map_keys_to_value, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__243)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2676, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable, __pyx_n_s_map_keys_to_values, __pyx_t_4) < 0) __PYX_ERR(2, 2676, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2693
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const int64_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_17 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_17.memview)) __PYX_ERR(2, 2693, __pyx_L1_error)
  __pyx_k__22 = __pyx_t_17;
  __pyx_t_17.memview = NULL;
  __pyx_t_17.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":2692
 *                 self.table.vals[k] = <Py_ssize_t>values[i]
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const int64_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_17 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_17.memview)) __PYX_ERR(2, 2693, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2693
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const int64_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_t_17, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2693, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_17, 1);
  __pyx_t_17.memview = NULL; __pyx_t_17.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":2692
 *                 self.table.vals[k] = <Py_ssize_t>values[i]
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const int64_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4)) __PYX_ERR(2, 2692, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_n_s_None) < 0) __PYX_ERR(2, 2692, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_23map_locations, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int64HashTable_map_locations, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__244)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2692, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable, __pyx_n_s_map_locations, __pyx_t_7) < 0) __PYX_ERR(2, 2692, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2722
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const int64_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_18 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_18.memview)) __PYX_ERR(2, 2722, __pyx_L1_error)
  __pyx_k__23 = __pyx_t_18;
  __pyx_t_18.memview = NULL;
  __pyx_t_18.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":2721
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const int64_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_18 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_18.memview)) __PYX_ERR(2, 2722, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":2722
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const int64_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_7 = __pyx_memoryview_fromslice(__pyx_t_18, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2722, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_18, 1);
  __pyx_t_18.memview = NULL; __pyx_t_18.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":2721
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const int64_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 2721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_7)) __PYX_ERR(2, 2721, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_n_s_ndarray) < 0) __PYX_ERR(2, 2721, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_25lookup, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int64HashTable_lookup, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__245)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable, __pyx_n_s_lookup, __pyx_t_5) < 0) __PYX_ERR(2, 2721, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2750
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const int64_t[:] values, Int64Vector uniques,
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_27_unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int64HashTable__unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__246)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2750, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__184);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable, __pyx_n_s_unique, __pyx_t_5) < 0) __PYX_ERR(2, 2750, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2915
 *         return uniques.to_array()
 * 
 *     def unique(self, const int64_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_29unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int64HashTable_unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__247)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2915, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__187);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable, __pyx_n_s_unique_2, __pyx_t_5) < 0) __PYX_ERR(2, 2915, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2944
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const int64_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_31factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int64HashTable_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__248)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__190);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable, __pyx_n_s_factorize, __pyx_t_5) < 0) __PYX_ERR(2, 2944, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2980
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const int64_t[:] values, Int64Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_33get_labels, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int64HashTable_get_labels, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__249)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2980, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__194);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable, __pyx_n_s_get_labels, __pyx_t_5) < 0) __PYX_ERR(2, 2980, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":2989
 *         return labels
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def get_labels_groupby(
 *         self, const int64_t[:] values
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 2989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_kp_s_tuple_ndarray_ndarray) < 0) __PYX_ERR(2, 2989, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_35get_labels_groupby, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int64HashTable_get_labels_groupb, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__251)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 2989, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable, __pyx_n_s_get_labels_groupby, __pyx_t_7) < 0) __PYX_ERR(2, 2989, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_37__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int64HashTable___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__252)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int64HashTable_39__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int64HashTable___setstate_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__253)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3045
 *         self.uniques = Int64Vector()
 * 
 *     def factorize(self, const int64_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 3045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_kp_s_np_ndarray) < 0) __PYX_ERR(2, 3045, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15Int64Factorizer_3factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int64Factorizer_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__254)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3045, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__199);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64Factorizer, __pyx_n_s_factorize, __pyx_t_5) < 0) __PYX_ERR(2, 3045, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int64Factorizer);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15Int64Factorizer_5__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int64Factorizer___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__255)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_5) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15Int64Factorizer_7__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int64Factorizer___setstate_cytho, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__256)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_5) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3105
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_deep, __pyx_n_s_bool) < 0) __PYX_ERR(2, 3105, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_int) < 0) __PYX_ERR(2, 3105, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_9sizeof, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex64HashTable_sizeof, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__257)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 3105, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__170);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable, __pyx_n_s_sizeof, __pyx_t_7) < 0) __PYX_ERR(2, 3105, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":3113
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 3113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_kp_s_dict_str_int) < 0) __PYX_ERR(2, 3113, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_11get_state, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex64HashTable_get_state, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__258)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3113, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable, __pyx_n_s_get_state, __pyx_t_5) < 0) __PYX_ERR(2, 3113, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":3122
 *         }
 * 
 *     cpdef get_item(self, complex64_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_13get_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex64HashTable_get_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__259)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3122, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable, __pyx_n_s_get_item, __pyx_t_5) < 0) __PYX_ERR(2, 3122, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":3148
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_15get_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex64HashTable_get_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__260)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable, __pyx_n_s_get_na, __pyx_t_5) < 0) __PYX_ERR(2, 3148, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":3163
 *         return self.na_position
 * 
 *     cpdef set_item(self, complex64_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_17set_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex64HashTable_set_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__261)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3163, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable, __pyx_n_s_set_item, __pyx_t_5) < 0) __PYX_ERR(2, 3163, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":3178
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_19set_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex64HashTable_set_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__262)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3178, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable, __pyx_n_s_set_na, __pyx_t_5) < 0) __PYX_ERR(2, 3178, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":3192
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const complex64_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_19 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_19.memview)) __PYX_ERR(2, 3192, __pyx_L1_error)
  __pyx_k__24 = __pyx_t_19;
  __pyx_t_19.memview = NULL;
  __pyx_t_19.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":3191
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const complex64_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_19 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_19.memview)) __PYX_ERR(2, 3192, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3192
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const complex64_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_19, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_19, 1);
  __pyx_t_19.memview = NULL; __pyx_t_19.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":3191
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const complex64_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 3191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5)) __PYX_ERR(2, 3191, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_None) < 0) __PYX_ERR(2, 3191, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_21map_locations, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex64HashTable_map_locations, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__263)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_t_7);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable, __pyx_n_s_map_locations, __pyx_t_4) < 0) __PYX_ERR(2, 3191, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":3221
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const complex64_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_20 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_20.memview)) __PYX_ERR(2, 3221, __pyx_L1_error)
  __pyx_k__25 = __pyx_t_20;
  __pyx_t_20.memview = NULL;
  __pyx_t_20.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":3220
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const complex64_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_20 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_20.memview)) __PYX_ERR(2, 3221, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3221
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const complex64_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_t_20, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_20, 1);
  __pyx_t_20.memview = NULL; __pyx_t_20.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":3220
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const complex64_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4)) __PYX_ERR(2, 3220, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_n_s_ndarray) < 0) __PYX_ERR(2, 3220, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_23lookup, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex64HashTable_lookup, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__264)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 3220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable, __pyx_n_s_lookup, __pyx_t_7) < 0) __PYX_ERR(2, 3220, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":3249
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const complex64_t[:] values, Complex64Vector uniques,
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_25_unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex64HashTable__unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__265)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 3249, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__184);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable, __pyx_n_s_unique, __pyx_t_7) < 0) __PYX_ERR(2, 3249, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":3414
 *         return uniques.to_array()
 * 
 *     def unique(self, const complex64_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_27unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex64HashTable_unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__266)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 3414, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__187);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable, __pyx_n_s_unique_2, __pyx_t_7) < 0) __PYX_ERR(2, 3414, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":3443
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const complex64_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_29factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex64HashTable_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__267)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 3443, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__190);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable, __pyx_n_s_factorize, __pyx_t_7) < 0) __PYX_ERR(2, 3443, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":3479
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const complex64_t[:] values, Complex64Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_31get_labels, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex64HashTable_get_labels, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__268)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 3479, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__194);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable, __pyx_n_s_get_labels, __pyx_t_7) < 0) __PYX_ERR(2, 3479, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex64HashTable);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_33__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex64HashTable___reduce_cyth, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__269)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_18Complex64HashTable_35__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex64HashTable___setstate_cy, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__270)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3499
 *         self.uniques = Complex64Vector()
 * 
 *     def factorize(self, const khcomplex64_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 3499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_kp_s_np_ndarray) < 0) __PYX_ERR(2, 3499, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_19Complex64Factorizer_3factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex64Factorizer_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__271)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3499, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__199);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Factorizer, __pyx_n_s_factorize, __pyx_t_4) < 0) __PYX_ERR(2, 3499, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Complex64Factorizer);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_19Complex64Factorizer_5__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex64Factorizer___reduce_cyt, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__272)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_4) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_19Complex64Factorizer_7__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Complex64Factorizer___setstate_c, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__273)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_4) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3559
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_deep, __pyx_n_s_bool) < 0) __PYX_ERR(2, 3559, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_n_s_int) < 0) __PYX_ERR(2, 3559, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_9sizeof, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float32HashTable_sizeof, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__274)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 3559, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__170);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable, __pyx_n_s_sizeof, __pyx_t_7) < 0) __PYX_ERR(2, 3559, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":3567
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 3567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_kp_s_dict_str_int) < 0) __PYX_ERR(2, 3567, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_11get_state, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float32HashTable_get_state, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__275)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3567, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable, __pyx_n_s_get_state, __pyx_t_4) < 0) __PYX_ERR(2, 3567, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":3576
 *         }
 * 
 *     cpdef get_item(self, float32_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_13get_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float32HashTable_get_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__276)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3576, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable, __pyx_n_s_get_item, __pyx_t_4) < 0) __PYX_ERR(2, 3576, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":3602
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_15get_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float32HashTable_get_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__277)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3602, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable, __pyx_n_s_get_na, __pyx_t_4) < 0) __PYX_ERR(2, 3602, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":3617
 *         return self.na_position
 * 
 *     cpdef set_item(self, float32_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_17set_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float32HashTable_set_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__278)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3617, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable, __pyx_n_s_set_item, __pyx_t_4) < 0) __PYX_ERR(2, 3617, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":3632
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_19set_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float32HashTable_set_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__279)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3632, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable, __pyx_n_s_set_na, __pyx_t_4) < 0) __PYX_ERR(2, 3632, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":3646
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const float32_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_21 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_21.memview)) __PYX_ERR(2, 3646, __pyx_L1_error)
  __pyx_k__26 = __pyx_t_21;
  __pyx_t_21.memview = NULL;
  __pyx_t_21.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":3645
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const float32_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_21 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_21.memview)) __PYX_ERR(2, 3646, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3646
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const float32_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_t_21, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3646, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_21, 1);
  __pyx_t_21.memview = NULL; __pyx_t_21.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":3645
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const float32_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 3645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_4)) __PYX_ERR(2, 3645, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_n_s_None) < 0) __PYX_ERR(2, 3645, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_21map_locations, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float32HashTable_map_locations, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__280)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3645, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_7);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable, __pyx_n_s_map_locations, __pyx_t_5) < 0) __PYX_ERR(2, 3645, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":3675
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const float32_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_22 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_22.memview)) __PYX_ERR(2, 3675, __pyx_L1_error)
  __pyx_k__27 = __pyx_t_22;
  __pyx_t_22.memview = NULL;
  __pyx_t_22.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":3674
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const float32_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_22 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_22.memview)) __PYX_ERR(2, 3675, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":3675
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const float32_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_22, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3675, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_22, 1);
  __pyx_t_22.memview = NULL; __pyx_t_22.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":3674
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const float32_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 3674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5)) __PYX_ERR(2, 3674, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_ndarray) < 0) __PYX_ERR(2, 3674, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_23lookup, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float32HashTable_lookup, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__281)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 3674, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable, __pyx_n_s_lookup, __pyx_t_7) < 0) __PYX_ERR(2, 3674, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":3703
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const float32_t[:] values, Float32Vector uniques,
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_25_unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float32HashTable__unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__282)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 3703, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__184);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable, __pyx_n_s_unique, __pyx_t_7) < 0) __PYX_ERR(2, 3703, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":3868
 *         return uniques.to_array()
 * 
 *     def unique(self, const float32_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_27unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float32HashTable_unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__283)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 3868, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__187);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable, __pyx_n_s_unique_2, __pyx_t_7) < 0) __PYX_ERR(2, 3868, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":3897
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const float32_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_29factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float32HashTable_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__284)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 3897, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__190);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable, __pyx_n_s_factorize, __pyx_t_7) < 0) __PYX_ERR(2, 3897, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":3933
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const float32_t[:] values, Float32Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_31get_labels, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float32HashTable_get_labels, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__285)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 3933, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__194);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable, __pyx_n_s_get_labels, __pyx_t_7) < 0) __PYX_ERR(2, 3933, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float32HashTable);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_33__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float32HashTable___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__286)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16Float32HashTable_35__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float32HashTable___setstate_cyth, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__287)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":3953
 *         self.uniques = Float32Vector()
 * 
 *     def factorize(self, const float32_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 3953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_kp_s_np_ndarray) < 0) __PYX_ERR(2, 3953, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_17Float32Factorizer_3factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float32Factorizer_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__288)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 3953, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__199);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Float32Factorizer, __pyx_n_s_factorize, __pyx_t_5) < 0) __PYX_ERR(2, 3953, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Float32Factorizer);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_17Float32Factorizer_5__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float32Factorizer___reduce_cytho, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__289)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_5) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_17Float32Factorizer_7__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Float32Factorizer___setstate_cyt, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__290)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_5) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4013
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_deep, __pyx_n_s_bool) < 0) __PYX_ERR(2, 4013, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_int) < 0) __PYX_ERR(2, 4013, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_9sizeof, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt32HashTable_sizeof, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__291)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 4013, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__170);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable, __pyx_n_s_sizeof, __pyx_t_7) < 0) __PYX_ERR(2, 4013, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4021
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 4021, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_kp_s_dict_str_int) < 0) __PYX_ERR(2, 4021, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_11get_state, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt32HashTable_get_state, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__292)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4021, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable, __pyx_n_s_get_state, __pyx_t_5) < 0) __PYX_ERR(2, 4021, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4030
 *         }
 * 
 *     cpdef get_item(self, uint32_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_13get_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt32HashTable_get_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__293)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4030, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable, __pyx_n_s_get_item, __pyx_t_5) < 0) __PYX_ERR(2, 4030, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4056
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_15get_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt32HashTable_get_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__294)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4056, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable, __pyx_n_s_get_na, __pyx_t_5) < 0) __PYX_ERR(2, 4056, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4071
 *         return self.na_position
 * 
 *     cpdef set_item(self, uint32_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_17set_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt32HashTable_set_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__295)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4071, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable, __pyx_n_s_set_item, __pyx_t_5) < 0) __PYX_ERR(2, 4071, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4086
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_19set_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt32HashTable_set_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__296)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4086, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable, __pyx_n_s_set_na, __pyx_t_5) < 0) __PYX_ERR(2, 4086, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4100
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const uint32_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_23 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_23.memview)) __PYX_ERR(2, 4100, __pyx_L1_error)
  __pyx_k__28 = __pyx_t_23;
  __pyx_t_23.memview = NULL;
  __pyx_t_23.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":4099
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const uint32_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_23 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_23.memview)) __PYX_ERR(2, 4100, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4100
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const uint32_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_23, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4100, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_23, 1);
  __pyx_t_23.memview = NULL; __pyx_t_23.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":4099
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const uint32_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 4099, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5)) __PYX_ERR(2, 4099, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4099, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_None) < 0) __PYX_ERR(2, 4099, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_21map_locations, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt32HashTable_map_locations, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__297)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4099, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_t_7);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable, __pyx_n_s_map_locations, __pyx_t_4) < 0) __PYX_ERR(2, 4099, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4129
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const uint32_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_24 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_24.memview)) __PYX_ERR(2, 4129, __pyx_L1_error)
  __pyx_k__29 = __pyx_t_24;
  __pyx_t_24.memview = NULL;
  __pyx_t_24.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":4128
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const uint32_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_24 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_24.memview)) __PYX_ERR(2, 4129, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4129
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const uint32_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_t_24, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4129, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_24, 1);
  __pyx_t_24.memview = NULL; __pyx_t_24.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":4128
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const uint32_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4)) __PYX_ERR(2, 4128, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_n_s_ndarray) < 0) __PYX_ERR(2, 4128, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_23lookup, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt32HashTable_lookup, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__298)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 4128, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable, __pyx_n_s_lookup, __pyx_t_7) < 0) __PYX_ERR(2, 4128, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4157
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const uint32_t[:] values, UInt32Vector uniques,
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_25_unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt32HashTable__unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__299)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 4157, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__184);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable, __pyx_n_s_unique, __pyx_t_7) < 0) __PYX_ERR(2, 4157, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4322
 *         return uniques.to_array()
 * 
 *     def unique(self, const uint32_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_27unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt32HashTable_unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__300)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 4322, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__187);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable, __pyx_n_s_unique_2, __pyx_t_7) < 0) __PYX_ERR(2, 4322, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4351
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const uint32_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_29factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt32HashTable_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__301)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 4351, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__190);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable, __pyx_n_s_factorize, __pyx_t_7) < 0) __PYX_ERR(2, 4351, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4387
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const uint32_t[:] values, UInt32Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_31get_labels, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt32HashTable_get_labels, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__302)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 4387, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__194);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable, __pyx_n_s_get_labels, __pyx_t_7) < 0) __PYX_ERR(2, 4387, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt32HashTable);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_33__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt32HashTable___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__303)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt32HashTable_35__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt32HashTable___setstate_cytho, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__304)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4407
 *         self.uniques = UInt32Vector()
 * 
 *     def factorize(self, const uint32_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 4407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_kp_s_np_ndarray) < 0) __PYX_ERR(2, 4407, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16UInt32Factorizer_3factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt32Factorizer_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__305)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4407, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__199);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Factorizer, __pyx_n_s_factorize, __pyx_t_4) < 0) __PYX_ERR(2, 4407, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt32Factorizer);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16UInt32Factorizer_5__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt32Factorizer___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__306)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_4) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16UInt32Factorizer_7__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt32Factorizer___setstate_cyth, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__307)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_4) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4467
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_deep, __pyx_n_s_bool) < 0) __PYX_ERR(2, 4467, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_n_s_int) < 0) __PYX_ERR(2, 4467, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_9sizeof, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int32HashTable_sizeof, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__308)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 4467, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__170);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable, __pyx_n_s_sizeof, __pyx_t_7) < 0) __PYX_ERR(2, 4467, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4475
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 4475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_kp_s_dict_str_int) < 0) __PYX_ERR(2, 4475, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_11get_state, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int32HashTable_get_state, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__309)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4475, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable, __pyx_n_s_get_state, __pyx_t_4) < 0) __PYX_ERR(2, 4475, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4484
 *         }
 * 
 *     cpdef get_item(self, int32_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_13get_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int32HashTable_get_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__310)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4484, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable, __pyx_n_s_get_item, __pyx_t_4) < 0) __PYX_ERR(2, 4484, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4510
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_15get_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int32HashTable_get_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__311)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4510, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable, __pyx_n_s_get_na, __pyx_t_4) < 0) __PYX_ERR(2, 4510, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4525
 *         return self.na_position
 * 
 *     cpdef set_item(self, int32_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_17set_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int32HashTable_set_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__312)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4525, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable, __pyx_n_s_set_item, __pyx_t_4) < 0) __PYX_ERR(2, 4525, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4540
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_19set_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int32HashTable_set_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__313)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4540, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable, __pyx_n_s_set_na, __pyx_t_4) < 0) __PYX_ERR(2, 4540, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4554
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const int32_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_25 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_25.memview)) __PYX_ERR(2, 4554, __pyx_L1_error)
  __pyx_k__30 = __pyx_t_25;
  __pyx_t_25.memview = NULL;
  __pyx_t_25.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":4553
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const int32_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_25 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_25.memview)) __PYX_ERR(2, 4554, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4554
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const int32_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_t_25, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4554, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_25, 1);
  __pyx_t_25.memview = NULL; __pyx_t_25.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":4553
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const int32_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 4553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_4)) __PYX_ERR(2, 4553, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_n_s_None) < 0) __PYX_ERR(2, 4553, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_21map_locations, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int32HashTable_map_locations, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__314)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4553, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_7);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable, __pyx_n_s_map_locations, __pyx_t_5) < 0) __PYX_ERR(2, 4553, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4583
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const int32_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_26 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_26.memview)) __PYX_ERR(2, 4583, __pyx_L1_error)
  __pyx_k__31 = __pyx_t_26;
  __pyx_t_26.memview = NULL;
  __pyx_t_26.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":4582
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const int32_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_26 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_26.memview)) __PYX_ERR(2, 4583, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":4583
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const int32_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_26, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4583, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_26, 1);
  __pyx_t_26.memview = NULL; __pyx_t_26.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":4582
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const int32_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 4582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5)) __PYX_ERR(2, 4582, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_ndarray) < 0) __PYX_ERR(2, 4582, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_23lookup, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int32HashTable_lookup, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__315)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 4582, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable, __pyx_n_s_lookup, __pyx_t_7) < 0) __PYX_ERR(2, 4582, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4611
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const int32_t[:] values, Int32Vector uniques,
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_25_unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int32HashTable__unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__316)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 4611, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__184);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable, __pyx_n_s_unique, __pyx_t_7) < 0) __PYX_ERR(2, 4611, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4776
 *         return uniques.to_array()
 * 
 *     def unique(self, const int32_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_27unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int32HashTable_unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__317)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 4776, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__187);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable, __pyx_n_s_unique_2, __pyx_t_7) < 0) __PYX_ERR(2, 4776, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4805
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const int32_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_29factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int32HashTable_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__318)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 4805, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__190);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable, __pyx_n_s_factorize, __pyx_t_7) < 0) __PYX_ERR(2, 4805, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4841
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const int32_t[:] values, Int32Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_31get_labels, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int32HashTable_get_labels, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__319)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 4841, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__194);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable, __pyx_n_s_get_labels, __pyx_t_7) < 0) __PYX_ERR(2, 4841, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_33__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int32HashTable___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__320)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int32HashTable_35__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int32HashTable___setstate_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__321)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4861
 *         self.uniques = Int32Vector()
 * 
 *     def factorize(self, const int32_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 4861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_kp_s_np_ndarray) < 0) __PYX_ERR(2, 4861, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15Int32Factorizer_3factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int32Factorizer_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__322)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4861, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__199);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int32Factorizer, __pyx_n_s_factorize, __pyx_t_5) < 0) __PYX_ERR(2, 4861, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int32Factorizer);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15Int32Factorizer_5__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int32Factorizer___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__323)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_5) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15Int32Factorizer_7__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int32Factorizer___setstate_cytho, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__324)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_5) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":4921
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4921, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_deep, __pyx_n_s_bool) < 0) __PYX_ERR(2, 4921, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_int) < 0) __PYX_ERR(2, 4921, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_9sizeof, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt16HashTable_sizeof, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__325)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 4921, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__170);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable, __pyx_n_s_sizeof, __pyx_t_7) < 0) __PYX_ERR(2, 4921, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4929
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 4929, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_kp_s_dict_str_int) < 0) __PYX_ERR(2, 4929, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_11get_state, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt16HashTable_get_state, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__326)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4929, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable, __pyx_n_s_get_state, __pyx_t_5) < 0) __PYX_ERR(2, 4929, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4938
 *         }
 * 
 *     cpdef get_item(self, uint16_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_13get_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt16HashTable_get_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__327)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4938, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable, __pyx_n_s_get_item, __pyx_t_5) < 0) __PYX_ERR(2, 4938, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4964
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_15get_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt16HashTable_get_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__328)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4964, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable, __pyx_n_s_get_na, __pyx_t_5) < 0) __PYX_ERR(2, 4964, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4979
 *         return self.na_position
 * 
 *     cpdef set_item(self, uint16_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_17set_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt16HashTable_set_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__329)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4979, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable, __pyx_n_s_set_item, __pyx_t_5) < 0) __PYX_ERR(2, 4979, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":4994
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_19set_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt16HashTable_set_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__330)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 4994, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable, __pyx_n_s_set_na, __pyx_t_5) < 0) __PYX_ERR(2, 4994, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5008
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const uint16_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_27 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_27.memview)) __PYX_ERR(2, 5008, __pyx_L1_error)
  __pyx_k__32 = __pyx_t_27;
  __pyx_t_27.memview = NULL;
  __pyx_t_27.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":5007
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const uint16_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_27 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_27.memview)) __PYX_ERR(2, 5008, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5008
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const uint16_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_27, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5008, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_27, 1);
  __pyx_t_27.memview = NULL; __pyx_t_27.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":5007
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const uint16_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 5007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5)) __PYX_ERR(2, 5007, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_None) < 0) __PYX_ERR(2, 5007, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_21map_locations, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt16HashTable_map_locations, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__331)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5007, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_t_7);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable, __pyx_n_s_map_locations, __pyx_t_4) < 0) __PYX_ERR(2, 5007, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5037
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const uint16_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_28 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_28.memview)) __PYX_ERR(2, 5037, __pyx_L1_error)
  __pyx_k__33 = __pyx_t_28;
  __pyx_t_28.memview = NULL;
  __pyx_t_28.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":5036
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const uint16_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_28 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_28.memview)) __PYX_ERR(2, 5037, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5037
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const uint16_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_t_28, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5037, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_28, 1);
  __pyx_t_28.memview = NULL; __pyx_t_28.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":5036
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const uint16_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4)) __PYX_ERR(2, 5036, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_n_s_ndarray) < 0) __PYX_ERR(2, 5036, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_23lookup, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt16HashTable_lookup, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__332)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 5036, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable, __pyx_n_s_lookup, __pyx_t_7) < 0) __PYX_ERR(2, 5036, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5065
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const uint16_t[:] values, UInt16Vector uniques,
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_25_unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt16HashTable__unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__333)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 5065, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__184);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable, __pyx_n_s_unique, __pyx_t_7) < 0) __PYX_ERR(2, 5065, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5230
 *         return uniques.to_array()
 * 
 *     def unique(self, const uint16_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_27unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt16HashTable_unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__334)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 5230, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__187);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable, __pyx_n_s_unique_2, __pyx_t_7) < 0) __PYX_ERR(2, 5230, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5259
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const uint16_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_29factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt16HashTable_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__335)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 5259, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__190);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable, __pyx_n_s_factorize, __pyx_t_7) < 0) __PYX_ERR(2, 5259, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5295
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const uint16_t[:] values, UInt16Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_31get_labels, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt16HashTable_get_labels, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__336)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 5295, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__194);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable, __pyx_n_s_get_labels, __pyx_t_7) < 0) __PYX_ERR(2, 5295, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt16HashTable);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_33__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt16HashTable___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__337)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt16HashTable_35__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt16HashTable___setstate_cytho, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__338)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5315
 *         self.uniques = UInt16Vector()
 * 
 *     def factorize(self, const uint16_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 5315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_kp_s_np_ndarray) < 0) __PYX_ERR(2, 5315, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16UInt16Factorizer_3factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt16Factorizer_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__339)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5315, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__199);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Factorizer, __pyx_n_s_factorize, __pyx_t_4) < 0) __PYX_ERR(2, 5315, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt16Factorizer);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16UInt16Factorizer_5__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt16Factorizer___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__340)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_4) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16UInt16Factorizer_7__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt16Factorizer___setstate_cyth, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__341)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_4) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5375
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_deep, __pyx_n_s_bool) < 0) __PYX_ERR(2, 5375, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_n_s_int) < 0) __PYX_ERR(2, 5375, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_9sizeof, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int16HashTable_sizeof, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__342)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 5375, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__170);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable, __pyx_n_s_sizeof, __pyx_t_7) < 0) __PYX_ERR(2, 5375, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5383
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 5383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_kp_s_dict_str_int) < 0) __PYX_ERR(2, 5383, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_11get_state, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int16HashTable_get_state, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__343)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5383, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable, __pyx_n_s_get_state, __pyx_t_4) < 0) __PYX_ERR(2, 5383, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5392
 *         }
 * 
 *     cpdef get_item(self, int16_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_13get_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int16HashTable_get_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__344)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5392, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable, __pyx_n_s_get_item, __pyx_t_4) < 0) __PYX_ERR(2, 5392, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5418
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_15get_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int16HashTable_get_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__345)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5418, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable, __pyx_n_s_get_na, __pyx_t_4) < 0) __PYX_ERR(2, 5418, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5433
 *         return self.na_position
 * 
 *     cpdef set_item(self, int16_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_17set_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int16HashTable_set_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__346)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5433, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable, __pyx_n_s_set_item, __pyx_t_4) < 0) __PYX_ERR(2, 5433, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5448
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_19set_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int16HashTable_set_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__347)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5448, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable, __pyx_n_s_set_na, __pyx_t_4) < 0) __PYX_ERR(2, 5448, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5462
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const int16_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_29 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_29.memview)) __PYX_ERR(2, 5462, __pyx_L1_error)
  __pyx_k__34 = __pyx_t_29;
  __pyx_t_29.memview = NULL;
  __pyx_t_29.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":5461
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const int16_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_29 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_29.memview)) __PYX_ERR(2, 5462, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5462
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const int16_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_t_29, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5462, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_29, 1);
  __pyx_t_29.memview = NULL; __pyx_t_29.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":5461
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const int16_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 5461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_4)) __PYX_ERR(2, 5461, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_n_s_None) < 0) __PYX_ERR(2, 5461, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_21map_locations, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int16HashTable_map_locations, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__348)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5461, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_7);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable, __pyx_n_s_map_locations, __pyx_t_5) < 0) __PYX_ERR(2, 5461, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5491
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const int16_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_30 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_30.memview)) __PYX_ERR(2, 5491, __pyx_L1_error)
  __pyx_k__35 = __pyx_t_30;
  __pyx_t_30.memview = NULL;
  __pyx_t_30.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":5490
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const int16_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_30 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_30.memview)) __PYX_ERR(2, 5491, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5491
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const int16_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_30, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5491, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_30, 1);
  __pyx_t_30.memview = NULL; __pyx_t_30.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":5490
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const int16_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5)) __PYX_ERR(2, 5490, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_ndarray) < 0) __PYX_ERR(2, 5490, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_23lookup, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int16HashTable_lookup, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__349)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 5490, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable, __pyx_n_s_lookup, __pyx_t_7) < 0) __PYX_ERR(2, 5490, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5519
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const int16_t[:] values, Int16Vector uniques,
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_25_unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int16HashTable__unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__350)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 5519, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__184);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable, __pyx_n_s_unique, __pyx_t_7) < 0) __PYX_ERR(2, 5519, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5684
 *         return uniques.to_array()
 * 
 *     def unique(self, const int16_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_27unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int16HashTable_unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__351)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 5684, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__187);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable, __pyx_n_s_unique_2, __pyx_t_7) < 0) __PYX_ERR(2, 5684, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5713
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const int16_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_29factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int16HashTable_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__352)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 5713, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__190);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable, __pyx_n_s_factorize, __pyx_t_7) < 0) __PYX_ERR(2, 5713, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5749
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const int16_t[:] values, Int16Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_31get_labels, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int16HashTable_get_labels, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__353)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 5749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__194);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable, __pyx_n_s_get_labels, __pyx_t_7) < 0) __PYX_ERR(2, 5749, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int16HashTable);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_33__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int16HashTable___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__354)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int16HashTable_35__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int16HashTable___setstate_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__355)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5769
 *         self.uniques = Int16Vector()
 * 
 *     def factorize(self, const int16_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 5769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_kp_s_np_ndarray) < 0) __PYX_ERR(2, 5769, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15Int16Factorizer_3factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int16Factorizer_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__356)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5769, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__199);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int16Factorizer, __pyx_n_s_factorize, __pyx_t_5) < 0) __PYX_ERR(2, 5769, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int16Factorizer);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15Int16Factorizer_5__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int16Factorizer___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__357)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_5) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15Int16Factorizer_7__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int16Factorizer___setstate_cytho, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__358)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_5) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":5829
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_deep, __pyx_n_s_bool) < 0) __PYX_ERR(2, 5829, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_int) < 0) __PYX_ERR(2, 5829, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_9sizeof, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt8HashTable_sizeof, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__359)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 5829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__170);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable, __pyx_n_s_sizeof, __pyx_t_7) < 0) __PYX_ERR(2, 5829, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5837
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 5837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_kp_s_dict_str_int) < 0) __PYX_ERR(2, 5837, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_11get_state, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt8HashTable_get_state, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__360)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5837, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable, __pyx_n_s_get_state, __pyx_t_5) < 0) __PYX_ERR(2, 5837, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5846
 *         }
 * 
 *     cpdef get_item(self, uint8_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_13get_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt8HashTable_get_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__361)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5846, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable, __pyx_n_s_get_item, __pyx_t_5) < 0) __PYX_ERR(2, 5846, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5872
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_15get_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt8HashTable_get_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__362)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5872, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable, __pyx_n_s_get_na, __pyx_t_5) < 0) __PYX_ERR(2, 5872, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5887
 *         return self.na_position
 * 
 *     cpdef set_item(self, uint8_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_17set_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt8HashTable_set_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__363)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5887, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable, __pyx_n_s_set_item, __pyx_t_5) < 0) __PYX_ERR(2, 5887, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5902
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_19set_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt8HashTable_set_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__364)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5902, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable, __pyx_n_s_set_na, __pyx_t_5) < 0) __PYX_ERR(2, 5902, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5916
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const uint8_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_31 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_31.memview)) __PYX_ERR(2, 5916, __pyx_L1_error)
  __pyx_k__36 = __pyx_t_31;
  __pyx_t_31.memview = NULL;
  __pyx_t_31.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":5915
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const uint8_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_31 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_31.memview)) __PYX_ERR(2, 5916, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5916
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const uint8_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_31, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5916, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_31, 1);
  __pyx_t_31.memview = NULL; __pyx_t_31.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":5915
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const uint8_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 5915, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_5)) __PYX_ERR(2, 5915, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5915, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_None) < 0) __PYX_ERR(2, 5915, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_21map_locations, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt8HashTable_map_locations, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__365)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5915, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_t_7);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable, __pyx_n_s_map_locations, __pyx_t_4) < 0) __PYX_ERR(2, 5915, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5945
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const uint8_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_32 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_32.memview)) __PYX_ERR(2, 5945, __pyx_L1_error)
  __pyx_k__37 = __pyx_t_32;
  __pyx_t_32.memview = NULL;
  __pyx_t_32.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":5944
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const uint8_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_32 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_32.memview)) __PYX_ERR(2, 5945, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":5945
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const uint8_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_t_32, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5945, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_32, 1);
  __pyx_t_32.memview = NULL; __pyx_t_32.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":5944
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const uint8_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 5944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4)) __PYX_ERR(2, 5944, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 5944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_n_s_ndarray) < 0) __PYX_ERR(2, 5944, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_23lookup, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt8HashTable_lookup, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__366)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 5944, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable, __pyx_n_s_lookup, __pyx_t_7) < 0) __PYX_ERR(2, 5944, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":5973
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const uint8_t[:] values, UInt8Vector uniques,
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_25_unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt8HashTable__unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__367)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 5973, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__184);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable, __pyx_n_s_unique, __pyx_t_7) < 0) __PYX_ERR(2, 5973, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6138
 *         return uniques.to_array()
 * 
 *     def unique(self, const uint8_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_27unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt8HashTable_unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__368)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 6138, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__187);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable, __pyx_n_s_unique_2, __pyx_t_7) < 0) __PYX_ERR(2, 6138, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6167
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const uint8_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_29factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt8HashTable_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__369)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 6167, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__190);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable, __pyx_n_s_factorize, __pyx_t_7) < 0) __PYX_ERR(2, 6167, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6203
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const uint8_t[:] values, UInt8Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_31get_labels, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt8HashTable_get_labels, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__370)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 6203, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__194);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable, __pyx_n_s_get_labels, __pyx_t_7) < 0) __PYX_ERR(2, 6203, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt8HashTable);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_33__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt8HashTable___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__371)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14UInt8HashTable_35__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt8HashTable___setstate_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__372)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6223
 *         self.uniques = UInt8Vector()
 * 
 *     def factorize(self, const uint8_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 6223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_kp_s_np_ndarray) < 0) __PYX_ERR(2, 6223, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt8Factorizer_3factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt8Factorizer_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__373)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6223, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_4, __pyx_tuple__199);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Factorizer, __pyx_n_s_factorize, __pyx_t_4) < 0) __PYX_ERR(2, 6223, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_UInt8Factorizer);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt8Factorizer_5__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt8Factorizer___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__374)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_4) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15UInt8Factorizer_7__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_UInt8Factorizer___setstate_cytho, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__375)); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_4) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6283
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_t_4 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_deep, __pyx_n_s_bool) < 0) __PYX_ERR(2, 6283, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_n_s_int) < 0) __PYX_ERR(2, 6283, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_9sizeof, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int8HashTable_sizeof, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__376)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 6283, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__170);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable, __pyx_n_s_sizeof, __pyx_t_7) < 0) __PYX_ERR(2, 6283, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6291
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 6291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_kp_s_dict_str_int) < 0) __PYX_ERR(2, 6291, __pyx_L1_error)
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_11get_state, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int8HashTable_get_state, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__377)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6291, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_4, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable, __pyx_n_s_get_state, __pyx_t_4) < 0) __PYX_ERR(2, 6291, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6300
 *         }
 * 
 *     cpdef get_item(self, int8_t val):             # <<<<<<<<<<<<<<
 *         """Extracts the position of val from the hashtable.
 * 
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_13get_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int8HashTable_get_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__378)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6300, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable, __pyx_n_s_get_item, __pyx_t_4) < 0) __PYX_ERR(2, 6300, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6326
 *             raise KeyError(val)
 * 
 *     cpdef get_na(self):             # <<<<<<<<<<<<<<
 *         """Extracts the position of na_value from the hashtable.
 * 
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_15get_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int8HashTable_get_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__379)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6326, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable, __pyx_n_s_get_na, __pyx_t_4) < 0) __PYX_ERR(2, 6326, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6341
 *         return self.na_position
 * 
 *     cpdef set_item(self, int8_t key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Used in libjoin
 *         # Caller is responsible for checking for pd.NA
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_17set_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int8HashTable_set_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__380)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable, __pyx_n_s_set_item, __pyx_t_4) < 0) __PYX_ERR(2, 6341, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6356
 *             raise KeyError(key)
 * 
 *     cpdef set_na(self, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         # Caller is responsible for checking for pd.NA
 *         cdef:
 */
  __pyx_t_4 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_19set_na, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int8HashTable_set_na, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__381)); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6356, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable, __pyx_n_s_set_na, __pyx_t_4) < 0) __PYX_ERR(2, 6356, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6370
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const int8_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_33 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_33.memview)) __PYX_ERR(2, 6370, __pyx_L1_error)
  __pyx_k__38 = __pyx_t_33;
  __pyx_t_33.memview = NULL;
  __pyx_t_33.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":6369
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const int8_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_33 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_33.memview)) __PYX_ERR(2, 6370, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6370
 * 
 *     @cython.boundscheck(False)
 *     def map_locations(self, const int8_t[:] values, const uint8_t[:] mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # Used in libindex, safe_sort
 *         cdef:
 */
  __pyx_t_4 = __pyx_memoryview_fromslice(__pyx_t_33, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6370, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_33, 1);
  __pyx_t_33.memview = NULL; __pyx_t_33.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":6369
 * 
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, const int8_t[:] values, const uint8_t[:] mask = None) -> None:
 *         # Used in libindex, safe_sort
 */
  __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 6369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_4);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_4)) __PYX_ERR(2, 6369, __pyx_L1_error);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_return, __pyx_n_s_None) < 0) __PYX_ERR(2, 6369, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_21map_locations, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int8HashTable_map_locations, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__382)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6369, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_7);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable, __pyx_n_s_map_locations, __pyx_t_5) < 0) __PYX_ERR(2, 6369, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6399
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const int8_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_34 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_34.memview)) __PYX_ERR(2, 6399, __pyx_L1_error)
  __pyx_k__39 = __pyx_t_34;
  __pyx_t_34.memview = NULL;
  __pyx_t_34.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":6398
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const int8_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_34 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_34.memview)) __PYX_ERR(2, 6399, __pyx_L1_error)

  /* "pandas/_libs/hashtable_class_helper.pxi":6399
 * 
 *     @cython.boundscheck(False)
 *     def lookup(self, const int8_t[:] values, const uint8_t[:] mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # Used in safe_sort, IndexEngine.get_indexer
 */
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_34, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6399, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_34, 1);
  __pyx_t_34.memview = NULL; __pyx_t_34.data = NULL;

  /* "pandas/_libs/hashtable_class_helper.pxi":6398
 *         self.na_position = na_position
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, const int8_t[:] values, const uint8_t[:] mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) __PYX_ERR(2, 6398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5)) __PYX_ERR(2, 6398, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_ndarray) < 0) __PYX_ERR(2, 6398, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_23lookup, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int8HashTable_lookup, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__383)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 6398, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_4);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable, __pyx_n_s_lookup, __pyx_t_7) < 0) __PYX_ERR(2, 6398, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6427
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, const int8_t[:] values, Int8Vector uniques,
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_25_unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int8HashTable__unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__384)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 6427, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__184);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable, __pyx_n_s_unique, __pyx_t_7) < 0) __PYX_ERR(2, 6427, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6592
 *         return uniques.to_array()
 * 
 *     def unique(self, const int8_t[:] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_27unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int8HashTable_unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__385)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 6592, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__187);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable, __pyx_n_s_unique_2, __pyx_t_7) < 0) __PYX_ERR(2, 6592, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6621
 *                             return_inverse=return_inverse, mask=mask, use_result_mask=use_result_mask)
 * 
 *     def factorize(self, const int8_t[:] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_29factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int8HashTable_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__386)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 6621, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__190);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable, __pyx_n_s_factorize, __pyx_t_7) < 0) __PYX_ERR(2, 6621, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6657
 *                             return_inverse=True)
 * 
 *     def get_labels(self, const int8_t[:] values, Int8Vector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None, object mask=None):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_31get_labels, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int8HashTable_get_labels, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__387)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 6657, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__194);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable, __pyx_n_s_get_labels, __pyx_t_7) < 0) __PYX_ERR(2, 6657, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int8HashTable);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_33__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int8HashTable___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__388)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_13Int8HashTable_35__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int8HashTable___setstate_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__389)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6677
 *         self.uniques = Int8Vector()
 * 
 *     def factorize(self, const int8_t[:] values,             # <<<<<<<<<<<<<<
 *                   na_sentinel=-1, na_value=None, object mask=None) -> np.ndarray:
 *         """
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 6677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_kp_s_np_ndarray) < 0) __PYX_ERR(2, 6677, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int8Factorizer_3factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int8Factorizer_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__390)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6677, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__199);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int8Factorizer, __pyx_n_s_factorize, __pyx_t_5) < 0) __PYX_ERR(2, 6677, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Int8Factorizer);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int8Factorizer_5__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int8Factorizer___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__391)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_5) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_14Int8Factorizer_7__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Int8Factorizer___setstate_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__392)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_5) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":6709
 *     # these by-definition *must* be strings
 *     # or a sentinel np.nan / None missing value
 *     na_string_sentinel = '__nan__'             # <<<<<<<<<<<<<<
 * 
 *     def __init__(self, int64_t size_hint=1):
 */
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable, __pyx_n_s_na_string_sentinel, __pyx_n_u_nan) < 0) __PYX_ERR(2, 6709, __pyx_L1_error)
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6721
 *             self.table = NULL
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 *         for_flags = max(1, self.table.n_buckets >> 5) * sizeof(uint32_t)
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_deep, __pyx_n_s_bool) < 0) __PYX_ERR(2, 6721, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_int) < 0) __PYX_ERR(2, 6721, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_5sizeof, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_StringHashTable_sizeof, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__393)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 6721, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__170);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable, __pyx_n_s_sizeof, __pyx_t_7) < 0) __PYX_ERR(2, 6721, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6728
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """ returns infos about the state of the hashtable"""
 *         return {
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 6728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_kp_s_dict_str_int) < 0) __PYX_ERR(2, 6728, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_7get_state, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_StringHashTable_get_state, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__394)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6728, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable, __pyx_n_s_get_state, __pyx_t_5) < 0) __PYX_ERR(2, 6728, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6737
 *         }
 * 
 *     cpdef get_item(self, str val):             # <<<<<<<<<<<<<<
 *         cdef:
 *             khiter_t k
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_9get_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_StringHashTable_get_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__395)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6737, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable, __pyx_n_s_get_item, __pyx_t_5) < 0) __PYX_ERR(2, 6737, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6749
 *             raise KeyError(val)
 * 
 *     cpdef set_item(self, str key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         cdef:
 *             khiter_t k
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_11set_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_StringHashTable_set_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__396)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6749, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable, __pyx_n_s_set_item, __pyx_t_5) < 0) __PYX_ERR(2, 6749, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6763
 *             raise KeyError(key)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def get_indexer(self, ndarray[object] values) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_ndarray) < 0) __PYX_ERR(2, 6763, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_13get_indexer, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_StringHashTable_get_indexer, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__398)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 6763, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable, __pyx_n_s_get_indexer, __pyx_t_7) < 0) __PYX_ERR(2, 6763, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6792
 *         return labels
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def lookup(self, ndarray[object] values, object mask = None) -> ndarray:
 *         # -> np.ndarray[np.intp]
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 6792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_n_s_ndarray) < 0) __PYX_ERR(2, 6792, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_15lookup, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_StringHashTable_lookup, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__400)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6792, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__401);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable, __pyx_n_s_lookup, __pyx_t_5) < 0) __PYX_ERR(2, 6792, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6829
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     def map_locations(self, ndarray[object] values, object mask = None) -> None:
 *         # mask not yet implemented
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 6829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_None) < 0) __PYX_ERR(2, 6829, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_17map_locations, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_StringHashTable_map_locations, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__403)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 6829, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__401);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable, __pyx_n_s_map_locations, __pyx_t_7) < 0) __PYX_ERR(2, 6829, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6860
 *         free(vecs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, ndarray[object] values, ObjectVector uniques,
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_19_unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_StringHashTable__unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__405)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 6860, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__406);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable, __pyx_n_s_unique, __pyx_t_7) < 0) __PYX_ERR(2, 6860, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6968
 *         return uniques.to_array()
 * 
 *     def unique(self, ndarray[object] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_21unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_StringHashTable_unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__408)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 6968, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__187);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable, __pyx_n_s_unique_2, __pyx_t_7) < 0) __PYX_ERR(2, 6968, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":6993
 *                             return_inverse=return_inverse)
 * 
 *     def factorize(self, ndarray[object] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_23factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_StringHashTable_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__409)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 6993, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__190);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable, __pyx_n_s_factorize, __pyx_t_7) < 0) __PYX_ERR(2, 6993, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":7027
 *                             return_inverse=True)
 * 
 *     def get_labels(self, ndarray[object] values, ObjectVector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_25get_labels, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_StringHashTable_get_labels, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__411)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 7027, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__412);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable, __pyx_n_s_get_labels, __pyx_t_7) < 0) __PYX_ERR(2, 7027, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_StringHashTable);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_27__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_StringHashTable___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__413)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15StringHashTable_29__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_StringHashTable___setstate_cytho, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__414)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_class_helper.pxi":7060
 *         return k != self.table.n_buckets
 * 
 *     def sizeof(self, deep: bool = False) -> int:             # <<<<<<<<<<<<<<
 *         """ return the size of my table in bytes """
 *         overhead = 4 * sizeof(uint32_t) + 3 * sizeof(uint32_t*)
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 7060, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_deep, __pyx_n_s_bool) < 0) __PYX_ERR(2, 7060, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_n_s_int) < 0) __PYX_ERR(2, 7060, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_9sizeof, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_PyObjectHashTable_sizeof, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__415)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 7060, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__170);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable, __pyx_n_s_sizeof, __pyx_t_5) < 0) __PYX_ERR(2, 7060, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":7068
 *         return overhead + for_flags + for_pairs
 * 
 *     def get_state(self) -> dict[str, int]:             # <<<<<<<<<<<<<<
 *         """
 *         returns infos about the current state of the hashtable like size,
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 7068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_kp_s_dict_str_int) < 0) __PYX_ERR(2, 7068, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_11get_state, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_PyObjectHashTable_get_state, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__416)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 7068, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable, __pyx_n_s_get_state, __pyx_t_7) < 0) __PYX_ERR(2, 7068, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":7080
 *         }
 * 
 *     cpdef get_item(self, object val):             # <<<<<<<<<<<<<<
 *         cdef:
 *             khiter_t k
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_13get_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_PyObjectHashTable_get_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__417)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 7080, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable, __pyx_n_s_get_item, __pyx_t_7) < 0) __PYX_ERR(2, 7080, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":7090
 *             raise KeyError(val)
 * 
 *     cpdef set_item(self, object key, Py_ssize_t val):             # <<<<<<<<<<<<<<
 *         cdef:
 *             khiter_t k
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_15set_item, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_PyObjectHashTable_set_item, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__418)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 7090, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable, __pyx_n_s_set_item, __pyx_t_7) < 0) __PYX_ERR(2, 7090, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":7104
 *             raise KeyError(key)
 * 
 *     def map_locations(self, ndarray[object] values, object mask = None) -> None:             # <<<<<<<<<<<<<<
 *         # mask not yet implemented
 *         cdef:
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 7104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_n_s_None) < 0) __PYX_ERR(2, 7104, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_17map_locations, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_PyObjectHashTable_map_locations, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__420)); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 7104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__401);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable, __pyx_n_s_map_locations, __pyx_t_5) < 0) __PYX_ERR(2, 7104, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":7119
 *             self.table.vals[k] = i
 * 
 *     def lookup(self, ndarray[object] values, object mask = None) -> ndarray:             # <<<<<<<<<<<<<<
 *         # -> np.ndarray[np.intp]
 *         # mask not yet implemented
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(2, 7119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_ndarray) < 0) __PYX_ERR(2, 7119, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_19lookup, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_PyObjectHashTable_lookup, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__422)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 7119, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__401);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable, __pyx_n_s_lookup, __pyx_t_7) < 0) __PYX_ERR(2, 7119, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":7141
 *         return np.asarray(locs)
 * 
 *     @cython.boundscheck(False)             # <<<<<<<<<<<<<<
 *     @cython.wraparound(False)
 *     def _unique(self, ndarray[object] values, ObjectVector uniques,
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_21_unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_PyObjectHashTable__unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__424)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 7141, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__406);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable, __pyx_n_s_unique, __pyx_t_7) < 0) __PYX_ERR(2, 7141, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":7225
 *         return uniques.to_array()
 * 
 *     def unique(self, ndarray[object] values, bint return_inverse=False, object mask=None):             # <<<<<<<<<<<<<<
 *         """
 *         Calculate unique values and labels (no sorting!)
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_23unique, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_PyObjectHashTable_unique, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__425)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 7225, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__187);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable, __pyx_n_s_unique_2, __pyx_t_7) < 0) __PYX_ERR(2, 7225, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":7250
 *                             return_inverse=return_inverse)
 * 
 *     def factorize(self, ndarray[object] values, Py_ssize_t na_sentinel=-1,             # <<<<<<<<<<<<<<
 *                   object na_value=None, object mask=None, ignore_na=True):
 *         """
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_25factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_PyObjectHashTable_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__426)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 7250, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__190);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable, __pyx_n_s_factorize, __pyx_t_7) < 0) __PYX_ERR(2, 7250, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable);

  /* "pandas/_libs/hashtable_class_helper.pxi":7284
 *                             return_inverse=True)
 * 
 *     def get_labels(self, ndarray[object] values, ObjectVector uniques,             # <<<<<<<<<<<<<<
 *                    Py_ssize_t count_prior=0, Py_ssize_t na_sentinel=-1,
 *                    object na_value=None):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_27get_labels, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_PyObjectHashTable_get_labels, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__427)); if (unlikely(!__pyx_t_7)) __PYX_ERR(2, 7284, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__412);
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable, __pyx_n_s_get_labels, __pyx_t_7) < 0) __PYX_ERR(2, 7284, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_PyObjectHashTable);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_29__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_PyObjectHashTable___reduce_cytho, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__428)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_7) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "self.table cannot be converted to a Python object for pickling"
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_17PyObjectHashTable_31__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_PyObjectHashTable___setstate_cyt, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__429)); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_7) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":10
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_complex128(const complex128_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
  __pyx_t_35 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_35.memview)) __PYX_ERR(5, 10, __pyx_L1_error)
  __pyx_k__40 = __pyx_t_35;
  __pyx_t_35.memview = NULL;
  __pyx_t_35.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":71
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_complex128(const complex128_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
  __pyx_t_36 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_36.memview)) __PYX_ERR(5, 71, __pyx_L1_error)
  __pyx_k__42 = __pyx_t_36;
  __pyx_t_36.memview = NULL;
  __pyx_t_36.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":204
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_complex64(const complex64_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
  __pyx_t_37 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_37.memview)) __PYX_ERR(5, 204, __pyx_L1_error)
  __pyx_k__44 = __pyx_t_37;
  __pyx_t_37.memview = NULL;
  __pyx_t_37.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":265
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_complex64(const complex64_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
  __pyx_t_38 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_38.memview)) __PYX_ERR(5, 265, __pyx_L1_error)
  __pyx_k__45 = __pyx_t_38;
  __pyx_t_38.memview = NULL;
  __pyx_t_38.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":398
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_float64(const float64_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
  __pyx_t_39 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_39.memview)) __PYX_ERR(5, 398, __pyx_L1_error)
  __pyx_k__46 = __pyx_t_39;
  __pyx_t_39.memview = NULL;
  __pyx_t_39.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":459
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_float64(const float64_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
  __pyx_t_40 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_40.memview)) __PYX_ERR(5, 459, __pyx_L1_error)
  __pyx_k__47 = __pyx_t_40;
  __pyx_t_40.memview = NULL;
  __pyx_t_40.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":592
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_float32(const float32_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
  __pyx_t_41 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_41.memview)) __PYX_ERR(5, 592, __pyx_L1_error)
  __pyx_k__48 = __pyx_t_41;
  __pyx_t_41.memview = NULL;
  __pyx_t_41.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":653
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_float32(const float32_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
  __pyx_t_42 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_42.memview)) __PYX_ERR(5, 653, __pyx_L1_error)
  __pyx_k__49 = __pyx_t_42;
  __pyx_t_42.memview = NULL;
  __pyx_t_42.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":786
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_uint64(const uint64_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
  __pyx_t_43 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_43.memview)) __PYX_ERR(5, 786, __pyx_L1_error)
  __pyx_k__50 = __pyx_t_43;
  __pyx_t_43.memview = NULL;
  __pyx_t_43.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":847
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_uint64(const uint64_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
  __pyx_t_44 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_44.memview)) __PYX_ERR(5, 847, __pyx_L1_error)
  __pyx_k__51 = __pyx_t_44;
  __pyx_t_44.memview = NULL;
  __pyx_t_44.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":980
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_uint32(const uint32_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
  __pyx_t_45 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_45.memview)) __PYX_ERR(5, 980, __pyx_L1_error)
  __pyx_k__52 = __pyx_t_45;
  __pyx_t_45.memview = NULL;
  __pyx_t_45.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":1041
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_uint32(const uint32_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
  __pyx_t_46 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_46.memview)) __PYX_ERR(5, 1041, __pyx_L1_error)
  __pyx_k__53 = __pyx_t_46;
  __pyx_t_46.memview = NULL;
  __pyx_t_46.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":1174
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_uint16(const uint16_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
  __pyx_t_47 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_47.memview)) __PYX_ERR(5, 1174, __pyx_L1_error)
  __pyx_k__54 = __pyx_t_47;
  __pyx_t_47.memview = NULL;
  __pyx_t_47.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":1235
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_uint16(const uint16_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
  __pyx_t_48 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_48.memview)) __PYX_ERR(5, 1235, __pyx_L1_error)
  __pyx_k__55 = __pyx_t_48;
  __pyx_t_48.memview = NULL;
  __pyx_t_48.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":1368
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_uint8(const uint8_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
  __pyx_t_49 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_49.memview)) __PYX_ERR(5, 1368, __pyx_L1_error)
  __pyx_k__56 = __pyx_t_49;
  __pyx_t_49.memview = NULL;
  __pyx_t_49.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":1429
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_uint8(const uint8_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
  __pyx_t_50 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_50.memview)) __PYX_ERR(5, 1429, __pyx_L1_error)
  __pyx_k__57 = __pyx_t_50;
  __pyx_t_50.memview = NULL;
  __pyx_t_50.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":1562
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_object(ndarray[object] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
  __pyx_t_51 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_51.memview)) __PYX_ERR(5, 1562, __pyx_L1_error)
  __pyx_k__58 = __pyx_t_51;
  __pyx_t_51.memview = NULL;
  __pyx_t_51.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":1619
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_object(ndarray[object] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
  __pyx_t_52 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_52.memview)) __PYX_ERR(5, 1619, __pyx_L1_error)
  __pyx_k__60 = __pyx_t_52;
  __pyx_t_52.memview = NULL;
  __pyx_t_52.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":1752
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_int64(const int64_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
  __pyx_t_53 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_53.memview)) __PYX_ERR(5, 1752, __pyx_L1_error)
  __pyx_k__61 = __pyx_t_53;
  __pyx_t_53.memview = NULL;
  __pyx_t_53.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":1813
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_int64(const int64_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
  __pyx_t_54 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_54.memview)) __PYX_ERR(5, 1813, __pyx_L1_error)
  __pyx_k__62 = __pyx_t_54;
  __pyx_t_54.memview = NULL;
  __pyx_t_54.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":1946
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_int32(const int32_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
  __pyx_t_55 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_55.memview)) __PYX_ERR(5, 1946, __pyx_L1_error)
  __pyx_k__63 = __pyx_t_55;
  __pyx_t_55.memview = NULL;
  __pyx_t_55.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2007
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_int32(const int32_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
  __pyx_t_56 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_56.memview)) __PYX_ERR(5, 2007, __pyx_L1_error)
  __pyx_k__64 = __pyx_t_56;
  __pyx_t_56.memview = NULL;
  __pyx_t_56.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2140
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_int16(const int16_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
  __pyx_t_57 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_57.memview)) __PYX_ERR(5, 2140, __pyx_L1_error)
  __pyx_k__65 = __pyx_t_57;
  __pyx_t_57.memview = NULL;
  __pyx_t_57.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2201
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_int16(const int16_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
  __pyx_t_58 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_58.memview)) __PYX_ERR(5, 2201, __pyx_L1_error)
  __pyx_k__66 = __pyx_t_58;
  __pyx_t_58.memview = NULL;
  __pyx_t_58.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2334
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef value_count_int8(const int8_t[:] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         Py_ssize_t i = 0
 */
  __pyx_t_59 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_59.memview)) __PYX_ERR(5, 2334, __pyx_L1_error)
  __pyx_k__67 = __pyx_t_59;
  __pyx_t_59.memview = NULL;
  __pyx_t_59.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2395
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * cdef duplicated_int8(const int8_t[:] values, object keep='first', const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     cdef:
 *         int ret = 0
 */
  __pyx_t_60 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_60.memview)) __PYX_ERR(5, 2395, __pyx_L1_error)
  __pyx_k__68 = __pyx_t_60;
  __pyx_t_60.memview = NULL;
  __pyx_t_60.data = NULL;

  /* "pandas/_libs/hashtable_func_helper.pxi":2532
 * 
 * 
 * cpdef value_count(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return value_count_object(values, dropna, mask=mask)
 */
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_k__73 = __pyx_t_61;
  __pyx_t_61.memview = NULL;
  __pyx_t_61.data = NULL;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_t_7 = __pyx_memoryview_fromslice(__pyx_t_61, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_61, 1);
  __pyx_t_61.memview = NULL; __pyx_t_61.data = NULL;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_0__pyx_mdef_6pandas_5_libs_9hashtable_21__pyx_fuse_0value_count, 0, __pyx_n_s_pyx_fuse_0value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__432)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_value_count, __pyx_t_7) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_k__74 = __pyx_t_61;
  __pyx_t_61.memview = NULL;
  __pyx_t_61.data = NULL;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_t_7 = __pyx_memoryview_fromslice(__pyx_t_61, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_61, 1);
  __pyx_t_61.memview = NULL; __pyx_t_61.data = NULL;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_1__pyx_mdef_6pandas_5_libs_9hashtable_23__pyx_fuse_1value_count, 0, __pyx_n_s_pyx_fuse_1value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__433)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_value_count, __pyx_t_7) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_k__75 = __pyx_t_61;
  __pyx_t_61.memview = NULL;
  __pyx_t_61.data = NULL;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_t_7 = __pyx_memoryview_fromslice(__pyx_t_61, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_61, 1);
  __pyx_t_61.memview = NULL; __pyx_t_61.data = NULL;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_2__pyx_mdef_6pandas_5_libs_9hashtable_25__pyx_fuse_2value_count, 0, __pyx_n_s_pyx_fuse_2value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__434)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_value_count, __pyx_t_7) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_k__76 = __pyx_t_61;
  __pyx_t_61.memview = NULL;
  __pyx_t_61.data = NULL;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_t_7 = __pyx_memoryview_fromslice(__pyx_t_61, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_61, 1);
  __pyx_t_61.memview = NULL; __pyx_t_61.data = NULL;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_3__pyx_mdef_6pandas_5_libs_9hashtable_27__pyx_fuse_3value_count, 0, __pyx_n_s_pyx_fuse_3value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__435)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_value_count, __pyx_t_7) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_k__77 = __pyx_t_61;
  __pyx_t_61.memview = NULL;
  __pyx_t_61.data = NULL;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_t_7 = __pyx_memoryview_fromslice(__pyx_t_61, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_61, 1);
  __pyx_t_61.memview = NULL; __pyx_t_61.data = NULL;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_4__pyx_mdef_6pandas_5_libs_9hashtable_29__pyx_fuse_4value_count, 0, __pyx_n_s_pyx_fuse_4value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__436)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_value_count, __pyx_t_7) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_k__78 = __pyx_t_61;
  __pyx_t_61.memview = NULL;
  __pyx_t_61.data = NULL;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_t_7 = __pyx_memoryview_fromslice(__pyx_t_61, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_61, 1);
  __pyx_t_61.memview = NULL; __pyx_t_61.data = NULL;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_5__pyx_mdef_6pandas_5_libs_9hashtable_31__pyx_fuse_5value_count, 0, __pyx_n_s_pyx_fuse_5value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__437)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_value_count, __pyx_t_7) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_k__79 = __pyx_t_61;
  __pyx_t_61.memview = NULL;
  __pyx_t_61.data = NULL;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_t_7 = __pyx_memoryview_fromslice(__pyx_t_61, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_61, 1);
  __pyx_t_61.memview = NULL; __pyx_t_61.data = NULL;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_6__pyx_mdef_6pandas_5_libs_9hashtable_33__pyx_fuse_6value_count, 0, __pyx_n_s_pyx_fuse_6value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__438)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_value_count, __pyx_t_7) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_k__80 = __pyx_t_61;
  __pyx_t_61.memview = NULL;
  __pyx_t_61.data = NULL;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_t_7 = __pyx_memoryview_fromslice(__pyx_t_61, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_61, 1);
  __pyx_t_61.memview = NULL; __pyx_t_61.data = NULL;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_7__pyx_mdef_6pandas_5_libs_9hashtable_35__pyx_fuse_7value_count, 0, __pyx_n_s_pyx_fuse_7value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__439)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_value_count, __pyx_t_7) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_k__81 = __pyx_t_61;
  __pyx_t_61.memview = NULL;
  __pyx_t_61.data = NULL;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_t_7 = __pyx_memoryview_fromslice(__pyx_t_61, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_61, 1);
  __pyx_t_61.memview = NULL; __pyx_t_61.data = NULL;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_8__pyx_mdef_6pandas_5_libs_9hashtable_37__pyx_fuse_8value_count, 0, __pyx_n_s_pyx_fuse_8value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__440)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_value_count, __pyx_t_7) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_k__82 = __pyx_t_61;
  __pyx_t_61.memview = NULL;
  __pyx_t_61.data = NULL;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_t_7 = __pyx_memoryview_fromslice(__pyx_t_61, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_61, 1);
  __pyx_t_61.memview = NULL; __pyx_t_61.data = NULL;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_9__pyx_mdef_6pandas_5_libs_9hashtable_39__pyx_fuse_9value_count, 0, __pyx_n_s_pyx_fuse_9value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__441)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_value_count, __pyx_t_7) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_k__83 = __pyx_t_61;
  __pyx_t_61.memview = NULL;
  __pyx_t_61.data = NULL;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_t_7 = __pyx_memoryview_fromslice(__pyx_t_61, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_61, 1);
  __pyx_t_61.memview = NULL; __pyx_t_61.data = NULL;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_10__pyx_mdef_6pandas_5_libs_9hashtable_41__pyx_fuse_10value_count, 0, __pyx_n_s_pyx_fuse_10value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__442)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_value_count, __pyx_t_7) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_k__84 = __pyx_t_61;
  __pyx_t_61.memview = NULL;
  __pyx_t_61.data = NULL;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_t_7 = __pyx_memoryview_fromslice(__pyx_t_61, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_61, 1);
  __pyx_t_61.memview = NULL; __pyx_t_61.data = NULL;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_11__pyx_mdef_6pandas_5_libs_9hashtable_43__pyx_fuse_11value_count, 0, __pyx_n_s_pyx_fuse_11value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__443)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_value_count, __pyx_t_7) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_k__85 = __pyx_t_61;
  __pyx_t_61.memview = NULL;
  __pyx_t_61.data = NULL;
  __pyx_t_61 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_61.memview)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_t_7 = __pyx_memoryview_fromslice(__pyx_t_61, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_61, 1);
  __pyx_t_61.memview = NULL; __pyx_t_61.data = NULL;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_7);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error);
  __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_12__pyx_mdef_6pandas_5_libs_9hashtable_45__pyx_fuse_12value_count, 0, __pyx_n_s_pyx_fuse_12value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__444)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_value_count, __pyx_t_7) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyDict_NewPresized(13); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_0__pyx_mdef_6pandas_5_libs_9hashtable_21__pyx_fuse_0value_count, 0, __pyx_n_s_pyx_fuse_0value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__431)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__401);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_int8_t, __pyx_t_5) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_1__pyx_mdef_6pandas_5_libs_9hashtable_23__pyx_fuse_1value_count, 0, __pyx_n_s_pyx_fuse_1value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__431)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__401);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_int16_t, __pyx_t_5) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_2__pyx_mdef_6pandas_5_libs_9hashtable_25__pyx_fuse_2value_count, 0, __pyx_n_s_pyx_fuse_2value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__431)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__401);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_int32_t, __pyx_t_5) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_3__pyx_mdef_6pandas_5_libs_9hashtable_27__pyx_fuse_3value_count, 0, __pyx_n_s_pyx_fuse_3value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__431)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__401);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_int64_t, __pyx_t_5) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_4__pyx_mdef_6pandas_5_libs_9hashtable_29__pyx_fuse_4value_count, 0, __pyx_n_s_pyx_fuse_4value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__431)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__401);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_uint8_t, __pyx_t_5) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_5__pyx_mdef_6pandas_5_libs_9hashtable_31__pyx_fuse_5value_count, 0, __pyx_n_s_pyx_fuse_5value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__431)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__401);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_uint16_t, __pyx_t_5) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_6__pyx_mdef_6pandas_5_libs_9hashtable_33__pyx_fuse_6value_count, 0, __pyx_n_s_pyx_fuse_6value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__431)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__401);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_uint32_t, __pyx_t_5) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_7__pyx_mdef_6pandas_5_libs_9hashtable_35__pyx_fuse_7value_count, 0, __pyx_n_s_pyx_fuse_7value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__431)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__401);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_uint64_t, __pyx_t_5) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_8__pyx_mdef_6pandas_5_libs_9hashtable_37__pyx_fuse_8value_count, 0, __pyx_n_s_pyx_fuse_8value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__431)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__401);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_float32_t, __pyx_t_5) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_9__pyx_mdef_6pandas_5_libs_9hashtable_39__pyx_fuse_9value_count, 0, __pyx_n_s_pyx_fuse_9value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__431)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__401);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_float64_t, __pyx_t_5) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_10__pyx_mdef_6pandas_5_libs_9hashtable_41__pyx_fuse_10value_count, 0, __pyx_n_s_pyx_fuse_10value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__431)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__401);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_object, __pyx_t_5) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_11__pyx_mdef_6pandas_5_libs_9hashtable_43__pyx_fuse_11value_count, 0, __pyx_n_s_pyx_fuse_11value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__431)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__401);
  if (PyDict_SetItem(__pyx_t_7, __pyx_kp_s_double_complex, __pyx_t_5) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_12__pyx_mdef_6pandas_5_libs_9hashtable_45__pyx_fuse_12value_count, 0, __pyx_n_s_pyx_fuse_12value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__431)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__401);
  if (PyDict_SetItem(__pyx_t_7, __pyx_kp_s_float_complex, __pyx_t_5) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_7value_count, 0, __pyx_n_s_value_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__431)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_5, sizeof(__pyx_defaults), 1)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_Defaults(__pyx_defaults, __pyx_t_5)->__pyx_arg__fused_sigindex = __pyx_t_4;
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__401);
  ((__pyx_FusedFunctionObject *) __pyx_t_5)->__signatures__ = __pyx_t_7;
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_value_count, __pyx_t_5) < 0) __PYX_ERR(5, 2532, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2568
 * 
 * 
 * cpdef duplicated(ndarray[htfunc_t] values, object keep="first", const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return duplicated_object(values, keep, mask=mask)
 */
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_k__87 = __pyx_t_62;
  __pyx_t_62.memview = NULL;
  __pyx_t_62.data = NULL;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_62, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_62, 1);
  __pyx_t_62.memview = NULL; __pyx_t_62.data = NULL;
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_n_u_first);
  __Pyx_GIVEREF(__pyx_n_u_first);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_n_u_first)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_fuse_0__pyx_mdef_6pandas_5_libs_9hashtable_49__pyx_fuse_0duplicated, 0, __pyx_n_s_pyx_fuse_0duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__448)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_duplicated, __pyx_t_5) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_k__88 = __pyx_t_62;
  __pyx_t_62.memview = NULL;
  __pyx_t_62.data = NULL;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_62, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_62, 1);
  __pyx_t_62.memview = NULL; __pyx_t_62.data = NULL;
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_n_u_first);
  __Pyx_GIVEREF(__pyx_n_u_first);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_n_u_first)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_fuse_1__pyx_mdef_6pandas_5_libs_9hashtable_51__pyx_fuse_1duplicated, 0, __pyx_n_s_pyx_fuse_1duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__449)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_duplicated, __pyx_t_5) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_k__89 = __pyx_t_62;
  __pyx_t_62.memview = NULL;
  __pyx_t_62.data = NULL;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_62, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_62, 1);
  __pyx_t_62.memview = NULL; __pyx_t_62.data = NULL;
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_n_u_first);
  __Pyx_GIVEREF(__pyx_n_u_first);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_n_u_first)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_fuse_2__pyx_mdef_6pandas_5_libs_9hashtable_53__pyx_fuse_2duplicated, 0, __pyx_n_s_pyx_fuse_2duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__450)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_duplicated, __pyx_t_5) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_k__90 = __pyx_t_62;
  __pyx_t_62.memview = NULL;
  __pyx_t_62.data = NULL;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_62, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_62, 1);
  __pyx_t_62.memview = NULL; __pyx_t_62.data = NULL;
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_n_u_first);
  __Pyx_GIVEREF(__pyx_n_u_first);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_n_u_first)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_fuse_3__pyx_mdef_6pandas_5_libs_9hashtable_55__pyx_fuse_3duplicated, 0, __pyx_n_s_pyx_fuse_3duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__451)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_duplicated, __pyx_t_5) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_k__91 = __pyx_t_62;
  __pyx_t_62.memview = NULL;
  __pyx_t_62.data = NULL;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_62, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_62, 1);
  __pyx_t_62.memview = NULL; __pyx_t_62.data = NULL;
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_n_u_first);
  __Pyx_GIVEREF(__pyx_n_u_first);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_n_u_first)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_fuse_4__pyx_mdef_6pandas_5_libs_9hashtable_57__pyx_fuse_4duplicated, 0, __pyx_n_s_pyx_fuse_4duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__452)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_duplicated, __pyx_t_5) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_k__92 = __pyx_t_62;
  __pyx_t_62.memview = NULL;
  __pyx_t_62.data = NULL;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_62, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_62, 1);
  __pyx_t_62.memview = NULL; __pyx_t_62.data = NULL;
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_n_u_first);
  __Pyx_GIVEREF(__pyx_n_u_first);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_n_u_first)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_fuse_5__pyx_mdef_6pandas_5_libs_9hashtable_59__pyx_fuse_5duplicated, 0, __pyx_n_s_pyx_fuse_5duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__453)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_duplicated, __pyx_t_5) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_k__93 = __pyx_t_62;
  __pyx_t_62.memview = NULL;
  __pyx_t_62.data = NULL;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_62, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_62, 1);
  __pyx_t_62.memview = NULL; __pyx_t_62.data = NULL;
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_n_u_first);
  __Pyx_GIVEREF(__pyx_n_u_first);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_n_u_first)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_fuse_6__pyx_mdef_6pandas_5_libs_9hashtable_61__pyx_fuse_6duplicated, 0, __pyx_n_s_pyx_fuse_6duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__454)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_duplicated, __pyx_t_5) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_k__94 = __pyx_t_62;
  __pyx_t_62.memview = NULL;
  __pyx_t_62.data = NULL;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_62, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_62, 1);
  __pyx_t_62.memview = NULL; __pyx_t_62.data = NULL;
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_n_u_first);
  __Pyx_GIVEREF(__pyx_n_u_first);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_n_u_first)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_fuse_7__pyx_mdef_6pandas_5_libs_9hashtable_63__pyx_fuse_7duplicated, 0, __pyx_n_s_pyx_fuse_7duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__455)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_duplicated, __pyx_t_5) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_k__95 = __pyx_t_62;
  __pyx_t_62.memview = NULL;
  __pyx_t_62.data = NULL;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_62, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_62, 1);
  __pyx_t_62.memview = NULL; __pyx_t_62.data = NULL;
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_n_u_first);
  __Pyx_GIVEREF(__pyx_n_u_first);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_n_u_first)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_fuse_8__pyx_mdef_6pandas_5_libs_9hashtable_65__pyx_fuse_8duplicated, 0, __pyx_n_s_pyx_fuse_8duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__456)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_duplicated, __pyx_t_5) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_k__96 = __pyx_t_62;
  __pyx_t_62.memview = NULL;
  __pyx_t_62.data = NULL;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_62, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_62, 1);
  __pyx_t_62.memview = NULL; __pyx_t_62.data = NULL;
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_n_u_first);
  __Pyx_GIVEREF(__pyx_n_u_first);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_n_u_first)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_fuse_9__pyx_mdef_6pandas_5_libs_9hashtable_67__pyx_fuse_9duplicated, 0, __pyx_n_s_pyx_fuse_9duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__457)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_duplicated, __pyx_t_5) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_k__97 = __pyx_t_62;
  __pyx_t_62.memview = NULL;
  __pyx_t_62.data = NULL;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_62, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_62, 1);
  __pyx_t_62.memview = NULL; __pyx_t_62.data = NULL;
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_n_u_first);
  __Pyx_GIVEREF(__pyx_n_u_first);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_n_u_first)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_fuse_10__pyx_mdef_6pandas_5_libs_9hashtable_69__pyx_fuse_10duplicated, 0, __pyx_n_s_pyx_fuse_10duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__458)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_duplicated, __pyx_t_5) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_k__98 = __pyx_t_62;
  __pyx_t_62.memview = NULL;
  __pyx_t_62.data = NULL;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_62, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_62, 1);
  __pyx_t_62.memview = NULL; __pyx_t_62.data = NULL;
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_n_u_first);
  __Pyx_GIVEREF(__pyx_n_u_first);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_n_u_first)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_fuse_11__pyx_mdef_6pandas_5_libs_9hashtable_71__pyx_fuse_11duplicated, 0, __pyx_n_s_pyx_fuse_11duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__459)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_duplicated, __pyx_t_5) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_k__99 = __pyx_t_62;
  __pyx_t_62.memview = NULL;
  __pyx_t_62.data = NULL;
  __pyx_t_62 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_62.memview)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_t_5 = __pyx_memoryview_fromslice(__pyx_t_62, 1, (PyObject *(*)(char *)) __pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__, (int (*)(char *, PyObject *)) NULL, 0);; if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_62, 1);
  __pyx_t_62.memview = NULL; __pyx_t_62.data = NULL;
  __pyx_t_7 = PyTuple_New(2); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_INCREF(__pyx_n_u_first);
  __Pyx_GIVEREF(__pyx_n_u_first);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_n_u_first)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __Pyx_GIVEREF(__pyx_t_5);
  if (__Pyx_PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error);
  __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_fuse_12__pyx_mdef_6pandas_5_libs_9hashtable_73__pyx_fuse_12duplicated, 0, __pyx_n_s_pyx_fuse_12duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__460)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_duplicated, __pyx_t_5) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyDict_NewPresized(13); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_0__pyx_mdef_6pandas_5_libs_9hashtable_49__pyx_fuse_0duplicated, 0, __pyx_n_s_pyx_fuse_0duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__447)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__445);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_int8_t, __pyx_t_7) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_1__pyx_mdef_6pandas_5_libs_9hashtable_51__pyx_fuse_1duplicated, 0, __pyx_n_s_pyx_fuse_1duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__447)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__445);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_int16_t, __pyx_t_7) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_2__pyx_mdef_6pandas_5_libs_9hashtable_53__pyx_fuse_2duplicated, 0, __pyx_n_s_pyx_fuse_2duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__447)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__445);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_int32_t, __pyx_t_7) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_3__pyx_mdef_6pandas_5_libs_9hashtable_55__pyx_fuse_3duplicated, 0, __pyx_n_s_pyx_fuse_3duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__447)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__445);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_int64_t, __pyx_t_7) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_4__pyx_mdef_6pandas_5_libs_9hashtable_57__pyx_fuse_4duplicated, 0, __pyx_n_s_pyx_fuse_4duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__447)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__445);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_uint8_t, __pyx_t_7) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_5__pyx_mdef_6pandas_5_libs_9hashtable_59__pyx_fuse_5duplicated, 0, __pyx_n_s_pyx_fuse_5duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__447)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__445);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_uint16_t, __pyx_t_7) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_6__pyx_mdef_6pandas_5_libs_9hashtable_61__pyx_fuse_6duplicated, 0, __pyx_n_s_pyx_fuse_6duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__447)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__445);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_uint32_t, __pyx_t_7) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_7__pyx_mdef_6pandas_5_libs_9hashtable_63__pyx_fuse_7duplicated, 0, __pyx_n_s_pyx_fuse_7duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__447)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__445);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_uint64_t, __pyx_t_7) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_8__pyx_mdef_6pandas_5_libs_9hashtable_65__pyx_fuse_8duplicated, 0, __pyx_n_s_pyx_fuse_8duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__447)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__445);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_float32_t, __pyx_t_7) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_9__pyx_mdef_6pandas_5_libs_9hashtable_67__pyx_fuse_9duplicated, 0, __pyx_n_s_pyx_fuse_9duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__447)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__445);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_float64_t, __pyx_t_7) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_10__pyx_mdef_6pandas_5_libs_9hashtable_69__pyx_fuse_10duplicated, 0, __pyx_n_s_pyx_fuse_10duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__447)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__445);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_object, __pyx_t_7) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_11__pyx_mdef_6pandas_5_libs_9hashtable_71__pyx_fuse_11duplicated, 0, __pyx_n_s_pyx_fuse_11duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__447)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__445);
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_s_double_complex, __pyx_t_7) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_12__pyx_mdef_6pandas_5_libs_9hashtable_73__pyx_fuse_12duplicated, 0, __pyx_n_s_pyx_fuse_12duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__447)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__445);
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_s_float_complex, __pyx_t_7) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_9duplicated, 0, __pyx_n_s_duplicated, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__447)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_7, sizeof(__pyx_defaults1), 1)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_Defaults(__pyx_defaults1, __pyx_t_7)->__pyx_arg__fused_sigindex = __pyx_t_4;
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__445);
  ((__pyx_FusedFunctionObject *) __pyx_t_7)->__signatures__ = __pyx_t_5;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_duplicated, __pyx_t_7) < 0) __PYX_ERR(5, 2568, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2604
 * 
 * 
 * cpdef ismember(ndarray[htfunc_t] arr, ndarray[htfunc_t] values):             # <<<<<<<<<<<<<<
 *     if htfunc_t is object:
 *         return ismember_object(arr, values)
 */
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_0__pyx_mdef_6pandas_5_libs_9hashtable_77__pyx_fuse_0ismember, 0, __pyx_n_s_pyx_fuse_0ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__463)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ismember, __pyx_t_7) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_1__pyx_mdef_6pandas_5_libs_9hashtable_79__pyx_fuse_1ismember, 0, __pyx_n_s_pyx_fuse_1ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__464)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ismember, __pyx_t_7) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_2__pyx_mdef_6pandas_5_libs_9hashtable_81__pyx_fuse_2ismember, 0, __pyx_n_s_pyx_fuse_2ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__465)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ismember, __pyx_t_7) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_3__pyx_mdef_6pandas_5_libs_9hashtable_83__pyx_fuse_3ismember, 0, __pyx_n_s_pyx_fuse_3ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__466)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ismember, __pyx_t_7) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_4__pyx_mdef_6pandas_5_libs_9hashtable_85__pyx_fuse_4ismember, 0, __pyx_n_s_pyx_fuse_4ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__467)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ismember, __pyx_t_7) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_5__pyx_mdef_6pandas_5_libs_9hashtable_87__pyx_fuse_5ismember, 0, __pyx_n_s_pyx_fuse_5ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__468)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ismember, __pyx_t_7) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_6__pyx_mdef_6pandas_5_libs_9hashtable_89__pyx_fuse_6ismember, 0, __pyx_n_s_pyx_fuse_6ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__469)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ismember, __pyx_t_7) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_7__pyx_mdef_6pandas_5_libs_9hashtable_91__pyx_fuse_7ismember, 0, __pyx_n_s_pyx_fuse_7ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__470)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ismember, __pyx_t_7) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_8__pyx_mdef_6pandas_5_libs_9hashtable_93__pyx_fuse_8ismember, 0, __pyx_n_s_pyx_fuse_8ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__471)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ismember, __pyx_t_7) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_9__pyx_mdef_6pandas_5_libs_9hashtable_95__pyx_fuse_9ismember, 0, __pyx_n_s_pyx_fuse_9ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__472)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ismember, __pyx_t_7) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_10__pyx_mdef_6pandas_5_libs_9hashtable_97__pyx_fuse_10ismember, 0, __pyx_n_s_pyx_fuse_10ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__473)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ismember, __pyx_t_7) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_11__pyx_mdef_6pandas_5_libs_9hashtable_99__pyx_fuse_11ismember, 0, __pyx_n_s_pyx_fuse_11ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__474)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ismember, __pyx_t_7) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_fuse_12__pyx_mdef_6pandas_5_libs_9hashtable_101__pyx_fuse_12ismember, 0, __pyx_n_s_pyx_fuse_12ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__475)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ismember, __pyx_t_7) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyDict_NewPresized(13); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_0__pyx_mdef_6pandas_5_libs_9hashtable_77__pyx_fuse_0ismember, 0, __pyx_n_s_pyx_fuse_0ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__462)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_empty_tuple);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_int8_t, __pyx_t_5) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_1__pyx_mdef_6pandas_5_libs_9hashtable_79__pyx_fuse_1ismember, 0, __pyx_n_s_pyx_fuse_1ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__462)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_empty_tuple);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_int16_t, __pyx_t_5) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_2__pyx_mdef_6pandas_5_libs_9hashtable_81__pyx_fuse_2ismember, 0, __pyx_n_s_pyx_fuse_2ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__462)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_empty_tuple);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_int32_t, __pyx_t_5) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_3__pyx_mdef_6pandas_5_libs_9hashtable_83__pyx_fuse_3ismember, 0, __pyx_n_s_pyx_fuse_3ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__462)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_empty_tuple);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_int64_t, __pyx_t_5) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_4__pyx_mdef_6pandas_5_libs_9hashtable_85__pyx_fuse_4ismember, 0, __pyx_n_s_pyx_fuse_4ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__462)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_empty_tuple);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_uint8_t, __pyx_t_5) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_5__pyx_mdef_6pandas_5_libs_9hashtable_87__pyx_fuse_5ismember, 0, __pyx_n_s_pyx_fuse_5ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__462)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_empty_tuple);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_uint16_t, __pyx_t_5) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_6__pyx_mdef_6pandas_5_libs_9hashtable_89__pyx_fuse_6ismember, 0, __pyx_n_s_pyx_fuse_6ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__462)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_empty_tuple);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_uint32_t, __pyx_t_5) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_7__pyx_mdef_6pandas_5_libs_9hashtable_91__pyx_fuse_7ismember, 0, __pyx_n_s_pyx_fuse_7ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__462)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_empty_tuple);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_uint64_t, __pyx_t_5) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_8__pyx_mdef_6pandas_5_libs_9hashtable_93__pyx_fuse_8ismember, 0, __pyx_n_s_pyx_fuse_8ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__462)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_empty_tuple);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_float32_t, __pyx_t_5) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_9__pyx_mdef_6pandas_5_libs_9hashtable_95__pyx_fuse_9ismember, 0, __pyx_n_s_pyx_fuse_9ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__462)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_empty_tuple);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_float64_t, __pyx_t_5) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_10__pyx_mdef_6pandas_5_libs_9hashtable_97__pyx_fuse_10ismember, 0, __pyx_n_s_pyx_fuse_10ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__462)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_empty_tuple);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_object, __pyx_t_5) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_11__pyx_mdef_6pandas_5_libs_9hashtable_99__pyx_fuse_11ismember, 0, __pyx_n_s_pyx_fuse_11ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__462)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_empty_tuple);
  if (PyDict_SetItem(__pyx_t_7, __pyx_kp_s_double_complex, __pyx_t_5) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_fuse_12__pyx_mdef_6pandas_5_libs_9hashtable_101__pyx_fuse_12ismember, 0, __pyx_n_s_pyx_fuse_12ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__462)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_empty_tuple);
  if (PyDict_SetItem(__pyx_t_7, __pyx_kp_s_float_complex, __pyx_t_5) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __pyx_FusedFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_11ismember, 0, __pyx_n_s_ismember, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__462)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_5, sizeof(__pyx_defaults2), 1)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_Defaults(__pyx_defaults2, __pyx_t_5)->__pyx_arg__fused_sigindex = __pyx_t_4;
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_empty_tuple);
  ((__pyx_FusedFunctionObject *) __pyx_t_5)->__signatures__ = __pyx_t_7;
  __Pyx_GIVEREF(__pyx_t_7);
  __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_ismember, __pyx_t_5) < 0) __PYX_ERR(5, 2604, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(13); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_0__pyx_mdef_6pandas_5_libs_9hashtable_105mode, 0, __pyx_n_s_mode, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__477)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_7, sizeof(__pyx_defaults17), 0)) __PYX_ERR(5, 2640, __pyx_L1_error)

  /* "pandas/_libs/hashtable_func_helper.pxi":2642
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     # TODO(cython3): use const htfunct_t[:]
 * 
 */
  __pyx_t_63 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_63.memview)) __PYX_ERR(5, 2642, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults17, __pyx_t_7)->__pyx_arg_mask = __pyx_t_63;
  __pyx_t_63.memview = NULL;
  __pyx_t_63.data = NULL;
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__401);
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_7, __pyx_pf_6pandas_5_libs_9hashtable_158__defaults__);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_int8_t, __pyx_t_7) < 0) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_1__pyx_mdef_6pandas_5_libs_9hashtable_107mode, 0, __pyx_n_s_mode, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__477)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_7, sizeof(__pyx_defaults18), 0)) __PYX_ERR(5, 2640, __pyx_L1_error)

  /* "pandas/_libs/hashtable_func_helper.pxi":2642
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     # TODO(cython3): use const htfunct_t[:]
 * 
 */
  __pyx_t_63 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_63.memview)) __PYX_ERR(5, 2642, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults18, __pyx_t_7)->__pyx_arg_mask = __pyx_t_63;
  __pyx_t_63.memview = NULL;
  __pyx_t_63.data = NULL;
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__401);
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_7, __pyx_pf_6pandas_5_libs_9hashtable_160__defaults__);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_int16_t, __pyx_t_7) < 0) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_2__pyx_mdef_6pandas_5_libs_9hashtable_109mode, 0, __pyx_n_s_mode, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__477)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_7, sizeof(__pyx_defaults19), 0)) __PYX_ERR(5, 2640, __pyx_L1_error)

  /* "pandas/_libs/hashtable_func_helper.pxi":2642
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     # TODO(cython3): use const htfunct_t[:]
 * 
 */
  __pyx_t_63 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_63.memview)) __PYX_ERR(5, 2642, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults19, __pyx_t_7)->__pyx_arg_mask = __pyx_t_63;
  __pyx_t_63.memview = NULL;
  __pyx_t_63.data = NULL;
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__401);
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_7, __pyx_pf_6pandas_5_libs_9hashtable_162__defaults__);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_int32_t, __pyx_t_7) < 0) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_3__pyx_mdef_6pandas_5_libs_9hashtable_111mode, 0, __pyx_n_s_mode, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__477)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_7, sizeof(__pyx_defaults20), 0)) __PYX_ERR(5, 2640, __pyx_L1_error)

  /* "pandas/_libs/hashtable_func_helper.pxi":2642
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     # TODO(cython3): use const htfunct_t[:]
 * 
 */
  __pyx_t_63 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_63.memview)) __PYX_ERR(5, 2642, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults20, __pyx_t_7)->__pyx_arg_mask = __pyx_t_63;
  __pyx_t_63.memview = NULL;
  __pyx_t_63.data = NULL;
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__401);
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_7, __pyx_pf_6pandas_5_libs_9hashtable_164__defaults__);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_int64_t, __pyx_t_7) < 0) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_4__pyx_mdef_6pandas_5_libs_9hashtable_113mode, 0, __pyx_n_s_mode, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__477)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_7, sizeof(__pyx_defaults21), 0)) __PYX_ERR(5, 2640, __pyx_L1_error)

  /* "pandas/_libs/hashtable_func_helper.pxi":2642
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     # TODO(cython3): use const htfunct_t[:]
 * 
 */
  __pyx_t_63 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_63.memview)) __PYX_ERR(5, 2642, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults21, __pyx_t_7)->__pyx_arg_mask = __pyx_t_63;
  __pyx_t_63.memview = NULL;
  __pyx_t_63.data = NULL;
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__401);
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_7, __pyx_pf_6pandas_5_libs_9hashtable_166__defaults__);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_uint8_t, __pyx_t_7) < 0) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_5__pyx_mdef_6pandas_5_libs_9hashtable_115mode, 0, __pyx_n_s_mode, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__477)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_7, sizeof(__pyx_defaults22), 0)) __PYX_ERR(5, 2640, __pyx_L1_error)

  /* "pandas/_libs/hashtable_func_helper.pxi":2642
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     # TODO(cython3): use const htfunct_t[:]
 * 
 */
  __pyx_t_63 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_63.memview)) __PYX_ERR(5, 2642, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults22, __pyx_t_7)->__pyx_arg_mask = __pyx_t_63;
  __pyx_t_63.memview = NULL;
  __pyx_t_63.data = NULL;
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__401);
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_7, __pyx_pf_6pandas_5_libs_9hashtable_168__defaults__);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_uint16_t, __pyx_t_7) < 0) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_6__pyx_mdef_6pandas_5_libs_9hashtable_117mode, 0, __pyx_n_s_mode, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__477)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_7, sizeof(__pyx_defaults23), 0)) __PYX_ERR(5, 2640, __pyx_L1_error)

  /* "pandas/_libs/hashtable_func_helper.pxi":2642
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     # TODO(cython3): use const htfunct_t[:]
 * 
 */
  __pyx_t_63 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_63.memview)) __PYX_ERR(5, 2642, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults23, __pyx_t_7)->__pyx_arg_mask = __pyx_t_63;
  __pyx_t_63.memview = NULL;
  __pyx_t_63.data = NULL;
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__401);
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_7, __pyx_pf_6pandas_5_libs_9hashtable_170__defaults__);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_uint32_t, __pyx_t_7) < 0) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_7__pyx_mdef_6pandas_5_libs_9hashtable_119mode, 0, __pyx_n_s_mode, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__477)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_7, sizeof(__pyx_defaults24), 0)) __PYX_ERR(5, 2640, __pyx_L1_error)

  /* "pandas/_libs/hashtable_func_helper.pxi":2642
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     # TODO(cython3): use const htfunct_t[:]
 * 
 */
  __pyx_t_63 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_63.memview)) __PYX_ERR(5, 2642, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults24, __pyx_t_7)->__pyx_arg_mask = __pyx_t_63;
  __pyx_t_63.memview = NULL;
  __pyx_t_63.data = NULL;
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__401);
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_7, __pyx_pf_6pandas_5_libs_9hashtable_172__defaults__);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_uint64_t, __pyx_t_7) < 0) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_8__pyx_mdef_6pandas_5_libs_9hashtable_121mode, 0, __pyx_n_s_mode, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__477)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_7, sizeof(__pyx_defaults25), 0)) __PYX_ERR(5, 2640, __pyx_L1_error)

  /* "pandas/_libs/hashtable_func_helper.pxi":2642
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     # TODO(cython3): use const htfunct_t[:]
 * 
 */
  __pyx_t_63 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_63.memview)) __PYX_ERR(5, 2642, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults25, __pyx_t_7)->__pyx_arg_mask = __pyx_t_63;
  __pyx_t_63.memview = NULL;
  __pyx_t_63.data = NULL;
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__401);
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_7, __pyx_pf_6pandas_5_libs_9hashtable_174__defaults__);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_float32_t, __pyx_t_7) < 0) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_9__pyx_mdef_6pandas_5_libs_9hashtable_123mode, 0, __pyx_n_s_mode, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__477)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_7, sizeof(__pyx_defaults26), 0)) __PYX_ERR(5, 2640, __pyx_L1_error)

  /* "pandas/_libs/hashtable_func_helper.pxi":2642
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     # TODO(cython3): use const htfunct_t[:]
 * 
 */
  __pyx_t_63 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_63.memview)) __PYX_ERR(5, 2642, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults26, __pyx_t_7)->__pyx_arg_mask = __pyx_t_63;
  __pyx_t_63.memview = NULL;
  __pyx_t_63.data = NULL;
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__401);
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_7, __pyx_pf_6pandas_5_libs_9hashtable_176__defaults__);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_float64_t, __pyx_t_7) < 0) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_10__pyx_mdef_6pandas_5_libs_9hashtable_125mode, 0, __pyx_n_s_mode, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__477)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_7, sizeof(__pyx_defaults27), 0)) __PYX_ERR(5, 2640, __pyx_L1_error)

  /* "pandas/_libs/hashtable_func_helper.pxi":2642
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     # TODO(cython3): use const htfunct_t[:]
 * 
 */
  __pyx_t_63 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_63.memview)) __PYX_ERR(5, 2642, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults27, __pyx_t_7)->__pyx_arg_mask = __pyx_t_63;
  __pyx_t_63.memview = NULL;
  __pyx_t_63.data = NULL;
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__401);
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_7, __pyx_pf_6pandas_5_libs_9hashtable_178__defaults__);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_object, __pyx_t_7) < 0) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_11__pyx_mdef_6pandas_5_libs_9hashtable_127mode, 0, __pyx_n_s_mode, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__477)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_7, sizeof(__pyx_defaults28), 0)) __PYX_ERR(5, 2640, __pyx_L1_error)

  /* "pandas/_libs/hashtable_func_helper.pxi":2642
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     # TODO(cython3): use const htfunct_t[:]
 * 
 */
  __pyx_t_63 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_63.memview)) __PYX_ERR(5, 2642, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults28, __pyx_t_7)->__pyx_arg_mask = __pyx_t_63;
  __pyx_t_63.memview = NULL;
  __pyx_t_63.data = NULL;
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__401);
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_7, __pyx_pf_6pandas_5_libs_9hashtable_180__defaults__);
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_s_double_complex, __pyx_t_7) < 0) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_fuse_12__pyx_mdef_6pandas_5_libs_9hashtable_129mode, 0, __pyx_n_s_mode, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__477)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_7, sizeof(__pyx_defaults29), 0)) __PYX_ERR(5, 2640, __pyx_L1_error)

  /* "pandas/_libs/hashtable_func_helper.pxi":2642
 * @cython.wraparound(False)
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):             # <<<<<<<<<<<<<<
 *     # TODO(cython3): use const htfunct_t[:]
 * 
 */
  __pyx_t_63 = __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(Py_None, 0); if (unlikely(!__pyx_t_63.memview)) __PYX_ERR(5, 2642, __pyx_L1_error)
  __Pyx_CyFunction_Defaults(__pyx_defaults29, __pyx_t_7)->__pyx_arg_mask = __pyx_t_63;
  __pyx_t_63.memview = NULL;
  __pyx_t_63.data = NULL;
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__401);
  __Pyx_CyFunction_SetDefaultsGetter(__pyx_t_7, __pyx_pf_6pandas_5_libs_9hashtable_182__defaults__);
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_s_float_complex, __pyx_t_7) < 0) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2640
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def mode(ndarray[htfunc_t] values, bint dropna, const uint8_t[:] mask=None):
 */
  __pyx_t_7 = __pyx_FusedFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_13mode, 0, __pyx_n_s_mode, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__477)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (!__Pyx_CyFunction_InitDefaults(__pyx_t_7, sizeof(__pyx_defaults3), 1)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __pyx_t_4 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_4)) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_CyFunction_Defaults(__pyx_defaults3, __pyx_t_7)->__pyx_arg__fused_sigindex = __pyx_t_4;
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_7, __pyx_tuple__401);
  ((__pyx_FusedFunctionObject *) __pyx_t_7)->__signatures__ = __pyx_t_5;
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_mode, __pyx_t_7) < 0) __PYX_ERR(5, 2640, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2688
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def _unique_label_indices_int64(const int64_t[:] labels) -> ndarray:
 */
  __pyx_t_7 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  if (PyDict_SetItem(__pyx_t_7, __pyx_n_s_return, __pyx_n_s_ndarray) < 0) __PYX_ERR(5, 2688, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_15_unique_label_indices_int64, 0, __pyx_n_s_unique_label_indices_int64, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__479)); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2688, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_unique_label_indices_int64, __pyx_t_5) < 0) __PYX_ERR(5, 2688, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable_func_helper.pxi":2723
 * 
 * 
 * @cython.wraparound(False)             # <<<<<<<<<<<<<<
 * @cython.boundscheck(False)
 * def _unique_label_indices_int32(const int32_t[:] labels) -> ndarray:
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(5, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_n_s_ndarray) < 0) __PYX_ERR(5, 2723, __pyx_L1_error)
  __pyx_t_7 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_17_unique_label_indices_int32, 0, __pyx_n_s_unique_label_indices_int32, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__480)); if (unlikely(!__pyx_t_7)) __PYX_ERR(5, 2723, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_7, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_unique_label_indices_int32, __pyx_t_7) < 0) __PYX_ERR(5, 2723, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pandas/_libs/hashtable.pyx":62
 * 
 * # map derived hash-map types onto basic hash-map types:
 * if np.dtype(np.intp) == np.dtype(np.int64):             # <<<<<<<<<<<<<<
 *     IntpHashTable = Int64HashTable
 *     unique_label_indices = _unique_label_indices_int64
 */
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_dtype); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_intp); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_dtype); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_np); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_64 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_int64); if (unlikely(!__pyx_t_64)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_64);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_CallOneArg(__pyx_t_5, __pyx_t_64); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_64); __pyx_t_64 = 0;
  __pyx_t_64 = PyObject_RichCompare(__pyx_t_7, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_64); if (unlikely(!__pyx_t_64)) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_64); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 62, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_64); __pyx_t_64 = 0;
  if (__pyx_t_6) {

    /* "pandas/_libs/hashtable.pyx":63
 * # map derived hash-map types onto basic hash-map types:
 * if np.dtype(np.intp) == np.dtype(np.int64):
 *     IntpHashTable = Int64HashTable             # <<<<<<<<<<<<<<
 *     unique_label_indices = _unique_label_indices_int64
 * elif np.dtype(np.intp) == np.dtype(np.int32):
 */
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_IntpHashTable, ((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int64HashTable)) < 0) __PYX_ERR(0, 63, __pyx_L1_error)

    /* "pandas/_libs/hashtable.pyx":64
 * if np.dtype(np.intp) == np.dtype(np.int64):
 *     IntpHashTable = Int64HashTable
 *     unique_label_indices = _unique_label_indices_int64             # <<<<<<<<<<<<<<
 * elif np.dtype(np.intp) == np.dtype(np.int32):
 *     IntpHashTable = Int32HashTable
 */
    __Pyx_GetModuleGlobalName(__pyx_t_64, __pyx_n_s_unique_label_indices_int64); if (unlikely(!__pyx_t_64)) __PYX_ERR(0, 64, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_64);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_unique_label_indices, __pyx_t_64) < 0) __PYX_ERR(0, 64, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_64); __pyx_t_64 = 0;

    /* "pandas/_libs/hashtable.pyx":62
 * 
 * # map derived hash-map types onto basic hash-map types:
 * if np.dtype(np.intp) == np.dtype(np.int64):             # <<<<<<<<<<<<<<
 *     IntpHashTable = Int64HashTable
 *     unique_label_indices = _unique_label_indices_int64
 */
    goto __pyx_L30;
  }

  /* "pandas/_libs/hashtable.pyx":65
 *     IntpHashTable = Int64HashTable
 *     unique_label_indices = _unique_label_indices_int64
 * elif np.dtype(np.intp) == np.dtype(np.int32):             # <<<<<<<<<<<<<<
 *     IntpHashTable = Int32HashTable
 *     unique_label_indices = _unique_label_indices_int32
 */
  __Pyx_GetModuleGlobalName(__pyx_t_64, __pyx_n_s_np); if (unlikely(!__pyx_t_64)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_64);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_64, __pyx_n_s_dtype); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_64); __pyx_t_64 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_64, __pyx_n_s_np); if (unlikely(!__pyx_t_64)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_64);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_64, __pyx_n_s_intp); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_64); __pyx_t_64 = 0;
  __pyx_t_64 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_7); if (unlikely(!__pyx_t_64)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_64);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_dtype); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_GetModuleGlobalName(__pyx_t_7, __pyx_n_s_np); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_int32); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyObject_RichCompare(__pyx_t_64, __pyx_t_7, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_64); __pyx_t_64 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely((__pyx_t_6 < 0))) __PYX_ERR(0, 65, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (likely(__pyx_t_6)) {

    /* "pandas/_libs/hashtable.pyx":66
 *     unique_label_indices = _unique_label_indices_int64
 * elif np.dtype(np.intp) == np.dtype(np.int32):
 *     IntpHashTable = Int32HashTable             # <<<<<<<<<<<<<<
 *     unique_label_indices = _unique_label_indices_int32
 * else:
 */
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_IntpHashTable, ((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Int32HashTable)) < 0) __PYX_ERR(0, 66, __pyx_L1_error)

    /* "pandas/_libs/hashtable.pyx":67
 * elif np.dtype(np.intp) == np.dtype(np.int32):
 *     IntpHashTable = Int32HashTable
 *     unique_label_indices = _unique_label_indices_int32             # <<<<<<<<<<<<<<
 * else:
 *     raise ValueError(np.dtype(np.intp))
 */
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_unique_label_indices_int32); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 67, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    if (PyDict_SetItem(__pyx_d, __pyx_n_s_unique_label_indices, __pyx_t_5) < 0) __PYX_ERR(0, 67, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "pandas/_libs/hashtable.pyx":65
 *     IntpHashTable = Int64HashTable
 *     unique_label_indices = _unique_label_indices_int64
 * elif np.dtype(np.intp) == np.dtype(np.int32):             # <<<<<<<<<<<<<<
 *     IntpHashTable = Int32HashTable
 *     unique_label_indices = _unique_label_indices_int32
 */
    goto __pyx_L30;
  }

  /* "pandas/_libs/hashtable.pyx":69
 *     unique_label_indices = _unique_label_indices_int32
 * else:
 *     raise ValueError(np.dtype(np.intp))             # <<<<<<<<<<<<<<
 * 
 * 
 */
  /*else*/ {
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_dtype); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_np); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_64 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_intp); if (unlikely(!__pyx_t_64)) __PYX_ERR(0, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_64);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_64); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(__pyx_t_64); __pyx_t_64 = 0;
    __pyx_t_64 = __Pyx_PyObject_CallOneArg(__pyx_builtin_ValueError, __pyx_t_5); if (unlikely(!__pyx_t_64)) __PYX_ERR(0, 69, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_64);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_Raise(__pyx_t_64, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_64); __pyx_t_64 = 0;
    __PYX_ERR(0, 69, __pyx_L1_error)
  }
  __pyx_L30:;

  /* "pandas/_libs/hashtable.pyx":79
 *         self.count = 0
 * 
 *     def get_count(self) -> int:             # <<<<<<<<<<<<<<
 *         return self.count
 * 
 */
  __pyx_t_64 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_64)) __PYX_ERR(0, 79, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_64);
  if (PyDict_SetItem(__pyx_t_64, __pyx_n_s_return, __pyx_n_s_int) < 0) __PYX_ERR(0, 79, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_10Factorizer_3get_count, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Factorizer_get_count, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__481)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 79, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_64);
  __Pyx_DECREF(__pyx_t_64); __pyx_t_64 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer, __pyx_n_s_get_count, __pyx_t_5) < 0) __PYX_ERR(0, 79, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer);

  /* "pandas/_libs/hashtable.pyx":82
 *         return self.count
 * 
 *     def factorize(self, values, na_sentinel=-1, na_value=None, mask=None) -> np.ndarray:             # <<<<<<<<<<<<<<
 *         raise NotImplementedError
 * 
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 82, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_return, __pyx_kp_s_np_ndarray) < 0) __PYX_ERR(0, 82, __pyx_L1_error)
  __pyx_t_64 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_10Factorizer_5factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Factorizer_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__483)); if (unlikely(!__pyx_t_64)) __PYX_ERR(0, 82, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_64);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_64, __pyx_tuple__199);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_64, __pyx_t_5);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer, __pyx_n_s_factorize, __pyx_t_64) < 0) __PYX_ERR(0, 82, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_64); __pyx_t_64 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_Factorizer);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_64 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_10Factorizer_7__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Factorizer___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__484)); if (unlikely(!__pyx_t_64)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_64);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_64) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_64); __pyx_t_64 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_64 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_10Factorizer_9__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_Factorizer___setstate_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__485)); if (unlikely(!__pyx_t_64)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_64);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_64) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_64); __pyx_t_64 = 0;

  /* "pandas/_libs/hashtable.pyx":95
 *         self.uniques = ObjectVector()
 * 
 *     def factorize(             # <<<<<<<<<<<<<<
 *         self, ndarray[object] values, na_sentinel=-1, na_value=None, mask=None
 *     ) -> np.ndarray:
 */
  __pyx_t_64 = __Pyx_PyDict_NewPresized(1); if (unlikely(!__pyx_t_64)) __PYX_ERR(0, 95, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_64);
  if (PyDict_SetItem(__pyx_t_64, __pyx_n_s_return, __pyx_kp_s_np_ndarray) < 0) __PYX_ERR(0, 95, __pyx_L1_error)
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16ObjectFactorizer_3factorize, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_ObjectFactorizer_factorize, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__486)); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 95, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_CyFunction_SetDefaultsTuple(__pyx_t_5, __pyx_tuple__199);
  __Pyx_CyFunction_SetAnnotationsDict(__pyx_t_5, __pyx_t_64);
  __Pyx_DECREF(__pyx_t_64); __pyx_t_64 = 0;
  if (__Pyx_SetItemOnTypeDict((PyObject *)__pyx_ptype_6pandas_5_libs_9hashtable_ObjectFactorizer, __pyx_n_s_factorize, __pyx_t_5) < 0) __PYX_ERR(0, 95, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  PyType_Modified(__pyx_ptype_6pandas_5_libs_9hashtable_ObjectFactorizer);

  /* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16ObjectFactorizer_5__reduce_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_ObjectFactorizer___reduce_cython, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__487)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_reduce_cython, __pyx_t_5) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":3
 * def __reduce_cython__(self):
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     raise TypeError, "no default __reduce__ due to non-trivial __cinit__"
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_16ObjectFactorizer_7__setstate_cython__, __Pyx_CYFUNCTION_CCLASS, __pyx_n_s_ObjectFactorizer___setstate_cyth, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__488)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_setstate_cython, __pyx_t_5) < 0) __PYX_ERR(1, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "(tree fragment)":1
 * def __pyx_unpickle_HashTable(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_5 = __Pyx_CyFunction_New(&__pyx_mdef_6pandas_5_libs_9hashtable_19__pyx_unpickle_HashTable, 0, __pyx_n_s_pyx_unpickle_HashTable, NULL, __pyx_n_s_pandas__libs_hashtable, __pyx_d, ((PyObject *)__pyx_codeobj__489)); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_HashTable, __pyx_t_5) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pandas/_libs/hashtable.pyx":1
 * cimport cython             # <<<<<<<<<<<<<<
 * from cpython.mem cimport (
 *     PyMem_Free,
 */
  __pyx_t_5 = __Pyx_PyDict_NewPresized(13); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_Complex128Factorizer_factorize_l, __pyx_kp_u_Returns_ndarray_intp_t_Examples) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_Float64Factorizer_factorize_line, __pyx_kp_u_Returns_ndarray_intp_t_Examples_2) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_UInt64Factorizer_factorize_line, __pyx_kp_u_Returns_ndarray_intp_t_Examples_3) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_Int64Factorizer_factorize_line_3, __pyx_kp_u_Returns_ndarray_intp_t_Examples_4) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_Complex64Factorizer_factorize_li, __pyx_kp_u_Returns_ndarray_intp_t_Examples_5) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_Float32Factorizer_factorize_line, __pyx_kp_u_Returns_ndarray_intp_t_Examples_6) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_UInt32Factorizer_factorize_line, __pyx_kp_u_Returns_ndarray_intp_t_Examples_7) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_Int32Factorizer_factorize_line_4, __pyx_kp_u_Returns_ndarray_intp_t_Examples_8) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_UInt16Factorizer_factorize_line, __pyx_kp_u_Returns_ndarray_intp_t_Examples_9) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_Int16Factorizer_factorize_line_5, __pyx_kp_u_Returns_ndarray_intp_t_Examples_10) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_UInt8Factorizer_factorize_line_6, __pyx_kp_u_Returns_ndarray_intp_t_Examples_11) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_Int8Factorizer_factorize_line_66, __pyx_kp_u_Returns_ndarray_intp_t_Examples_12) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_t_5, __pyx_kp_u_ObjectFactorizer_factorize_line, __pyx_kp_u_Returns_np_ndarray_np_intp_Exam) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_5) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_7);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_11, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_12, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_13, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_14, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_15, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_16, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_17, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_18, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_19, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_20, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_21, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_22, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_23, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_24, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_25, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_26, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_27, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_28, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_29, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_30, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_31, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_32, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_33, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_34, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_35, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_36, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_37, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_38, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_39, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_40, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_41, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_42, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_43, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_44, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_45, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_46, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_47, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_48, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_49, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_50, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_51, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_52, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_53, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_54, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_55, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_56, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_57, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_58, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_59, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_60, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_61, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_62, 1);
  __PYX_XCLEAR_MEMVIEW(&__pyx_t_63, 1);
  __Pyx_XDECREF(__pyx_t_64);
  if (__pyx_m) {
    if (__pyx_d && stringtab_initialized) {
      __Pyx_AddTraceback("init pandas._libs.hashtable", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    #if !CYTHON_USE_MODULE_STATE
    Py_CLEAR(__pyx_m);
    #else
    Py_DECREF(__pyx_m);
    if (pystate_addmodule_run) {
      PyObject *tp, *value, *tb;
      PyErr_Fetch(&tp, &value, &tb);
      PyState_RemoveModule(&__pyx_moduledef);
      PyErr_Restore(tp, value, tb);
    }
    #endif
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init pandas._libs.hashtable");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}
/* #### Code section: cleanup_globals ### */
/* #### Code section: cleanup_module ### */
/* #### Code section: main_method ### */
/* #### Code section: utility_code_pragmas ### */
#ifdef _MSC_VER
#pragma warning( push )
/* Warning 4127: conditional expression is constant
 * Cython uses constant conditional expressions to allow in inline functions to be optimized at
 * compile-time, so this warning is not useful
 */
#pragma warning( disable : 4127 )
#endif



/* #### Code section: utility_code_def ### */

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    int result;
    PyObject *exc_type;
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *current_exception = tstate->current_exception;
    if (unlikely(!current_exception)) return 0;
    exc_type = (PyObject*) Py_TYPE(current_exception);
    if (exc_type == err) return 1;
#else
    exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
#endif
    #if CYTHON_AVOID_BORROWED_REFS
    Py_INCREF(exc_type);
    #endif
    if (unlikely(PyTuple_Check(err))) {
        result = __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    } else {
        result = __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
    }
    #if CYTHON_AVOID_BORROWED_REFS
    Py_DECREF(exc_type);
    #endif
    return result;
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject *tmp_value;
    assert(type == NULL || (value != NULL && type == (PyObject*) Py_TYPE(value)));
    if (value) {
        #if CYTHON_COMPILING_IN_CPYTHON
        if (unlikely(((PyBaseExceptionObject*) value)->traceback != tb))
        #endif
            PyException_SetTraceback(value, tb);
    }
    tmp_value = tstate->current_exception;
    tstate->current_exception = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
#else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
#if PY_VERSION_HEX >= 0x030C00A6
    PyObject* exc_value;
    exc_value = tstate->current_exception;
    tstate->current_exception = 0;
    *value = exc_value;
    *type = NULL;
    *tb = NULL;
    if (exc_value) {
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        #if CYTHON_COMPILING_IN_CPYTHON
        *tb = ((PyBaseExceptionObject*) exc_value)->traceback;
        Py_XINCREF(*tb);
        #else
        *tb = PyException_GetTraceback(exc_value);
        #endif
    }
#else
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#endif
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* PyObjectGetAttrStrNoError */
#if __PYX_LIMITED_VERSION_HEX < 0x030d00A1
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
    (void) PyObject_GetOptionalAttr(obj, attr_name, &result);
    return result;
#else
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
#endif
}

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStrNoError(__pyx_b, name);
    if (unlikely(!result) && !PyErr_Occurred()) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* TupleAndListFromArray */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE void __Pyx_copy_object_array(PyObject *const *CYTHON_RESTRICT src, PyObject** CYTHON_RESTRICT dest, Py_ssize_t length) {
    PyObject *v;
    Py_ssize_t i;
    for (i = 0; i < length; i++) {
        v = dest[i] = src[i];
        Py_INCREF(v);
    }
}
static CYTHON_INLINE PyObject *
__Pyx_PyTuple_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        Py_INCREF(__pyx_empty_tuple);
        return __pyx_empty_tuple;
    }
    res = PyTuple_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyTupleObject*)res)->ob_item, n);
    return res;
}
static CYTHON_INLINE PyObject *
__Pyx_PyList_FromArray(PyObject *const *src, Py_ssize_t n)
{
    PyObject *res;
    if (n <= 0) {
        return PyList_New(0);
    }
    res = PyList_New(n);
    if (unlikely(res == NULL)) return NULL;
    __Pyx_copy_object_array(src, ((PyListObject*)res)->ob_item, n);
    return res;
}
#endif

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS && (PY_VERSION_HEX < 0x030B0000)
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* fastcall */
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE PyObject * __Pyx_GetKwValue_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues, PyObject *s)
{
    Py_ssize_t i, n = PyTuple_GET_SIZE(kwnames);
    for (i = 0; i < n; i++)
    {
        if (s == PyTuple_GET_ITEM(kwnames, i)) return kwvalues[i];
    }
    for (i = 0; i < n; i++)
    {
        int eq = __Pyx_PyUnicode_Equals(s, PyTuple_GET_ITEM(kwnames, i), Py_EQ);
        if (unlikely(eq != 0)) {
            if (unlikely(eq < 0)) return NULL;
            return kwvalues[i];
        }
    }
    return NULL;
}
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030d0000
CYTHON_UNUSED static PyObject *__Pyx_KwargsAsDict_FASTCALL(PyObject *kwnames, PyObject *const *kwvalues) {
    Py_ssize_t i, nkwargs = PyTuple_GET_SIZE(kwnames);
    PyObject *dict;
    dict = PyDict_New();
    if (unlikely(!dict))
        return NULL;
    for (i=0; i<nkwargs; i++) {
        PyObject *key = PyTuple_GET_ITEM(kwnames, i);
        if (unlikely(PyDict_SetItem(dict, key, kwvalues[i]) < 0))
            goto bad;
    }
    return dict;
bad:
    Py_DECREF(dict);
    return NULL;
}
#endif
#endif

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject *const *kwvalues,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    int kwds_is_tuple = CYTHON_METH_FASTCALL && likely(PyTuple_Check(kwds));
    while (1) {
        Py_XDECREF(key); key = NULL;
        Py_XDECREF(value); value = NULL;
        if (kwds_is_tuple) {
            Py_ssize_t size;
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(kwds);
#else
            size = PyTuple_Size(kwds);
            if (size < 0) goto bad;
#endif
            if (pos >= size) break;
#if CYTHON_AVOID_BORROWED_REFS
            key = __Pyx_PySequence_ITEM(kwds, pos);
            if (!key) goto bad;
#elif CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kwds, pos);
#else
            key = PyTuple_GetItem(kwds, pos);
            if (!key) goto bad;
#endif
            value = kwvalues[pos];
            pos++;
        }
        else
        {
            if (!PyDict_Next(kwds, &pos, &key, &value)) break;
#if CYTHON_AVOID_BORROWED_REFS
            Py_INCREF(key);
#endif
        }
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
            Py_INCREF(value);
            Py_DECREF(key);
#endif
            key = NULL;
            value = NULL;
            continue;
        }
#if !CYTHON_AVOID_BORROWED_REFS
        Py_INCREF(key);
#endif
        Py_INCREF(value);
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
                    value = NULL;
#endif
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key)
                );
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
#if CYTHON_AVOID_BORROWED_REFS
                    value = NULL;
#endif
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    Py_XDECREF(key);
    Py_XDECREF(value);
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    Py_XDECREF(key);
    Py_XDECREF(value);
    return -1;
}

/* ArgTypeTest */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    __Pyx_TypeName type_name;
    __Pyx_TypeName obj_type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    type_name = __Pyx_PyType_GetName(type);
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected " __Pyx_FMT_TYPENAME
        ", got " __Pyx_FMT_TYPENAME ")", name, type_name, obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    __Pyx_PyThreadState_declare
    CYTHON_UNUSED_VAR(cause);
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
      #if PY_VERSION_HEX >= 0x030C00A6
        PyException_SetTraceback(value, tb);
      #elif CYTHON_FAST_THREAD_STATE
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#else
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL && !CYTHON_VECTORCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object"))) {
        return NULL;
    }
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object"))) {
        return NULL;
    }
    #endif
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = Py_TYPE(func)->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    #endif
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = __Pyx_CyOrPyCFunction_GET_FUNCTION(func);
    self = __Pyx_CyOrPyCFunction_GET_SELF(func);
    #if PY_MAJOR_VERSION < 3
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    #else
    if (unlikely(Py_EnterRecursiveCall(" while calling a Python object")))
        return NULL;
    #endif
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectFastCall */
#if PY_VERSION_HEX < 0x03090000 || CYTHON_COMPILING_IN_LIMITED_API
static PyObject* __Pyx_PyObject_FastCall_fallback(PyObject *func, PyObject **args, size_t nargs, PyObject *kwargs) {
    PyObject *argstuple;
    PyObject *result = 0;
    size_t i;
    argstuple = PyTuple_New((Py_ssize_t)nargs);
    if (unlikely(!argstuple)) return NULL;
    for (i = 0; i < nargs; i++) {
        Py_INCREF(args[i]);
        if (__Pyx_PyTuple_SET_ITEM(argstuple, (Py_ssize_t)i, args[i]) < 0) goto bad;
    }
    result = __Pyx_PyObject_Call(func, argstuple, kwargs);
  bad:
    Py_DECREF(argstuple);
    return result;
}
#endif
static CYTHON_INLINE PyObject* __Pyx_PyObject_FastCallDict(PyObject *func, PyObject **args, size_t _nargs, PyObject *kwargs) {
    Py_ssize_t nargs = __Pyx_PyVectorcall_NARGS(_nargs);
#if CYTHON_COMPILING_IN_CPYTHON
    if (nargs == 0 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_NOARGS))
            return __Pyx_PyObject_CallMethO(func, NULL);
    }
    else if (nargs == 1 && kwargs == NULL) {
        if (__Pyx_CyOrPyCFunction_Check(func) && likely( __Pyx_CyOrPyCFunction_GET_FLAGS(func) & METH_O))
            return __Pyx_PyObject_CallMethO(func, args[0]);
    }
#endif
    #if PY_VERSION_HEX < 0x030800B1
    #if CYTHON_FAST_PYCCALL
    if (PyCFunction_Check(func)) {
        if (kwargs) {
            return _PyCFunction_FastCallDict(func, args, nargs, kwargs);
        } else {
            return _PyCFunction_FastCallKeywords(func, args, nargs, NULL);
        }
    }
    #if PY_VERSION_HEX >= 0x030700A1
    if (!kwargs && __Pyx_IS_TYPE(func, &PyMethodDescr_Type)) {
        return _PyMethodDescr_FastCallKeywords(func, args, nargs, NULL);
    }
    #endif
    #endif
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs);
    }
    #endif
    #endif
    if (kwargs == NULL) {
        #if CYTHON_VECTORCALL
        #if PY_VERSION_HEX < 0x03090000
        vectorcallfunc f = _PyVectorcall_Function(func);
        #else
        vectorcallfunc f = PyVectorcall_Function(func);
        #endif
        if (f) {
            return f(func, args, (size_t)nargs, NULL);
        }
        #elif defined(__Pyx_CyFunction_USED) && CYTHON_BACKPORT_VECTORCALL
        if (__Pyx_CyFunction_CheckExact(func)) {
            __pyx_vectorcallfunc f = __Pyx_CyFunction_func_vectorcall(func);
            if (f) return f(func, args, (size_t)nargs, NULL);
        }
        #endif
    }
    if (nargs == 0) {
        return __Pyx_PyObject_Call(func, __pyx_empty_tuple, kwargs);
    }
    #if PY_VERSION_HEX >= 0x03090000 && !CYTHON_COMPILING_IN_LIMITED_API
    return PyObject_VectorcallDict(func, args, (size_t)nargs, kwargs);
    #else
    return __Pyx_PyObject_FastCall_fallback(func, args, (size_t)nargs, kwargs);
    #endif
}

/* RaiseUnexpectedTypeError */
static int
__Pyx_RaiseUnexpectedTypeError(const char *expected, PyObject *obj)
{
    __Pyx_TypeName obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError, "Expected %s, got " __Pyx_FMT_TYPENAME,
                 expected, obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return 0;
}

/* CIntToDigits */
static const char DIGIT_PAIRS_10[2*10*10+1] = {
    "00010203040506070809"
    "10111213141516171819"
    "20212223242526272829"
    "30313233343536373839"
    "40414243444546474849"
    "50515253545556575859"
    "60616263646566676869"
    "70717273747576777879"
    "80818283848586878889"
    "90919293949596979899"
};
static const char DIGIT_PAIRS_8[2*8*8+1] = {
    "0001020304050607"
    "1011121314151617"
    "2021222324252627"
    "3031323334353637"
    "4041424344454647"
    "5051525354555657"
    "6061626364656667"
    "7071727374757677"
};
static const char DIGITS_HEX[2*16+1] = {
    "0123456789abcdef"
    "0123456789ABCDEF"
};

/* BuildPyUnicode */
static PyObject* __Pyx_PyUnicode_BuildFromAscii(Py_ssize_t ulength, char* chars, int clength,
                                                int prepend_sign, char padding_char) {
    PyObject *uval;
    Py_ssize_t uoffset = ulength - clength;
#if CYTHON_USE_UNICODE_INTERNALS
    Py_ssize_t i;
#if CYTHON_PEP393_ENABLED
    void *udata;
    uval = PyUnicode_New(ulength, 127);
    if (unlikely(!uval)) return NULL;
    udata = PyUnicode_DATA(uval);
#else
    Py_UNICODE *udata;
    uval = PyUnicode_FromUnicode(NULL, ulength);
    if (unlikely(!uval)) return NULL;
    udata = PyUnicode_AS_UNICODE(uval);
#endif
    if (uoffset > 0) {
        i = 0;
        if (prepend_sign) {
            __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, 0, '-');
            i++;
        }
        for (; i < uoffset; i++) {
            __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, i, padding_char);
        }
    }
    for (i=0; i < clength; i++) {
        __Pyx_PyUnicode_WRITE(PyUnicode_1BYTE_KIND, udata, uoffset+i, chars[i]);
    }
#else
    {
        PyObject *sign = NULL, *padding = NULL;
        uval = NULL;
        if (uoffset > 0) {
            prepend_sign = !!prepend_sign;
            if (uoffset > prepend_sign) {
                padding = PyUnicode_FromOrdinal(padding_char);
                if (likely(padding) && uoffset > prepend_sign + 1) {
                    PyObject *tmp;
                    PyObject *repeat = PyInt_FromSsize_t(uoffset - prepend_sign);
                    if (unlikely(!repeat)) goto done_or_error;
                    tmp = PyNumber_Multiply(padding, repeat);
                    Py_DECREF(repeat);
                    Py_DECREF(padding);
                    padding = tmp;
                }
                if (unlikely(!padding)) goto done_or_error;
            }
            if (prepend_sign) {
                sign = PyUnicode_FromOrdinal('-');
                if (unlikely(!sign)) goto done_or_error;
            }
        }
        uval = PyUnicode_DecodeASCII(chars, clength, NULL);
        if (likely(uval) && padding) {
            PyObject *tmp = PyNumber_Add(padding, uval);
            Py_DECREF(uval);
            uval = tmp;
        }
        if (likely(uval) && sign) {
            PyObject *tmp = PyNumber_Add(sign, uval);
            Py_DECREF(uval);
            uval = tmp;
        }
done_or_error:
        Py_XDECREF(padding);
        Py_XDECREF(sign);
    }
#endif
    return uval;
}

/* CIntToPyUnicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_int(int value, Py_ssize_t width, char padding_char, char format_char) {
    char digits[sizeof(int)*3+2];
    char *dpos, *end = digits + sizeof(int)*3+2;
    const char *hex_digits = DIGITS_HEX;
    Py_ssize_t length, ulength;
    int prepend_sign, last_one_off;
    int remaining;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (format_char == 'X') {
        hex_digits += 16;
        format_char = 'x';
    }
    remaining = value;
    last_one_off = 0;
    dpos = end;
    do {
        int digit_pos;
        switch (format_char) {
        case 'o':
            digit_pos = abs((int)(remaining % (8*8)));
            remaining = (int) (remaining / (8*8));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_8 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 8);
            break;
        case 'd':
            digit_pos = abs((int)(remaining % (10*10)));
            remaining = (int) (remaining / (10*10));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_10 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 10);
            break;
        case 'x':
            *(--dpos) = hex_digits[abs((int)(remaining % 16))];
            remaining = (int) (remaining / 16);
            break;
        default:
            assert(0);
            break;
        }
    } while (unlikely(remaining != 0));
    assert(!last_one_off || *dpos == '0');
    dpos += last_one_off;
    length = end - dpos;
    ulength = length;
    prepend_sign = 0;
    if (!is_unsigned && value <= neg_one) {
        if (padding_char == ' ' || width <= length + 1) {
            *(--dpos) = '-';
            ++length;
        } else {
            prepend_sign = 1;
        }
        ++ulength;
    }
    if (width > ulength) {
        ulength = width;
    }
    if (ulength == 1) {
        return PyUnicode_FromOrdinal(*dpos);
    }
    return __Pyx_PyUnicode_BuildFromAscii(ulength, dpos, (int) length, prepend_sign, padding_char);
}

/* CIntToPyUnicode */
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_From_Py_ssize_t(Py_ssize_t value, Py_ssize_t width, char padding_char, char format_char) {
    char digits[sizeof(Py_ssize_t)*3+2];
    char *dpos, *end = digits + sizeof(Py_ssize_t)*3+2;
    const char *hex_digits = DIGITS_HEX;
    Py_ssize_t length, ulength;
    int prepend_sign, last_one_off;
    Py_ssize_t remaining;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const Py_ssize_t neg_one = (Py_ssize_t) -1, const_zero = (Py_ssize_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (format_char == 'X') {
        hex_digits += 16;
        format_char = 'x';
    }
    remaining = value;
    last_one_off = 0;
    dpos = end;
    do {
        int digit_pos;
        switch (format_char) {
        case 'o':
            digit_pos = abs((int)(remaining % (8*8)));
            remaining = (Py_ssize_t) (remaining / (8*8));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_8 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 8);
            break;
        case 'd':
            digit_pos = abs((int)(remaining % (10*10)));
            remaining = (Py_ssize_t) (remaining / (10*10));
            dpos -= 2;
            memcpy(dpos, DIGIT_PAIRS_10 + digit_pos * 2, 2);
            last_one_off = (digit_pos < 10);
            break;
        case 'x':
            *(--dpos) = hex_digits[abs((int)(remaining % 16))];
            remaining = (Py_ssize_t) (remaining / 16);
            break;
        default:
            assert(0);
            break;
        }
    } while (unlikely(remaining != 0));
    assert(!last_one_off || *dpos == '0');
    dpos += last_one_off;
    length = end - dpos;
    ulength = length;
    prepend_sign = 0;
    if (!is_unsigned && value <= neg_one) {
        if (padding_char == ' ' || width <= length + 1) {
            *(--dpos) = '-';
            ++length;
        } else {
            prepend_sign = 1;
        }
        ++ulength;
    }
    if (width > ulength) {
        ulength = width;
    }
    if (ulength == 1) {
        return PyUnicode_FromOrdinal(*dpos);
    }
    return __Pyx_PyUnicode_BuildFromAscii(ulength, dpos, (int) length, prepend_sign, padding_char);
}

/* JoinPyUnicode */
static PyObject* __Pyx_PyUnicode_Join(PyObject* value_tuple, Py_ssize_t value_count, Py_ssize_t result_ulength,
                                      Py_UCS4 max_char) {
#if CYTHON_USE_UNICODE_INTERNALS && CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    PyObject *result_uval;
    int result_ukind, kind_shift;
    Py_ssize_t i, char_pos;
    void *result_udata;
    CYTHON_MAYBE_UNUSED_VAR(max_char);
#if CYTHON_PEP393_ENABLED
    result_uval = PyUnicode_New(result_ulength, max_char);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = (max_char <= 255) ? PyUnicode_1BYTE_KIND : (max_char <= 65535) ? PyUnicode_2BYTE_KIND : PyUnicode_4BYTE_KIND;
    kind_shift = (result_ukind == PyUnicode_4BYTE_KIND) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_DATA(result_uval);
#else
    result_uval = PyUnicode_FromUnicode(NULL, result_ulength);
    if (unlikely(!result_uval)) return NULL;
    result_ukind = sizeof(Py_UNICODE);
    kind_shift = (result_ukind == 4) ? 2 : result_ukind - 1;
    result_udata = PyUnicode_AS_UNICODE(result_uval);
#endif
    assert(kind_shift == 2 || kind_shift == 1 || kind_shift == 0);
    char_pos = 0;
    for (i=0; i < value_count; i++) {
        int ukind;
        Py_ssize_t ulength;
        void *udata;
        PyObject *uval = PyTuple_GET_ITEM(value_tuple, i);
        if (unlikely(__Pyx_PyUnicode_READY(uval)))
            goto bad;
        ulength = __Pyx_PyUnicode_GET_LENGTH(uval);
        if (unlikely(!ulength))
            continue;
        if (unlikely((PY_SSIZE_T_MAX >> kind_shift) - ulength < char_pos))
            goto overflow;
        ukind = __Pyx_PyUnicode_KIND(uval);
        udata = __Pyx_PyUnicode_DATA(uval);
        if (!CYTHON_PEP393_ENABLED || ukind == result_ukind) {
            memcpy((char *)result_udata + (char_pos << kind_shift), udata, (size_t) (ulength << kind_shift));
        } else {
            #if PY_VERSION_HEX >= 0x030d0000
            if (unlikely(PyUnicode_CopyCharacters(result_uval, char_pos, uval, 0, ulength) < 0)) goto bad;
            #elif CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030300F0 || defined(_PyUnicode_FastCopyCharacters)
            _PyUnicode_FastCopyCharacters(result_uval, char_pos, uval, 0, ulength);
            #else
            Py_ssize_t j;
            for (j=0; j < ulength; j++) {
                Py_UCS4 uchar = __Pyx_PyUnicode_READ(ukind, udata, j);
                __Pyx_PyUnicode_WRITE(result_ukind, result_udata, char_pos+j, uchar);
            }
            #endif
        }
        char_pos += ulength;
    }
    return result_uval;
overflow:
    PyErr_SetString(PyExc_OverflowError, "join() result is too long for a Python string");
bad:
    Py_DECREF(result_uval);
    return NULL;
#else
    CYTHON_UNUSED_VAR(max_char);
    CYTHON_UNUSED_VAR(result_ulength);
    CYTHON_UNUSED_VAR(value_count);
    return PyUnicode_Join(__pyx_empty_unicode, value_tuple);
#endif
}

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (unlikely(!j)) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (mm && mm->mp_subscript) {
            PyObject *r, *key = PyInt_FromSsize_t(i);
            if (unlikely(!key)) return NULL;
            r = mm->mp_subscript(o, key);
            Py_DECREF(key);
            return r;
        }
        if (likely(sm && sm->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return sm->sq_item(o, i);
        }
    }
#else
    if (is_list || !PyMapping_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* PyObjectCallOneArg */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *args[2] = {NULL, arg};
    return __Pyx_PyObject_FastCall(func, args+1, 1 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject *index) {
    PyObject *runerr = NULL;
    Py_ssize_t key_value;
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        __Pyx_TypeName index_type_name = __Pyx_PyType_GetName(Py_TYPE(index));
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError,
            "cannot fit '" __Pyx_FMT_TYPENAME "' into an index-sized integer", index_type_name);
        __Pyx_DECREF_TypeName(index_type_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem_Slow(PyObject *obj, PyObject *key) {
    __Pyx_TypeName obj_type_name;
    if (likely(PyType_Check(obj))) {
        PyObject *meth = __Pyx_PyObject_GetAttrStrNoError(obj, __pyx_n_s_class_getitem);
        if (!meth) {
            PyErr_Clear();
        } else {
            PyObject *result = __Pyx_PyObject_CallOneArg(meth, key);
            Py_DECREF(meth);
            return result;
        }
    }
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
        "'" __Pyx_FMT_TYPENAME "' object is not subscriptable", obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject *key) {
    PyTypeObject *tp = Py_TYPE(obj);
    PyMappingMethods *mm = tp->tp_as_mapping;
    PySequenceMethods *sm = tp->tp_as_sequence;
    if (likely(mm && mm->mp_subscript)) {
        return mm->mp_subscript(obj, key);
    }
    if (likely(sm && sm->sq_item)) {
        return __Pyx_PyObject_GetIndex(obj, key);
    }
    return __Pyx_PyObject_GetItem_Slow(obj, key);
}
#endif

/* KeywordStringCheck */
static int __Pyx_CheckKeywordStrings(
    PyObject *kw,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kw, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    if (CYTHON_METH_FASTCALL && likely(PyTuple_Check(kw))) {
        Py_ssize_t kwsize;
#if CYTHON_ASSUME_SAFE_MACROS
        kwsize = PyTuple_GET_SIZE(kw);
#else
        kwsize = PyTuple_Size(kw);
        if (kwsize < 0) return 0;
#endif
        if (unlikely(kwsize == 0))
            return 1;
        if (!kw_allowed) {
#if CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kw, 0);
#else
            key = PyTuple_GetItem(kw, pos);
            if (!key) return 0;
#endif
            goto invalid_keyword;
        }
#if PY_VERSION_HEX < 0x03090000
        for (pos = 0; pos < kwsize; pos++) {
#if CYTHON_ASSUME_SAFE_MACROS
            key = PyTuple_GET_ITEM(kw, pos);
#else
            key = PyTuple_GetItem(kw, pos);
            if (!key) return 0;
#endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
        }
#endif
        return 1;
    }
    while (PyDict_Next(kw, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if (!kw_allowed && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    #if PY_MAJOR_VERSION < 3
    PyErr_Format(PyExc_TypeError,
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
    PyErr_Format(PyExc_TypeError,
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

/* DivInt[Py_ssize_t] */
static CYTHON_INLINE Py_ssize_t __Pyx_div_Py_ssize_t(Py_ssize_t a, Py_ssize_t b) {
    Py_ssize_t q = a / b;
    Py_ssize_t r = a - q*b;
    q -= ((r != 0) & ((r ^ b) < 0));
    return q;
}

/* GetAttr3 */
#if __PYX_LIMITED_VERSION_HEX < 0x030d00A1
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
#endif
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r;
#if __PYX_LIMITED_VERSION_HEX >= 0x030d00A1
    int res = PyObject_GetOptionalAttr(o, n, &r);
    return (res != 0) ? r : __Pyx_NewRef(d);
#else
  #if CYTHON_USE_TYPE_SLOTS
    if (likely(PyString_Check(n))) {
        r = __Pyx_PyObject_GetAttrStrNoError(o, n);
        if (unlikely(!r) && likely(!PyErr_Occurred())) {
            r = __Pyx_NewRef(d);
        }
        return r;
    }
  #endif
    r = PyObject_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
#endif
}

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && PY_VERSION_HEX < 0x030d0000
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#elif CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(!__pyx_m)) {
        return NULL;
    }
    result = PyObject_GetAttr(__pyx_m, name);
    if (likely(result)) {
        return result;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* RaiseTooManyValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

/* RaiseNeedMoreValuesToUnpack */
static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

/* RaiseNoneIterError */
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    __Pyx_TypeName obj_type_name;
    __Pyx_TypeName type_name;
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    type_name = __Pyx_PyType_GetName(type);
    PyErr_Format(PyExc_TypeError,
                 "Cannot convert " __Pyx_FMT_TYPENAME " to " __Pyx_FMT_TYPENAME,
                 obj_type_name, type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    __Pyx_DECREF_TypeName(type_name);
    return 0;
}

/* GetTopmostException */
#if CYTHON_USE_EXC_INFO_STACK && CYTHON_FAST_THREAD_STATE
static _PyErr_StackItem *
__Pyx_PyErr_GetTopmostException(PyThreadState *tstate)
{
    _PyErr_StackItem *exc_info = tstate->exc_info;
    while ((exc_info->exc_value == NULL || exc_info->exc_value == Py_None) &&
           exc_info->previous_item != NULL)
    {
        exc_info = exc_info->previous_item;
    }
    return exc_info;
}
#endif

/* SaveResetException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSave(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    PyObject *exc_value = exc_info->exc_value;
    if (exc_value == NULL || exc_value == Py_None) {
        *value = NULL;
        *type = NULL;
        *tb = NULL;
    } else {
        *value = exc_value;
        Py_INCREF(*value);
        *type = (PyObject*) Py_TYPE(exc_value);
        Py_INCREF(*type);
        *tb = PyException_GetTraceback(exc_value);
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = __Pyx_PyErr_GetTopmostException(tstate);
    *type = exc_info->exc_type;
    *value = exc_info->exc_value;
    *tb = exc_info->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #else
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
  #endif
}
static CYTHON_INLINE void __Pyx__ExceptionReset(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    PyObject *tmp_value = exc_info->exc_value;
    exc_info->exc_value = value;
    Py_XDECREF(tmp_value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
  #else
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    #if CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = type;
    exc_info->exc_value = value;
    exc_info->exc_traceback = tb;
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
  #endif
}
#endif

/* GetException */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx__GetException(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb)
#else
static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb)
#endif
{
    PyObject *local_type = NULL, *local_value, *local_tb = NULL;
#if CYTHON_FAST_THREAD_STATE
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if PY_VERSION_HEX >= 0x030C00A6
    local_value = tstate->current_exception;
    tstate->current_exception = 0;
    if (likely(local_value)) {
        local_type = (PyObject*) Py_TYPE(local_value);
        Py_INCREF(local_type);
        local_tb = PyException_GetTraceback(local_value);
    }
  #else
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
  #endif
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_FAST_THREAD_STATE && PY_VERSION_HEX >= 0x030C00A6
    if (unlikely(tstate->current_exception))
#elif CYTHON_FAST_THREAD_STATE
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (local_tb) {
        if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
            goto bad;
    }
    #endif
    Py_XINCREF(local_tb);
    Py_XINCREF(local_type);
    Py_XINCREF(local_value);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_FAST_THREAD_STATE
    #if CYTHON_USE_EXC_INFO_STACK
    {
        _PyErr_StackItem *exc_info = tstate->exc_info;
      #if PY_VERSION_HEX >= 0x030B00a4
        tmp_value = exc_info->exc_value;
        exc_info->exc_value = local_value;
        tmp_type = NULL;
        tmp_tb = NULL;
        Py_XDECREF(local_type);
        Py_XDECREF(local_tb);
      #else
        tmp_type = exc_info->exc_type;
        tmp_value = exc_info->exc_value;
        tmp_tb = exc_info->exc_traceback;
        exc_info->exc_type = local_type;
        exc_info->exc_value = local_value;
        exc_info->exc_traceback = local_tb;
      #endif
    }
    #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    #endif
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

/* SwapException */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx__ExceptionSwap(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
  #if CYTHON_USE_EXC_INFO_STACK && PY_VERSION_HEX >= 0x030B00a4
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_value = exc_info->exc_value;
    exc_info->exc_value = *value;
    if (tmp_value == NULL || tmp_value == Py_None) {
        Py_XDECREF(tmp_value);
        tmp_value = NULL;
        tmp_type = NULL;
        tmp_tb = NULL;
    } else {
        tmp_type = (PyObject*) Py_TYPE(tmp_value);
        Py_INCREF(tmp_type);
        #if CYTHON_COMPILING_IN_CPYTHON
        tmp_tb = ((PyBaseExceptionObject*) tmp_value)->traceback;
        Py_XINCREF(tmp_tb);
        #else
        tmp_tb = PyException_GetTraceback(tmp_value);
        #endif
    }
  #elif CYTHON_USE_EXC_INFO_STACK
    _PyErr_StackItem *exc_info = tstate->exc_info;
    tmp_type = exc_info->exc_type;
    tmp_value = exc_info->exc_value;
    tmp_tb = exc_info->exc_traceback;
    exc_info->exc_type = *type;
    exc_info->exc_value = *value;
    exc_info->exc_traceback = *tb;
  #else
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = *type;
    tstate->exc_value = *value;
    tstate->exc_traceback = *tb;
  #endif
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#else
static CYTHON_INLINE void __Pyx_ExceptionSwap(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyErr_GetExcInfo(&tmp_type, &tmp_value, &tmp_tb);
    PyErr_SetExcInfo(*type, *value, *tb);
    *type = tmp_type;
    *value = tmp_value;
    *tb = tmp_tb;
}
#endif

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *module = 0;
    PyObject *empty_dict = 0;
    PyObject *empty_list = 0;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (unlikely(!py_import))
        goto bad;
    if (!from_list) {
        empty_list = PyList_New(0);
        if (unlikely(!empty_list))
            goto bad;
        from_list = empty_list;
    }
    #endif
    empty_dict = PyDict_New();
    if (unlikely(!empty_dict))
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.') != NULL) {
                module = PyImport_ImportModuleLevelObject(
                    name, __pyx_d, empty_dict, from_list, 1);
                if (unlikely(!module)) {
                    if (unlikely(!PyErr_ExceptionMatches(PyExc_ImportError)))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (unlikely(!py_level))
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, __pyx_d, empty_dict, from_list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, __pyx_d, empty_dict, from_list, level);
            #endif
        }
    }
bad:
    Py_XDECREF(empty_dict);
    Py_XDECREF(empty_list);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    return module;
}

/* ImportDottedModule */
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Error(PyObject *name, PyObject *parts_tuple, Py_ssize_t count) {
    PyObject *partial_name = NULL, *slice = NULL, *sep = NULL;
    if (unlikely(PyErr_Occurred())) {
        PyErr_Clear();
    }
    if (likely(PyTuple_GET_SIZE(parts_tuple) == count)) {
        partial_name = name;
    } else {
        slice = PySequence_GetSlice(parts_tuple, 0, count);
        if (unlikely(!slice))
            goto bad;
        sep = PyUnicode_FromStringAndSize(".", 1);
        if (unlikely(!sep))
            goto bad;
        partial_name = PyUnicode_Join(sep, slice);
    }
    PyErr_Format(
#if PY_MAJOR_VERSION < 3
        PyExc_ImportError,
        "No module named '%s'", PyString_AS_STRING(partial_name));
#else
#if PY_VERSION_HEX >= 0x030600B1
        PyExc_ModuleNotFoundError,
#else
        PyExc_ImportError,
#endif
        "No module named '%U'", partial_name);
#endif
bad:
    Py_XDECREF(sep);
    Py_XDECREF(slice);
    Py_XDECREF(partial_name);
    return NULL;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx__ImportDottedModule_Lookup(PyObject *name) {
    PyObject *imported_module;
#if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
    PyObject *modules = PyImport_GetModuleDict();
    if (unlikely(!modules))
        return NULL;
    imported_module = __Pyx_PyDict_GetItemStr(modules, name);
    Py_XINCREF(imported_module);
#else
    imported_module = PyImport_GetModule(name);
#endif
    return imported_module;
}
#endif
#if PY_MAJOR_VERSION >= 3
static PyObject *__Pyx_ImportDottedModule_WalkParts(PyObject *module, PyObject *name, PyObject *parts_tuple) {
    Py_ssize_t i, nparts;
    nparts = PyTuple_GET_SIZE(parts_tuple);
    for (i=1; i < nparts && module; i++) {
        PyObject *part, *submodule;
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        part = PyTuple_GET_ITEM(parts_tuple, i);
#else
        part = PySequence_ITEM(parts_tuple, i);
#endif
        submodule = __Pyx_PyObject_GetAttrStrNoError(module, part);
#if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
        Py_DECREF(part);
#endif
        Py_DECREF(module);
        module = submodule;
    }
    if (unlikely(!module)) {
        return __Pyx__ImportDottedModule_Error(name, parts_tuple, i);
    }
    return module;
}
#endif
static PyObject *__Pyx__ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if PY_MAJOR_VERSION < 3
    PyObject *module, *from_list, *star = __pyx_n_s__3;
    CYTHON_UNUSED_VAR(parts_tuple);
    from_list = PyList_New(1);
    if (unlikely(!from_list))
        return NULL;
    Py_INCREF(star);
    PyList_SET_ITEM(from_list, 0, star);
    module = __Pyx_Import(name, from_list, 0);
    Py_DECREF(from_list);
    return module;
#else
    PyObject *imported_module;
    PyObject *module = __Pyx_Import(name, NULL, 0);
    if (!parts_tuple || unlikely(!module))
        return module;
    imported_module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(imported_module)) {
        Py_DECREF(module);
        return imported_module;
    }
    PyErr_Clear();
    return __Pyx_ImportDottedModule_WalkParts(module, name, parts_tuple);
#endif
}
static PyObject *__Pyx_ImportDottedModule(PyObject *name, PyObject *parts_tuple) {
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030400B1
    PyObject *module = __Pyx__ImportDottedModule_Lookup(name);
    if (likely(module)) {
        PyObject *spec = __Pyx_PyObject_GetAttrStrNoError(module, __pyx_n_s_spec);
        if (likely(spec)) {
            PyObject *unsafe = __Pyx_PyObject_GetAttrStrNoError(spec, __pyx_n_s_initializing);
            if (likely(!unsafe || !__Pyx_PyObject_IsTrue(unsafe))) {
                Py_DECREF(spec);
                spec = NULL;
            }
            Py_XDECREF(unsafe);
        }
        if (likely(!spec)) {
            PyErr_Clear();
            return module;
        }
        Py_DECREF(spec);
        Py_DECREF(module);
    } else if (PyErr_Occurred()) {
        PyErr_Clear();
    }
#endif
    return __Pyx__ImportDottedModule(name, parts_tuple);
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = __Pyx_PyType_GetSlot(a, tp_base, PyTypeObject*);
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
static CYTHON_INLINE int __Pyx_IsAnySubtype2(PyTypeObject *cls, PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (cls == a || cls == b) return 1;
    mro = cls->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            PyObject *base = PyTuple_GET_ITEM(mro, i);
            if (base == (PyObject *)a || base == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(cls, a) || __Pyx_InBases(cls, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    if (exc_type1) {
        return __Pyx_IsAnySubtype2((PyTypeObject*)err, (PyTypeObject*)exc_type1, (PyTypeObject*)exc_type2);
    } else {
        return __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* PySequenceMultiply */
static PyObject* __Pyx_PySequence_Multiply_Generic(PyObject *seq, Py_ssize_t mul) {
    PyObject *result, *pymul = PyInt_FromSsize_t(mul);
    if (unlikely(!pymul))
        return NULL;
    result = PyNumber_Multiply(seq, pymul);
    Py_DECREF(pymul);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PySequence_Multiply(PyObject *seq, Py_ssize_t mul) {
#if CYTHON_USE_TYPE_SLOTS
    PyTypeObject *type = Py_TYPE(seq);
    if (likely(type->tp_as_sequence && type->tp_as_sequence->sq_repeat)) {
        return type->tp_as_sequence->sq_repeat(seq, mul);
    } else
#endif
    {
        return __Pyx_PySequence_Multiply_Generic(seq, mul);
    }
}

/* SetItemInt */
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v) {
    int r;
    if (unlikely(!j)) return -1;
    r = PyObject_SetItem(o, j, v);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v, int is_list,
                                               CYTHON_NCP_UNUSED int wraparound, CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = (!wraparound) ? i : ((likely(i >= 0)) ? i : i + PyList_GET_SIZE(o));
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o)))) {
            PyObject* old = PyList_GET_ITEM(o, n);
            Py_INCREF(v);
            PyList_SET_ITEM(o, n, v);
            Py_DECREF(old);
            return 1;
        }
    } else {
        PyMappingMethods *mm = Py_TYPE(o)->tp_as_mapping;
        PySequenceMethods *sm = Py_TYPE(o)->tp_as_sequence;
        if (mm && mm->mp_ass_subscript) {
            int r;
            PyObject *key = PyInt_FromSsize_t(i);
            if (unlikely(!key)) return -1;
            r = mm->mp_ass_subscript(o, key, v);
            Py_DECREF(key);
            return r;
        }
        if (likely(sm && sm->sq_ass_item)) {
            if (wraparound && unlikely(i < 0) && likely(sm->sq_length)) {
                Py_ssize_t l = sm->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return -1;
                    PyErr_Clear();
                }
            }
            return sm->sq_ass_item(o, i, v);
        }
    }
#else
    if (is_list || !PyMapping_Check(o))
    {
        return PySequence_SetItem(o, i, v);
    }
#endif
    return __Pyx_SetItemInt_Generic(o, PyInt_FromSsize_t(i), v);
}

/* RaiseUnboundLocalError */
static CYTHON_INLINE void __Pyx_RaiseUnboundLocalError(const char *varname) {
    PyErr_Format(PyExc_UnboundLocalError, "local variable '%s' referenced before assignment", varname);
}

/* DivInt[long] */
static CYTHON_INLINE long __Pyx_div_long(long a, long b) {
    long q = a / b;
    long r = a - q*b;
    q -= ((r != 0) & ((r ^ b) < 0));
    return q;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        const char* module_name_str = 0;
        PyObject* module_name = 0;
        PyObject* module_dot = 0;
        PyObject* full_name = 0;
        PyErr_Clear();
        module_name_str = PyModule_GetName(module);
        if (unlikely(!module_name_str)) { goto modbad; }
        module_name = PyUnicode_FromString(module_name_str);
        if (unlikely(!module_name)) { goto modbad; }
        module_dot = PyUnicode_Concat(module_name, __pyx_kp_u__2);
        if (unlikely(!module_dot)) { goto modbad; }
        full_name = PyUnicode_Concat(module_dot, name);
        if (unlikely(!full_name)) { goto modbad; }
        #if PY_VERSION_HEX < 0x030700A1 || (CYTHON_COMPILING_IN_PYPY && PYPY_VERSION_NUM  < 0x07030400)
        {
            PyObject *modules = PyImport_GetModuleDict();
            if (unlikely(!modules))
                goto modbad;
            value = PyObject_GetItem(modules, full_name);
        }
        #else
        value = PyImport_GetModule(full_name);
        #endif
      modbad:
        Py_XDECREF(full_name);
        Py_XDECREF(module_dot);
        Py_XDECREF(module_name);
    }
    if (unlikely(!value)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* HasAttr */
#if __PYX_LIMITED_VERSION_HEX < 0x030d00A1
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (!r) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}
#endif

/* ErrOccurredWithGIL */
static CYTHON_INLINE int __Pyx_ErrOccurredWithGIL(void) {
  int err;
  #ifdef WITH_THREAD
  PyGILState_STATE _save = PyGILState_Ensure();
  #endif
  err = !!PyErr_Occurred();
  #ifdef WITH_THREAD
  PyGILState_Release(_save);
  #endif
  return err;
}

/* BufferIndexError */
static void __Pyx_RaiseBufferIndexError(int axis) {
  PyErr_Format(PyExc_IndexError,
     "Out of bounds on buffer access (axis %d)", axis);
}

/* IsLittleEndian */
static CYTHON_INLINE int __Pyx_Is_Little_Endian(void)
{
  union {
    uint32_t u32;
    uint8_t u8[4];
  } S;
  S.u32 = 0x01020304;
  return S.u8[0] == 4;
}

/* BufferFormatCheck */
static void __Pyx_BufFmt_Init(__Pyx_BufFmt_Context* ctx,
                              __Pyx_BufFmt_StackElem* stack,
                              __Pyx_TypeInfo* type) {
  stack[0].field = &ctx->root;
  stack[0].parent_offset = 0;
  ctx->root.type = type;
  ctx->root.name = "buffer dtype";
  ctx->root.offset = 0;
  ctx->head = stack;
  ctx->head->field = &ctx->root;
  ctx->fmt_offset = 0;
  ctx->head->parent_offset = 0;
  ctx->new_packmode = '@';
  ctx->enc_packmode = '@';
  ctx->new_count = 1;
  ctx->enc_count = 0;
  ctx->enc_type = 0;
  ctx->is_complex = 0;
  ctx->is_valid_array = 0;
  ctx->struct_alignment = 0;
  while (type->typegroup == 'S') {
    ++ctx->head;
    ctx->head->field = type->fields;
    ctx->head->parent_offset = 0;
    type = type->fields->type;
  }
}
static int __Pyx_BufFmt_ParseNumber(const char** ts) {
    int count;
    const char* t = *ts;
    if (*t < '0' || *t > '9') {
      return -1;
    } else {
        count = *t++ - '0';
        while (*t >= '0' && *t <= '9') {
            count *= 10;
            count += *t++ - '0';
        }
    }
    *ts = t;
    return count;
}
static int __Pyx_BufFmt_ExpectNumber(const char **ts) {
    int number = __Pyx_BufFmt_ParseNumber(ts);
    if (number == -1)
        PyErr_Format(PyExc_ValueError,\
                     "Does not understand character buffer dtype format string ('%c')", **ts);
    return number;
}
static void __Pyx_BufFmt_RaiseUnexpectedChar(char ch) {
  PyErr_Format(PyExc_ValueError,
               "Unexpected format string character: '%c'", ch);
}
static const char* __Pyx_BufFmt_DescribeTypeChar(char ch, int is_complex) {
  switch (ch) {
    case '?': return "'bool'";
    case 'c': return "'char'";
    case 'b': return "'signed char'";
    case 'B': return "'unsigned char'";
    case 'h': return "'short'";
    case 'H': return "'unsigned short'";
    case 'i': return "'int'";
    case 'I': return "'unsigned int'";
    case 'l': return "'long'";
    case 'L': return "'unsigned long'";
    case 'q': return "'long long'";
    case 'Q': return "'unsigned long long'";
    case 'f': return (is_complex ? "'complex float'" : "'float'");
    case 'd': return (is_complex ? "'complex double'" : "'double'");
    case 'g': return (is_complex ? "'complex long double'" : "'long double'");
    case 'T': return "a struct";
    case 'O': return "Python object";
    case 'P': return "a pointer";
    case 's': case 'p': return "a string";
    case 0: return "end";
    default: return "unparsable format string";
  }
}
static size_t __Pyx_BufFmt_TypeCharToStandardSize(char ch, int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return 2;
    case 'i': case 'I': case 'l': case 'L': return 4;
    case 'q': case 'Q': return 8;
    case 'f': return (is_complex ? 8 : 4);
    case 'd': return (is_complex ? 16 : 8);
    case 'g': {
      PyErr_SetString(PyExc_ValueError, "Python does not define a standard format string size for long double ('g')..");
      return 0;
    }
    case 'O': case 'P': return sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
static size_t __Pyx_BufFmt_TypeCharToNativeSize(char ch, int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(short);
    case 'i': case 'I': return sizeof(int);
    case 'l': case 'L': return sizeof(long);
    #ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(PY_LONG_LONG);
    #endif
    case 'f': return sizeof(float) * (is_complex ? 2 : 1);
    case 'd': return sizeof(double) * (is_complex ? 2 : 1);
    case 'g': return sizeof(long double) * (is_complex ? 2 : 1);
    case 'O': case 'P': return sizeof(void*);
    default: {
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
  }
}
typedef struct { char c; short x; } __Pyx_st_short;
typedef struct { char c; int x; } __Pyx_st_int;
typedef struct { char c; long x; } __Pyx_st_long;
typedef struct { char c; float x; } __Pyx_st_float;
typedef struct { char c; double x; } __Pyx_st_double;
typedef struct { char c; long double x; } __Pyx_st_longdouble;
typedef struct { char c; void *x; } __Pyx_st_void_p;
#ifdef HAVE_LONG_LONG
typedef struct { char c; PY_LONG_LONG x; } __Pyx_st_longlong;
#endif
static size_t __Pyx_BufFmt_TypeCharToAlignment(char ch, int is_complex) {
  CYTHON_UNUSED_VAR(is_complex);
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(__Pyx_st_short) - sizeof(short);
    case 'i': case 'I': return sizeof(__Pyx_st_int) - sizeof(int);
    case 'l': case 'L': return sizeof(__Pyx_st_long) - sizeof(long);
#ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(__Pyx_st_longlong) - sizeof(PY_LONG_LONG);
#endif
    case 'f': return sizeof(__Pyx_st_float) - sizeof(float);
    case 'd': return sizeof(__Pyx_st_double) - sizeof(double);
    case 'g': return sizeof(__Pyx_st_longdouble) - sizeof(long double);
    case 'P': case 'O': return sizeof(__Pyx_st_void_p) - sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
/* These are for computing the padding at the end of the struct to align
   on the first member of the struct. This will probably the same as above,
   but we don't have any guarantees.
 */
typedef struct { short x; char c; } __Pyx_pad_short;
typedef struct { int x; char c; } __Pyx_pad_int;
typedef struct { long x; char c; } __Pyx_pad_long;
typedef struct { float x; char c; } __Pyx_pad_float;
typedef struct { double x; char c; } __Pyx_pad_double;
typedef struct { long double x; char c; } __Pyx_pad_longdouble;
typedef struct { void *x; char c; } __Pyx_pad_void_p;
#ifdef HAVE_LONG_LONG
typedef struct { PY_LONG_LONG x; char c; } __Pyx_pad_longlong;
#endif
static size_t __Pyx_BufFmt_TypeCharToPadding(char ch, int is_complex) {
  CYTHON_UNUSED_VAR(is_complex);
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(__Pyx_pad_short) - sizeof(short);
    case 'i': case 'I': return sizeof(__Pyx_pad_int) - sizeof(int);
    case 'l': case 'L': return sizeof(__Pyx_pad_long) - sizeof(long);
#ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(__Pyx_pad_longlong) - sizeof(PY_LONG_LONG);
#endif
    case 'f': return sizeof(__Pyx_pad_float) - sizeof(float);
    case 'd': return sizeof(__Pyx_pad_double) - sizeof(double);
    case 'g': return sizeof(__Pyx_pad_longdouble) - sizeof(long double);
    case 'P': case 'O': return sizeof(__Pyx_pad_void_p) - sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
static char __Pyx_BufFmt_TypeCharToGroup(char ch, int is_complex) {
  switch (ch) {
    case 'c':
        return 'H';
    case 'b': case 'h': case 'i':
    case 'l': case 'q': case 's': case 'p':
        return 'I';
    case '?': case 'B': case 'H': case 'I': case 'L': case 'Q':
        return 'U';
    case 'f': case 'd': case 'g':
        return (is_complex ? 'C' : 'R');
    case 'O':
        return 'O';
    case 'P':
        return 'P';
    default: {
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
  }
}
static void __Pyx_BufFmt_RaiseExpected(__Pyx_BufFmt_Context* ctx) {
  if (ctx->head == NULL || ctx->head->field == &ctx->root) {
    const char* expected;
    const char* quote;
    if (ctx->head == NULL) {
      expected = "end";
      quote = "";
    } else {
      expected = ctx->head->field->type->name;
      quote = "'";
    }
    PyErr_Format(PyExc_ValueError,
                 "Buffer dtype mismatch, expected %s%s%s but got %s",
                 quote, expected, quote,
                 __Pyx_BufFmt_DescribeTypeChar(ctx->enc_type, ctx->is_complex));
  } else {
    __Pyx_StructField* field = ctx->head->field;
    __Pyx_StructField* parent = (ctx->head - 1)->field;
    PyErr_Format(PyExc_ValueError,
                 "Buffer dtype mismatch, expected '%s' but got %s in '%s.%s'",
                 field->type->name, __Pyx_BufFmt_DescribeTypeChar(ctx->enc_type, ctx->is_complex),
                 parent->type->name, field->name);
  }
}
static int __Pyx_BufFmt_ProcessTypeChunk(__Pyx_BufFmt_Context* ctx) {
  char group;
  size_t size, offset, arraysize = 1;
  if (ctx->enc_type == 0) return 0;
  if (ctx->head->field->type->arraysize[0]) {
    int i, ndim = 0;
    if (ctx->enc_type == 's' || ctx->enc_type == 'p') {
        ctx->is_valid_array = ctx->head->field->type->ndim == 1;
        ndim = 1;
        if (ctx->enc_count != ctx->head->field->type->arraysize[0]) {
            PyErr_Format(PyExc_ValueError,
                         "Expected a dimension of size %zu, got %zu",
                         ctx->head->field->type->arraysize[0], ctx->enc_count);
            return -1;
        }
    }
    if (!ctx->is_valid_array) {
      PyErr_Format(PyExc_ValueError, "Expected %d dimensions, got %d",
                   ctx->head->field->type->ndim, ndim);
      return -1;
    }
    for (i = 0; i < ctx->head->field->type->ndim; i++) {
      arraysize *= ctx->head->field->type->arraysize[i];
    }
    ctx->is_valid_array = 0;
    ctx->enc_count = 1;
  }
  group = __Pyx_BufFmt_TypeCharToGroup(ctx->enc_type, ctx->is_complex);
  do {
    __Pyx_StructField* field = ctx->head->field;
    __Pyx_TypeInfo* type = field->type;
    if (ctx->enc_packmode == '@' || ctx->enc_packmode == '^') {
      size = __Pyx_BufFmt_TypeCharToNativeSize(ctx->enc_type, ctx->is_complex);
    } else {
      size = __Pyx_BufFmt_TypeCharToStandardSize(ctx->enc_type, ctx->is_complex);
    }
    if (ctx->enc_packmode == '@') {
      size_t align_at = __Pyx_BufFmt_TypeCharToAlignment(ctx->enc_type, ctx->is_complex);
      size_t align_mod_offset;
      if (align_at == 0) return -1;
      align_mod_offset = ctx->fmt_offset % align_at;
      if (align_mod_offset > 0) ctx->fmt_offset += align_at - align_mod_offset;
      if (ctx->struct_alignment == 0)
          ctx->struct_alignment = __Pyx_BufFmt_TypeCharToPadding(ctx->enc_type,
                                                                 ctx->is_complex);
    }
    if (type->size != size || type->typegroup != group) {
      if (type->typegroup == 'C' && type->fields != NULL) {
        size_t parent_offset = ctx->head->parent_offset + field->offset;
        ++ctx->head;
        ctx->head->field = type->fields;
        ctx->head->parent_offset = parent_offset;
        continue;
      }
      if ((type->typegroup == 'H' || group == 'H') && type->size == size) {
      } else {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return -1;
      }
    }
    offset = ctx->head->parent_offset + field->offset;
    if (ctx->fmt_offset != offset) {
      PyErr_Format(PyExc_ValueError,
                   "Buffer dtype mismatch; next field is at offset %" CYTHON_FORMAT_SSIZE_T "d but %" CYTHON_FORMAT_SSIZE_T "d expected",
                   (Py_ssize_t)ctx->fmt_offset, (Py_ssize_t)offset);
      return -1;
    }
    ctx->fmt_offset += size;
    if (arraysize)
      ctx->fmt_offset += (arraysize - 1) * size;
    --ctx->enc_count;
    while (1) {
      if (field == &ctx->root) {
        ctx->head = NULL;
        if (ctx->enc_count != 0) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return -1;
        }
        break;
      }
      ctx->head->field = ++field;
      if (field->type == NULL) {
        --ctx->head;
        field = ctx->head->field;
        continue;
      } else if (field->type->typegroup == 'S') {
        size_t parent_offset = ctx->head->parent_offset + field->offset;
        if (field->type->fields->type == NULL) continue;
        field = field->type->fields;
        ++ctx->head;
        ctx->head->field = field;
        ctx->head->parent_offset = parent_offset;
        break;
      } else {
        break;
      }
    }
  } while (ctx->enc_count);
  ctx->enc_type = 0;
  ctx->is_complex = 0;
  return 0;
}
static int
__pyx_buffmt_parse_array(__Pyx_BufFmt_Context* ctx, const char** tsp)
{
    const char *ts = *tsp;
    int i = 0, number, ndim;
    ++ts;
    if (ctx->new_count != 1) {
        PyErr_SetString(PyExc_ValueError,
                        "Cannot handle repeated arrays in format string");
        return -1;
    }
    if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return -1;
    ndim = ctx->head->field->type->ndim;
    while (*ts && *ts != ')') {
        switch (*ts) {
            case ' ': case '\f': case '\r': case '\n': case '\t': case '\v':  continue;
            default:  break;
        }
        number = __Pyx_BufFmt_ExpectNumber(&ts);
        if (number == -1) return -1;
        if (i < ndim && (size_t) number != ctx->head->field->type->arraysize[i]) {
            PyErr_Format(PyExc_ValueError,
                        "Expected a dimension of size %zu, got %d",
                        ctx->head->field->type->arraysize[i], number);
            return -1;
        }
        if (*ts != ',' && *ts != ')') {
            PyErr_Format(PyExc_ValueError,
                                "Expected a comma in format string, got '%c'", *ts);
            return -1;
        }
        if (*ts == ',') ts++;
        i++;
    }
    if (i != ndim) {
        PyErr_Format(PyExc_ValueError, "Expected %d dimension(s), got %d",
                            ctx->head->field->type->ndim, i);
        return -1;
    }
    if (!*ts) {
        PyErr_SetString(PyExc_ValueError,
                        "Unexpected end of format string, expected ')'");
        return -1;
    }
    ctx->is_valid_array = 1;
    ctx->new_count = 1;
    *tsp = ++ts;
    return 0;
}
static const char* __Pyx_BufFmt_CheckString(__Pyx_BufFmt_Context* ctx, const char* ts) {
  int got_Z = 0;
  while (1) {
    switch(*ts) {
      case 0:
        if (ctx->enc_type != 0 && ctx->head == NULL) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return NULL;
        }
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        if (ctx->head != NULL) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return NULL;
        }
        return ts;
      case ' ':
      case '\r':
      case '\n':
        ++ts;
        break;
      case '<':
        if (!__Pyx_Is_Little_Endian()) {
          PyErr_SetString(PyExc_ValueError, "Little-endian buffer not supported on big-endian compiler");
          return NULL;
        }
        ctx->new_packmode = '=';
        ++ts;
        break;
      case '>':
      case '!':
        if (__Pyx_Is_Little_Endian()) {
          PyErr_SetString(PyExc_ValueError, "Big-endian buffer not supported on little-endian compiler");
          return NULL;
        }
        ctx->new_packmode = '=';
        ++ts;
        break;
      case '=':
      case '@':
      case '^':
        ctx->new_packmode = *ts++;
        break;
      case 'T':
        {
          const char* ts_after_sub;
          size_t i, struct_count = ctx->new_count;
          size_t struct_alignment = ctx->struct_alignment;
          ctx->new_count = 1;
          ++ts;
          if (*ts != '{') {
            PyErr_SetString(PyExc_ValueError, "Buffer acquisition: Expected '{' after 'T'");
            return NULL;
          }
          if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
          ctx->enc_type = 0;
          ctx->enc_count = 0;
          ctx->struct_alignment = 0;
          ++ts;
          ts_after_sub = ts;
          for (i = 0; i != struct_count; ++i) {
            ts_after_sub = __Pyx_BufFmt_CheckString(ctx, ts);
            if (!ts_after_sub) return NULL;
          }
          ts = ts_after_sub;
          if (struct_alignment) ctx->struct_alignment = struct_alignment;
        }
        break;
      case '}':
        {
          size_t alignment = ctx->struct_alignment;
          ++ts;
          if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
          ctx->enc_type = 0;
          if (alignment && ctx->fmt_offset % alignment) {
            ctx->fmt_offset += alignment - (ctx->fmt_offset % alignment);
          }
        }
        return ts;
      case 'x':
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        ctx->fmt_offset += ctx->new_count;
        ctx->new_count = 1;
        ctx->enc_count = 0;
        ctx->enc_type = 0;
        ctx->enc_packmode = ctx->new_packmode;
        ++ts;
        break;
      case 'Z':
        got_Z = 1;
        ++ts;
        if (*ts != 'f' && *ts != 'd' && *ts != 'g') {
          __Pyx_BufFmt_RaiseUnexpectedChar('Z');
          return NULL;
        }
        CYTHON_FALLTHROUGH;
      case '?': case 'c': case 'b': case 'B': case 'h': case 'H': case 'i': case 'I':
      case 'l': case 'L': case 'q': case 'Q':
      case 'f': case 'd': case 'g':
      case 'O': case 'p':
        if ((ctx->enc_type == *ts) && (got_Z == ctx->is_complex) &&
            (ctx->enc_packmode == ctx->new_packmode) && (!ctx->is_valid_array)) {
          ctx->enc_count += ctx->new_count;
          ctx->new_count = 1;
          got_Z = 0;
          ++ts;
          break;
        }
        CYTHON_FALLTHROUGH;
      case 's':
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        ctx->enc_count = ctx->new_count;
        ctx->enc_packmode = ctx->new_packmode;
        ctx->enc_type = *ts;
        ctx->is_complex = got_Z;
        ++ts;
        ctx->new_count = 1;
        got_Z = 0;
        break;
      case ':':
        ++ts;
        while(*ts != ':') ++ts;
        ++ts;
        break;
      case '(':
        if (__pyx_buffmt_parse_array(ctx, &ts) < 0) return NULL;
        break;
      default:
        {
          int number = __Pyx_BufFmt_ExpectNumber(&ts);
          if (number == -1) return NULL;
          ctx->new_count = (size_t)number;
        }
    }
  }
}

/* BufferGetAndValidate */
  static CYTHON_INLINE void __Pyx_SafeReleaseBuffer(Py_buffer* info) {
  if (unlikely(info->buf == NULL)) return;
  if (info->suboffsets == __Pyx_minusones) info->suboffsets = NULL;
  __Pyx_ReleaseBuffer(info);
}
static void __Pyx_ZeroBuffer(Py_buffer* buf) {
  buf->buf = NULL;
  buf->obj = NULL;
  buf->strides = __Pyx_zeros;
  buf->shape = __Pyx_zeros;
  buf->suboffsets = __Pyx_minusones;
}
static int __Pyx__GetBufferAndValidate(
        Py_buffer* buf, PyObject* obj,  __Pyx_TypeInfo* dtype, int flags,
        int nd, int cast, __Pyx_BufFmt_StackElem* stack)
{
  buf->buf = NULL;
  if (unlikely(__Pyx_GetBuffer(obj, buf, flags) == -1)) {
    __Pyx_ZeroBuffer(buf);
    return -1;
  }
  if (unlikely(buf->ndim != nd)) {
    PyErr_Format(PyExc_ValueError,
                 "Buffer has wrong number of dimensions (expected %d, got %d)",
                 nd, buf->ndim);
    goto fail;
  }
  if (!cast) {
    __Pyx_BufFmt_Context ctx;
    __Pyx_BufFmt_Init(&ctx, stack, dtype);
    if (!__Pyx_BufFmt_CheckString(&ctx, buf->format)) goto fail;
  }
  if (unlikely((size_t)buf->itemsize != dtype->size)) {
    PyErr_Format(PyExc_ValueError,
      "Item size of buffer (%" CYTHON_FORMAT_SSIZE_T "d byte%s) does not match size of '%s' (%" CYTHON_FORMAT_SSIZE_T "d byte%s)",
      buf->itemsize, (buf->itemsize > 1) ? "s" : "",
      dtype->name, (Py_ssize_t)dtype->size, (dtype->size > 1) ? "s" : "");
    goto fail;
  }
  if (buf->suboffsets == NULL) buf->suboffsets = __Pyx_minusones;
  return 0;
fail:;
  __Pyx_SafeReleaseBuffer(buf);
  return -1;
}

/* PyObjectCallNoArg */
  static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
    PyObject *arg[2] = {NULL, NULL};
    return __Pyx_PyObject_FastCall(func, arg + 1, 0 | __Pyx_PY_VECTORCALL_ARGUMENTS_OFFSET);
}

/* RaiseUnboundMemoryviewSliceNogil */
  static void __Pyx_RaiseUnboundMemoryviewSliceNogil(const char *varname) {
    #ifdef WITH_THREAD
    PyGILState_STATE gilstate = PyGILState_Ensure();
    #endif
    __Pyx_RaiseUnboundLocalError(varname);
    #ifdef WITH_THREAD
    PyGILState_Release(gilstate);
    #endif
}

/* IterFinish */
  static CYTHON_INLINE int __Pyx_IterFinish(void) {
    PyObject* exc_type;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    exc_type = __Pyx_PyErr_CurrentExceptionType();
    if (unlikely(exc_type)) {
        if (unlikely(!__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)))
            return -1;
        __Pyx_PyErr_Clear();
        return 0;
    }
    return 0;
}

/* UnpackItemEndCheck */
  static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    }
    return __Pyx_IterFinish();
}

/* BufferFallbackError */
  static void __Pyx_RaiseBufferFallbackError(void) {
  PyErr_SetString(PyExc_ValueError,
     "Buffer acquisition failed on assignment; and then reacquiring the old buffer failed too!");
}

/* DictGetItem */
  #if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            if (unlikely(PyTuple_Check(key))) {
                PyObject* args = PyTuple_Pack(1, key);
                if (likely(args)) {
                    PyErr_SetObject(PyExc_KeyError, args);
                    Py_DECREF(args);
                }
            } else {
                PyErr_SetObject(PyExc_KeyError, key);
            }
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#endif

/* UnicodeAsUCS4 */
  static CYTHON_INLINE Py_UCS4 __Pyx_PyUnicode_AsPy_UCS4(PyObject* x) {
   Py_ssize_t length;
   #if CYTHON_PEP393_ENABLED
   length = PyUnicode_GET_LENGTH(x);
   if (likely(length == 1)) {
       return PyUnicode_READ_CHAR(x, 0);
   }
   #else
   length = PyUnicode_GET_SIZE(x);
   if (likely(length == 1)) {
       return PyUnicode_AS_UNICODE(x)[0];
   }
   #if Py_UNICODE_SIZE == 2
   else if (PyUnicode_GET_SIZE(x) == 2) {
       Py_UCS4 high_val = PyUnicode_AS_UNICODE(x)[0];
       if (high_val >= 0xD800 && high_val <= 0xDBFF) {
           Py_UCS4 low_val = PyUnicode_AS_UNICODE(x)[1];
           if (low_val >= 0xDC00 && low_val <= 0xDFFF) {
               return 0x10000 + (((high_val & ((1<<10)-1)) << 10) | (low_val & ((1<<10)-1)));
           }
       }
   }
   #endif
   #endif
   PyErr_Format(PyExc_ValueError,
                "only single character unicode strings can be converted to Py_UCS4, "
                "got length %" CYTHON_FORMAT_SSIZE_T "d", length);
   return (Py_UCS4)-1;
}

/* object_ord */
  static long __Pyx__PyObject_Ord(PyObject* c) {
    Py_ssize_t size;
    if (PyBytes_Check(c)) {
        size = PyBytes_GET_SIZE(c);
        if (likely(size == 1)) {
            return (unsigned char) PyBytes_AS_STRING(c)[0];
        }
#if PY_MAJOR_VERSION < 3
    } else if (PyUnicode_Check(c)) {
        return (long)__Pyx_PyUnicode_AsPy_UCS4(c);
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    } else if (PyByteArray_Check(c)) {
        size = PyByteArray_GET_SIZE(c);
        if (likely(size == 1)) {
            return (unsigned char) PyByteArray_AS_STRING(c)[0];
        }
#endif
    } else {
        __Pyx_TypeName c_type_name = __Pyx_PyType_GetName(Py_TYPE(c));
        PyErr_Format(PyExc_TypeError,
            "ord() expected string of length 1, but " __Pyx_FMT_TYPENAME " found",
            c_type_name);
        __Pyx_DECREF_TypeName(c_type_name);
        return (long)(Py_UCS4)-1;
    }
    PyErr_Format(PyExc_TypeError,
        "ord() expected a character, but string of length %zd found", size);
    return (long)(Py_UCS4)-1;
}

/* memoryview_get_from_buffer */
  #if !CYTHON_COMPILING_IN_LIMITED_API || CYTHON_LIMITED_API >= 0x030b0000
#else
static Py_ssize_t __Pyx_PyMemoryView_Get_itemsize(PyObject *obj) {
    Py_ssize_t result;
    PyObject *attr = PyObject_GetAttr(obj, __pyx_n_s_itemsize);
    if (!attr) {
        goto bad;
    }
    result = PyLong_AsSsize_t(attr);
    Py_DECREF(attr);
    return result;
    bad:
    Py_XDECREF(attr);
    return -1;
}
#endif

/* memoryview_get_from_buffer */
  #if !CYTHON_COMPILING_IN_LIMITED_API || CYTHON_LIMITED_API >= 0x030b0000
#else
static int __Pyx_PyMemoryView_Get_ndim(PyObject *obj) {
    int result;
    PyObject *attr = PyObject_GetAttr(obj, __pyx_n_s_ndim);
    if (!attr) {
        goto bad;
    }
    result = PyLong_AsLong(attr);
    Py_DECREF(attr);
    return result;
    bad:
    Py_XDECREF(attr);
    return -1;
}
#endif

/* PyObjectGetMethod */
  static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    __Pyx_TypeName type_name;
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if defined(Py_TPFLAGS_METHOD_DESCRIPTOR) && Py_TPFLAGS_METHOD_DESCRIPTOR
        if (__Pyx_PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_METHOD_DESCRIPTOR))
#elif PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || __Pyx_IS_TYPE(descr, &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (likely(descr != NULL)) {
        *method = descr;
        return 0;
    }
    type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod0 */
  static PyObject* __Pyx_PyObject_CallMethod0(PyObject* obj, PyObject* method_name) {
    PyObject *method = NULL, *result = NULL;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_CallOneArg(method, obj);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) goto bad;
    result = __Pyx_PyObject_CallNoArg(method);
    Py_DECREF(method);
bad:
    return result;
}

/* UnpackTupleError */
  static void __Pyx_UnpackTupleError(PyObject *t, Py_ssize_t index) {
    if (t == Py_None) {
      __Pyx_RaiseNoneNotIterableError();
    } else if (PyTuple_GET_SIZE(t) < index) {
      __Pyx_RaiseNeedMoreValuesError(PyTuple_GET_SIZE(t));
    } else {
      __Pyx_RaiseTooManyValuesError(index);
    }
}

/* UnpackTuple2 */
  static CYTHON_INLINE int __Pyx_unpack_tuple2_exact(
        PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2, int decref_tuple) {
    PyObject *value1 = NULL, *value2 = NULL;
#if CYTHON_COMPILING_IN_PYPY
    value1 = PySequence_ITEM(tuple, 0);  if (unlikely(!value1)) goto bad;
    value2 = PySequence_ITEM(tuple, 1);  if (unlikely(!value2)) goto bad;
#else
    value1 = PyTuple_GET_ITEM(tuple, 0);  Py_INCREF(value1);
    value2 = PyTuple_GET_ITEM(tuple, 1);  Py_INCREF(value2);
#endif
    if (decref_tuple) {
        Py_DECREF(tuple);
    }
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
#if CYTHON_COMPILING_IN_PYPY
bad:
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
#endif
}
static int __Pyx_unpack_tuple2_generic(PyObject* tuple, PyObject** pvalue1, PyObject** pvalue2,
                                       int has_known_size, int decref_tuple) {
    Py_ssize_t index;
    PyObject *value1 = NULL, *value2 = NULL, *iter = NULL;
    iternextfunc iternext;
    iter = PyObject_GetIter(tuple);
    if (unlikely(!iter)) goto bad;
    if (decref_tuple) { Py_DECREF(tuple); tuple = NULL; }
    iternext = __Pyx_PyObject_GetIterNextFunc(iter);
    value1 = iternext(iter); if (unlikely(!value1)) { index = 0; goto unpacking_failed; }
    value2 = iternext(iter); if (unlikely(!value2)) { index = 1; goto unpacking_failed; }
    if (!has_known_size && unlikely(__Pyx_IternextUnpackEndCheck(iternext(iter), 2))) goto bad;
    Py_DECREF(iter);
    *pvalue1 = value1;
    *pvalue2 = value2;
    return 0;
unpacking_failed:
    if (!has_known_size && __Pyx_IterFinish() == 0)
        __Pyx_RaiseNeedMoreValuesError(index);
bad:
    Py_XDECREF(iter);
    Py_XDECREF(value1);
    Py_XDECREF(value2);
    if (decref_tuple) { Py_XDECREF(tuple); }
    return -1;
}

/* dict_iter */
  #if CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
#include <string.h>
#endif
static CYTHON_INLINE PyObject* __Pyx_dict_iterator(PyObject* iterable, int is_dict, PyObject* method_name,
                                                   Py_ssize_t* p_orig_length, int* p_source_is_dict) {
    is_dict = is_dict || likely(PyDict_CheckExact(iterable));
    *p_source_is_dict = is_dict;
    if (is_dict) {
#if !CYTHON_COMPILING_IN_PYPY
        *p_orig_length = PyDict_Size(iterable);
        Py_INCREF(iterable);
        return iterable;
#elif PY_MAJOR_VERSION >= 3
        static PyObject *py_items = NULL, *py_keys = NULL, *py_values = NULL;
        PyObject **pp = NULL;
        if (method_name) {
            const char *name = PyUnicode_AsUTF8(method_name);
            if (strcmp(name, "iteritems") == 0) pp = &py_items;
            else if (strcmp(name, "iterkeys") == 0) pp = &py_keys;
            else if (strcmp(name, "itervalues") == 0) pp = &py_values;
            if (pp) {
                if (!*pp) {
                    *pp = PyUnicode_FromString(name + 4);
                    if (!*pp)
                        return NULL;
                }
                method_name = *pp;
            }
        }
#endif
    }
    *p_orig_length = 0;
    if (method_name) {
        PyObject* iter;
        iterable = __Pyx_PyObject_CallMethod0(iterable, method_name);
        if (!iterable)
            return NULL;
#if !CYTHON_COMPILING_IN_PYPY
        if (PyTuple_CheckExact(iterable) || PyList_CheckExact(iterable))
            return iterable;
#endif
        iter = PyObject_GetIter(iterable);
        Py_DECREF(iterable);
        return iter;
    }
    return PyObject_GetIter(iterable);
}
static CYTHON_INLINE int __Pyx_dict_iter_next(
        PyObject* iter_obj, CYTHON_NCP_UNUSED Py_ssize_t orig_length, CYTHON_NCP_UNUSED Py_ssize_t* ppos,
        PyObject** pkey, PyObject** pvalue, PyObject** pitem, int source_is_dict) {
    PyObject* next_item;
#if !CYTHON_COMPILING_IN_PYPY
    if (source_is_dict) {
        PyObject *key, *value;
        if (unlikely(orig_length != PyDict_Size(iter_obj))) {
            PyErr_SetString(PyExc_RuntimeError, "dictionary changed size during iteration");
            return -1;
        }
        if (unlikely(!PyDict_Next(iter_obj, ppos, &key, &value))) {
            return 0;
        }
        if (pitem) {
            PyObject* tuple = PyTuple_New(2);
            if (unlikely(!tuple)) {
                return -1;
            }
            Py_INCREF(key);
            Py_INCREF(value);
            PyTuple_SET_ITEM(tuple, 0, key);
            PyTuple_SET_ITEM(tuple, 1, value);
            *pitem = tuple;
        } else {
            if (pkey) {
                Py_INCREF(key);
                *pkey = key;
            }
            if (pvalue) {
                Py_INCREF(value);
                *pvalue = value;
            }
        }
        return 1;
    } else if (PyTuple_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyTuple_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyTuple_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else if (PyList_CheckExact(iter_obj)) {
        Py_ssize_t pos = *ppos;
        if (unlikely(pos >= PyList_GET_SIZE(iter_obj))) return 0;
        *ppos = pos + 1;
        next_item = PyList_GET_ITEM(iter_obj, pos);
        Py_INCREF(next_item);
    } else
#endif
    {
        next_item = PyIter_Next(iter_obj);
        if (unlikely(!next_item)) {
            return __Pyx_IterFinish();
        }
    }
    if (pitem) {
        *pitem = next_item;
    } else if (pkey && pvalue) {
        if (__Pyx_unpack_tuple2(next_item, pkey, pvalue, source_is_dict, source_is_dict, 1))
            return -1;
    } else if (pkey) {
        *pkey = next_item;
    } else {
        *pvalue = next_item;
    }
    return 1;
}

/* UnpackUnboundCMethod */
  static PyObject *__Pyx_SelflessCall(PyObject *method, PyObject *args, PyObject *kwargs) {
    PyObject *result;
    PyObject *selfless_args = PyTuple_GetSlice(args, 1, PyTuple_Size(args));
    if (unlikely(!selfless_args)) return NULL;
    result = PyObject_Call(method, selfless_args, kwargs);
    Py_DECREF(selfless_args);
    return result;
}
static PyMethodDef __Pyx_UnboundCMethod_Def = {
     "CythonUnboundCMethod",
     __PYX_REINTERPRET_FUNCION(PyCFunction, __Pyx_SelflessCall),
     METH_VARARGS | METH_KEYWORDS,
     NULL
};
static int __Pyx_TryUnpackUnboundCMethod(__Pyx_CachedCFunction* target) {
    PyObject *method;
    method = __Pyx_PyObject_GetAttrStr(target->type, *target->method_name);
    if (unlikely(!method))
        return -1;
    target->method = method;
#if CYTHON_COMPILING_IN_CPYTHON
    #if PY_MAJOR_VERSION >= 3
    if (likely(__Pyx_TypeCheck(method, &PyMethodDescr_Type)))
    #else
    if (likely(!__Pyx_CyOrPyCFunction_Check(method)))
    #endif
    {
        PyMethodDescrObject *descr = (PyMethodDescrObject*) method;
        target->func = descr->d_method->ml_meth;
        target->flag = descr->d_method->ml_flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_STACKLESS);
    } else
#endif
#if CYTHON_COMPILING_IN_PYPY
#else
    if (PyCFunction_Check(method))
#endif
    {
        PyObject *self;
        int self_found;
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        self = PyObject_GetAttrString(method, "__self__");
        if (!self) {
            PyErr_Clear();
        }
#else
        self = PyCFunction_GET_SELF(method);
#endif
        self_found = (self && self != Py_None);
#if CYTHON_COMPILING_IN_LIMITED_API || CYTHON_COMPILING_IN_PYPY
        Py_XDECREF(self);
#endif
        if (self_found) {
            PyObject *unbound_method = PyCFunction_New(&__Pyx_UnboundCMethod_Def, method);
            if (unlikely(!unbound_method)) return -1;
            Py_DECREF(method);
            target->method = unbound_method;
        }
    }
    return 0;
}

/* CallUnboundCMethod0 */
  static PyObject* __Pyx__CallUnboundCMethod0(__Pyx_CachedCFunction* cfunc, PyObject* self) {
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_ASSUME_SAFE_MACROS
    args = PyTuple_New(1);
    if (unlikely(!args)) goto bad;
    Py_INCREF(self);
    PyTuple_SET_ITEM(args, 0, self);
#else
    args = PyTuple_Pack(1, self);
    if (unlikely(!args)) goto bad;
#endif
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    Py_DECREF(args);
bad:
    return result;
}

/* py_dict_values */
  static CYTHON_INLINE PyObject* __Pyx_PyDict_Values(PyObject* d) {
    if (PY_MAJOR_VERSION >= 3)
        return __Pyx_CallUnboundCMethod0(&__pyx_umethod_PyDict_Type_values, d);
    else
        return PyDict_Values(d);
}

/* CallUnboundCMethod1 */
  #if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg) {
    if (likely(cfunc->func)) {
        int flag = cfunc->flag;
        if (flag == METH_O) {
            return (*(cfunc->func))(self, arg);
        } else if ((PY_VERSION_HEX >= 0x030600B1) && flag == METH_FASTCALL) {
            #if PY_VERSION_HEX >= 0x030700A0
                return (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)cfunc->func)(self, &arg, 1);
            #else
                return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
            #endif
        } else if ((PY_VERSION_HEX >= 0x030700A0) && flag == (METH_FASTCALL | METH_KEYWORDS)) {
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, &arg, 1, NULL);
        }
    }
    return __Pyx__CallUnboundCMethod1(cfunc, self, arg);
}
#endif
static PyObject* __Pyx__CallUnboundCMethod1(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg){
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        args = PyTuple_New(1);
        if (unlikely(!args)) goto bad;
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 0, arg);
        if (cfunc->flag & METH_KEYWORDS)
            result = (*(PyCFunctionWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, NULL);
        else
            result = (*cfunc->func)(self, args);
    } else {
        args = PyTuple_New(2);
        if (unlikely(!args)) goto bad;
        Py_INCREF(self);
        PyTuple_SET_ITEM(args, 0, self);
        Py_INCREF(arg);
        PyTuple_SET_ITEM(args, 1, arg);
        result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    }
#else
    args = PyTuple_Pack(2, self, arg);
    if (unlikely(!args)) goto bad;
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
#endif
bad:
    Py_XDECREF(args);
    return result;
}

/* CallUnboundCMethod2 */
  #if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030600B1
static CYTHON_INLINE PyObject *__Pyx_CallUnboundCMethod2(__Pyx_CachedCFunction *cfunc, PyObject *self, PyObject *arg1, PyObject *arg2) {
    if (likely(cfunc->func)) {
        PyObject *args[2] = {arg1, arg2};
        if (cfunc->flag == METH_FASTCALL) {
            #if PY_VERSION_HEX >= 0x030700A0
            return (*(__Pyx_PyCFunctionFast)(void*)(PyCFunction)cfunc->func)(self, args, 2);
            #else
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, 2, NULL);
            #endif
        }
        #if PY_VERSION_HEX >= 0x030700A0
        if (cfunc->flag == (METH_FASTCALL | METH_KEYWORDS))
            return (*(__Pyx_PyCFunctionFastWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, 2, NULL);
        #endif
    }
    return __Pyx__CallUnboundCMethod2(cfunc, self, arg1, arg2);
}
#endif
static PyObject* __Pyx__CallUnboundCMethod2(__Pyx_CachedCFunction* cfunc, PyObject* self, PyObject* arg1, PyObject* arg2){
    PyObject *args, *result = NULL;
    if (unlikely(!cfunc->func && !cfunc->method) && unlikely(__Pyx_TryUnpackUnboundCMethod(cfunc) < 0)) return NULL;
#if CYTHON_COMPILING_IN_CPYTHON
    if (cfunc->func && (cfunc->flag & METH_VARARGS)) {
        args = PyTuple_New(2);
        if (unlikely(!args)) goto bad;
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 0, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 1, arg2);
        if (cfunc->flag & METH_KEYWORDS)
            result = (*(PyCFunctionWithKeywords)(void*)(PyCFunction)cfunc->func)(self, args, NULL);
        else
            result = (*cfunc->func)(self, args);
    } else {
        args = PyTuple_New(3);
        if (unlikely(!args)) goto bad;
        Py_INCREF(self);
        PyTuple_SET_ITEM(args, 0, self);
        Py_INCREF(arg1);
        PyTuple_SET_ITEM(args, 1, arg1);
        Py_INCREF(arg2);
        PyTuple_SET_ITEM(args, 2, arg2);
        result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
    }
#else
    args = PyTuple_Pack(3, self, arg1, arg2);
    if (unlikely(!args)) goto bad;
    result = __Pyx_PyObject_Call(cfunc->method, args, NULL);
#endif
bad:
    Py_XDECREF(args);
    return result;
}

/* dict_getitem_default */
  static PyObject* __Pyx_PyDict_GetItemDefault(PyObject* d, PyObject* key, PyObject* default_value) {
    PyObject* value;
#if PY_MAJOR_VERSION >= 3 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07020000)
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (unlikely(PyErr_Occurred()))
            return NULL;
        value = default_value;
    }
    Py_INCREF(value);
    if ((1));
#else
    if (PyString_CheckExact(key) || PyUnicode_CheckExact(key) || PyInt_CheckExact(key)) {
        value = PyDict_GetItem(d, key);
        if (unlikely(!value)) {
            value = default_value;
        }
        Py_INCREF(value);
    }
#endif
    else {
        if (default_value == Py_None)
            value = __Pyx_CallUnboundCMethod1(&__pyx_umethod_PyDict_Type_get, d, key);
        else
            value = __Pyx_CallUnboundCMethod2(&__pyx_umethod_PyDict_Type_get, d, key, default_value);
    }
    return value;
}

/* CallNextTpTraverse */
  static int __Pyx_call_next_tp_traverse(PyObject* obj, visitproc v, void *a, traverseproc current_tp_traverse) {
    PyTypeObject* type = Py_TYPE(obj);
    traverseproc tp_traverse = NULL;
    while (type && __Pyx_PyType_GetSlot(type, tp_traverse, traverseproc) != current_tp_traverse)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    while (type && (tp_traverse = __Pyx_PyType_GetSlot(type, tp_traverse, traverseproc)) == current_tp_traverse)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    if (type && tp_traverse)
        return tp_traverse(obj, v, a);
    return 0;
}

/* CallNextTpClear */
  static void __Pyx_call_next_tp_clear(PyObject* obj, inquiry current_tp_clear) {
    PyTypeObject* type = Py_TYPE(obj);
    inquiry tp_clear = NULL;
    while (type && __Pyx_PyType_GetSlot(type, tp_clear, inquiry) != current_tp_clear)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    while (type && (tp_clear = __Pyx_PyType_GetSlot(type, tp_clear, inquiry)) == current_tp_clear)
        type = __Pyx_PyType_GetSlot(type, tp_base, PyTypeObject*);
    if (type && tp_clear)
        tp_clear(obj);
}

/* PyObject_GenericGetAttrNoDict */
  #if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    __Pyx_TypeName type_name = __Pyx_PyType_GetName(tp);
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%U'",
                 type_name, attr_name);
#else
                 "'" __Pyx_FMT_TYPENAME "' object has no attribute '%.400s'",
                 type_name, PyString_AS_STRING(attr_name));
#endif
    __Pyx_DECREF_TypeName(type_name);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PyObject_GenericGetAttr */
  #if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* FixUpExtensionType */
  #if CYTHON_USE_TYPE_SPECS
static int __Pyx_fix_up_extension_type_from_spec(PyType_Spec *spec, PyTypeObject *type) {
#if PY_VERSION_HEX > 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    CYTHON_UNUSED_VAR(spec);
    CYTHON_UNUSED_VAR(type);
#else
    const PyType_Slot *slot = spec->slots;
    while (slot && slot->slot && slot->slot != Py_tp_members)
        slot++;
    if (slot && slot->slot == Py_tp_members) {
        int changed = 0;
#if !(PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON)
        const
#endif
            PyMemberDef *memb = (PyMemberDef*) slot->pfunc;
        while (memb && memb->name) {
            if (memb->name[0] == '_' && memb->name[1] == '_') {
#if PY_VERSION_HEX < 0x030900b1
                if (strcmp(memb->name, "__weaklistoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_weaklistoffset = memb->offset;
                    changed = 1;
                }
                else if (strcmp(memb->name, "__dictoffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
                    type->tp_dictoffset = memb->offset;
                    changed = 1;
                }
#if CYTHON_METH_FASTCALL
                else if (strcmp(memb->name, "__vectorcalloffset__") == 0) {
                    assert(memb->type == T_PYSSIZET);
                    assert(memb->flags == READONLY);
#if PY_VERSION_HEX >= 0x030800b4
                    type->tp_vectorcall_offset = memb->offset;
#else
                    type->tp_print = (printfunc) memb->offset;
#endif
                    changed = 1;
                }
#endif
#else
                if ((0));
#endif
#if PY_VERSION_HEX <= 0x030900b1 && CYTHON_COMPILING_IN_CPYTHON
                else if (strcmp(memb->name, "__module__") == 0) {
                    PyObject *descr;
                    assert(memb->type == T_OBJECT);
                    assert(memb->flags == 0 || memb->flags == READONLY);
                    descr = PyDescr_NewMember(type, memb);
                    if (unlikely(!descr))
                        return -1;
                    if (unlikely(PyDict_SetItem(type->tp_dict, PyDescr_NAME(descr), descr) < 0)) {
                        Py_DECREF(descr);
                        return -1;
                    }
                    Py_DECREF(descr);
                    changed = 1;
                }
#endif
            }
            memb++;
        }
        if (changed)
            PyType_Modified(type);
    }
#endif
    return 0;
}
#endif

/* ValidateBasesTuple */
  #if CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API || CYTHON_USE_TYPE_SPECS
static int __Pyx_validate_bases_tuple(const char *type_name, Py_ssize_t dictoffset, PyObject *bases) {
    Py_ssize_t i, n;
#if CYTHON_ASSUME_SAFE_MACROS
    n = PyTuple_GET_SIZE(bases);
#else
    n = PyTuple_Size(bases);
    if (n < 0) return -1;
#endif
    for (i = 1; i < n; i++)
    {
#if CYTHON_AVOID_BORROWED_REFS
        PyObject *b0 = PySequence_GetItem(bases, i);
        if (!b0) return -1;
#elif CYTHON_ASSUME_SAFE_MACROS
        PyObject *b0 = PyTuple_GET_ITEM(bases, i);
#else
        PyObject *b0 = PyTuple_GetItem(bases, i);
        if (!b0) return -1;
#endif
        PyTypeObject *b;
#if PY_MAJOR_VERSION < 3
        if (PyClass_Check(b0))
        {
            PyErr_Format(PyExc_TypeError, "base class '%.200s' is an old-style class",
                         PyString_AS_STRING(((PyClassObject*)b0)->cl_name));
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
#endif
        b = (PyTypeObject*) b0;
        if (!__Pyx_PyType_HasFeature(b, Py_TPFLAGS_HEAPTYPE))
        {
            __Pyx_TypeName b_name = __Pyx_PyType_GetName(b);
            PyErr_Format(PyExc_TypeError,
                "base class '" __Pyx_FMT_TYPENAME "' is not a heap type", b_name);
            __Pyx_DECREF_TypeName(b_name);
#if CYTHON_AVOID_BORROWED_REFS
            Py_DECREF(b0);
#endif
            return -1;
        }
        if (dictoffset == 0)
        {
            Py_ssize_t b_dictoffset = 0;
#if CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY
            b_dictoffset = b->tp_dictoffset;
#else
            PyObject *py_b_dictoffset = PyObject_GetAttrString((PyObject*)b, "__dictoffset__");
            if (!py_b_dictoffset) goto dictoffset_return;
            b_dictoffset = PyLong_AsSsize_t(py_b_dictoffset);
            Py_DECREF(py_b_dictoffset);
            if (b_dictoffset == -1 && PyErr_Occurred()) goto dictoffset_return;
#endif
            if (b_dictoffset) {
                {
                    __Pyx_TypeName b_name = __Pyx_PyType_GetName(b);
                    PyErr_Format(PyExc_TypeError,
                        "extension type '%.200s' has no __dict__ slot, "
                        "but base type '" __Pyx_FMT_TYPENAME "' has: "
                        "either add 'cdef dict __dict__' to the extension type "
                        "or add '__slots__ = [...]' to the base type",
                        type_name, b_name);
                    __Pyx_DECREF_TypeName(b_name);
                }
#if !(CYTHON_USE_TYPE_SLOTS || CYTHON_COMPILING_IN_PYPY)
              dictoffset_return:
#endif
#if CYTHON_AVOID_BORROWED_REFS
                Py_DECREF(b0);
#endif
                return -1;
            }
        }
#if CYTHON_AVOID_BORROWED_REFS
        Py_DECREF(b0);
#endif
    }
    return 0;
}
#endif

/* PyType_Ready */
  static int __Pyx_PyType_Ready(PyTypeObject *t) {
#if CYTHON_USE_TYPE_SPECS || !(CYTHON_COMPILING_IN_CPYTHON || CYTHON_COMPILING_IN_LIMITED_API) || defined(PYSTON_MAJOR_VERSION)
    (void)__Pyx_PyObject_CallMethod0;
#if CYTHON_USE_TYPE_SPECS
    (void)__Pyx_validate_bases_tuple;
#endif
    return PyType_Ready(t);
#else
    int r;
    PyObject *bases = __Pyx_PyType_GetSlot(t, tp_bases, PyObject*);
    if (bases && unlikely(__Pyx_validate_bases_tuple(t->tp_name, t->tp_dictoffset, bases) == -1))
        return -1;
#if PY_VERSION_HEX >= 0x03050000 && !defined(PYSTON_MAJOR_VERSION)
    {
        int gc_was_enabled;
    #if PY_VERSION_HEX >= 0x030A00b1
        gc_was_enabled = PyGC_Disable();
        (void)__Pyx_PyObject_CallMethod0;
    #else
        PyObject *ret, *py_status;
        PyObject *gc = NULL;
        #if PY_VERSION_HEX >= 0x030700a1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM+0 >= 0x07030400)
        gc = PyImport_GetModule(__pyx_kp_u_gc);
        #endif
        if (unlikely(!gc)) gc = PyImport_Import(__pyx_kp_u_gc);
        if (unlikely(!gc)) return -1;
        py_status = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_isenabled);
        if (unlikely(!py_status)) {
            Py_DECREF(gc);
            return -1;
        }
        gc_was_enabled = __Pyx_PyObject_IsTrue(py_status);
        Py_DECREF(py_status);
        if (gc_was_enabled > 0) {
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_disable);
            if (unlikely(!ret)) {
                Py_DECREF(gc);
                return -1;
            }
            Py_DECREF(ret);
        } else if (unlikely(gc_was_enabled == -1)) {
            Py_DECREF(gc);
            return -1;
        }
    #endif
        t->tp_flags |= Py_TPFLAGS_HEAPTYPE;
#if PY_VERSION_HEX >= 0x030A0000
        t->tp_flags |= Py_TPFLAGS_IMMUTABLETYPE;
#endif
#else
        (void)__Pyx_PyObject_CallMethod0;
#endif
    r = PyType_Ready(t);
#if PY_VERSION_HEX >= 0x03050000 && !defined(PYSTON_MAJOR_VERSION)
        t->tp_flags &= ~Py_TPFLAGS_HEAPTYPE;
    #if PY_VERSION_HEX >= 0x030A00b1
        if (gc_was_enabled)
            PyGC_Enable();
    #else
        if (gc_was_enabled) {
            PyObject *tp, *v, *tb;
            PyErr_Fetch(&tp, &v, &tb);
            ret = __Pyx_PyObject_CallMethod0(gc, __pyx_kp_u_enable);
            if (likely(ret || r == -1)) {
                Py_XDECREF(ret);
                PyErr_Restore(tp, v, tb);
            } else {
                Py_XDECREF(tp);
                Py_XDECREF(v);
                Py_XDECREF(tb);
                r = -1;
            }
        }
        Py_DECREF(gc);
    #endif
    }
#endif
    return r;
#endif
}

/* SetupReduce */
  #if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStrNoError(meth, __pyx_n_s_name_2);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_getstate = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
    PyObject *getstate = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    getstate = _PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate);
#else
    getstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_getstate);
    if (!getstate && PyErr_Occurred()) {
        goto __PYX_BAD;
    }
#endif
    if (getstate) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_getstate = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_getstate);
#else
        object_getstate = __Pyx_PyObject_GetAttrStrNoError((PyObject*)&PyBaseObject_Type, __pyx_n_s_getstate);
        if (!object_getstate && PyErr_Occurred()) {
            goto __PYX_BAD;
        }
#endif
        if (object_getstate != getstate) {
            goto __PYX_GOOD;
        }
    }
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_reduce_cython);
            if (likely(reduce_cython)) {
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred()) {
        __Pyx_TypeName type_obj_name =
            __Pyx_PyType_GetName((PyTypeObject*)type_obj);
        PyErr_Format(PyExc_RuntimeError,
            "Unable to initialize pickling for " __Pyx_FMT_TYPENAME, type_obj_name);
        __Pyx_DECREF_TypeName(type_obj_name);
    }
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
    Py_XDECREF(object_getstate);
    Py_XDECREF(getstate);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}
#endif

/* SetVTable */
  static int __Pyx_SetVtable(PyTypeObject *type, void *vtable) {
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
    if (unlikely(!ob))
        goto bad;
#if CYTHON_COMPILING_IN_LIMITED_API
    if (unlikely(PyObject_SetAttr((PyObject *) type, __pyx_n_s_pyx_vtable, ob) < 0))
#else
    if (unlikely(PyDict_SetItem(type->tp_dict, __pyx_n_s_pyx_vtable, ob) < 0))
#endif
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* GetVTable */
  static void* __Pyx_GetVtable(PyTypeObject *type) {
    void* ptr;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *ob = PyObject_GetAttr((PyObject *)type, __pyx_n_s_pyx_vtable);
#else
    PyObject *ob = PyObject_GetItem(type->tp_dict, __pyx_n_s_pyx_vtable);
#endif
    if (!ob)
        goto bad;
    ptr = PyCapsule_GetPointer(ob, 0);
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* MergeVTables */
  #if !CYTHON_COMPILING_IN_LIMITED_API
static int __Pyx_MergeVtables(PyTypeObject *type) {
    int i;
    void** base_vtables;
    __Pyx_TypeName tp_base_name;
    __Pyx_TypeName base_name;
    void* unknown = (void*)-1;
    PyObject* bases = type->tp_bases;
    int base_depth = 0;
    {
        PyTypeObject* base = type->tp_base;
        while (base) {
            base_depth += 1;
            base = base->tp_base;
        }
    }
    base_vtables = (void**) malloc(sizeof(void*) * (size_t)(base_depth + 1));
    base_vtables[0] = unknown;
    for (i = 1; i < PyTuple_GET_SIZE(bases); i++) {
        void* base_vtable = __Pyx_GetVtable(((PyTypeObject*)PyTuple_GET_ITEM(bases, i)));
        if (base_vtable != NULL) {
            int j;
            PyTypeObject* base = type->tp_base;
            for (j = 0; j < base_depth; j++) {
                if (base_vtables[j] == unknown) {
                    base_vtables[j] = __Pyx_GetVtable(base);
                    base_vtables[j + 1] = unknown;
                }
                if (base_vtables[j] == base_vtable) {
                    break;
                } else if (base_vtables[j] == NULL) {
                    goto bad;
                }
                base = base->tp_base;
            }
        }
    }
    PyErr_Clear();
    free(base_vtables);
    return 0;
bad:
    tp_base_name = __Pyx_PyType_GetName(type->tp_base);
    base_name = __Pyx_PyType_GetName((PyTypeObject*)PyTuple_GET_ITEM(bases, i));
    PyErr_Format(PyExc_TypeError,
        "multiple bases have vtable conflict: '" __Pyx_FMT_TYPENAME "' and '" __Pyx_FMT_TYPENAME "'", tp_base_name, base_name);
    __Pyx_DECREF_TypeName(tp_base_name);
    __Pyx_DECREF_TypeName(base_name);
    free(base_vtables);
    return -1;
}
#endif

/* TypeImport */
  #ifndef __PYX_HAVE_RT_ImportType_3_0_8
#define __PYX_HAVE_RT_ImportType_3_0_8
static PyTypeObject *__Pyx_ImportType_3_0_8(PyObject *module, const char *module_name, const char *class_name,
    size_t size, size_t alignment, enum __Pyx_ImportType_CheckSize_3_0_8 check_size)
{
    PyObject *result = 0;
    char warning[200];
    Py_ssize_t basicsize;
    Py_ssize_t itemsize;
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *py_basicsize;
    PyObject *py_itemsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#if !CYTHON_COMPILING_IN_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
    itemsize = ((PyTypeObject *)result)->tp_itemsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
    py_itemsize = PyObject_GetAttrString(result, "__itemsize__");
    if (!py_itemsize)
        goto bad;
    itemsize = PyLong_AsSsize_t(py_itemsize);
    Py_DECREF(py_itemsize);
    py_itemsize = 0;
    if (itemsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (itemsize) {
        if (size % alignment) {
            alignment = size % alignment;
        }
        if (itemsize < (Py_ssize_t)alignment)
            itemsize = (Py_ssize_t)alignment;
    }
    if ((size_t)(basicsize + itemsize) < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize+itemsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error_3_0_8 &&
            ((size_t)basicsize > size || (size_t)(basicsize + itemsize) < size)) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd-%zd from PyObject",
            module_name, class_name, size, basicsize, basicsize+itemsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn_3_0_8 && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* FetchSharedCythonModule */
  static PyObject *__Pyx_FetchSharedCythonABIModule(void) {
    return __Pyx_PyImport_AddModuleRef((char*) __PYX_ABI_MODULE_NAME);
}

/* FetchCommonType */
  static int __Pyx_VerifyCachedType(PyObject *cached_type,
                               const char *name,
                               Py_ssize_t basicsize,
                               Py_ssize_t expected_basicsize) {
    if (!PyType_Check(cached_type)) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s is not a type object", name);
        return -1;
    }
    if (basicsize != expected_basicsize) {
        PyErr_Format(PyExc_TypeError,
            "Shared Cython type %.200s has the wrong size, try recompiling",
            name);
        return -1;
    }
    return 0;
}
#if !CYTHON_USE_TYPE_SPECS
static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* abi_module;
    const char* object_name;
    PyTypeObject *cached_type = NULL;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    object_name = strrchr(type->tp_name, '.');
    object_name = object_name ? object_name+1 : type->tp_name;
    cached_type = (PyTypeObject*) PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        if (__Pyx_VerifyCachedType(
              (PyObject *)cached_type,
              object_name,
              cached_type->tp_basicsize,
              type->tp_basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    if (PyType_Ready(type) < 0) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, (PyObject *)type) < 0)
        goto bad;
    Py_INCREF(type);
    cached_type = type;
done:
    Py_DECREF(abi_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#else
static PyTypeObject *__Pyx_FetchCommonTypeFromSpec(PyObject *module, PyType_Spec *spec, PyObject *bases) {
    PyObject *abi_module, *cached_type = NULL;
    const char* object_name = strrchr(spec->name, '.');
    object_name = object_name ? object_name+1 : spec->name;
    abi_module = __Pyx_FetchSharedCythonABIModule();
    if (!abi_module) return NULL;
    cached_type = PyObject_GetAttrString(abi_module, object_name);
    if (cached_type) {
        Py_ssize_t basicsize;
#if CYTHON_COMPILING_IN_LIMITED_API
        PyObject *py_basicsize;
        py_basicsize = PyObject_GetAttrString(cached_type, "__basicsize__");
        if (unlikely(!py_basicsize)) goto bad;
        basicsize = PyLong_AsSsize_t(py_basicsize);
        Py_DECREF(py_basicsize);
        py_basicsize = 0;
        if (unlikely(basicsize == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
#else
        basicsize = likely(PyType_Check(cached_type)) ? ((PyTypeObject*) cached_type)->tp_basicsize : -1;
#endif
        if (__Pyx_VerifyCachedType(
              cached_type,
              object_name,
              basicsize,
              spec->basicsize) < 0) {
            goto bad;
        }
        goto done;
    }
    if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
    PyErr_Clear();
    CYTHON_UNUSED_VAR(module);
    cached_type = __Pyx_PyType_FromModuleAndSpec(abi_module, spec, bases);
    if (unlikely(!cached_type)) goto bad;
    if (unlikely(__Pyx_fix_up_extension_type_from_spec(spec, (PyTypeObject *) cached_type) < 0)) goto bad;
    if (PyObject_SetAttrString(abi_module, object_name, cached_type) < 0) goto bad;
done:
    Py_DECREF(abi_module);
    assert(cached_type == NULL || PyType_Check(cached_type));
    return (PyTypeObject *) cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}
#endif

/* PyVectorcallFastCallDict */
  #if CYTHON_METH_FASTCALL
static PyObject *__Pyx_PyVectorcall_FastCallDict_kw(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    PyObject *res = NULL;
    PyObject *kwnames;
    PyObject **newargs;
    PyObject **kwvalues;
    Py_ssize_t i, pos;
    size_t j;
    PyObject *key, *value;
    unsigned long keys_are_strings;
    Py_ssize_t nkw = PyDict_GET_SIZE(kw);
    newargs = (PyObject **)PyMem_Malloc((nargs + (size_t)nkw) * sizeof(args[0]));
    if (unlikely(newargs == NULL)) {
        PyErr_NoMemory();
        return NULL;
    }
    for (j = 0; j < nargs; j++) newargs[j] = args[j];
    kwnames = PyTuple_New(nkw);
    if (unlikely(kwnames == NULL)) {
        PyMem_Free(newargs);
        return NULL;
    }
    kwvalues = newargs + nargs;
    pos = i = 0;
    keys_are_strings = Py_TPFLAGS_UNICODE_SUBCLASS;
    while (PyDict_Next(kw, &pos, &key, &value)) {
        keys_are_strings &= Py_TYPE(key)->tp_flags;
        Py_INCREF(key);
        Py_INCREF(value);
        PyTuple_SET_ITEM(kwnames, i, key);
        kwvalues[i] = value;
        i++;
    }
    if (unlikely(!keys_are_strings)) {
        PyErr_SetString(PyExc_TypeError, "keywords must be strings");
        goto cleanup;
    }
    res = vc(func, newargs, nargs, kwnames);
cleanup:
    Py_DECREF(kwnames);
    for (i = 0; i < nkw; i++)
        Py_DECREF(kwvalues[i]);
    PyMem_Free(newargs);
    return res;
}
static CYTHON_INLINE PyObject *__Pyx_PyVectorcall_FastCallDict(PyObject *func, __pyx_vectorcallfunc vc, PyObject *const *args, size_t nargs, PyObject *kw)
{
    if (likely(kw == NULL) || PyDict_GET_SIZE(kw) == 0) {
        return vc(func, args, nargs, NULL);
    }
    return __Pyx_PyVectorcall_FastCallDict_kw(func, vc, args, nargs, kw);
}
#endif

/* CythonFunctionShared */
  #if CYTHON_COMPILING_IN_LIMITED_API
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc) {
    if (__Pyx_CyFunction_Check(func)) {
        return PyCFunction_GetFunction(((__pyx_CyFunctionObject*)func)->func) == (PyCFunction) cfunc;
    } else if (PyCFunction_Check(func)) {
        return PyCFunction_GetFunction(func) == (PyCFunction) cfunc;
    }
    return 0;
}
#else
static CYTHON_INLINE int __Pyx__IsSameCyOrCFunction(PyObject *func, void *cfunc) {
    return __Pyx_CyOrPyCFunction_Check(func) && __Pyx_CyOrPyCFunction_GET_FUNCTION(func) == (PyCFunction) cfunc;
}
#endif
static CYTHON_INLINE void __Pyx__CyFunction_SetClassObj(__pyx_CyFunctionObject* f, PyObject* classobj) {
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    __Pyx_Py_XDECREF_SET(
        __Pyx_CyFunction_GetClassObj(f),
            ((classobj) ? __Pyx_NewRef(classobj) : NULL));
#else
    __Pyx_Py_XDECREF_SET(
        ((PyCMethodObject *) (f))->mm_class,
        (PyTypeObject*)((classobj) ? __Pyx_NewRef(classobj) : NULL));
#endif
}
static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, void *closure)
{
    CYTHON_UNUSED_VAR(closure);
    if (unlikely(op->func_doc == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_doc = PyObject_GetAttrString(op->func, "__doc__");
        if (unlikely(!op->func_doc)) return NULL;
#else
        if (((PyCFunctionObject*)op)->m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(((PyCFunctionObject*)op)->m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
#endif
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_doc, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_name == NULL)) {
#if CYTHON_COMPILING_IN_LIMITED_API
        op->func_name = PyObject_GetAttrString(op->func, "__name__");
#elif PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(((PyCFunctionObject*)op)->m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_name, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value)))
#else
    if (unlikely(value == NULL || !PyString_Check(value)))
#endif
    {
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_qualname, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value, void *context)
{
    CYTHON_UNUSED_VAR(context);
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_dict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(__pyx_CyFunctionObject *op, void *context)
{
    CYTHON_UNUSED_VAR(op);
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op, void *context)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    CYTHON_UNUSED_VAR(context);
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = __Pyx_PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = __Pyx_PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyTuple_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__defaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_tuple, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_tuple;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value) {
        value = Py_None;
    } else if (unlikely(value != Py_None && !PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    PyErr_WarnEx(PyExc_RuntimeWarning, "changes to cyfunction.__kwdefaults__ will not "
                 "currently affect the values used in function calls", 1);
    Py_INCREF(value);
    __Pyx_Py_XDECREF_SET(op->defaults_kwdict, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->defaults_kwdict;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (unlikely(__Pyx_CyFunction_init_defaults(op) < 0)) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    if (!value || value == Py_None) {
        value = NULL;
    } else if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    __Pyx_Py_XDECREF_SET(op->func_annotations, value);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op, void *context) {
    PyObject* result = op->func_annotations;
    CYTHON_UNUSED_VAR(context);
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyObject *
__Pyx_CyFunction_get_is_coroutine(__pyx_CyFunctionObject *op, void *context) {
    int is_coroutine;
    CYTHON_UNUSED_VAR(context);
    if (op->func_is_coroutine) {
        return __Pyx_NewRef(op->func_is_coroutine);
    }
    is_coroutine = op->flags & __Pyx_CYFUNCTION_COROUTINE;
#if PY_VERSION_HEX >= 0x03050000
    if (is_coroutine) {
        PyObject *module, *fromlist, *marker = __pyx_n_s_is_coroutine;
        fromlist = PyList_New(1);
        if (unlikely(!fromlist)) return NULL;
        Py_INCREF(marker);
#if CYTHON_ASSUME_SAFE_MACROS
        PyList_SET_ITEM(fromlist, 0, marker);
#else
        if (unlikely(PyList_SetItem(fromlist, 0, marker) < 0)) {
            Py_DECREF(marker);
            Py_DECREF(fromlist);
            return NULL;
        }
#endif
        module = PyImport_ImportModuleLevelObject(__pyx_n_s_asyncio_coroutines, NULL, NULL, fromlist, 0);
        Py_DECREF(fromlist);
        if (unlikely(!module)) goto ignore;
        op->func_is_coroutine = __Pyx_PyObject_GetAttrStr(module, marker);
        Py_DECREF(module);
        if (likely(op->func_is_coroutine)) {
            return __Pyx_NewRef(op->func_is_coroutine);
        }
ignore:
        PyErr_Clear();
    }
#endif
    op->func_is_coroutine = __Pyx_PyBool_FromLong(is_coroutine);
    return __Pyx_NewRef(op->func_is_coroutine);
}
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *
__Pyx_CyFunction_get_module(__pyx_CyFunctionObject *op, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_GetAttrString(op->func, "__module__");
}
static int
__Pyx_CyFunction_set_module(__pyx_CyFunctionObject *op, PyObject* value, void *context) {
    CYTHON_UNUSED_VAR(context);
    return PyObject_SetAttrString(op->func, "__module__", value);
}
#endif
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {(char *) "_is_coroutine", (getter)__Pyx_CyFunction_get_is_coroutine, 0, 0, 0},
#if CYTHON_COMPILING_IN_LIMITED_API
    {"__module__", (getter)__Pyx_CyFunction_get_module, (setter)__Pyx_CyFunction_set_module, 0, 0},
#endif
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
#if !CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__module__", T_OBJECT, offsetof(PyCFunctionObject, m_module), 0, 0},
#endif
#if CYTHON_USE_TYPE_SPECS
    {(char *) "__dictoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_dict), READONLY, 0},
#if CYTHON_METH_FASTCALL
#if CYTHON_BACKPORT_VECTORCALL
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_vectorcall), READONLY, 0},
#else
#if !CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__vectorcalloffset__", T_PYSSIZET, offsetof(PyCFunctionObject, vectorcall), READONLY, 0},
#endif
#endif
#endif
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(__pyx_CyFunctionObject, func_weakreflist), READONLY, 0},
#else
    {(char *) "__weaklistoffset__", T_PYSSIZET, offsetof(PyCFunctionObject, m_weakreflist), READONLY, 0},
#endif
#endif
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, PyObject *args)
{
    CYTHON_UNUSED_VAR(args);
#if PY_MAJOR_VERSION >= 3
    Py_INCREF(m->func_qualname);
    return m->func_qualname;
#else
    return PyString_FromString(((PyCFunctionObject*)m)->m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0 || CYTHON_COMPILING_IN_LIMITED_API
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) (((PyCFunctionObject*)cyfunc)->m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_Init(__pyx_CyFunctionObject *op, PyMethodDef *ml, int flags, PyObject* qualname,
                                       PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
#if !CYTHON_COMPILING_IN_LIMITED_API
    PyCFunctionObject *cf = (PyCFunctionObject*) op;
#endif
    if (unlikely(op == NULL))
        return NULL;
#if CYTHON_COMPILING_IN_LIMITED_API
    op->func = PyCFunction_NewEx(ml, (PyObject*)op, module);
    if (unlikely(!op->func)) return NULL;
#endif
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
#if !CYTHON_COMPILING_IN_LIMITED_API
    cf->m_ml = ml;
    cf->m_self = (PyObject *) op;
#endif
    Py_XINCREF(closure);
    op->func_closure = closure;
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_XINCREF(module);
    cf->m_module = module;
#endif
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
#if PY_VERSION_HEX < 0x030900B1 || CYTHON_COMPILING_IN_LIMITED_API
    op->func_classobj = NULL;
#else
    ((PyCMethodObject*)op)->mm_class = NULL;
#endif
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults_size = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    op->func_is_coroutine = NULL;
#if CYTHON_METH_FASTCALL
    switch (ml->ml_flags & (METH_VARARGS | METH_FASTCALL | METH_NOARGS | METH_O | METH_KEYWORDS | METH_METHOD)) {
    case METH_NOARGS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_NOARGS;
        break;
    case METH_O:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_O;
        break;
    case METH_METHOD | METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD;
        break;
    case METH_FASTCALL | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS;
        break;
    case METH_VARARGS | METH_KEYWORDS:
        __Pyx_CyFunction_func_vectorcall(op) = NULL;
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        Py_DECREF(op);
        return NULL;
    }
#endif
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_CLEAR(m->func);
#else
    Py_CLEAR(((PyCFunctionObject*)m)->m_module);
#endif
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
#if PY_VERSION_HEX < 0x030900B1
    Py_CLEAR(__Pyx_CyFunction_GetClassObj(m));
#else
    {
        PyObject *cls = (PyObject*) ((PyCMethodObject *) (m))->mm_class;
        ((PyCMethodObject *) (m))->mm_class = NULL;
        Py_XDECREF(cls);
    }
#endif
#endif
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    Py_CLEAR(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyObject_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx__CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    __Pyx_PyHeapTypeObject_GC_Del(m);
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    __Pyx__CyFunction_dealloc(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
#if CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(m->func);
#else
    Py_VISIT(((PyCFunctionObject*)m)->m_module);
#endif
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
#if !CYTHON_COMPILING_IN_LIMITED_API
    Py_VISIT(__Pyx_CyFunction_GetClassObj(m));
#endif
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    Py_VISIT(m->func_is_coroutine);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
static PyObject * __Pyx_CyFunction_CallMethod(PyObject *func, PyObject *self, PyObject *arg, PyObject *kw) {
#if CYTHON_COMPILING_IN_LIMITED_API
    PyObject *f = ((__pyx_CyFunctionObject*)func)->func;
    PyObject *py_name = NULL;
    PyCFunction meth;
    int flags;
    meth = PyCFunction_GetFunction(f);
    if (unlikely(!meth)) return NULL;
    flags = PyCFunction_GetFlags(f);
    if (unlikely(flags < 0)) return NULL;
#else
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    int flags = f->m_ml->ml_flags;
#endif
    Py_ssize_t size;
    switch (flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)(void*)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 0))
                return (*meth)(self, NULL);
#if CYTHON_COMPILING_IN_LIMITED_API
            py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
            if (!py_name) return NULL;
            PyErr_Format(PyExc_TypeError,
                "%.200S() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                py_name, size);
            Py_DECREF(py_name);
#else
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
#endif
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
#if CYTHON_ASSUME_SAFE_MACROS
            size = PyTuple_GET_SIZE(arg);
#else
            size = PyTuple_Size(arg);
            if (unlikely(size < 0)) return NULL;
#endif
            if (likely(size == 1)) {
                PyObject *result, *arg0;
                #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
                arg0 = PyTuple_GET_ITEM(arg, 0);
                #else
                arg0 = __Pyx_PySequence_ITEM(arg, 0); if (unlikely(!arg0)) return NULL;
                #endif
                result = (*meth)(self, arg0);
                #if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
                Py_DECREF(arg0);
                #endif
                return result;
            }
#if CYTHON_COMPILING_IN_LIMITED_API
            py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
            if (!py_name) return NULL;
            PyErr_Format(PyExc_TypeError,
                "%.200S() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                py_name, size);
            Py_DECREF(py_name);
#else
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
#endif
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags for CyFunction");
        return NULL;
    }
#if CYTHON_COMPILING_IN_LIMITED_API
    py_name = __Pyx_CyFunction_get_name((__pyx_CyFunctionObject*)func, NULL);
    if (!py_name) return NULL;
    PyErr_Format(PyExc_TypeError, "%.200S() takes no keyword arguments",
                 py_name);
    Py_DECREF(py_name);
#else
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
#endif
    return NULL;
}
static CYTHON_INLINE PyObject *__Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *self, *result;
#if CYTHON_COMPILING_IN_LIMITED_API
    self = PyCFunction_GetSelf(((__pyx_CyFunctionObject*)func)->func);
    if (unlikely(!self) && PyErr_Occurred()) return NULL;
#else
    self = ((PyCFunctionObject*)func)->m_self;
#endif
    result = __Pyx_CyFunction_CallMethod(func, self, arg, kw);
    return result;
}
static PyObject *__Pyx_CyFunction_CallAsMethod(PyObject *func, PyObject *args, PyObject *kw) {
    PyObject *result;
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
#if CYTHON_METH_FASTCALL
     __pyx_vectorcallfunc vc = __Pyx_CyFunction_func_vectorcall(cyfunc);
    if (vc) {
#if CYTHON_ASSUME_SAFE_MACROS
        return __Pyx_PyVectorcall_FastCallDict(func, vc, &PyTuple_GET_ITEM(args, 0), (size_t)PyTuple_GET_SIZE(args), kw);
#else
        (void) &__Pyx_PyVectorcall_FastCallDict;
        return PyVectorcall_Call(func, args, kw);
#endif
    }
#endif
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        Py_ssize_t argc;
        PyObject *new_args;
        PyObject *self;
#if CYTHON_ASSUME_SAFE_MACROS
        argc = PyTuple_GET_SIZE(args);
#else
        argc = PyTuple_Size(args);
        if (unlikely(!argc) < 0) return NULL;
#endif
        new_args = PyTuple_GetSlice(args, 1, argc);
        if (unlikely(!new_args))
            return NULL;
        self = PyTuple_GetItem(args, 0);
        if (unlikely(!self)) {
            Py_DECREF(new_args);
#if PY_MAJOR_VERSION > 2
            PyErr_Format(PyExc_TypeError,
                         "unbound method %.200S() needs an argument",
                         cyfunc->func_qualname);
#else
            PyErr_SetString(PyExc_TypeError,
                            "unbound method needs an argument");
#endif
            return NULL;
        }
        result = __Pyx_CyFunction_CallMethod(func, self, new_args, kw);
        Py_DECREF(new_args);
    } else {
        result = __Pyx_CyFunction_Call(func, args, kw);
    }
    return result;
}
#if CYTHON_METH_FASTCALL
static CYTHON_INLINE int __Pyx_CyFunction_Vectorcall_CheckArgs(__pyx_CyFunctionObject *cyfunc, Py_ssize_t nargs, PyObject *kwnames)
{
    int ret = 0;
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !(cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD)) {
        if (unlikely(nargs < 1)) {
            PyErr_Format(PyExc_TypeError, "%.200s() needs an argument",
                         ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
            return -1;
        }
        ret = 1;
    }
    if (unlikely(kwnames) && unlikely(PyTuple_GET_SIZE(kwnames))) {
        PyErr_Format(PyExc_TypeError,
                     "%.200s() takes no keyword arguments", ((PyCFunctionObject*)cyfunc)->m_ml->ml_name);
        return -1;
    }
    return ret;
}
static PyObject * __Pyx_CyFunction_Vectorcall_NOARGS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 0)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, NULL);
}
static PyObject * __Pyx_CyFunction_Vectorcall_O(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, kwnames)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    if (unlikely(nargs != 1)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
            def->ml_name, nargs);
        return NULL;
    }
    return def->ml_meth(self, args[0]);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((_PyCFunctionFastWithKeywords)(void(*)(void))def->ml_meth)(self, args, nargs, kwnames);
}
static PyObject * __Pyx_CyFunction_Vectorcall_FASTCALL_KEYWORDS_METHOD(PyObject *func, PyObject *const *args, size_t nargsf, PyObject *kwnames)
{
    __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *)func;
    PyMethodDef* def = ((PyCFunctionObject*)cyfunc)->m_ml;
    PyTypeObject *cls = (PyTypeObject *) __Pyx_CyFunction_GetClassObj(cyfunc);
#if CYTHON_BACKPORT_VECTORCALL
    Py_ssize_t nargs = (Py_ssize_t)nargsf;
#else
    Py_ssize_t nargs = PyVectorcall_NARGS(nargsf);
#endif
    PyObject *self;
    switch (__Pyx_CyFunction_Vectorcall_CheckArgs(cyfunc, nargs, NULL)) {
    case 1:
        self = args[0];
        args += 1;
        nargs -= 1;
        break;
    case 0:
        self = ((PyCFunctionObject*)cyfunc)->m_self;
        break;
    default:
        return NULL;
    }
    return ((__Pyx_PyCMethod)(void(*)(void))def->ml_meth)(self, cls, args, (size_t)nargs, kwnames);
}
#endif
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_CyFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__Pyx_CyFunction_dealloc},
    {Py_tp_repr, (void *)__Pyx_CyFunction_repr},
    {Py_tp_call, (void *)__Pyx_CyFunction_CallAsMethod},
    {Py_tp_traverse, (void *)__Pyx_CyFunction_traverse},
    {Py_tp_clear, (void *)__Pyx_CyFunction_clear},
    {Py_tp_methods, (void *)__pyx_CyFunction_methods},
    {Py_tp_members, (void *)__pyx_CyFunction_members},
    {Py_tp_getset, (void *)__pyx_CyFunction_getsets},
    {Py_tp_descr_get, (void *)__Pyx_PyMethod_New},
    {0, 0},
};
static PyType_Spec __pyx_CyFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if (defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL)
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_CyFunctionType_slots
};
#else
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __PYX_TYPE_MODULE_PREFIX "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
#if !CYTHON_METH_FASTCALL
    0,
#elif CYTHON_BACKPORT_VECTORCALL
    (printfunc)offsetof(__pyx_CyFunctionObject, func_vectorcall),
#else
    offsetof(PyCFunctionObject, vectorcall),
#endif
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_CallAsMethod,
    0,
    0,
    0,
    0,
#ifdef Py_TPFLAGS_METHOD_DESCRIPTOR
    Py_TPFLAGS_METHOD_DESCRIPTOR |
#endif
#if defined(_Py_TPFLAGS_HAVE_VECTORCALL) && CYTHON_METH_FASTCALL
    _Py_TPFLAGS_HAVE_VECTORCALL |
#endif
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_PyMethod_New,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if __PYX_NEED_TP_PRINT_SLOT
    0,
#endif
#if PY_VERSION_HEX >= 0x030C0000
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
    0,
#endif
};
#endif
static int __pyx_CyFunction_init(PyObject *module) {
#if CYTHON_USE_TYPE_SPECS
    __pyx_CyFunctionType = __Pyx_FetchCommonTypeFromSpec(module, &__pyx_CyFunctionType_spec, NULL);
#else
    CYTHON_UNUSED_VAR(module);
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
#endif
    if (unlikely(__pyx_CyFunctionType == NULL)) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyObject_Malloc(size);
    if (unlikely(!m->defaults))
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    m->defaults_size = size;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

/* CythonFunction */
  static PyObject *__Pyx_CyFunction_New(PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_CyFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        PyObject_GC_Track(op);
    }
    return op;
}

/* FusedFunction */
  static PyObject *
__pyx_FusedFunction_New(PyMethodDef *ml, int flags,
                        PyObject *qualname, PyObject *closure,
                        PyObject *module, PyObject *globals,
                        PyObject *code)
{
    PyObject *op = __Pyx_CyFunction_Init(
        PyObject_GC_New(__pyx_CyFunctionObject, __pyx_FusedFunctionType),
        ml, flags, qualname, closure, module, globals, code
    );
    if (likely(op)) {
        __pyx_FusedFunctionObject *fusedfunc = (__pyx_FusedFunctionObject *) op;
        fusedfunc->__signatures__ = NULL;
        fusedfunc->self = NULL;
        PyObject_GC_Track(op);
    }
    return op;
}
static void
__pyx_FusedFunction_dealloc(__pyx_FusedFunctionObject *self)
{
    PyObject_GC_UnTrack(self);
    Py_CLEAR(self->self);
    Py_CLEAR(self->__signatures__);
    __Pyx__CyFunction_dealloc((__pyx_CyFunctionObject *) self);
}
static int
__pyx_FusedFunction_traverse(__pyx_FusedFunctionObject *self,
                             visitproc visit,
                             void *arg)
{
    Py_VISIT(self->self);
    Py_VISIT(self->__signatures__);
    return __Pyx_CyFunction_traverse((__pyx_CyFunctionObject *) self, visit, arg);
}
static int
__pyx_FusedFunction_clear(__pyx_FusedFunctionObject *self)
{
    Py_CLEAR(self->self);
    Py_CLEAR(self->__signatures__);
    return __Pyx_CyFunction_clear((__pyx_CyFunctionObject *) self);
}
static PyObject *
__pyx_FusedFunction_descr_get(PyObject *self, PyObject *obj, PyObject *type)
{
    __pyx_FusedFunctionObject *func, *meth;
    func = (__pyx_FusedFunctionObject *) self;
    if (func->self || func->func.flags & __Pyx_CYFUNCTION_STATICMETHOD) {
        Py_INCREF(self);
        return self;
    }
    if (obj == Py_None)
        obj = NULL;
    if (func->func.flags & __Pyx_CYFUNCTION_CLASSMETHOD)
        obj = type;
    if (obj == NULL) {
        Py_INCREF(self);
        return self;
    }
    meth = (__pyx_FusedFunctionObject *) __pyx_FusedFunction_New(
                    ((PyCFunctionObject *) func)->m_ml,
                    ((__pyx_CyFunctionObject *) func)->flags,
                    ((__pyx_CyFunctionObject *) func)->func_qualname,
                    ((__pyx_CyFunctionObject *) func)->func_closure,
                    ((PyCFunctionObject *) func)->m_module,
                    ((__pyx_CyFunctionObject *) func)->func_globals,
                    ((__pyx_CyFunctionObject *) func)->func_code);
    if (unlikely(!meth))
        return NULL;
    if (func->func.defaults) {
        PyObject **pydefaults;
        int i;
        if (unlikely(!__Pyx_CyFunction_InitDefaults(
                (PyObject*)meth,
                func->func.defaults_size,
                func->func.defaults_pyobjects))) {
            Py_XDECREF((PyObject*)meth);
            return NULL;
        }
        memcpy(meth->func.defaults, func->func.defaults, func->func.defaults_size);
        pydefaults = __Pyx_CyFunction_Defaults(PyObject *, meth);
        for (i = 0; i < meth->func.defaults_pyobjects; i++)
            Py_XINCREF(pydefaults[i]);
    }
    __Pyx_CyFunction_SetClassObj(meth, __Pyx_CyFunction_GetClassObj(func));
    Py_XINCREF(func->__signatures__);
    meth->__signatures__ = func->__signatures__;
    Py_XINCREF(func->func.defaults_tuple);
    meth->func.defaults_tuple = func->func.defaults_tuple;
    Py_XINCREF(obj);
    meth->self = obj;
    return (PyObject *) meth;
}
static PyObject *
_obj_to_string(PyObject *obj)
{
    if (PyUnicode_CheckExact(obj))
        return __Pyx_NewRef(obj);
#if PY_MAJOR_VERSION == 2
    else if (PyString_Check(obj))
        return PyUnicode_FromEncodedObject(obj, NULL, "strict");
#endif
    else if (PyType_Check(obj))
        return PyObject_GetAttr(obj, __pyx_n_s_name_2);
    else
        return PyObject_Unicode(obj);
}
static PyObject *
__pyx_FusedFunction_getitem(__pyx_FusedFunctionObject *self, PyObject *idx)
{
    PyObject *signature = NULL;
    PyObject *unbound_result_func;
    PyObject *result_func = NULL;
    if (unlikely(self->__signatures__ == NULL)) {
        PyErr_SetString(PyExc_TypeError, "Function is not fused");
        return NULL;
    }
    if (PyTuple_Check(idx)) {
        Py_ssize_t n = PyTuple_GET_SIZE(idx);
        PyObject *list = PyList_New(n);
        int i;
        if (unlikely(!list))
            return NULL;
        for (i = 0; i < n; i++) {
            PyObject *string;
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            PyObject *item = PyTuple_GET_ITEM(idx, i);
#else
            PyObject *item = PySequence_ITEM(idx, i);  if (unlikely(!item)) goto __pyx_err;
#endif
            string = _obj_to_string(item);
#if !(CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS)
            Py_DECREF(item);
#endif
            if (unlikely(!string)) goto __pyx_err;
            PyList_SET_ITEM(list, i, string);
        }
        signature = PyUnicode_Join(__pyx_kp_u__70, list);
__pyx_err:;
        Py_DECREF(list);
    } else {
        signature = _obj_to_string(idx);
    }
    if (unlikely(!signature))
        return NULL;
    unbound_result_func = PyObject_GetItem(self->__signatures__, signature);
    if (likely(unbound_result_func)) {
        if (self->self) {
            __pyx_FusedFunctionObject *unbound = (__pyx_FusedFunctionObject *) unbound_result_func;
            __Pyx_CyFunction_SetClassObj(unbound, __Pyx_CyFunction_GetClassObj(self));
            result_func = __pyx_FusedFunction_descr_get(unbound_result_func,
                                                        self->self, self->self);
        } else {
            result_func = unbound_result_func;
            Py_INCREF(result_func);
        }
    }
    Py_DECREF(signature);
    Py_XDECREF(unbound_result_func);
    return result_func;
}
static PyObject *
__pyx_FusedFunction_callfunction(PyObject *func, PyObject *args, PyObject *kw)
{
     __pyx_CyFunctionObject *cyfunc = (__pyx_CyFunctionObject *) func;
    int static_specialized = (cyfunc->flags & __Pyx_CYFUNCTION_STATICMETHOD &&
                              !((__pyx_FusedFunctionObject *) func)->__signatures__);
    if ((cyfunc->flags & __Pyx_CYFUNCTION_CCLASS) && !static_specialized) {
        return __Pyx_CyFunction_CallAsMethod(func, args, kw);
    } else {
        return __Pyx_CyFunction_Call(func, args, kw);
    }
}
static PyObject *
__pyx_FusedFunction_call(PyObject *func, PyObject *args, PyObject *kw)
{
    __pyx_FusedFunctionObject *binding_func = (__pyx_FusedFunctionObject *) func;
    Py_ssize_t argc = PyTuple_GET_SIZE(args);
    PyObject *new_args = NULL;
    __pyx_FusedFunctionObject *new_func = NULL;
    PyObject *result = NULL;
    int is_staticmethod = binding_func->func.flags & __Pyx_CYFUNCTION_STATICMETHOD;
    if (binding_func->self) {
        PyObject *self;
        Py_ssize_t i;
        new_args = PyTuple_New(argc + 1);
        if (unlikely(!new_args))
            return NULL;
        self = binding_func->self;
        Py_INCREF(self);
        PyTuple_SET_ITEM(new_args, 0, self);
        self = NULL;
        for (i = 0; i < argc; i++) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
            PyObject *item = PyTuple_GET_ITEM(args, i);
            Py_INCREF(item);
#else
            PyObject *item = PySequence_ITEM(args, i);  if (unlikely(!item)) goto bad;
#endif
            PyTuple_SET_ITEM(new_args, i + 1, item);
        }
        args = new_args;
    }
    if (binding_func->__signatures__) {
        PyObject *tup;
        if (is_staticmethod && binding_func->func.flags & __Pyx_CYFUNCTION_CCLASS) {
            tup = PyTuple_Pack(3, args,
                               kw == NULL ? Py_None : kw,
                               binding_func->func.defaults_tuple);
            if (unlikely(!tup)) goto bad;
            new_func = (__pyx_FusedFunctionObject *) __Pyx_CyFunction_CallMethod(
                func, binding_func->__signatures__, tup, NULL);
        } else {
            tup = PyTuple_Pack(4, binding_func->__signatures__, args,
                               kw == NULL ? Py_None : kw,
                               binding_func->func.defaults_tuple);
            if (unlikely(!tup)) goto bad;
            new_func = (__pyx_FusedFunctionObject *) __pyx_FusedFunction_callfunction(func, tup, NULL);
        }
        Py_DECREF(tup);
        if (unlikely(!new_func))
            goto bad;
        __Pyx_CyFunction_SetClassObj(new_func, __Pyx_CyFunction_GetClassObj(binding_func));
        func = (PyObject *) new_func;
    }
    result = __pyx_FusedFunction_callfunction(func, args, kw);
bad:
    Py_XDECREF(new_args);
    Py_XDECREF((PyObject *) new_func);
    return result;
}
static PyMemberDef __pyx_FusedFunction_members[] = {
    {(char *) "__signatures__",
     T_OBJECT,
     offsetof(__pyx_FusedFunctionObject, __signatures__),
     READONLY,
     0},
    {(char *) "__self__", T_OBJECT_EX, offsetof(__pyx_FusedFunctionObject, self), READONLY, 0},
    {0, 0, 0, 0, 0},
};
static PyGetSetDef __pyx_FusedFunction_getsets[] = {
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {0, 0, 0, 0, 0}
};
#if CYTHON_USE_TYPE_SPECS
static PyType_Slot __pyx_FusedFunctionType_slots[] = {
    {Py_tp_dealloc, (void *)__pyx_FusedFunction_dealloc},
    {Py_tp_call, (void *)__pyx_FusedFunction_call},
    {Py_tp_traverse, (void *)__pyx_FusedFunction_traverse},
    {Py_tp_clear, (void *)__pyx_FusedFunction_clear},
    {Py_tp_members, (void *)__pyx_FusedFunction_members},
    {Py_tp_getset, (void *)__pyx_FusedFunction_getsets},
    {Py_tp_descr_get, (void *)__pyx_FusedFunction_descr_get},
    {Py_mp_subscript, (void *)__pyx_FusedFunction_getitem},
    {0, 0},
};
static PyType_Spec __pyx_FusedFunctionType_spec = {
    __PYX_TYPE_MODULE_PREFIX "fused_cython_function",
    sizeof(__pyx_FusedFunctionObject),
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    __pyx_FusedFunctionType_slots
};
#else
static PyMappingMethods __pyx_FusedFunction_mapping_methods = {
    0,
    (binaryfunc) __pyx_FusedFunction_getitem,
    0,
};
static PyTypeObject __pyx_FusedFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    __PYX_TYPE_MODULE_PREFIX "fused_cython_function",
    sizeof(__pyx_FusedFunctionObject),
    0,
    (destructor) __pyx_FusedFunction_dealloc,
    0,
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    0,
    0,
    0,
    &__pyx_FusedFunction_mapping_methods,
    0,
    (ternaryfunc) __pyx_FusedFunction_call,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC | Py_TPFLAGS_BASETYPE,
    0,
    (traverseproc) __pyx_FusedFunction_traverse,
    (inquiry) __pyx_FusedFunction_clear,
    0,
    0,
    0,
    0,
    0,
    __pyx_FusedFunction_members,
    __pyx_FusedFunction_getsets,
    &__pyx_CyFunctionType_type,
    0,
    __pyx_FusedFunction_descr_get,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
#if PY_VERSION_HEX >= 0x030800b1 && (!CYTHON_COMPILING_IN_PYPY || PYPY_VERSION_NUM >= 0x07030800)
    0,
#endif
#if __PYX_NEED_TP_PRINT_SLOT
    0,
#endif
#if PY_VERSION_HEX >= 0x030C0000
    0,
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX >= 0x03090000 && PY_VERSION_HEX < 0x030a0000
    0,
#endif
};
#endif
static int __pyx_FusedFunction_init(PyObject *module) {
#if CYTHON_USE_TYPE_SPECS
    PyObject *bases = PyTuple_Pack(1, __pyx_CyFunctionType);
    if (unlikely(!bases)) {
        return -1;
    }
    __pyx_FusedFunctionType = __Pyx_FetchCommonTypeFromSpec(module, &__pyx_FusedFunctionType_spec, bases);
    Py_DECREF(bases);
#else
    CYTHON_UNUSED_VAR(module);
    __pyx_FusedFunctionType_type.tp_base = __pyx_CyFunctionType;
    __pyx_FusedFunctionType = __Pyx_FetchCommonType(&__pyx_FusedFunctionType_type);
#endif
    if (unlikely(__pyx_FusedFunctionType == NULL)) {
        return -1;
    }
    return 0;
}

/* CLineInTraceback */
  #ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    CYTHON_MAYBE_UNUSED_VAR(tstate);
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStrNoError(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        (void) PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
  #if !CYTHON_COMPILING_IN_LIMITED_API
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}
#endif

/* AddTraceback */
  #include "compile.h"
#include "frameobject.h"
#include "traceback.h"
#if PY_VERSION_HEX >= 0x030b00a6 && !CYTHON_COMPILING_IN_LIMITED_API
  #ifndef Py_BUILD_CORE
    #define Py_BUILD_CORE 1
  #endif
  #include "internal/pycore_frame.h"
#endif
#if CYTHON_COMPILING_IN_LIMITED_API
static PyObject *__Pyx_PyCode_Replace_For_AddTraceback(PyObject *code, PyObject *scratch_dict,
                                                       PyObject *firstlineno, PyObject *name) {
    PyObject *replace = NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_firstlineno", firstlineno))) return NULL;
    if (unlikely(PyDict_SetItemString(scratch_dict, "co_name", name))) return NULL;
    replace = PyObject_GetAttrString(code, "replace");
    if (likely(replace)) {
        PyObject *result;
        result = PyObject_Call(replace, __pyx_empty_tuple, scratch_dict);
        Py_DECREF(replace);
        return result;
    }
    PyErr_Clear();
    #if __PYX_LIMITED_VERSION_HEX < 0x030780000
    {
        PyObject *compiled = NULL, *result = NULL;
        if (unlikely(PyDict_SetItemString(scratch_dict, "code", code))) return NULL;
        if (unlikely(PyDict_SetItemString(scratch_dict, "type", (PyObject*)(&PyType_Type)))) return NULL;
        compiled = Py_CompileString(
            "out = type(code)(\n"
            "  code.co_argcount, code.co_kwonlyargcount, code.co_nlocals, code.co_stacksize,\n"
            "  code.co_flags, code.co_code, code.co_consts, code.co_names,\n"
            "  code.co_varnames, code.co_filename, co_name, co_firstlineno,\n"
            "  code.co_lnotab)\n", "<dummy>", Py_file_input);
        if (!compiled) return NULL;
        result = PyEval_EvalCode(compiled, scratch_dict, scratch_dict);
        Py_DECREF(compiled);
        if (!result) PyErr_Print();
        Py_DECREF(result);
        result = PyDict_GetItemString(scratch_dict, "out");
        if (result) Py_INCREF(result);
        return result;
    }
    #else
    return NULL;
    #endif
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyObject *code_object = NULL, *py_py_line = NULL, *py_funcname = NULL, *dict = NULL;
    PyObject *replace = NULL, *getframe = NULL, *frame = NULL;
    PyObject *exc_type, *exc_value, *exc_traceback;
    int success = 0;
    if (c_line) {
        (void) __pyx_cfilenm;
        (void) __Pyx_CLineForTraceback(__Pyx_PyThreadState_Current, c_line);
    }
    PyErr_Fetch(&exc_type, &exc_value, &exc_traceback);
    code_object = Py_CompileString("_getframe()", filename, Py_eval_input);
    if (unlikely(!code_object)) goto bad;
    py_py_line = PyLong_FromLong(py_line);
    if (unlikely(!py_py_line)) goto bad;
    py_funcname = PyUnicode_FromString(funcname);
    if (unlikely(!py_funcname)) goto bad;
    dict = PyDict_New();
    if (unlikely(!dict)) goto bad;
    {
        PyObject *old_code_object = code_object;
        code_object = __Pyx_PyCode_Replace_For_AddTraceback(code_object, dict, py_py_line, py_funcname);
        Py_DECREF(old_code_object);
    }
    if (unlikely(!code_object)) goto bad;
    getframe = PySys_GetObject("_getframe");
    if (unlikely(!getframe)) goto bad;
    if (unlikely(PyDict_SetItemString(dict, "_getframe", getframe))) goto bad;
    frame = PyEval_EvalCode(code_object, dict, dict);
    if (unlikely(!frame) || frame == Py_None) goto bad;
    success = 1;
  bad:
    PyErr_Restore(exc_type, exc_value, exc_traceback);
    Py_XDECREF(code_object);
    Py_XDECREF(py_py_line);
    Py_XDECREF(py_funcname);
    Py_XDECREF(dict);
    Py_XDECREF(replace);
    if (success) {
        PyTraceBack_Here(
            (struct _frame*)frame);
    }
    Py_XDECREF(frame);
}
#else
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = NULL;
    PyObject *py_funcname = NULL;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_srcfile = NULL;
    py_srcfile = PyString_FromString(filename);
    if (!py_srcfile) goto bad;
    #endif
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        if (!py_funcname) goto bad;
        funcname = PyUnicode_AsUTF8(py_funcname);
        if (!funcname) goto bad;
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        if (!py_funcname) goto bad;
        #endif
    }
    #if PY_MAJOR_VERSION < 3
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    #else
    py_code = PyCode_NewEmpty(filename, funcname, py_line);
    #endif
    Py_XDECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_funcname);
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_srcfile);
    #endif
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject *ptype, *pvalue, *ptraceback;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) {
            /* If the code object creation fails, then we should clear the
               fetched exception references and propagate the new exception */
            Py_XDECREF(ptype);
            Py_XDECREF(pvalue);
            Py_XDECREF(ptraceback);
            goto bad;
        }
        __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}
#endif

#if PY_MAJOR_VERSION < 3
static int __Pyx_GetBuffer(PyObject *obj, Py_buffer *view, int flags) {
    __Pyx_TypeName obj_type_name;
    if (PyObject_CheckBuffer(obj)) return PyObject_GetBuffer(obj, view, flags);
        if (__Pyx_TypeCheck(obj, __pyx_array_type)) return __pyx_array_getbuffer(obj, view, flags);
        if (__Pyx_TypeCheck(obj, __pyx_memoryview_type)) return __pyx_memoryview_getbuffer(obj, view, flags);
    obj_type_name = __Pyx_PyType_GetName(Py_TYPE(obj));
    PyErr_Format(PyExc_TypeError,
                 "'" __Pyx_FMT_TYPENAME "' does not have the buffer interface",
                 obj_type_name);
    __Pyx_DECREF_TypeName(obj_type_name);
    return -1;
}
static void __Pyx_ReleaseBuffer(Py_buffer *view) {
    PyObject *obj = view->obj;
    if (!obj) return;
    if (PyObject_CheckBuffer(obj)) {
        PyBuffer_Release(view);
        return;
    }
    if ((0)) {}
    view->obj = NULL;
    Py_DECREF(obj);
}
#endif


  /* MemviewSliceIsContig */
  static int
__pyx_memviewslice_is_contig(const __Pyx_memviewslice mvs, char order, int ndim)
{
    int i, index, step, start;
    Py_ssize_t itemsize = mvs.memview->view.itemsize;
    if (order == 'F') {
        step = 1;
        start = 0;
    } else {
        step = -1;
        start = ndim - 1;
    }
    for (i = 0; i < ndim; i++) {
        index = start + step * i;
        if (mvs.suboffsets[index] >= 0 || mvs.strides[index] != itemsize)
            return 0;
        itemsize *= mvs.shape[index];
    }
    return 1;
}

/* OverlappingSlices */
  static void
__pyx_get_array_memory_extents(__Pyx_memviewslice *slice,
                               void **out_start, void **out_end,
                               int ndim, size_t itemsize)
{
    char *start, *end;
    int i;
    start = end = slice->data;
    for (i = 0; i < ndim; i++) {
        Py_ssize_t stride = slice->strides[i];
        Py_ssize_t extent = slice->shape[i];
        if (extent == 0) {
            *out_start = *out_end = start;
            return;
        } else {
            if (stride > 0)
                end += stride * (extent - 1);
            else
                start += stride * (extent - 1);
        }
    }
    *out_start = start;
    *out_end = end + itemsize;
}
static int
__pyx_slices_overlap(__Pyx_memviewslice *slice1,
                     __Pyx_memviewslice *slice2,
                     int ndim, size_t itemsize)
{
    void *start1, *end1, *start2, *end2;
    __pyx_get_array_memory_extents(slice1, &start1, &end1, ndim, itemsize);
    __pyx_get_array_memory_extents(slice2, &start2, &end2, ndim, itemsize);
    return (start1 < end2) && (start2 < end1);
}

/* TypeInfoCompare */
  static int
__pyx_typeinfo_cmp(__Pyx_TypeInfo *a, __Pyx_TypeInfo *b)
{
    int i;
    if (!a || !b)
        return 0;
    if (a == b)
        return 1;
    if (a->size != b->size || a->typegroup != b->typegroup ||
            a->is_unsigned != b->is_unsigned || a->ndim != b->ndim) {
        if (a->typegroup == 'H' || b->typegroup == 'H') {
            return a->size == b->size;
        } else {
            return 0;
        }
    }
    if (a->ndim) {
        for (i = 0; i < a->ndim; i++)
            if (a->arraysize[i] != b->arraysize[i])
                return 0;
    }
    if (a->typegroup == 'S') {
        if (a->flags != b->flags)
            return 0;
        if (a->fields || b->fields) {
            if (!(a->fields && b->fields))
                return 0;
            for (i = 0; a->fields[i].type && b->fields[i].type; i++) {
                __Pyx_StructField *field_a = a->fields + i;
                __Pyx_StructField *field_b = b->fields + i;
                if (field_a->offset != field_b->offset ||
                    !__pyx_typeinfo_cmp(field_a->type, field_b->type))
                    return 0;
            }
            return !a->fields[i].type && !b->fields[i].type;
        }
    }
    return 1;
}

/* MemviewSliceValidateAndInit */
  static int
__pyx_check_strides(Py_buffer *buf, int dim, int ndim, int spec)
{
    if (buf->shape[dim] <= 1)
        return 1;
    if (buf->strides) {
        if (spec & __Pyx_MEMVIEW_CONTIG) {
            if (spec & (__Pyx_MEMVIEW_PTR|__Pyx_MEMVIEW_FULL)) {
                if (unlikely(buf->strides[dim] != sizeof(void *))) {
                    PyErr_Format(PyExc_ValueError,
                                 "Buffer is not indirectly contiguous "
                                 "in dimension %d.", dim);
                    goto fail;
                }
            } else if (unlikely(buf->strides[dim] != buf->itemsize)) {
                PyErr_SetString(PyExc_ValueError,
                                "Buffer and memoryview are not contiguous "
                                "in the same dimension.");
                goto fail;
            }
        }
        if (spec & __Pyx_MEMVIEW_FOLLOW) {
            Py_ssize_t stride = buf->strides[dim];
            if (stride < 0)
                stride = -stride;
            if (unlikely(stride < buf->itemsize)) {
                PyErr_SetString(PyExc_ValueError,
                                "Buffer and memoryview are not contiguous "
                                "in the same dimension.");
                goto fail;
            }
        }
    } else {
        if (unlikely(spec & __Pyx_MEMVIEW_CONTIG && dim != ndim - 1)) {
            PyErr_Format(PyExc_ValueError,
                         "C-contiguous buffer is not contiguous in "
                         "dimension %d", dim);
            goto fail;
        } else if (unlikely(spec & (__Pyx_MEMVIEW_PTR))) {
            PyErr_Format(PyExc_ValueError,
                         "C-contiguous buffer is not indirect in "
                         "dimension %d", dim);
            goto fail;
        } else if (unlikely(buf->suboffsets)) {
            PyErr_SetString(PyExc_ValueError,
                            "Buffer exposes suboffsets but no strides");
            goto fail;
        }
    }
    return 1;
fail:
    return 0;
}
static int
__pyx_check_suboffsets(Py_buffer *buf, int dim, int ndim, int spec)
{
    CYTHON_UNUSED_VAR(ndim);
    if (spec & __Pyx_MEMVIEW_DIRECT) {
        if (unlikely(buf->suboffsets && buf->suboffsets[dim] >= 0)) {
            PyErr_Format(PyExc_ValueError,
                         "Buffer not compatible with direct access "
                         "in dimension %d.", dim);
            goto fail;
        }
    }
    if (spec & __Pyx_MEMVIEW_PTR) {
        if (unlikely(!buf->suboffsets || (buf->suboffsets[dim] < 0))) {
            PyErr_Format(PyExc_ValueError,
                         "Buffer is not indirectly accessible "
                         "in dimension %d.", dim);
            goto fail;
        }
    }
    return 1;
fail:
    return 0;
}
static int
__pyx_verify_contig(Py_buffer *buf, int ndim, int c_or_f_flag)
{
    int i;
    if (c_or_f_flag & __Pyx_IS_F_CONTIG) {
        Py_ssize_t stride = 1;
        for (i = 0; i < ndim; i++) {
            if (unlikely(stride * buf->itemsize != buf->strides[i]  &&  buf->shape[i] > 1)) {
                PyErr_SetString(PyExc_ValueError,
                    "Buffer not fortran contiguous.");
                goto fail;
            }
            stride = stride * buf->shape[i];
        }
    } else if (c_or_f_flag & __Pyx_IS_C_CONTIG) {
        Py_ssize_t stride = 1;
        for (i = ndim - 1; i >- 1; i--) {
            if (unlikely(stride * buf->itemsize != buf->strides[i]  &&  buf->shape[i] > 1)) {
                PyErr_SetString(PyExc_ValueError,
                    "Buffer not C contiguous.");
                goto fail;
            }
            stride = stride * buf->shape[i];
        }
    }
    return 1;
fail:
    return 0;
}
static int __Pyx_ValidateAndInit_memviewslice(
                int *axes_specs,
                int c_or_f_flag,
                int buf_flags,
                int ndim,
                __Pyx_TypeInfo *dtype,
                __Pyx_BufFmt_StackElem stack[],
                __Pyx_memviewslice *memviewslice,
                PyObject *original_obj)
{
    struct __pyx_memoryview_obj *memview, *new_memview;
    __Pyx_RefNannyDeclarations
    Py_buffer *buf;
    int i, spec = 0, retval = -1;
    __Pyx_BufFmt_Context ctx;
    int from_memoryview = __pyx_memoryview_check(original_obj);
    __Pyx_RefNannySetupContext("ValidateAndInit_memviewslice", 0);
    if (from_memoryview && __pyx_typeinfo_cmp(dtype, ((struct __pyx_memoryview_obj *)
                                                            original_obj)->typeinfo)) {
        memview = (struct __pyx_memoryview_obj *) original_obj;
        new_memview = NULL;
    } else {
        memview = (struct __pyx_memoryview_obj *) __pyx_memoryview_new(
                                            original_obj, buf_flags, 0, dtype);
        new_memview = memview;
        if (unlikely(!memview))
            goto fail;
    }
    buf = &memview->view;
    if (unlikely(buf->ndim != ndim)) {
        PyErr_Format(PyExc_ValueError,
                "Buffer has wrong number of dimensions (expected %d, got %d)",
                ndim, buf->ndim);
        goto fail;
    }
    if (new_memview) {
        __Pyx_BufFmt_Init(&ctx, stack, dtype);
        if (unlikely(!__Pyx_BufFmt_CheckString(&ctx, buf->format))) goto fail;
    }
    if (unlikely((unsigned) buf->itemsize != dtype->size)) {
        PyErr_Format(PyExc_ValueError,
                     "Item size of buffer (%" CYTHON_FORMAT_SSIZE_T "u byte%s) "
                     "does not match size of '%s' (%" CYTHON_FORMAT_SSIZE_T "u byte%s)",
                     buf->itemsize,
                     (buf->itemsize > 1) ? "s" : "",
                     dtype->name,
                     dtype->size,
                     (dtype->size > 1) ? "s" : "");
        goto fail;
    }
    if (buf->len > 0) {
        for (i = 0; i < ndim; i++) {
            spec = axes_specs[i];
            if (unlikely(!__pyx_check_strides(buf, i, ndim, spec)))
                goto fail;
            if (unlikely(!__pyx_check_suboffsets(buf, i, ndim, spec)))
                goto fail;
        }
        if (unlikely(buf->strides && !__pyx_verify_contig(buf, ndim, c_or_f_flag)))
            goto fail;
    }
    if (unlikely(__Pyx_init_memviewslice(memview, ndim, memviewslice,
                                         new_memview != NULL) == -1)) {
        goto fail;
    }
    retval = 0;
    goto no_fail;
fail:
    Py_XDECREF(new_memview);
    retval = -1;
no_fail:
    __Pyx_RefNannyFinishContext();
    return retval;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int8_t(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_int8_t, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int16_t(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int32_t(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint16_t(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint16_t, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint32_t(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint32_t, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint64_t(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint64_t, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float32_t(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float64_t(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_object(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_object, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_double_complex(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo___pyx_t_double_complex, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_float_complex(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo___pyx_t_float_complex, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* CIntFromPyVerify */
  #define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* FromPy */
  static __pyx_t_double_complex __Pyx_PyComplex_As___pyx_t_double_complex(PyObject* o) {
    Py_complex cval;
#if !CYTHON_COMPILING_IN_PYPY
    if (PyComplex_CheckExact(o))
        cval = ((PyComplexObject *)o)->cval;
    else
#endif
        cval = PyComplex_AsCComplex(o);
    return __pyx_t_double_complex_from_parts(
               (double)cval.real,
               (double)cval.imag);
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint8_t__const__(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint8_t__const__, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_double_complex__const__(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo___pyx_t_double_complex__const__, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* MemviewDtypeToObject */
  static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_uint8_t__const__(const char *itemp) {
    return (PyObject *) __Pyx_PyInt_From_npy_uint8(*(__pyx_t_5numpy_uint8_t const  *) itemp);
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn_khcomplex128_t__const__(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[2];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn_khcomplex128_t__const__, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float64_t__const__(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t__const__, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint64_t__const__(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint64_t__const__, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int64_t__const__(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t__const__, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* FromPy */
  static __pyx_t_float_complex __Pyx_PyComplex_As___pyx_t_float_complex(PyObject* o) {
    Py_complex cval;
#if !CYTHON_COMPILING_IN_PYPY
    if (PyComplex_CheckExact(o))
        cval = ((PyComplexObject *)o)->cval;
    else
#endif
        cval = PyComplex_AsCComplex(o);
    return __pyx_t_float_complex_from_parts(
               (float)cval.real,
               (float)cval.imag);
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds___pyx_t_float_complex__const__(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo___pyx_t_float_complex__const__, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn_khcomplex64_t__const__(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[2];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn_khcomplex64_t__const__, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_float32_t__const__(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t__const__, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint32_t__const__(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint32_t__const__, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int32_t__const__(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t__const__, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_uint16_t__const__(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_uint16_t__const__, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int16_t__const__(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_int16_t__const__, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_ds_nn___pyx_t_5numpy_int8_t__const__(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_STRIDED) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, 0,
                                                 PyBUF_RECORDS_RO | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_int8_t__const__, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* Declarations */
  #if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return ::std::complex< double >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return x + y*(__pyx_t_double_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      __pyx_t_double_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

/* Arithmetic */
  #if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
#else
    static CYTHON_INLINE int __Pyx_c_eq_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    #if 1
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        if (b.imag == 0) {
            return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else if (fabs(b.real) >= fabs(b.imag)) {
            if (b.real == 0 && b.imag == 0) {
                return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.imag);
            } else {
                double r = b.imag / b.real;
                double s = (double)(1.0) / (b.real + b.imag * r);
                return __pyx_t_double_complex_from_parts(
                    (a.real + a.imag * r) * s, (a.imag - a.real * r) * s);
            }
        } else {
            double r = b.real / b.imag;
            double s = (double)(1.0) / (b.imag + b.real * r);
            return __pyx_t_double_complex_from_parts(
                (a.real * r + a.imag) * s, (a.imag * r - a.real) * s);
        }
    }
    #else
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        if (b.imag == 0) {
            return __pyx_t_double_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else {
            double denom = b.real * b.real + b.imag * b.imag;
            return __pyx_t_double_complex_from_parts(
                (a.real * b.real + a.imag * b.imag) / denom,
                (a.imag * b.real - a.real * b.imag) / denom);
        }
    }
    #endif
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg_double(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero_double(__pyx_t_double_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj_double(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs_double(__pyx_t_double_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrt(z.real*z.real + z.imag*z.imag);
          #else
            return hypot(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow_double(__pyx_t_double_complex a, __pyx_t_double_complex b) {
            __pyx_t_double_complex z;
            double r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    double denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        return __Pyx_c_prod_double(a, a);
                    case 3:
                        z = __Pyx_c_prod_double(a, a);
                        return __Pyx_c_prod_double(z, a);
                    case 4:
                        z = __Pyx_c_prod_double(a, a);
                        return __Pyx_c_prod_double(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                } else if ((b.imag == 0) && (a.real >= 0)) {
                    z.real = pow(a.real, b.real);
                    z.imag = 0;
                    return z;
                } else if (a.real > 0) {
                    r = a.real;
                    theta = 0;
                } else {
                    r = -a.real;
                    theta = atan2(0.0, -1.0);
                }
            } else {
                r = __Pyx_c_abs_double(a);
                theta = atan2(a.imag, a.real);
            }
            lnr = log(r);
            z_r = exp(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cos(z_theta);
            z.imag = z_r * sin(z_theta);
            return z;
        }
    #endif
#endif

/* Declarations */
  #if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return ::std::complex< float >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return x + y*(__pyx_t_float_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      __pyx_t_float_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

/* Arithmetic */
  #if CYTHON_CCOMPLEX && (1) && (!0 || __cplusplus)
#else
    static CYTHON_INLINE int __Pyx_c_eq_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sum_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_diff_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prod_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    #if 1
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        if (b.imag == 0) {
            return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else if (fabsf(b.real) >= fabsf(b.imag)) {
            if (b.real == 0 && b.imag == 0) {
                return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.imag);
            } else {
                float r = b.imag / b.real;
                float s = (float)(1.0) / (b.real + b.imag * r);
                return __pyx_t_float_complex_from_parts(
                    (a.real + a.imag * r) * s, (a.imag - a.real * r) * s);
            }
        } else {
            float r = b.real / b.imag;
            float s = (float)(1.0) / (b.imag + b.real * r);
            return __pyx_t_float_complex_from_parts(
                (a.real * r + a.imag) * s, (a.imag * r - a.real) * s);
        }
    }
    #else
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quot_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        if (b.imag == 0) {
            return __pyx_t_float_complex_from_parts(a.real / b.real, a.imag / b.real);
        } else {
            float denom = b.real * b.real + b.imag * b.imag;
            return __pyx_t_float_complex_from_parts(
                (a.real * b.real + a.imag * b.imag) / denom,
                (a.imag * b.real - a.real * b.imag) / denom);
        }
    }
    #endif
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_neg_float(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero_float(__pyx_t_float_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conj_float(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE float __Pyx_c_abs_float(__pyx_t_float_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrtf(z.real*z.real + z.imag*z.imag);
          #else
            return hypotf(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_pow_float(__pyx_t_float_complex a, __pyx_t_float_complex b) {
            __pyx_t_float_complex z;
            float r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    float denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        return __Pyx_c_prod_float(a, a);
                    case 3:
                        z = __Pyx_c_prod_float(a, a);
                        return __Pyx_c_prod_float(z, a);
                    case 4:
                        z = __Pyx_c_prod_float(a, a);
                        return __Pyx_c_prod_float(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                } else if ((b.imag == 0) && (a.real >= 0)) {
                    z.real = powf(a.real, b.real);
                    z.imag = 0;
                    return z;
                } else if (a.real > 0) {
                    r = a.real;
                    theta = 0;
                } else {
                    r = -a.real;
                    theta = atan2f(0.0, -1.0);
                }
            } else {
                r = __Pyx_c_abs_float(a);
                theta = atan2f(a.imag, a.real);
            }
            lnr = logf(r);
            z_r = expf(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cosf(z_theta);
            z.imag = z_r * sinf(z_theta);
            return z;
        }
    #endif
#endif

static PyObject* __pyx_convert__to_py_khcomplex128_t(khcomplex128_t s) {
    PyObject* res;
    PyObject* member;
    res = __Pyx_PyDict_NewPresized(2); if (unlikely(!res)) return NULL;
    member = PyFloat_FromDouble(s.real); if (unlikely(!member)) goto bad;
    if (unlikely(PyDict_SetItem(res, __pyx_n_s_real, member) < 0)) goto bad;
    Py_DECREF(member);
    member = PyFloat_FromDouble(s.imag); if (unlikely(!member)) goto bad;
    if (unlikely(PyDict_SetItem(res, __pyx_n_s_imag, member) < 0)) goto bad;
    Py_DECREF(member);
    return res;
    bad:
    Py_XDECREF(member);
    Py_DECREF(res);
    return NULL;
  }
  /* MemviewDtypeToObject */
  static CYTHON_INLINE PyObject *__pyx_memview_get_nn_khcomplex128_t__const__(const char *itemp) {
    return (PyObject *) __pyx_convert__to_py_khcomplex128_t(*(khcomplex128_t const  *) itemp);
}

static PyObject* __pyx_convert__to_py_khcomplex64_t(khcomplex64_t s) {
    PyObject* res;
    PyObject* member;
    res = __Pyx_PyDict_NewPresized(2); if (unlikely(!res)) return NULL;
    member = PyFloat_FromDouble(s.real); if (unlikely(!member)) goto bad;
    if (unlikely(PyDict_SetItem(res, __pyx_n_s_real, member) < 0)) goto bad;
    Py_DECREF(member);
    member = PyFloat_FromDouble(s.imag); if (unlikely(!member)) goto bad;
    if (unlikely(PyDict_SetItem(res, __pyx_n_s_imag, member) < 0)) goto bad;
    Py_DECREF(member);
    return res;
    bad:
    Py_XDECREF(member);
    Py_DECREF(res);
    return NULL;
  }
  /* MemviewDtypeToObject */
  static CYTHON_INLINE PyObject *__pyx_memview_get_nn_khcomplex64_t__const__(const char *itemp) {
    return (PyObject *) __pyx_convert__to_py_khcomplex64_t(*(khcomplex64_t const  *) itemp);
}

/* MemviewDtypeToObject */
  static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_float64_t__const__(const char *itemp) {
    return (PyObject *) PyFloat_FromDouble(*(__pyx_t_5numpy_float64_t const  *) itemp);
}

/* MemviewDtypeToObject */
  static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_uint64_t__const__(const char *itemp) {
    return (PyObject *) __Pyx_PyInt_From_npy_uint64(*(__pyx_t_5numpy_uint64_t const  *) itemp);
}

/* MemviewDtypeToObject */
  static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_int64_t__const__(const char *itemp) {
    return (PyObject *) __Pyx_PyInt_From_npy_int64(*(__pyx_t_5numpy_int64_t const  *) itemp);
}

/* MemviewDtypeToObject */
  static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_float32_t__const__(const char *itemp) {
    return (PyObject *) PyFloat_FromDouble(*(__pyx_t_5numpy_float32_t const  *) itemp);
}

/* MemviewDtypeToObject */
  static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_uint32_t__const__(const char *itemp) {
    return (PyObject *) __Pyx_PyInt_From_npy_uint32(*(__pyx_t_5numpy_uint32_t const  *) itemp);
}

/* MemviewDtypeToObject */
  static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_int32_t__const__(const char *itemp) {
    return (PyObject *) __Pyx_PyInt_From_npy_int32(*(__pyx_t_5numpy_int32_t const  *) itemp);
}

/* MemviewDtypeToObject */
  static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_uint16_t__const__(const char *itemp) {
    return (PyObject *) __Pyx_PyInt_From_npy_uint16(*(__pyx_t_5numpy_uint16_t const  *) itemp);
}

/* MemviewDtypeToObject */
  static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_int16_t__const__(const char *itemp) {
    return (PyObject *) __Pyx_PyInt_From_npy_int16(*(__pyx_t_5numpy_int16_t const  *) itemp);
}

/* MemviewDtypeToObject */
  static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_int8_t__const__(const char *itemp) {
    return (PyObject *) __Pyx_PyInt_From_npy_int8(*(__pyx_t_5numpy_int8_t const  *) itemp);
}

/* MemviewDtypeToObject */
  static CYTHON_INLINE PyObject *__pyx_memview_get___pyx_t_double_complex__const__(const char *itemp) {
    return (PyObject *) __pyx_PyComplex_FromComplex(*(__pyx_t_double_complex const  *) itemp);
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_intp_t(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_CONTIG) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, __Pyx_IS_C_CONTIG,
                                                 (PyBUF_C_CONTIGUOUS | PyBUF_FORMAT) | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* MemviewDtypeToObject */
  static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_intp_t(const char *itemp) {
    return (PyObject *) __Pyx_PyInt_From_Py_intptr_t(*(__pyx_t_5numpy_intp_t *) itemp);
}
static CYTHON_INLINE int __pyx_memview_set_nn___pyx_t_5numpy_intp_t(const char *itemp, PyObject *obj) {
    __pyx_t_5numpy_intp_t value = __Pyx_PyInt_As_Py_intptr_t(obj);
    if (unlikely((value == ((npy_intp)-1)) && PyErr_Occurred()))
        return 0;
    *(__pyx_t_5numpy_intp_t *) itemp = value;
    return 1;
}

/* MemviewDtypeToObject */
  static CYTHON_INLINE PyObject *__pyx_memview_get___pyx_t_float_complex__const__(const char *itemp) {
    return (PyObject *) __pyx_PyComplex_FromComplex(*(__pyx_t_float_complex const  *) itemp);
}

/* ObjectToMemviewSlice */
  static CYTHON_INLINE __Pyx_memviewslice __Pyx_PyObject_to_MemoryviewSlice_dc_nn___pyx_t_5numpy_int64_t(PyObject *obj, int writable_flag) {
    __Pyx_memviewslice result = { 0, 0, { 0 }, { 0 }, { 0 } };
    __Pyx_BufFmt_StackElem stack[1];
    int axes_specs[] = { (__Pyx_MEMVIEW_DIRECT | __Pyx_MEMVIEW_CONTIG) };
    int retcode;
    if (obj == Py_None) {
        result.memview = (struct __pyx_memoryview_obj *) Py_None;
        return result;
    }
    retcode = __Pyx_ValidateAndInit_memviewslice(axes_specs, __Pyx_IS_C_CONTIG,
                                                 (PyBUF_C_CONTIGUOUS | PyBUF_FORMAT) | writable_flag, 1,
                                                 &__Pyx_TypeInfo_nn___pyx_t_5numpy_int64_t, stack,
                                                 &result, obj);
    if (unlikely(retcode == -1))
        goto __pyx_fail;
    return result;
__pyx_fail:
    result.memview = NULL;
    result.data = NULL;
    return result;
}

/* MemviewDtypeToObject */
  static CYTHON_INLINE PyObject *__pyx_memview_get_nn___pyx_t_5numpy_int64_t(const char *itemp) {
    return (PyObject *) __Pyx_PyInt_From_npy_int64(*(__pyx_t_5numpy_int64_t *) itemp);
}
static CYTHON_INLINE int __pyx_memview_set_nn___pyx_t_5numpy_int64_t(const char *itemp, PyObject *obj) {
    __pyx_t_5numpy_int64_t value = __Pyx_PyInt_As_npy_int64(obj);
    if (unlikely((value == ((npy_int64)-1)) && PyErr_Occurred()))
        return 0;
    *(__pyx_t_5numpy_int64_t *) itemp = value;
    return 1;
}

/* PyUCS4InUnicode */
  #if PY_VERSION_HEX < 0x03090000 || (defined(PyUnicode_WCHAR_KIND) && defined(PyUnicode_AS_UNICODE))
#if PY_VERSION_HEX < 0x03090000
#define __Pyx_PyUnicode_AS_UNICODE(op) PyUnicode_AS_UNICODE(op)
#define __Pyx_PyUnicode_GET_SIZE(op) PyUnicode_GET_SIZE(op)
#else
#define __Pyx_PyUnicode_AS_UNICODE(op) (((PyASCIIObject *)(op))->wstr)
#define __Pyx_PyUnicode_GET_SIZE(op) ((PyCompactUnicodeObject *)(op))->wstr_length
#endif
#if !defined(Py_UNICODE_SIZE) || Py_UNICODE_SIZE == 2
static int __Pyx_PyUnicodeBufferContainsUCS4_SP(Py_UNICODE* buffer, Py_ssize_t length, Py_UCS4 character) {
    Py_UNICODE high_val, low_val;
    Py_UNICODE* pos;
    high_val = (Py_UNICODE) (0xD800 | (((character - 0x10000) >> 10) & ((1<<10)-1)));
    low_val  = (Py_UNICODE) (0xDC00 | ( (character - 0x10000)        & ((1<<10)-1)));
    for (pos=buffer; pos < buffer+length-1; pos++) {
        if (unlikely((high_val == pos[0]) & (low_val == pos[1]))) return 1;
    }
    return 0;
}
#endif
static int __Pyx_PyUnicodeBufferContainsUCS4_BMP(Py_UNICODE* buffer, Py_ssize_t length, Py_UCS4 character) {
    Py_UNICODE uchar;
    Py_UNICODE* pos;
    uchar = (Py_UNICODE) character;
    for (pos=buffer; pos < buffer+length; pos++) {
        if (unlikely(uchar == pos[0])) return 1;
    }
    return 0;
}
#endif
static CYTHON_INLINE int __Pyx_UnicodeContainsUCS4(PyObject* unicode, Py_UCS4 character) {
#if CYTHON_PEP393_ENABLED
    const int kind = PyUnicode_KIND(unicode);
    #ifdef PyUnicode_WCHAR_KIND
    if (likely(kind != PyUnicode_WCHAR_KIND))
    #endif
    {
        Py_ssize_t i;
        const void* udata = PyUnicode_DATA(unicode);
        const Py_ssize_t length = PyUnicode_GET_LENGTH(unicode);
        for (i=0; i < length; i++) {
            if (unlikely(character == PyUnicode_READ(kind, udata, i))) return 1;
        }
        return 0;
    }
#elif PY_VERSION_HEX >= 0x03090000
    #error Cannot use "UChar in Unicode" in Python 3.9 without PEP-393 unicode strings.
#elif !defined(PyUnicode_AS_UNICODE)
    #error Cannot use "UChar in Unicode" in Python < 3.9 without Py_UNICODE support.
#endif
#if PY_VERSION_HEX < 0x03090000 || (defined(PyUnicode_WCHAR_KIND) && defined(PyUnicode_AS_UNICODE))
#if !defined(Py_UNICODE_SIZE) || Py_UNICODE_SIZE == 2
    if ((sizeof(Py_UNICODE) == 2) && unlikely(character > 65535)) {
        return __Pyx_PyUnicodeBufferContainsUCS4_SP(
            __Pyx_PyUnicode_AS_UNICODE(unicode),
            __Pyx_PyUnicode_GET_SIZE(unicode),
            character);
    } else
#endif
    {
        return __Pyx_PyUnicodeBufferContainsUCS4_BMP(
            __Pyx_PyUnicode_AS_UNICODE(unicode),
            __Pyx_PyUnicode_GET_SIZE(unicode),
            character);
    }
#endif
}

/* MemviewSliceCopyTemplate */
  static __Pyx_memviewslice
__pyx_memoryview_copy_new_contig(const __Pyx_memviewslice *from_mvs,
                                 const char *mode, int ndim,
                                 size_t sizeof_dtype, int contig_flag,
                                 int dtype_is_object)
{
    __Pyx_RefNannyDeclarations
    int i;
    __Pyx_memviewslice new_mvs = { 0, 0, { 0 }, { 0 }, { 0 } };
    struct __pyx_memoryview_obj *from_memview = from_mvs->memview;
    Py_buffer *buf = &from_memview->view;
    PyObject *shape_tuple = NULL;
    PyObject *temp_int = NULL;
    struct __pyx_array_obj *array_obj = NULL;
    struct __pyx_memoryview_obj *memview_obj = NULL;
    __Pyx_RefNannySetupContext("__pyx_memoryview_copy_new_contig", 0);
    for (i = 0; i < ndim; i++) {
        if (unlikely(from_mvs->suboffsets[i] >= 0)) {
            PyErr_Format(PyExc_ValueError, "Cannot copy memoryview slice with "
                                           "indirect dimensions (axis %d)", i);
            goto fail;
        }
    }
    shape_tuple = PyTuple_New(ndim);
    if (unlikely(!shape_tuple)) {
        goto fail;
    }
    __Pyx_GOTREF(shape_tuple);
    for(i = 0; i < ndim; i++) {
        temp_int = PyInt_FromSsize_t(from_mvs->shape[i]);
        if(unlikely(!temp_int)) {
            goto fail;
        } else {
            PyTuple_SET_ITEM(shape_tuple, i, temp_int);
            temp_int = NULL;
        }
    }
    array_obj = __pyx_array_new(shape_tuple, sizeof_dtype, buf->format, (char *) mode, NULL);
    if (unlikely(!array_obj)) {
        goto fail;
    }
    __Pyx_GOTREF(array_obj);
    memview_obj = (struct __pyx_memoryview_obj *) __pyx_memoryview_new(
                                    (PyObject *) array_obj, contig_flag,
                                    dtype_is_object,
                                    from_mvs->memview->typeinfo);
    if (unlikely(!memview_obj))
        goto fail;
    if (unlikely(__Pyx_init_memviewslice(memview_obj, ndim, &new_mvs, 1) < 0))
        goto fail;
    if (unlikely(__pyx_memoryview_copy_contents(*from_mvs, new_mvs, ndim, ndim,
                                                dtype_is_object) < 0))
        goto fail;
    goto no_fail;
fail:
    __Pyx_XDECREF(new_mvs.memview);
    new_mvs.memview = NULL;
    new_mvs.data = NULL;
no_fail:
    __Pyx_XDECREF(shape_tuple);
    __Pyx_XDECREF(temp_int);
    __Pyx_XDECREF(array_obj);
    __Pyx_RefNannyFinishContext();
    return new_mvs;
}

/* MemviewSliceInit */
  static int
__Pyx_init_memviewslice(struct __pyx_memoryview_obj *memview,
                        int ndim,
                        __Pyx_memviewslice *memviewslice,
                        int memview_is_new_reference)
{
    __Pyx_RefNannyDeclarations
    int i, retval=-1;
    Py_buffer *buf = &memview->view;
    __Pyx_RefNannySetupContext("init_memviewslice", 0);
    if (unlikely(memviewslice->memview || memviewslice->data)) {
        PyErr_SetString(PyExc_ValueError,
            "memviewslice is already initialized!");
        goto fail;
    }
    if (buf->strides) {
        for (i = 0; i < ndim; i++) {
            memviewslice->strides[i] = buf->strides[i];
        }
    } else {
        Py_ssize_t stride = buf->itemsize;
        for (i = ndim - 1; i >= 0; i--) {
            memviewslice->strides[i] = stride;
            stride *= buf->shape[i];
        }
    }
    for (i = 0; i < ndim; i++) {
        memviewslice->shape[i]   = buf->shape[i];
        if (buf->suboffsets) {
            memviewslice->suboffsets[i] = buf->suboffsets[i];
        } else {
            memviewslice->suboffsets[i] = -1;
        }
    }
    memviewslice->memview = memview;
    memviewslice->data = (char *)buf->buf;
    if (__pyx_add_acquisition_count(memview) == 0 && !memview_is_new_reference) {
        Py_INCREF(memview);
    }
    retval = 0;
    goto no_fail;
fail:
    memviewslice->memview = 0;
    memviewslice->data = 0;
    retval = -1;
no_fail:
    __Pyx_RefNannyFinishContext();
    return retval;
}
#ifndef Py_NO_RETURN
#define Py_NO_RETURN
#endif
static void __pyx_fatalerror(const char *fmt, ...) Py_NO_RETURN {
    va_list vargs;
    char msg[200];
#if PY_VERSION_HEX >= 0x030A0000 || defined(HAVE_STDARG_PROTOTYPES)
    va_start(vargs, fmt);
#else
    va_start(vargs);
#endif
    vsnprintf(msg, 200, fmt, vargs);
    va_end(vargs);
    Py_FatalError(msg);
}
static CYTHON_INLINE int
__pyx_add_acquisition_count_locked(__pyx_atomic_int_type *acquisition_count,
                                   PyThread_type_lock lock)
{
    int result;
    PyThread_acquire_lock(lock, 1);
    result = (*acquisition_count)++;
    PyThread_release_lock(lock);
    return result;
}
static CYTHON_INLINE int
__pyx_sub_acquisition_count_locked(__pyx_atomic_int_type *acquisition_count,
                                   PyThread_type_lock lock)
{
    int result;
    PyThread_acquire_lock(lock, 1);
    result = (*acquisition_count)--;
    PyThread_release_lock(lock);
    return result;
}
static CYTHON_INLINE void
__Pyx_INC_MEMVIEW(__Pyx_memviewslice *memslice, int have_gil, int lineno)
{
    __pyx_nonatomic_int_type old_acquisition_count;
    struct __pyx_memoryview_obj *memview = memslice->memview;
    if (unlikely(!memview || (PyObject *) memview == Py_None)) {
        return;
    }
    old_acquisition_count = __pyx_add_acquisition_count(memview);
    if (unlikely(old_acquisition_count <= 0)) {
        if (likely(old_acquisition_count == 0)) {
            if (have_gil) {
                Py_INCREF((PyObject *) memview);
            } else {
                PyGILState_STATE _gilstate = PyGILState_Ensure();
                Py_INCREF((PyObject *) memview);
                PyGILState_Release(_gilstate);
            }
        } else {
            __pyx_fatalerror("Acquisition count is %d (line %d)",
                             old_acquisition_count+1, lineno);
        }
    }
}
static CYTHON_INLINE void __Pyx_XCLEAR_MEMVIEW(__Pyx_memviewslice *memslice,
                                             int have_gil, int lineno) {
    __pyx_nonatomic_int_type old_acquisition_count;
    struct __pyx_memoryview_obj *memview = memslice->memview;
    if (unlikely(!memview || (PyObject *) memview == Py_None)) {
        memslice->memview = NULL;
        return;
    }
    old_acquisition_count = __pyx_sub_acquisition_count(memview);
    memslice->data = NULL;
    if (likely(old_acquisition_count > 1)) {
        memslice->memview = NULL;
    } else if (likely(old_acquisition_count == 1)) {
        if (have_gil) {
            Py_CLEAR(memslice->memview);
        } else {
            PyGILState_STATE _gilstate = PyGILState_Ensure();
            Py_CLEAR(memslice->memview);
            PyGILState_Release(_gilstate);
        }
    } else {
        __pyx_fatalerror("Acquisition count is %d (line %d)",
                         old_acquisition_count-1, lineno);
    }
}

/* CIntFromPy */
  static CYTHON_INLINE npy_int64 __Pyx_PyInt_As_npy_int64(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const npy_int64 neg_one = (npy_int64) -1, const_zero = (npy_int64) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(npy_int64) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(npy_int64, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (npy_int64) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(npy_int64, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(npy_int64) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int64, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int64) >= 2 * PyLong_SHIFT)) {
                                return (npy_int64) (((((npy_int64)digits[1]) << PyLong_SHIFT) | (npy_int64)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(npy_int64) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int64, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int64) >= 3 * PyLong_SHIFT)) {
                                return (npy_int64) (((((((npy_int64)digits[2]) << PyLong_SHIFT) | (npy_int64)digits[1]) << PyLong_SHIFT) | (npy_int64)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(npy_int64) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int64, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int64) >= 4 * PyLong_SHIFT)) {
                                return (npy_int64) (((((((((npy_int64)digits[3]) << PyLong_SHIFT) | (npy_int64)digits[2]) << PyLong_SHIFT) | (npy_int64)digits[1]) << PyLong_SHIFT) | (npy_int64)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (npy_int64) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(npy_int64) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int64, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(npy_int64) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int64, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(npy_int64, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(npy_int64) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int64, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int64) - 1 > 2 * PyLong_SHIFT)) {
                                return (npy_int64) (((npy_int64)-1)*(((((npy_int64)digits[1]) << PyLong_SHIFT) | (npy_int64)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(npy_int64) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int64, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int64) - 1 > 2 * PyLong_SHIFT)) {
                                return (npy_int64) ((((((npy_int64)digits[1]) << PyLong_SHIFT) | (npy_int64)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(npy_int64) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int64, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int64) - 1 > 3 * PyLong_SHIFT)) {
                                return (npy_int64) (((npy_int64)-1)*(((((((npy_int64)digits[2]) << PyLong_SHIFT) | (npy_int64)digits[1]) << PyLong_SHIFT) | (npy_int64)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(npy_int64) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int64, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int64) - 1 > 3 * PyLong_SHIFT)) {
                                return (npy_int64) ((((((((npy_int64)digits[2]) << PyLong_SHIFT) | (npy_int64)digits[1]) << PyLong_SHIFT) | (npy_int64)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(npy_int64) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int64, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int64) - 1 > 4 * PyLong_SHIFT)) {
                                return (npy_int64) (((npy_int64)-1)*(((((((((npy_int64)digits[3]) << PyLong_SHIFT) | (npy_int64)digits[2]) << PyLong_SHIFT) | (npy_int64)digits[1]) << PyLong_SHIFT) | (npy_int64)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(npy_int64) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int64, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int64) - 1 > 4 * PyLong_SHIFT)) {
                                return (npy_int64) ((((((((((npy_int64)digits[3]) << PyLong_SHIFT) | (npy_int64)digits[2]) << PyLong_SHIFT) | (npy_int64)digits[1]) << PyLong_SHIFT) | (npy_int64)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(npy_int64) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int64, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(npy_int64) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int64, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            npy_int64 val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (npy_int64) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (npy_int64) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (npy_int64) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (npy_int64) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (npy_int64) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(npy_int64) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((npy_int64) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(npy_int64) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((npy_int64) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((npy_int64) 1) << (sizeof(npy_int64) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (npy_int64) -1;
        }
    } else {
        npy_int64 val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (npy_int64) -1;
        val = __Pyx_PyInt_As_npy_int64(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to npy_int64");
    return (npy_int64) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to npy_int64");
    return (npy_int64) -1;
}

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_uint8(npy_uint8 value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const npy_uint8 neg_one = (npy_uint8) -1, const_zero = (npy_uint8) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(npy_uint8) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(npy_uint8) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_uint8) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(npy_uint8) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_uint8) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        return _PyLong_FromByteArray(bytes, sizeof(npy_uint8),
                                     little, !is_unsigned);
#else
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(npy_uint8));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntFromPy */
  static CYTHON_INLINE npy_uint64 __Pyx_PyInt_As_npy_uint64(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const npy_uint64 neg_one = (npy_uint64) -1, const_zero = (npy_uint64) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(npy_uint64) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(npy_uint64, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (npy_uint64) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(npy_uint64, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(npy_uint64) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint64, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint64) >= 2 * PyLong_SHIFT)) {
                                return (npy_uint64) (((((npy_uint64)digits[1]) << PyLong_SHIFT) | (npy_uint64)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(npy_uint64) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint64, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint64) >= 3 * PyLong_SHIFT)) {
                                return (npy_uint64) (((((((npy_uint64)digits[2]) << PyLong_SHIFT) | (npy_uint64)digits[1]) << PyLong_SHIFT) | (npy_uint64)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(npy_uint64) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint64, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint64) >= 4 * PyLong_SHIFT)) {
                                return (npy_uint64) (((((((((npy_uint64)digits[3]) << PyLong_SHIFT) | (npy_uint64)digits[2]) << PyLong_SHIFT) | (npy_uint64)digits[1]) << PyLong_SHIFT) | (npy_uint64)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (npy_uint64) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(npy_uint64) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_uint64, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(npy_uint64) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_uint64, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(npy_uint64, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(npy_uint64) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint64, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint64) - 1 > 2 * PyLong_SHIFT)) {
                                return (npy_uint64) (((npy_uint64)-1)*(((((npy_uint64)digits[1]) << PyLong_SHIFT) | (npy_uint64)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(npy_uint64) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint64, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint64) - 1 > 2 * PyLong_SHIFT)) {
                                return (npy_uint64) ((((((npy_uint64)digits[1]) << PyLong_SHIFT) | (npy_uint64)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(npy_uint64) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint64, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint64) - 1 > 3 * PyLong_SHIFT)) {
                                return (npy_uint64) (((npy_uint64)-1)*(((((((npy_uint64)digits[2]) << PyLong_SHIFT) | (npy_uint64)digits[1]) << PyLong_SHIFT) | (npy_uint64)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(npy_uint64) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint64, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint64) - 1 > 3 * PyLong_SHIFT)) {
                                return (npy_uint64) ((((((((npy_uint64)digits[2]) << PyLong_SHIFT) | (npy_uint64)digits[1]) << PyLong_SHIFT) | (npy_uint64)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(npy_uint64) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint64, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint64) - 1 > 4 * PyLong_SHIFT)) {
                                return (npy_uint64) (((npy_uint64)-1)*(((((((((npy_uint64)digits[3]) << PyLong_SHIFT) | (npy_uint64)digits[2]) << PyLong_SHIFT) | (npy_uint64)digits[1]) << PyLong_SHIFT) | (npy_uint64)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(npy_uint64) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint64, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint64) - 1 > 4 * PyLong_SHIFT)) {
                                return (npy_uint64) ((((((((((npy_uint64)digits[3]) << PyLong_SHIFT) | (npy_uint64)digits[2]) << PyLong_SHIFT) | (npy_uint64)digits[1]) << PyLong_SHIFT) | (npy_uint64)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(npy_uint64) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_uint64, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(npy_uint64) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_uint64, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            npy_uint64 val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (npy_uint64) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (npy_uint64) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (npy_uint64) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (npy_uint64) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (npy_uint64) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(npy_uint64) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((npy_uint64) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(npy_uint64) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((npy_uint64) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((npy_uint64) 1) << (sizeof(npy_uint64) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (npy_uint64) -1;
        }
    } else {
        npy_uint64 val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (npy_uint64) -1;
        val = __Pyx_PyInt_As_npy_uint64(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to npy_uint64");
    return (npy_uint64) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to npy_uint64");
    return (npy_uint64) -1;
}

/* CIntFromPy */
  static CYTHON_INLINE npy_uint32 __Pyx_PyInt_As_npy_uint32(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const npy_uint32 neg_one = (npy_uint32) -1, const_zero = (npy_uint32) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(npy_uint32) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(npy_uint32, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (npy_uint32) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(npy_uint32, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(npy_uint32) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint32, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint32) >= 2 * PyLong_SHIFT)) {
                                return (npy_uint32) (((((npy_uint32)digits[1]) << PyLong_SHIFT) | (npy_uint32)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(npy_uint32) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint32, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint32) >= 3 * PyLong_SHIFT)) {
                                return (npy_uint32) (((((((npy_uint32)digits[2]) << PyLong_SHIFT) | (npy_uint32)digits[1]) << PyLong_SHIFT) | (npy_uint32)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(npy_uint32) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint32, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint32) >= 4 * PyLong_SHIFT)) {
                                return (npy_uint32) (((((((((npy_uint32)digits[3]) << PyLong_SHIFT) | (npy_uint32)digits[2]) << PyLong_SHIFT) | (npy_uint32)digits[1]) << PyLong_SHIFT) | (npy_uint32)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (npy_uint32) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(npy_uint32) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_uint32, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(npy_uint32) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_uint32, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(npy_uint32, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(npy_uint32) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint32, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint32) - 1 > 2 * PyLong_SHIFT)) {
                                return (npy_uint32) (((npy_uint32)-1)*(((((npy_uint32)digits[1]) << PyLong_SHIFT) | (npy_uint32)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(npy_uint32) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint32, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint32) - 1 > 2 * PyLong_SHIFT)) {
                                return (npy_uint32) ((((((npy_uint32)digits[1]) << PyLong_SHIFT) | (npy_uint32)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(npy_uint32) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint32, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint32) - 1 > 3 * PyLong_SHIFT)) {
                                return (npy_uint32) (((npy_uint32)-1)*(((((((npy_uint32)digits[2]) << PyLong_SHIFT) | (npy_uint32)digits[1]) << PyLong_SHIFT) | (npy_uint32)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(npy_uint32) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint32, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint32) - 1 > 3 * PyLong_SHIFT)) {
                                return (npy_uint32) ((((((((npy_uint32)digits[2]) << PyLong_SHIFT) | (npy_uint32)digits[1]) << PyLong_SHIFT) | (npy_uint32)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(npy_uint32) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint32, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint32) - 1 > 4 * PyLong_SHIFT)) {
                                return (npy_uint32) (((npy_uint32)-1)*(((((((((npy_uint32)digits[3]) << PyLong_SHIFT) | (npy_uint32)digits[2]) << PyLong_SHIFT) | (npy_uint32)digits[1]) << PyLong_SHIFT) | (npy_uint32)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(npy_uint32) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint32, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint32) - 1 > 4 * PyLong_SHIFT)) {
                                return (npy_uint32) ((((((((((npy_uint32)digits[3]) << PyLong_SHIFT) | (npy_uint32)digits[2]) << PyLong_SHIFT) | (npy_uint32)digits[1]) << PyLong_SHIFT) | (npy_uint32)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(npy_uint32) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_uint32, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(npy_uint32) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_uint32, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            npy_uint32 val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (npy_uint32) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (npy_uint32) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (npy_uint32) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (npy_uint32) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (npy_uint32) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(npy_uint32) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((npy_uint32) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(npy_uint32) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((npy_uint32) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((npy_uint32) 1) << (sizeof(npy_uint32) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (npy_uint32) -1;
        }
    } else {
        npy_uint32 val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (npy_uint32) -1;
        val = __Pyx_PyInt_As_npy_uint32(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to npy_uint32");
    return (npy_uint32) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to npy_uint32");
    return (npy_uint32) -1;
}

/* CIntFromPy */
  static CYTHON_INLINE npy_int32 __Pyx_PyInt_As_npy_int32(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const npy_int32 neg_one = (npy_int32) -1, const_zero = (npy_int32) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(npy_int32) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(npy_int32, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (npy_int32) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(npy_int32, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(npy_int32) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int32, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int32) >= 2 * PyLong_SHIFT)) {
                                return (npy_int32) (((((npy_int32)digits[1]) << PyLong_SHIFT) | (npy_int32)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(npy_int32) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int32, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int32) >= 3 * PyLong_SHIFT)) {
                                return (npy_int32) (((((((npy_int32)digits[2]) << PyLong_SHIFT) | (npy_int32)digits[1]) << PyLong_SHIFT) | (npy_int32)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(npy_int32) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int32, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int32) >= 4 * PyLong_SHIFT)) {
                                return (npy_int32) (((((((((npy_int32)digits[3]) << PyLong_SHIFT) | (npy_int32)digits[2]) << PyLong_SHIFT) | (npy_int32)digits[1]) << PyLong_SHIFT) | (npy_int32)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (npy_int32) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(npy_int32) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int32, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(npy_int32) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int32, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(npy_int32, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(npy_int32) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int32, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int32) - 1 > 2 * PyLong_SHIFT)) {
                                return (npy_int32) (((npy_int32)-1)*(((((npy_int32)digits[1]) << PyLong_SHIFT) | (npy_int32)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(npy_int32) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int32, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int32) - 1 > 2 * PyLong_SHIFT)) {
                                return (npy_int32) ((((((npy_int32)digits[1]) << PyLong_SHIFT) | (npy_int32)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(npy_int32) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int32, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int32) - 1 > 3 * PyLong_SHIFT)) {
                                return (npy_int32) (((npy_int32)-1)*(((((((npy_int32)digits[2]) << PyLong_SHIFT) | (npy_int32)digits[1]) << PyLong_SHIFT) | (npy_int32)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(npy_int32) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int32, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int32) - 1 > 3 * PyLong_SHIFT)) {
                                return (npy_int32) ((((((((npy_int32)digits[2]) << PyLong_SHIFT) | (npy_int32)digits[1]) << PyLong_SHIFT) | (npy_int32)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(npy_int32) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int32, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int32) - 1 > 4 * PyLong_SHIFT)) {
                                return (npy_int32) (((npy_int32)-1)*(((((((((npy_int32)digits[3]) << PyLong_SHIFT) | (npy_int32)digits[2]) << PyLong_SHIFT) | (npy_int32)digits[1]) << PyLong_SHIFT) | (npy_int32)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(npy_int32) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int32, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int32) - 1 > 4 * PyLong_SHIFT)) {
                                return (npy_int32) ((((((((((npy_int32)digits[3]) << PyLong_SHIFT) | (npy_int32)digits[2]) << PyLong_SHIFT) | (npy_int32)digits[1]) << PyLong_SHIFT) | (npy_int32)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(npy_int32) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int32, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(npy_int32) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int32, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            npy_int32 val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (npy_int32) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (npy_int32) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (npy_int32) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (npy_int32) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (npy_int32) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(npy_int32) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((npy_int32) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(npy_int32) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((npy_int32) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((npy_int32) 1) << (sizeof(npy_int32) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (npy_int32) -1;
        }
    } else {
        npy_int32 val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (npy_int32) -1;
        val = __Pyx_PyInt_As_npy_int32(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to npy_int32");
    return (npy_int32) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to npy_int32");
    return (npy_int32) -1;
}

/* CIntFromPy */
  static CYTHON_INLINE npy_uint16 __Pyx_PyInt_As_npy_uint16(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const npy_uint16 neg_one = (npy_uint16) -1, const_zero = (npy_uint16) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(npy_uint16) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(npy_uint16, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (npy_uint16) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(npy_uint16, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(npy_uint16) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint16, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint16) >= 2 * PyLong_SHIFT)) {
                                return (npy_uint16) (((((npy_uint16)digits[1]) << PyLong_SHIFT) | (npy_uint16)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(npy_uint16) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint16, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint16) >= 3 * PyLong_SHIFT)) {
                                return (npy_uint16) (((((((npy_uint16)digits[2]) << PyLong_SHIFT) | (npy_uint16)digits[1]) << PyLong_SHIFT) | (npy_uint16)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(npy_uint16) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint16, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint16) >= 4 * PyLong_SHIFT)) {
                                return (npy_uint16) (((((((((npy_uint16)digits[3]) << PyLong_SHIFT) | (npy_uint16)digits[2]) << PyLong_SHIFT) | (npy_uint16)digits[1]) << PyLong_SHIFT) | (npy_uint16)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (npy_uint16) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(npy_uint16) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_uint16, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(npy_uint16) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_uint16, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(npy_uint16, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(npy_uint16) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint16, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint16) - 1 > 2 * PyLong_SHIFT)) {
                                return (npy_uint16) (((npy_uint16)-1)*(((((npy_uint16)digits[1]) << PyLong_SHIFT) | (npy_uint16)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(npy_uint16) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint16, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint16) - 1 > 2 * PyLong_SHIFT)) {
                                return (npy_uint16) ((((((npy_uint16)digits[1]) << PyLong_SHIFT) | (npy_uint16)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(npy_uint16) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint16, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint16) - 1 > 3 * PyLong_SHIFT)) {
                                return (npy_uint16) (((npy_uint16)-1)*(((((((npy_uint16)digits[2]) << PyLong_SHIFT) | (npy_uint16)digits[1]) << PyLong_SHIFT) | (npy_uint16)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(npy_uint16) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint16, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint16) - 1 > 3 * PyLong_SHIFT)) {
                                return (npy_uint16) ((((((((npy_uint16)digits[2]) << PyLong_SHIFT) | (npy_uint16)digits[1]) << PyLong_SHIFT) | (npy_uint16)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(npy_uint16) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint16, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint16) - 1 > 4 * PyLong_SHIFT)) {
                                return (npy_uint16) (((npy_uint16)-1)*(((((((((npy_uint16)digits[3]) << PyLong_SHIFT) | (npy_uint16)digits[2]) << PyLong_SHIFT) | (npy_uint16)digits[1]) << PyLong_SHIFT) | (npy_uint16)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(npy_uint16) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint16, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint16) - 1 > 4 * PyLong_SHIFT)) {
                                return (npy_uint16) ((((((((((npy_uint16)digits[3]) << PyLong_SHIFT) | (npy_uint16)digits[2]) << PyLong_SHIFT) | (npy_uint16)digits[1]) << PyLong_SHIFT) | (npy_uint16)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(npy_uint16) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_uint16, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(npy_uint16) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_uint16, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            npy_uint16 val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (npy_uint16) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (npy_uint16) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (npy_uint16) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (npy_uint16) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (npy_uint16) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(npy_uint16) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((npy_uint16) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(npy_uint16) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((npy_uint16) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((npy_uint16) 1) << (sizeof(npy_uint16) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (npy_uint16) -1;
        }
    } else {
        npy_uint16 val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (npy_uint16) -1;
        val = __Pyx_PyInt_As_npy_uint16(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to npy_uint16");
    return (npy_uint16) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to npy_uint16");
    return (npy_uint16) -1;
}

/* CIntFromPy */
  static CYTHON_INLINE npy_int16 __Pyx_PyInt_As_npy_int16(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const npy_int16 neg_one = (npy_int16) -1, const_zero = (npy_int16) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(npy_int16) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(npy_int16, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (npy_int16) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(npy_int16, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(npy_int16) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int16, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int16) >= 2 * PyLong_SHIFT)) {
                                return (npy_int16) (((((npy_int16)digits[1]) << PyLong_SHIFT) | (npy_int16)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(npy_int16) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int16, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int16) >= 3 * PyLong_SHIFT)) {
                                return (npy_int16) (((((((npy_int16)digits[2]) << PyLong_SHIFT) | (npy_int16)digits[1]) << PyLong_SHIFT) | (npy_int16)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(npy_int16) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int16, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int16) >= 4 * PyLong_SHIFT)) {
                                return (npy_int16) (((((((((npy_int16)digits[3]) << PyLong_SHIFT) | (npy_int16)digits[2]) << PyLong_SHIFT) | (npy_int16)digits[1]) << PyLong_SHIFT) | (npy_int16)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (npy_int16) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(npy_int16) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int16, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(npy_int16) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int16, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(npy_int16, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(npy_int16) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int16, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int16) - 1 > 2 * PyLong_SHIFT)) {
                                return (npy_int16) (((npy_int16)-1)*(((((npy_int16)digits[1]) << PyLong_SHIFT) | (npy_int16)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(npy_int16) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int16, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int16) - 1 > 2 * PyLong_SHIFT)) {
                                return (npy_int16) ((((((npy_int16)digits[1]) << PyLong_SHIFT) | (npy_int16)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(npy_int16) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int16, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int16) - 1 > 3 * PyLong_SHIFT)) {
                                return (npy_int16) (((npy_int16)-1)*(((((((npy_int16)digits[2]) << PyLong_SHIFT) | (npy_int16)digits[1]) << PyLong_SHIFT) | (npy_int16)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(npy_int16) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int16, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int16) - 1 > 3 * PyLong_SHIFT)) {
                                return (npy_int16) ((((((((npy_int16)digits[2]) << PyLong_SHIFT) | (npy_int16)digits[1]) << PyLong_SHIFT) | (npy_int16)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(npy_int16) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int16, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int16) - 1 > 4 * PyLong_SHIFT)) {
                                return (npy_int16) (((npy_int16)-1)*(((((((((npy_int16)digits[3]) << PyLong_SHIFT) | (npy_int16)digits[2]) << PyLong_SHIFT) | (npy_int16)digits[1]) << PyLong_SHIFT) | (npy_int16)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(npy_int16) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int16, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int16) - 1 > 4 * PyLong_SHIFT)) {
                                return (npy_int16) ((((((((((npy_int16)digits[3]) << PyLong_SHIFT) | (npy_int16)digits[2]) << PyLong_SHIFT) | (npy_int16)digits[1]) << PyLong_SHIFT) | (npy_int16)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(npy_int16) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int16, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(npy_int16) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int16, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            npy_int16 val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (npy_int16) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (npy_int16) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (npy_int16) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (npy_int16) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (npy_int16) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(npy_int16) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((npy_int16) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(npy_int16) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((npy_int16) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((npy_int16) 1) << (sizeof(npy_int16) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (npy_int16) -1;
        }
    } else {
        npy_int16 val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (npy_int16) -1;
        val = __Pyx_PyInt_As_npy_int16(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to npy_int16");
    return (npy_int16) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to npy_int16");
    return (npy_int16) -1;
}

/* CIntFromPy */
  static CYTHON_INLINE npy_uint8 __Pyx_PyInt_As_npy_uint8(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const npy_uint8 neg_one = (npy_uint8) -1, const_zero = (npy_uint8) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(npy_uint8) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(npy_uint8, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (npy_uint8) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(npy_uint8, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(npy_uint8) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint8, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint8) >= 2 * PyLong_SHIFT)) {
                                return (npy_uint8) (((((npy_uint8)digits[1]) << PyLong_SHIFT) | (npy_uint8)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(npy_uint8) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint8, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint8) >= 3 * PyLong_SHIFT)) {
                                return (npy_uint8) (((((((npy_uint8)digits[2]) << PyLong_SHIFT) | (npy_uint8)digits[1]) << PyLong_SHIFT) | (npy_uint8)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(npy_uint8) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint8, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint8) >= 4 * PyLong_SHIFT)) {
                                return (npy_uint8) (((((((((npy_uint8)digits[3]) << PyLong_SHIFT) | (npy_uint8)digits[2]) << PyLong_SHIFT) | (npy_uint8)digits[1]) << PyLong_SHIFT) | (npy_uint8)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (npy_uint8) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(npy_uint8) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_uint8, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(npy_uint8) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_uint8, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(npy_uint8, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(npy_uint8) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint8, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint8) - 1 > 2 * PyLong_SHIFT)) {
                                return (npy_uint8) (((npy_uint8)-1)*(((((npy_uint8)digits[1]) << PyLong_SHIFT) | (npy_uint8)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(npy_uint8) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint8, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint8) - 1 > 2 * PyLong_SHIFT)) {
                                return (npy_uint8) ((((((npy_uint8)digits[1]) << PyLong_SHIFT) | (npy_uint8)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(npy_uint8) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint8, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint8) - 1 > 3 * PyLong_SHIFT)) {
                                return (npy_uint8) (((npy_uint8)-1)*(((((((npy_uint8)digits[2]) << PyLong_SHIFT) | (npy_uint8)digits[1]) << PyLong_SHIFT) | (npy_uint8)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(npy_uint8) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint8, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint8) - 1 > 3 * PyLong_SHIFT)) {
                                return (npy_uint8) ((((((((npy_uint8)digits[2]) << PyLong_SHIFT) | (npy_uint8)digits[1]) << PyLong_SHIFT) | (npy_uint8)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(npy_uint8) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint8, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint8) - 1 > 4 * PyLong_SHIFT)) {
                                return (npy_uint8) (((npy_uint8)-1)*(((((((((npy_uint8)digits[3]) << PyLong_SHIFT) | (npy_uint8)digits[2]) << PyLong_SHIFT) | (npy_uint8)digits[1]) << PyLong_SHIFT) | (npy_uint8)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(npy_uint8) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_uint8, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_uint8) - 1 > 4 * PyLong_SHIFT)) {
                                return (npy_uint8) ((((((((((npy_uint8)digits[3]) << PyLong_SHIFT) | (npy_uint8)digits[2]) << PyLong_SHIFT) | (npy_uint8)digits[1]) << PyLong_SHIFT) | (npy_uint8)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(npy_uint8) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_uint8, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(npy_uint8) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_uint8, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            npy_uint8 val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (npy_uint8) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (npy_uint8) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (npy_uint8) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (npy_uint8) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (npy_uint8) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(npy_uint8) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((npy_uint8) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(npy_uint8) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((npy_uint8) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((npy_uint8) 1) << (sizeof(npy_uint8) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (npy_uint8) -1;
        }
    } else {
        npy_uint8 val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (npy_uint8) -1;
        val = __Pyx_PyInt_As_npy_uint8(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to npy_uint8");
    return (npy_uint8) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to npy_uint8");
    return (npy_uint8) -1;
}

/* CIntFromPy */
  static CYTHON_INLINE npy_int8 __Pyx_PyInt_As_npy_int8(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const npy_int8 neg_one = (npy_int8) -1, const_zero = (npy_int8) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(npy_int8) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(npy_int8, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (npy_int8) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(npy_int8, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(npy_int8) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int8, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int8) >= 2 * PyLong_SHIFT)) {
                                return (npy_int8) (((((npy_int8)digits[1]) << PyLong_SHIFT) | (npy_int8)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(npy_int8) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int8, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int8) >= 3 * PyLong_SHIFT)) {
                                return (npy_int8) (((((((npy_int8)digits[2]) << PyLong_SHIFT) | (npy_int8)digits[1]) << PyLong_SHIFT) | (npy_int8)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(npy_int8) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int8, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int8) >= 4 * PyLong_SHIFT)) {
                                return (npy_int8) (((((((((npy_int8)digits[3]) << PyLong_SHIFT) | (npy_int8)digits[2]) << PyLong_SHIFT) | (npy_int8)digits[1]) << PyLong_SHIFT) | (npy_int8)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (npy_int8) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(npy_int8) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int8, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(npy_int8) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int8, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(npy_int8, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(npy_int8) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int8, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int8) - 1 > 2 * PyLong_SHIFT)) {
                                return (npy_int8) (((npy_int8)-1)*(((((npy_int8)digits[1]) << PyLong_SHIFT) | (npy_int8)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(npy_int8) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int8, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int8) - 1 > 2 * PyLong_SHIFT)) {
                                return (npy_int8) ((((((npy_int8)digits[1]) << PyLong_SHIFT) | (npy_int8)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(npy_int8) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int8, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int8) - 1 > 3 * PyLong_SHIFT)) {
                                return (npy_int8) (((npy_int8)-1)*(((((((npy_int8)digits[2]) << PyLong_SHIFT) | (npy_int8)digits[1]) << PyLong_SHIFT) | (npy_int8)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(npy_int8) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int8, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int8) - 1 > 3 * PyLong_SHIFT)) {
                                return (npy_int8) ((((((((npy_int8)digits[2]) << PyLong_SHIFT) | (npy_int8)digits[1]) << PyLong_SHIFT) | (npy_int8)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(npy_int8) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int8, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int8) - 1 > 4 * PyLong_SHIFT)) {
                                return (npy_int8) (((npy_int8)-1)*(((((((((npy_int8)digits[3]) << PyLong_SHIFT) | (npy_int8)digits[2]) << PyLong_SHIFT) | (npy_int8)digits[1]) << PyLong_SHIFT) | (npy_int8)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(npy_int8) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(npy_int8, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(npy_int8) - 1 > 4 * PyLong_SHIFT)) {
                                return (npy_int8) ((((((((((npy_int8)digits[3]) << PyLong_SHIFT) | (npy_int8)digits[2]) << PyLong_SHIFT) | (npy_int8)digits[1]) << PyLong_SHIFT) | (npy_int8)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(npy_int8) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int8, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(npy_int8) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(npy_int8, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            npy_int8 val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (npy_int8) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (npy_int8) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (npy_int8) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (npy_int8) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (npy_int8) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(npy_int8) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((npy_int8) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(npy_int8) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((npy_int8) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((npy_int8) 1) << (sizeof(npy_int8) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (npy_int8) -1;
        }
    } else {
        npy_int8 val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (npy_int8) -1;
        val = __Pyx_PyInt_As_npy_int8(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to npy_int8");
    return (npy_int8) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to npy_int8");
    return (npy_int8) -1;
}

/* CIntFromPy */
  static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(long) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 2 * PyLong_SHIFT)) {
                                return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 3 * PyLong_SHIFT)) {
                                return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) >= 4 * PyLong_SHIFT)) {
                                return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(long) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(long) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(long, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(long) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(long) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                                return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(long) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(long) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                                return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(long) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                                return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(long) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(long) - 1 > 4 * PyLong_SHIFT)) {
                                return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(long) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(long) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (long) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (long) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (long) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (long) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (long) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(long) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((long) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(long) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((long) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((long) 1) << (sizeof(long) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
#else
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(int));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_uint32(npy_uint32 value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const npy_uint32 neg_one = (npy_uint32) -1, const_zero = (npy_uint32) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(npy_uint32) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(npy_uint32) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_uint32) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(npy_uint32) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_uint32) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        return _PyLong_FromByteArray(bytes, sizeof(npy_uint32),
                                     little, !is_unsigned);
#else
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(npy_uint32));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_uint64(npy_uint64 value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const npy_uint64 neg_one = (npy_uint64) -1, const_zero = (npy_uint64) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(npy_uint64) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(npy_uint64) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_uint64) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(npy_uint64) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_uint64) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        return _PyLong_FromByteArray(bytes, sizeof(npy_uint64),
                                     little, !is_unsigned);
#else
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(npy_uint64));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_int64(npy_int64 value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const npy_int64 neg_one = (npy_int64) -1, const_zero = (npy_int64) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(npy_int64) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(npy_int64) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_int64) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(npy_int64) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_int64) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        return _PyLong_FromByteArray(bytes, sizeof(npy_int64),
                                     little, !is_unsigned);
#else
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(npy_int64));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_int32(npy_int32 value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const npy_int32 neg_one = (npy_int32) -1, const_zero = (npy_int32) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(npy_int32) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(npy_int32) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_int32) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(npy_int32) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_int32) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        return _PyLong_FromByteArray(bytes, sizeof(npy_int32),
                                     little, !is_unsigned);
#else
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(npy_int32));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_uint16(npy_uint16 value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const npy_uint16 neg_one = (npy_uint16) -1, const_zero = (npy_uint16) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(npy_uint16) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(npy_uint16) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_uint16) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(npy_uint16) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_uint16) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        return _PyLong_FromByteArray(bytes, sizeof(npy_uint16),
                                     little, !is_unsigned);
#else
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(npy_uint16));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_int16(npy_int16 value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const npy_int16 neg_one = (npy_int16) -1, const_zero = (npy_int16) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(npy_int16) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(npy_int16) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_int16) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(npy_int16) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_int16) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        return _PyLong_FromByteArray(bytes, sizeof(npy_int16),
                                     little, !is_unsigned);
#else
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(npy_int16));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_int8(npy_int8 value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const npy_int8 neg_one = (npy_int8) -1, const_zero = (npy_int8) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(npy_int8) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(npy_int8) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_int8) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(npy_int8) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(npy_int8) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        return _PyLong_FromByteArray(bytes, sizeof(npy_int8),
                                     little, !is_unsigned);
#else
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(npy_int8));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_Py_intptr_t(Py_intptr_t value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const Py_intptr_t neg_one = (Py_intptr_t) -1, const_zero = (Py_intptr_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(Py_intptr_t) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(Py_intptr_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(Py_intptr_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(Py_intptr_t) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(Py_intptr_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        return _PyLong_FromByteArray(bytes, sizeof(Py_intptr_t),
                                     little, !is_unsigned);
#else
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(Py_intptr_t));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* CIntFromPy */
  static CYTHON_INLINE Py_intptr_t __Pyx_PyInt_As_Py_intptr_t(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const Py_intptr_t neg_one = (Py_intptr_t) -1, const_zero = (Py_intptr_t) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(Py_intptr_t) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(Py_intptr_t, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (Py_intptr_t) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(Py_intptr_t, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(Py_intptr_t) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(Py_intptr_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(Py_intptr_t) >= 2 * PyLong_SHIFT)) {
                                return (Py_intptr_t) (((((Py_intptr_t)digits[1]) << PyLong_SHIFT) | (Py_intptr_t)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(Py_intptr_t) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(Py_intptr_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(Py_intptr_t) >= 3 * PyLong_SHIFT)) {
                                return (Py_intptr_t) (((((((Py_intptr_t)digits[2]) << PyLong_SHIFT) | (Py_intptr_t)digits[1]) << PyLong_SHIFT) | (Py_intptr_t)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(Py_intptr_t) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(Py_intptr_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(Py_intptr_t) >= 4 * PyLong_SHIFT)) {
                                return (Py_intptr_t) (((((((((Py_intptr_t)digits[3]) << PyLong_SHIFT) | (Py_intptr_t)digits[2]) << PyLong_SHIFT) | (Py_intptr_t)digits[1]) << PyLong_SHIFT) | (Py_intptr_t)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (Py_intptr_t) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(Py_intptr_t) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(Py_intptr_t, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(Py_intptr_t) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(Py_intptr_t, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(Py_intptr_t, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(Py_intptr_t) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(Py_intptr_t, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(Py_intptr_t) - 1 > 2 * PyLong_SHIFT)) {
                                return (Py_intptr_t) (((Py_intptr_t)-1)*(((((Py_intptr_t)digits[1]) << PyLong_SHIFT) | (Py_intptr_t)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(Py_intptr_t) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(Py_intptr_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(Py_intptr_t) - 1 > 2 * PyLong_SHIFT)) {
                                return (Py_intptr_t) ((((((Py_intptr_t)digits[1]) << PyLong_SHIFT) | (Py_intptr_t)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(Py_intptr_t) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(Py_intptr_t, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(Py_intptr_t) - 1 > 3 * PyLong_SHIFT)) {
                                return (Py_intptr_t) (((Py_intptr_t)-1)*(((((((Py_intptr_t)digits[2]) << PyLong_SHIFT) | (Py_intptr_t)digits[1]) << PyLong_SHIFT) | (Py_intptr_t)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(Py_intptr_t) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(Py_intptr_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(Py_intptr_t) - 1 > 3 * PyLong_SHIFT)) {
                                return (Py_intptr_t) ((((((((Py_intptr_t)digits[2]) << PyLong_SHIFT) | (Py_intptr_t)digits[1]) << PyLong_SHIFT) | (Py_intptr_t)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(Py_intptr_t) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(Py_intptr_t, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(Py_intptr_t) - 1 > 4 * PyLong_SHIFT)) {
                                return (Py_intptr_t) (((Py_intptr_t)-1)*(((((((((Py_intptr_t)digits[3]) << PyLong_SHIFT) | (Py_intptr_t)digits[2]) << PyLong_SHIFT) | (Py_intptr_t)digits[1]) << PyLong_SHIFT) | (Py_intptr_t)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(Py_intptr_t) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(Py_intptr_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(Py_intptr_t) - 1 > 4 * PyLong_SHIFT)) {
                                return (Py_intptr_t) ((((((((((Py_intptr_t)digits[3]) << PyLong_SHIFT) | (Py_intptr_t)digits[2]) << PyLong_SHIFT) | (Py_intptr_t)digits[1]) << PyLong_SHIFT) | (Py_intptr_t)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(Py_intptr_t) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(Py_intptr_t, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(Py_intptr_t) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(Py_intptr_t, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            Py_intptr_t val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (Py_intptr_t) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (Py_intptr_t) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (Py_intptr_t) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (Py_intptr_t) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (Py_intptr_t) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(Py_intptr_t) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((Py_intptr_t) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(Py_intptr_t) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((Py_intptr_t) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((Py_intptr_t) 1) << (sizeof(Py_intptr_t) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (Py_intptr_t) -1;
        }
    } else {
        Py_intptr_t val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (Py_intptr_t) -1;
        val = __Pyx_PyInt_As_Py_intptr_t(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to Py_intptr_t");
    return (Py_intptr_t) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to Py_intptr_t");
    return (Py_intptr_t) -1;
}

/* CIntToPy */
  static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const long neg_one = (long) -1, const_zero = (long) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
#if !CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030d0000
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
#else
        PyObject *from_bytes, *result = NULL;
        PyObject *py_bytes = NULL, *arg_tuple = NULL, *kwds = NULL, *order_str = NULL;
        from_bytes = PyObject_GetAttrString((PyObject*)&PyLong_Type, "from_bytes");
        if (!from_bytes) return NULL;
        py_bytes = PyBytes_FromStringAndSize((char*)bytes, sizeof(long));
        if (!py_bytes) goto limited_bad;
        order_str = PyUnicode_FromString(little ? "little" : "big");
        if (!order_str) goto limited_bad;
        arg_tuple = PyTuple_Pack(2, py_bytes, order_str);
        if (!arg_tuple) goto limited_bad;
        if (!is_unsigned) {
            kwds = PyDict_New();
            if (!kwds) goto limited_bad;
            if (PyDict_SetItemString(kwds, "signed", __Pyx_NewRef(Py_True))) goto limited_bad;
        }
        result = PyObject_Call(from_bytes, arg_tuple, kwds);
        limited_bad:
        Py_XDECREF(kwds);
        Py_XDECREF(arg_tuple);
        Py_XDECREF(order_str);
        Py_XDECREF(py_bytes);
        Py_XDECREF(from_bytes);
        return result;
#endif
    }
}

/* ImportNumPyArray */
  static PyObject* __Pyx__ImportNumPyArray(void) {
    PyObject *numpy_module, *ndarray_object = NULL;
    numpy_module = __Pyx_Import(__pyx_n_s_numpy, NULL, 0);
    if (likely(numpy_module)) {
        ndarray_object = PyObject_GetAttrString(numpy_module, "ndarray");
        Py_DECREF(numpy_module);
    }
    if (unlikely(!ndarray_object)) {
        PyErr_Clear();
    }
    if (unlikely(!ndarray_object || !PyObject_TypeCheck(ndarray_object, &PyType_Type))) {
        Py_XDECREF(ndarray_object);
        Py_INCREF(Py_None);
        ndarray_object = Py_None;
    }
    return ndarray_object;
}
static CYTHON_INLINE PyObject* __Pyx_ImportNumPyArrayTypeIfAvailable(void) {
    if (unlikely(!__pyx_numpy_ndarray)) {
        __pyx_numpy_ndarray = __Pyx__ImportNumPyArray();
    }
    Py_INCREF(__pyx_numpy_ndarray);
    return __pyx_numpy_ndarray;
}

/* CIntFromPy */
  static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const int neg_one = (int) -1, const_zero = (int) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(int) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 2 * PyLong_SHIFT)) {
                                return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 3 * PyLong_SHIFT)) {
                                return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) >= 4 * PyLong_SHIFT)) {
                                return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(int) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(int) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(int, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(int) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(int) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                                return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(int) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(int) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                                return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(int) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                                return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(int) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(int) - 1 > 4 * PyLong_SHIFT)) {
                                return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(int) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(int) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (int) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (int) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (int) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (int) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (int) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(int) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((int) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(int) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((int) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((int) 1) << (sizeof(int) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntFromPy */
  static CYTHON_INLINE char __Pyx_PyInt_As_char(PyObject *x) {
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wconversion"
#endif
    const char neg_one = (char) -1, const_zero = (char) 0;
#ifdef __Pyx_HAS_GCC_DIAGNOSTIC
#pragma GCC diagnostic pop
#endif
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if ((sizeof(char) < sizeof(long))) {
            __PYX_VERIFY_RETURN_INT(char, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (char) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            if (unlikely(__Pyx_PyLong_IsNeg(x))) {
                goto raise_neg_overflow;
            } else if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(char, __Pyx_compact_upylong, __Pyx_PyLong_CompactValueUnsigned(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_DigitCount(x)) {
                    case 2:
                        if ((8 * sizeof(char) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(char) >= 2 * PyLong_SHIFT)) {
                                return (char) (((((char)digits[1]) << PyLong_SHIFT) | (char)digits[0]));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(char) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(char) >= 3 * PyLong_SHIFT)) {
                                return (char) (((((((char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0]));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(char) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(char) >= 4 * PyLong_SHIFT)) {
                                return (char) (((((((((char)digits[3]) << PyLong_SHIFT) | (char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0]));
                            }
                        }
                        break;
                }
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030C00A7
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (char) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if ((sizeof(char) <= sizeof(unsigned long))) {
                __PYX_VERIFY_RETURN_INT_EXC(char, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(char) <= sizeof(unsigned PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(char, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            if (__Pyx_PyLong_IsCompact(x)) {
                __PYX_VERIFY_RETURN_INT(char, __Pyx_compact_pylong, __Pyx_PyLong_CompactValue(x))
            } else {
                const digit* digits = __Pyx_PyLong_Digits(x);
                assert(__Pyx_PyLong_DigitCount(x) > 1);
                switch (__Pyx_PyLong_SignedDigitCount(x)) {
                    case -2:
                        if ((8 * sizeof(char) - 1 > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(char, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(char) - 1 > 2 * PyLong_SHIFT)) {
                                return (char) (((char)-1)*(((((char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                            }
                        }
                        break;
                    case 2:
                        if ((8 * sizeof(char) > 1 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 2 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(char) - 1 > 2 * PyLong_SHIFT)) {
                                return (char) ((((((char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                            }
                        }
                        break;
                    case -3:
                        if ((8 * sizeof(char) - 1 > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(char, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(char) - 1 > 3 * PyLong_SHIFT)) {
                                return (char) (((char)-1)*(((((((char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                            }
                        }
                        break;
                    case 3:
                        if ((8 * sizeof(char) > 2 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 3 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(char) - 1 > 3 * PyLong_SHIFT)) {
                                return (char) ((((((((char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                            }
                        }
                        break;
                    case -4:
                        if ((8 * sizeof(char) - 1 > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(char, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(char) - 1 > 4 * PyLong_SHIFT)) {
                                return (char) (((char)-1)*(((((((((char)digits[3]) << PyLong_SHIFT) | (char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                            }
                        }
                        break;
                    case 4:
                        if ((8 * sizeof(char) > 3 * PyLong_SHIFT)) {
                            if ((8 * sizeof(unsigned long) > 4 * PyLong_SHIFT)) {
                                __PYX_VERIFY_RETURN_INT(char, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                            } else if ((8 * sizeof(char) - 1 > 4 * PyLong_SHIFT)) {
                                return (char) ((((((((((char)digits[3]) << PyLong_SHIFT) | (char)digits[2]) << PyLong_SHIFT) | (char)digits[1]) << PyLong_SHIFT) | (char)digits[0])));
                            }
                        }
                        break;
                }
            }
#endif
            if ((sizeof(char) <= sizeof(long))) {
                __PYX_VERIFY_RETURN_INT_EXC(char, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if ((sizeof(char) <= sizeof(PY_LONG_LONG))) {
                __PYX_VERIFY_RETURN_INT_EXC(char, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
            char val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
#if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
#endif
            if (likely(v)) {
                int ret = -1;
#if PY_VERSION_HEX < 0x030d0000 && !(CYTHON_COMPILING_IN_PYPY || CYTHON_COMPILING_IN_LIMITED_API) || defined(_PyLong_AsByteArray)
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                ret = _PyLong_AsByteArray((PyLongObject *)v,
                                           bytes, sizeof(val),
                                           is_little, !is_unsigned);
#else
                PyObject *stepval = NULL, *mask = NULL, *shift = NULL;
                int bits, remaining_bits, is_negative = 0;
                long idigit;
                int chunk_size = (sizeof(long) < 8) ? 30 : 62;
                if (unlikely(!PyLong_CheckExact(v))) {
                    PyObject *tmp = v;
                    v = PyNumber_Long(v);
                    assert(PyLong_CheckExact(v));
                    Py_DECREF(tmp);
                    if (unlikely(!v)) return (char) -1;
                }
#if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                if (Py_SIZE(x) == 0)
                    return (char) 0;
                is_negative = Py_SIZE(x) < 0;
#else
                {
                    int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                    if (unlikely(result < 0))
                        return (char) -1;
                    is_negative = result == 1;
                }
#endif
                if (is_unsigned && unlikely(is_negative)) {
                    goto raise_neg_overflow;
                } else if (is_negative) {
                    stepval = PyNumber_Invert(v);
                    if (unlikely(!stepval))
                        return (char) -1;
                } else {
                    stepval = __Pyx_NewRef(v);
                }
                val = (char) 0;
                mask = PyLong_FromLong((1L << chunk_size) - 1); if (unlikely(!mask)) goto done;
                shift = PyLong_FromLong(chunk_size); if (unlikely(!shift)) goto done;
                for (bits = 0; bits < (int) sizeof(char) * 8 - chunk_size; bits += chunk_size) {
                    PyObject *tmp, *digit;
                    digit = PyNumber_And(stepval, mask);
                    if (unlikely(!digit)) goto done;
                    idigit = PyLong_AsLong(digit);
                    Py_DECREF(digit);
                    if (unlikely(idigit < 0)) goto done;
                    tmp = PyNumber_Rshift(stepval, shift);
                    if (unlikely(!tmp)) goto done;
                    Py_DECREF(stepval); stepval = tmp;
                    val |= ((char) idigit) << bits;
                    #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
                    if (Py_SIZE(stepval) == 0)
                        goto unpacking_done;
                    #endif
                }
                idigit = PyLong_AsLong(stepval);
                if (unlikely(idigit < 0)) goto done;
                remaining_bits = ((int) sizeof(char) * 8) - bits - (is_unsigned ? 0 : 1);
                if (unlikely(idigit >= (1L << remaining_bits)))
                    goto raise_overflow;
                val |= ((char) idigit) << bits;
            #if CYTHON_COMPILING_IN_LIMITED_API && PY_VERSION_HEX < 0x030B0000
            unpacking_done:
            #endif
                if (!is_unsigned) {
                    if (unlikely(val & (((char) 1) << (sizeof(char) * 8 - 1))))
                        goto raise_overflow;
                    if (is_negative)
                        val = ~val;
                }
                ret = 0;
            done:
                Py_XDECREF(shift);
                Py_XDECREF(mask);
                Py_XDECREF(stepval);
#endif
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
            return (char) -1;
        }
    } else {
        char val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (char) -1;
        val = __Pyx_PyInt_As_char(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to char");
    return (char) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to char");
    return (char) -1;
}

/* FormatTypeName */
  #if CYTHON_COMPILING_IN_LIMITED_API
static __Pyx_TypeName
__Pyx_PyType_GetName(PyTypeObject* tp)
{
    PyObject *name = __Pyx_PyObject_GetAttrStr((PyObject *)tp,
                                               __pyx_n_s_name_2);
    if (unlikely(name == NULL) || unlikely(!PyUnicode_Check(name))) {
        PyErr_Clear();
        Py_XDECREF(name);
        name = __Pyx_NewRef(__pyx_n_s__490);
    }
    return name;
}
#endif

/* CheckBinaryVersion */
  static unsigned long __Pyx_get_runtime_version(void) {
#if __PYX_LIMITED_VERSION_HEX >= 0x030B00A4
    return Py_Version & ~0xFFUL;
#else
    const char* rt_version = Py_GetVersion();
    unsigned long version = 0;
    unsigned long factor = 0x01000000UL;
    unsigned int digit = 0;
    int i = 0;
    while (factor) {
        while ('0' <= rt_version[i] && rt_version[i] <= '9') {
            digit = digit * 10 + (unsigned int) (rt_version[i] - '0');
            ++i;
        }
        version += factor * digit;
        if (rt_version[i] != '.')
            break;
        digit = 0;
        factor >>= 8;
        ++i;
    }
    return version;
#endif
}
static int __Pyx_check_binary_version(unsigned long ct_version, unsigned long rt_version, int allow_newer) {
    const unsigned long MAJOR_MINOR = 0xFFFF0000UL;
    if ((rt_version & MAJOR_MINOR) == (ct_version & MAJOR_MINOR))
        return 0;
    if (likely(allow_newer && (rt_version & MAJOR_MINOR) > (ct_version & MAJOR_MINOR)))
        return 1;
    {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compile time Python version %d.%d "
                      "of module '%.100s' "
                      "%s "
                      "runtime version %d.%d",
                       (int) (ct_version >> 24), (int) ((ct_version >> 16) & 0xFF),
                       __Pyx_MODULE_NAME,
                       (allow_newer) ? "was newer than" : "does not match",
                       (int) (rt_version >> 24), (int) ((rt_version >> 16) & 0xFF)
       );
        return PyErr_WarnEx(NULL, message, 1);
    }
}

/* VoidPtrImport */
  #ifndef __PYX_HAVE_RT_ImportVoidPtr_3_0_8
#define __PYX_HAVE_RT_ImportVoidPtr_3_0_8
static int __Pyx_ImportVoidPtr_3_0_8(PyObject *module, const char *name, void **p, const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    d = PyObject_GetAttrString(module, (char *)"__pyx_capi__");
    if (!d)
        goto bad;
    cobj = PyDict_GetItemString(d, name);
    if (!cobj) {
        PyErr_Format(PyExc_ImportError,
            "%.200s does not export expected C variable %.200s",
                PyModule_GetName(module), name);
        goto bad;
    }
    if (!PyCapsule_IsValid(cobj, sig)) {
        PyErr_Format(PyExc_TypeError,
            "C variable %.200s.%.200s has wrong signature (expected %.500s, got %.500s)",
             PyModule_GetName(module), name, sig, PyCapsule_GetName(cobj));
        goto bad;
    }
    *p = PyCapsule_GetPointer(cobj, sig);
    if (!(*p))
        goto bad;
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(d);
    return -1;
}
#endif

/* FunctionImport */
  #ifndef __PYX_HAVE_RT_ImportFunction_3_0_8
#define __PYX_HAVE_RT_ImportFunction_3_0_8
static int __Pyx_ImportFunction_3_0_8(PyObject *module, const char *funcname, void (**f)(void), const char *sig) {
    PyObject *d = 0;
    PyObject *cobj = 0;
    union {
        void (*fp)(void);
        void *p;
    } tmp;
    d = PyObject_GetAttrString(module, (char *)"__pyx_capi__");
    if (!d)
        goto bad;
    cobj = PyDict_GetItemString(d, funcname);
    if (!cobj) {
        PyErr_Format(PyExc_ImportError,
            "%.200s does not export expected C function %.200s",
                PyModule_GetName(module), funcname);
        goto bad;
    }
    if (!PyCapsule_IsValid(cobj, sig)) {
        PyErr_Format(PyExc_TypeError,
            "C function %.200s.%.200s has wrong signature (expected %.500s, got %.500s)",
             PyModule_GetName(module), funcname, sig, PyCapsule_GetName(cobj));
        goto bad;
    }
    tmp.p = PyCapsule_GetPointer(cobj, sig);
    *f = tmp.fp;
    if (!(*f))
        goto bad;
    Py_DECREF(d);
    return 0;
bad:
    Py_XDECREF(d);
    return -1;
}
#endif

/* InitStrings */
  #if PY_MAJOR_VERSION >= 3
static int __Pyx_InitString(__Pyx_StringTabEntry t, PyObject **str) {
    if (t.is_unicode | t.is_str) {
        if (t.intern) {
            *str = PyUnicode_InternFromString(t.s);
        } else if (t.encoding) {
            *str = PyUnicode_Decode(t.s, t.n - 1, t.encoding, NULL);
        } else {
            *str = PyUnicode_FromStringAndSize(t.s, t.n - 1);
        }
    } else {
        *str = PyBytes_FromStringAndSize(t.s, t.n - 1);
    }
    if (!*str)
        return -1;
    if (PyObject_Hash(*str) == -1)
        return -1;
    return 0;
}
#endif
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION >= 3
        __Pyx_InitString(*t, t->p);
        #else
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        #endif
        ++t;
    }
    return 0;
}

#include <string.h>
static CYTHON_INLINE Py_ssize_t __Pyx_ssize_strlen(const char *s) {
    size_t len = strlen(s);
    if (unlikely(len > (size_t) PY_SSIZE_T_MAX)) {
        PyErr_SetString(PyExc_OverflowError, "byte string is too long");
        return -1;
    }
    return (Py_ssize_t) len;
}
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return __Pyx_PyUnicode_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE PyObject* __Pyx_PyByteArray_FromString(const char* c_str) {
    Py_ssize_t len = __Pyx_ssize_strlen(c_str);
    if (unlikely(len < 0)) return NULL;
    return PyByteArray_FromStringAndSize(c_str, len);
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY && !CYTHON_COMPILING_IN_LIMITED_API) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
    __Pyx_TypeName result_type_name = __Pyx_PyType_GetName(Py_TYPE(result));
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type " __Pyx_FMT_TYPENAME ").  "
                "The ability to return an instance of a strict subclass of int is deprecated, "
                "and may be removed in a future version of Python.",
                result_type_name)) {
            __Pyx_DECREF_TypeName(result_type_name);
            Py_DECREF(result);
            return NULL;
        }
        __Pyx_DECREF_TypeName(result_type_name);
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type " __Pyx_FMT_TYPENAME ")",
                 type_name, type_name, result_type_name);
    __Pyx_DECREF_TypeName(result_type_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(__Pyx_PyLong_IsCompact(b))) {
        return __Pyx_PyLong_CompactValue(b);
    } else {
      const digit* digits = __Pyx_PyLong_Digits(b);
      const Py_ssize_t size = __Pyx_PyLong_SignedDigitCount(b);
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE Py_hash_t __Pyx_PyIndex_AsHash_t(PyObject* o) {
  if (sizeof(Py_hash_t) == sizeof(Py_ssize_t)) {
    return (Py_hash_t) __Pyx_PyIndex_AsSsize_t(o);
#if PY_MAJOR_VERSION < 3
  } else if (likely(PyInt_CheckExact(o))) {
    return PyInt_AS_LONG(o);
#endif
  } else {
    Py_ssize_t ival;
    PyObject *x;
    x = PyNumber_Index(o);
    if (!x) return -1;
    ival = PyInt_AsLong(x);
    Py_DECREF(x);
    return ival;
  }
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


/* #### Code section: utility_code_pragmas_end ### */
#ifdef _MSC_VER
#pragma warning( pop )
#endif



/* #### Code section: end ### */
#endif /* Py_PYTHON_H */
